(self.webpackChunkhome_assistant_frontend=self.webpackChunkhome_assistant_frontend||[]).push([[2914],{92914:(e,s,r)=>{"use strict";r.r(s),r.d(s,{codeMirror:()=>c,codeMirrorCss:()=>d});var n=r(79074),t=r.n(n),a=r(49338),o=(r(22080),r(19393),r(47181));t().commands.save=e=>{(0,o.B)(e.getWrapperElement(),"editor-save")};const c=t(),d=a.Z}}]);
//# sourceMappingURL=chunk.6ce95f807b6994d28ccf.js.map