/*! For license information please see onboarding.4e62ac17.js.LICENSE.txt */
(()=>{var e,t,r={27815:(e,t)=>{"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.shouldPolyfill=void 0,t.shouldPolyfill=function(){return"undefined"==typeof Intl||!("PluralRules"in Intl)||"one"===new Intl.PluralRules("en",{minimumFractionDigits:2}).select(1)}},72774:(e,t,r)=>{"use strict";r.d(t,{K:()=>n});var n=function(){function e(e){void 0===e&&(e={}),this.adapter=e}return Object.defineProperty(e,"cssClasses",{get:function(){return{}},enumerable:!0,configurable:!0}),Object.defineProperty(e,"strings",{get:function(){return{}},enumerable:!0,configurable:!0}),Object.defineProperty(e,"numbers",{get:function(){return{}},enumerable:!0,configurable:!0}),Object.defineProperty(e,"defaultAdapter",{get:function(){return{}},enumerable:!0,configurable:!0}),e.prototype.init=function(){},e.prototype.destroy=function(){},e}()},58014:(e,t,r)=>{"use strict";function n(e,t){if(e.closest)return e.closest(t);for(var r=e;r;){if(i(r,t))return r;r=r.parentElement}return null}function i(e,t){return(e.matches||e.webkitMatchesSelector||e.msMatchesSelector).call(e,t)}r.d(t,{oq:()=>n,wB:()=>i})},78220:(e,t,r)=>{"use strict";r.d(t,{q:()=>i.qN,H:()=>o});var n=r(15652),i=r(82612);class o extends n.oi{click(){if(this.mdcRoot)return this.mdcRoot.focus(),void this.mdcRoot.click();super.click()}createFoundation(){void 0!==this.mdcFoundation&&this.mdcFoundation.destroy(),this.mdcFoundationClass&&(this.mdcFoundation=new this.mdcFoundationClass(this.createAdapter()),this.mdcFoundation.init())}firstUpdated(){this.createFoundation()}}},82612:(e,t,r)=>{"use strict";r.d(t,{OE:()=>i,f6:()=>o,qN:()=>a,Mh:()=>d,WU:()=>u});var n=r(58014);const i=e=>e.nodeType===Node.ELEMENT_NODE;function o(e,t){for(const r of e.assignedNodes({flatten:!0}))if(i(r)){const e=r;if((0,n.wB)(e,t))return e}return null}function a(e){return{addClass:t=>{e.classList.add(t)},removeClass:t=>{e.classList.remove(t)},hasClass:t=>e.classList.contains(t)}}let s=!1;const l=()=>{},c={get passive(){return s=!0,!1}};document.addEventListener("x",l,c),document.removeEventListener("x",l);const d=(e=window.document)=>{let t=e.activeElement;const r=[];if(!t)return r;for(;t&&(r.push(t),t.shadowRoot);)t=t.shadowRoot.activeElement;return r},u=e=>{const t=d();if(!t.length)return!1;const r=t[t.length-1],n=new Event("check-if-focused",{bubbles:!0,composed:!0});let i=[];const o=e=>{i=e.composedPath()};return document.body.addEventListener("check-if-focused",o),r.dispatchEvent(n),document.body.removeEventListener("check-if-focused",o),-1!==i.indexOf(e)}},3071:(e,t,r)=>{"use strict";r.d(t,{X:()=>s});var n=r(85720),i=(r(70475),r(66702),r(98734)),o=r(15652),a=r(81471);class s extends o.oi{constructor(){super(...arguments),this.raised=!1,this.unelevated=!1,this.outlined=!1,this.dense=!1,this.disabled=!1,this.trailingIcon=!1,this.fullwidth=!1,this.icon="",this.label="",this.expandContent=!1,this.shouldRenderRipple=!1,this.rippleHandlers=new i.A((()=>(this.shouldRenderRipple=!0,this.ripple)))}renderOverlay(){return o.dy``}renderRipple(){const e=this.raised||this.unelevated;return this.shouldRenderRipple?o.dy`<mwc-ripple class="ripple" .primary="${!e}" .disabled="${this.disabled}"></mwc-ripple>`:""}createRenderRoot(){return this.attachShadow({mode:"open",delegatesFocus:!0})}focus(){const e=this.buttonElement;e&&(this.rippleHandlers.startFocus(),e.focus())}blur(){const e=this.buttonElement;e&&(this.rippleHandlers.endFocus(),e.blur())}getRenderClasses(){return(0,a.$)({"mdc-button--raised":this.raised,"mdc-button--unelevated":this.unelevated,"mdc-button--outlined":this.outlined,"mdc-button--dense":this.dense})}render(){return o.dy`
      <button
          id="button"
          class="mdc-button ${this.getRenderClasses()}"
          ?disabled="${this.disabled}"
          aria-label="${this.label||this.icon}"
          @focus="${this.handleRippleFocus}"
          @blur="${this.handleRippleBlur}"
          @mousedown="${this.handleRippleActivate}"
          @mouseenter="${this.handleRippleMouseEnter}"
          @mouseleave="${this.handleRippleMouseLeave}"
          @touchstart="${this.handleRippleActivate}"
          @touchend="${this.handleRippleDeactivate}"
          @touchcancel="${this.handleRippleDeactivate}">
        ${this.renderOverlay()}
        ${this.renderRipple()}
        <span class="leading-icon">
          <slot name="icon">
            ${this.icon&&!this.trailingIcon?this.renderIcon():""}
          </slot>
        </span>
        <span class="mdc-button__label">${this.label}</span>
        <span class="slot-container ${(0,a.$)({flex:this.expandContent})}">
          <slot></slot>
        </span>
        <span class="trailing-icon">
          <slot name="trailingIcon">
            ${this.icon&&this.trailingIcon?this.renderIcon():""}
          </slot>
        </span>
      </button>`}renderIcon(){return o.dy`
    <mwc-icon class="mdc-button__icon">
      ${this.icon}
    </mwc-icon>`}handleRippleActivate(e){const t=()=>{window.removeEventListener("mouseup",t),this.handleRippleDeactivate()};window.addEventListener("mouseup",t),this.rippleHandlers.startPress(e)}handleRippleDeactivate(){this.rippleHandlers.endPress()}handleRippleMouseEnter(){this.rippleHandlers.startHover()}handleRippleMouseLeave(){this.rippleHandlers.endHover()}handleRippleFocus(){this.rippleHandlers.startFocus()}handleRippleBlur(){this.rippleHandlers.endFocus()}}(0,n.gn)([(0,o.Cb)({type:Boolean,reflect:!0})],s.prototype,"raised",void 0),(0,n.gn)([(0,o.Cb)({type:Boolean,reflect:!0})],s.prototype,"unelevated",void 0),(0,n.gn)([(0,o.Cb)({type:Boolean,reflect:!0})],s.prototype,"outlined",void 0),(0,n.gn)([(0,o.Cb)({type:Boolean})],s.prototype,"dense",void 0),(0,n.gn)([(0,o.Cb)({type:Boolean,reflect:!0})],s.prototype,"disabled",void 0),(0,n.gn)([(0,o.Cb)({type:Boolean,attribute:"trailingicon"})],s.prototype,"trailingIcon",void 0),(0,n.gn)([(0,o.Cb)({type:Boolean,reflect:!0})],s.prototype,"fullwidth",void 0),(0,n.gn)([(0,o.Cb)({type:String})],s.prototype,"icon",void 0),(0,n.gn)([(0,o.Cb)({type:String})],s.prototype,"label",void 0),(0,n.gn)([(0,o.Cb)({type:Boolean})],s.prototype,"expandContent",void 0),(0,n.gn)([(0,o.IO)("#button")],s.prototype,"buttonElement",void 0),(0,n.gn)([(0,o.GC)("mwc-ripple")],s.prototype,"ripple",void 0),(0,n.gn)([(0,o.sz)()],s.prototype,"shouldRenderRipple",void 0),(0,n.gn)([(0,o.hO)({passive:!0})],s.prototype,"handleRippleActivate",null)},53918:(e,t,r)=>{"use strict";var n=r(85720),i=r(15652),o=r(3071),a=r(97591);let s=class extends o.X{};s.styles=a.o,s=(0,n.gn)([(0,i.Mo)("mwc-button")],s)},85720:(e,t,r)=>{"use strict";r.d(t,{gn:()=>n});function n(e,t,r,n){var i,o=arguments.length,a=o<3?t:null===n?n=Object.getOwnPropertyDescriptor(t,r):n;if("object"==typeof Reflect&&"function"==typeof Reflect.decorate)a=Reflect.decorate(e,t,r,n);else for(var s=e.length-1;s>=0;s--)(i=e[s])&&(a=(o<3?i(a):o>3?i(t,r,a):i(t,r))||a);return o>3&&a&&Object.defineProperty(t,r,a),a}Object.create;Object.create},97591:(e,t,r)=>{"use strict";r.d(t,{o:()=>n});const n=r(15652).iv`.mdc-touch-target-wrapper{display:inline}.mdc-elevation-overlay{position:absolute;border-radius:inherit;pointer-events:none;opacity:0;opacity:var(--mdc-elevation-overlay-opacity, 0);transition:opacity 280ms cubic-bezier(0.4, 0, 0.2, 1);background-color:#fff;background-color:var(--mdc-elevation-overlay-color, #fff)}.mdc-button{-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased;font-family:Roboto, sans-serif;font-family:var(--mdc-typography-button-font-family, var(--mdc-typography-font-family, Roboto, sans-serif));font-size:0.875rem;font-size:var(--mdc-typography-button-font-size, 0.875rem);line-height:2.25rem;line-height:var(--mdc-typography-button-line-height, 2.25rem);font-weight:500;font-weight:var(--mdc-typography-button-font-weight, 500);letter-spacing:0.0892857143em;letter-spacing:var(--mdc-typography-button-letter-spacing, 0.0892857143em);text-decoration:none;text-decoration:var(--mdc-typography-button-text-decoration, none);text-transform:uppercase;text-transform:var(--mdc-typography-button-text-transform, uppercase);padding:0 8px 0 8px;position:relative;display:inline-flex;align-items:center;justify-content:center;box-sizing:border-box;min-width:64px;border:none;outline:none;line-height:inherit;user-select:none;-webkit-appearance:none;overflow:visible;vertical-align:middle;border-radius:4px;border-radius:var(--mdc-shape-small, 4px);height:36px}.mdc-button .mdc-elevation-overlay{width:100%;height:100%;top:0;left:0}.mdc-button::-moz-focus-inner{padding:0;border:0}.mdc-button:active{outline:none}.mdc-button:hover{cursor:pointer}.mdc-button:disabled{cursor:default;pointer-events:none}.mdc-button .mdc-button__ripple{border-radius:4px;border-radius:var(--mdc-shape-small, 4px)}.mdc-button:not(:disabled){background-color:transparent}.mdc-button:disabled{background-color:transparent}.mdc-button .mdc-button__icon{margin-left:0;margin-right:8px;display:inline-block;width:18px;height:18px;font-size:18px;vertical-align:top}[dir=rtl] .mdc-button .mdc-button__icon,.mdc-button .mdc-button__icon[dir=rtl]{margin-left:8px;margin-right:0}.mdc-button .mdc-button__touch{position:absolute;top:50%;right:0;height:48px;left:0;transform:translateY(-50%)}.mdc-button:not(:disabled){color:#6200ee;color:var(--mdc-theme-primary, #6200ee)}.mdc-button:disabled{color:rgba(0, 0, 0, 0.38)}.mdc-button__label+.mdc-button__icon{margin-left:8px;margin-right:0}[dir=rtl] .mdc-button__label+.mdc-button__icon,.mdc-button__label+.mdc-button__icon[dir=rtl]{margin-left:0;margin-right:8px}svg.mdc-button__icon{fill:currentColor}.mdc-button--raised .mdc-button__icon,.mdc-button--unelevated .mdc-button__icon,.mdc-button--outlined .mdc-button__icon{margin-left:-4px;margin-right:8px}[dir=rtl] .mdc-button--raised .mdc-button__icon,.mdc-button--raised .mdc-button__icon[dir=rtl],[dir=rtl] .mdc-button--unelevated .mdc-button__icon,.mdc-button--unelevated .mdc-button__icon[dir=rtl],[dir=rtl] .mdc-button--outlined .mdc-button__icon,.mdc-button--outlined .mdc-button__icon[dir=rtl]{margin-left:8px;margin-right:-4px}.mdc-button--raised .mdc-button__label+.mdc-button__icon,.mdc-button--unelevated .mdc-button__label+.mdc-button__icon,.mdc-button--outlined .mdc-button__label+.mdc-button__icon{margin-left:8px;margin-right:-4px}[dir=rtl] .mdc-button--raised .mdc-button__label+.mdc-button__icon,.mdc-button--raised .mdc-button__label+.mdc-button__icon[dir=rtl],[dir=rtl] .mdc-button--unelevated .mdc-button__label+.mdc-button__icon,.mdc-button--unelevated .mdc-button__label+.mdc-button__icon[dir=rtl],[dir=rtl] .mdc-button--outlined .mdc-button__label+.mdc-button__icon,.mdc-button--outlined .mdc-button__label+.mdc-button__icon[dir=rtl]{margin-left:-4px;margin-right:8px}.mdc-button--raised,.mdc-button--unelevated{padding:0 16px 0 16px}.mdc-button--raised:not(:disabled),.mdc-button--unelevated:not(:disabled){background-color:#6200ee;background-color:var(--mdc-theme-primary, #6200ee)}.mdc-button--raised:not(:disabled),.mdc-button--unelevated:not(:disabled){color:#fff;color:var(--mdc-theme-on-primary, #fff)}.mdc-button--raised:disabled,.mdc-button--unelevated:disabled{background-color:rgba(0, 0, 0, 0.12)}.mdc-button--raised:disabled,.mdc-button--unelevated:disabled{color:rgba(0, 0, 0, 0.38)}.mdc-button--raised{box-shadow:0px 3px 1px -2px rgba(0, 0, 0, 0.2),0px 2px 2px 0px rgba(0, 0, 0, 0.14),0px 1px 5px 0px rgba(0,0,0,.12);transition:box-shadow 280ms cubic-bezier(0.4, 0, 0.2, 1)}.mdc-button--raised:hover,.mdc-button--raised:focus{box-shadow:0px 2px 4px -1px rgba(0, 0, 0, 0.2),0px 4px 5px 0px rgba(0, 0, 0, 0.14),0px 1px 10px 0px rgba(0,0,0,.12)}.mdc-button--raised:active{box-shadow:0px 5px 5px -3px rgba(0, 0, 0, 0.2),0px 8px 10px 1px rgba(0, 0, 0, 0.14),0px 3px 14px 2px rgba(0,0,0,.12)}.mdc-button--raised:disabled{box-shadow:0px 0px 0px 0px rgba(0, 0, 0, 0.2),0px 0px 0px 0px rgba(0, 0, 0, 0.14),0px 0px 0px 0px rgba(0,0,0,.12)}.mdc-button--outlined{padding:0 15px 0 15px;border-width:1px;border-style:solid}.mdc-button--outlined .mdc-button__ripple{top:-1px;left:-1px;border:1px solid transparent}.mdc-button--outlined .mdc-button__touch{left:-1px;width:calc(100% + 2 * 1px)}.mdc-button--outlined:not(:disabled){border-color:rgba(0, 0, 0, 0.12)}.mdc-button--outlined:disabled{border-color:rgba(0, 0, 0, 0.12)}.mdc-button--touch{margin-top:6px;margin-bottom:6px}:host{display:inline-flex;outline:none;-webkit-tap-highlight-color:transparent;vertical-align:top}:host([fullwidth]){width:100%}:host([raised]),:host([unelevated]){--mdc-ripple-color: #fff;--mdc-ripple-focus-opacity: 0.24;--mdc-ripple-hover-opacity: 0.08;--mdc-ripple-press-opacity: 0.24}.trailing-icon ::slotted(*),.trailing-icon .mdc-button__icon,.leading-icon ::slotted(*),.leading-icon .mdc-button__icon{margin-left:0;margin-right:8px;display:inline-block;width:18px;height:18px;font-size:18px;vertical-align:top}[dir=rtl] .trailing-icon ::slotted(*),.trailing-icon ::slotted(*)[dir=rtl],[dir=rtl] .trailing-icon .mdc-button__icon,.trailing-icon .mdc-button__icon[dir=rtl],[dir=rtl] .leading-icon ::slotted(*),.leading-icon ::slotted(*)[dir=rtl],[dir=rtl] .leading-icon .mdc-button__icon,.leading-icon .mdc-button__icon[dir=rtl]{margin-left:8px;margin-right:0}.trailing-icon ::slotted(*),.trailing-icon .mdc-button__icon{margin-left:8px;margin-right:0}[dir=rtl] .trailing-icon ::slotted(*),.trailing-icon ::slotted(*)[dir=rtl],[dir=rtl] .trailing-icon .mdc-button__icon,.trailing-icon .mdc-button__icon[dir=rtl]{margin-left:0;margin-right:8px}.slot-container{display:inline-flex;align-items:center;justify-content:center}.slot-container.flex{flex:auto}.mdc-button{flex:auto;overflow:hidden;padding-left:8px;padding-left:var(--mdc-button-horizontal-padding, 8px);padding-right:8px;padding-right:var(--mdc-button-horizontal-padding, 8px)}.mdc-button--raised{box-shadow:0px 3px 1px -2px rgba(0, 0, 0, 0.2), 0px 2px 2px 0px rgba(0, 0, 0, 0.14), 0px 1px 5px 0px rgba(0, 0, 0, 0.12);box-shadow:var(--mdc-button-raised-box-shadow, 0px 3px 1px -2px rgba(0, 0, 0, 0.2), 0px 2px 2px 0px rgba(0, 0, 0, 0.14), 0px 1px 5px 0px rgba(0, 0, 0, 0.12))}.mdc-button--raised:focus{box-shadow:0px 2px 4px -1px rgba(0, 0, 0, 0.2), 0px 4px 5px 0px rgba(0, 0, 0, 0.14), 0px 1px 10px 0px rgba(0, 0, 0, 0.12);box-shadow:var(--mdc-button-raised-box-shadow-focus, var(--mdc-button-raised-box-shadow-hover, 0px 2px 4px -1px rgba(0, 0, 0, 0.2), 0px 4px 5px 0px rgba(0, 0, 0, 0.14), 0px 1px 10px 0px rgba(0, 0, 0, 0.12)))}.mdc-button--raised:hover{box-shadow:0px 2px 4px -1px rgba(0, 0, 0, 0.2), 0px 4px 5px 0px rgba(0, 0, 0, 0.14), 0px 1px 10px 0px rgba(0, 0, 0, 0.12);box-shadow:var(--mdc-button-raised-box-shadow-hover, 0px 2px 4px -1px rgba(0, 0, 0, 0.2), 0px 4px 5px 0px rgba(0, 0, 0, 0.14), 0px 1px 10px 0px rgba(0, 0, 0, 0.12))}.mdc-button--raised:active{box-shadow:0px 5px 5px -3px rgba(0, 0, 0, 0.2), 0px 8px 10px 1px rgba(0, 0, 0, 0.14), 0px 3px 14px 2px rgba(0, 0, 0, 0.12);box-shadow:var(--mdc-button-raised-box-shadow-active, 0px 5px 5px -3px rgba(0, 0, 0, 0.2), 0px 8px 10px 1px rgba(0, 0, 0, 0.14), 0px 3px 14px 2px rgba(0, 0, 0, 0.12))}.mdc-button--raised:disabled{box-shadow:0px 0px 0px 0px rgba(0, 0, 0, 0.2), 0px 0px 0px 0px rgba(0, 0, 0, 0.14), 0px 0px 0px 0px rgba(0, 0, 0, 0.12);box-shadow:var(--mdc-button-raised-box-shadow-disabled, 0px 0px 0px 0px rgba(0, 0, 0, 0.2), 0px 0px 0px 0px rgba(0, 0, 0, 0.14), 0px 0px 0px 0px rgba(0, 0, 0, 0.12))}.mdc-button--raised,.mdc-button--unelevated{padding-left:16px;padding-left:var(--mdc-button-horizontal-padding, 16px);padding-right:16px;padding-right:var(--mdc-button-horizontal-padding, 16px)}.mdc-button--outlined{border-width:1px;border-width:var(--mdc-button-outline-width, 1px);padding-left:calc(16px - 1px);padding-left:calc(var(--mdc-button-horizontal-padding, 16px) - var(--mdc-button-outline-width, 1px));padding-right:calc(16px - 1px);padding-right:calc(var(--mdc-button-horizontal-padding, 16px) - var(--mdc-button-outline-width, 1px))}.mdc-button--outlined:not(:disabled){border-color:rgba(0, 0, 0, 0.12);border-color:var(--mdc-button-outline-color, rgba(0, 0, 0, 0.12))}.mdc-button--outlined .ripple{top:calc(-1 * 1px);top:calc(-1 * var(--mdc-button-outline-width, 1px));left:calc(-1 * 1px);left:calc(-1 * var(--mdc-button-outline-width, 1px));right:initial;border-width:1px;border-width:var(--mdc-button-outline-width, 1px);border-style:solid;border-color:transparent}[dir=rtl] .mdc-button--outlined .ripple,.mdc-button--outlined .ripple[dir=rtl]{left:initial;right:calc(-1 * 1px);right:calc(-1 * var(--mdc-button-outline-width, 1px))}.mdc-button--dense{height:28px;margin-top:0;margin-bottom:0}.mdc-button--dense .mdc-button__touch{display:none}:host([disabled]){pointer-events:none}:host([disabled]) .mdc-button{color:rgba(0, 0, 0, 0.38);color:var(--mdc-button-disabled-ink-color, rgba(0, 0, 0, 0.38))}:host([disabled]) .mdc-button--raised,:host([disabled]) .mdc-button--unelevated{background-color:rgba(0, 0, 0, 0.12);background-color:var(--mdc-button-disabled-fill-color, rgba(0, 0, 0, 0.12))}:host([disabled]) .mdc-button--outlined{border-color:rgba(0, 0, 0, 0.12);border-color:var(--mdc-button-disabled-outline-color, rgba(0, 0, 0, 0.12))}`},82110:(e,t,r)=>{"use strict";r.d(t,{o:()=>n});const n=r(15652).iv`:host{font-family:var(--mdc-icon-font, "Material Icons");font-weight:normal;font-style:normal;font-size:var(--mdc-icon-size, 24px);line-height:1;letter-spacing:normal;text-transform:none;display:inline-block;white-space:nowrap;word-wrap:normal;direction:ltr;-webkit-font-smoothing:antialiased;text-rendering:optimizeLegibility;-moz-osx-font-smoothing:grayscale;font-feature-settings:"liga"}`},70475:(e,t,r)=>{"use strict";var n=r(90241),i=r(15652),o=r(82110);let a=class extends i.oi{render(){return i.dy`<slot></slot>`}};a.styles=o.o,a=(0,n.gn)([(0,i.Mo)("mwc-icon")],a)},90241:(e,t,r)=>{"use strict";r.d(t,{gn:()=>n});function n(e,t,r,n){var i,o=arguments.length,a=o<3?t:null===n?n=Object.getOwnPropertyDescriptor(t,r):n;if("object"==typeof Reflect&&"function"==typeof Reflect.decorate)a=Reflect.decorate(e,t,r,n);else for(var s=e.length-1;s>=0;s--)(i=e[s])&&(a=(o<3?i(a):o>3?i(t,r,a):i(t,r))||a);return o>3&&a&&Object.defineProperty(t,r,a),a}Object.create;Object.create},80927:(e,t,r)=>{"use strict";r.d(t,{L:()=>c});var n=r(2395),i=r(78220),o=r(9698),a=r(15652),s=r(81471),l=r(79865);class c extends i.H{constructor(){super(...arguments),this.primary=!1,this.accent=!1,this.unbounded=!1,this.disabled=!1,this.activated=!1,this.selected=!1,this.hovering=!1,this.bgFocused=!1,this.fgActivation=!1,this.fgDeactivation=!1,this.fgScale="",this.fgSize="",this.translateStart="",this.translateEnd="",this.leftPos="",this.topPos="",this.mdcFoundationClass=o.Z}get isActive(){return(this.parentElement||this).matches(":active")}createAdapter(){return{browserSupportsCssVars:()=>!0,isUnbounded:()=>this.unbounded,isSurfaceActive:()=>this.isActive,isSurfaceDisabled:()=>this.disabled,addClass:e=>{switch(e){case"mdc-ripple-upgraded--background-focused":this.bgFocused=!0;break;case"mdc-ripple-upgraded--foreground-activation":this.fgActivation=!0;break;case"mdc-ripple-upgraded--foreground-deactivation":this.fgDeactivation=!0}},removeClass:e=>{switch(e){case"mdc-ripple-upgraded--background-focused":this.bgFocused=!1;break;case"mdc-ripple-upgraded--foreground-activation":this.fgActivation=!1;break;case"mdc-ripple-upgraded--foreground-deactivation":this.fgDeactivation=!1}},containsEventTarget:()=>!0,registerInteractionHandler:()=>{},deregisterInteractionHandler:()=>{},registerDocumentInteractionHandler:()=>{},deregisterDocumentInteractionHandler:()=>{},registerResizeHandler:()=>{},deregisterResizeHandler:()=>{},updateCssVariable:(e,t)=>{switch(e){case"--mdc-ripple-fg-scale":this.fgScale=t;break;case"--mdc-ripple-fg-size":this.fgSize=t;break;case"--mdc-ripple-fg-translate-end":this.translateEnd=t;break;case"--mdc-ripple-fg-translate-start":this.translateStart=t;break;case"--mdc-ripple-left":this.leftPos=t;break;case"--mdc-ripple-top":this.topPos=t}},computeBoundingRect:()=>(this.parentElement||this).getBoundingClientRect(),getWindowPageOffset:()=>({x:window.pageXOffset,y:window.pageYOffset})}}startPress(e){this.waitForFoundation((()=>{this.mdcFoundation.activate(e)}))}endPress(){this.waitForFoundation((()=>{this.mdcFoundation.deactivate()}))}startFocus(){this.waitForFoundation((()=>{this.mdcFoundation.handleFocus()}))}endFocus(){this.waitForFoundation((()=>{this.mdcFoundation.handleBlur()}))}startHover(){this.hovering=!0}endHover(){this.hovering=!1}waitForFoundation(e){this.mdcFoundation?e():this.updateComplete.then(e)}render(){const e=this.activated&&(this.primary||!this.accent),t=this.selected&&(this.primary||!this.accent),r={"mdc-ripple-surface--accent":this.accent,"mdc-ripple-surface--primary--activated":e,"mdc-ripple-surface--accent--activated":this.accent&&this.activated,"mdc-ripple-surface--primary--selected":t,"mdc-ripple-surface--accent--selected":this.accent&&this.selected,"mdc-ripple-surface--disabled":this.disabled,"mdc-ripple-surface--hover":this.hovering,"mdc-ripple-surface--primary":this.primary,"mdc-ripple-surface--selected":this.selected,"mdc-ripple-upgraded--background-focused":this.bgFocused,"mdc-ripple-upgraded--foreground-activation":this.fgActivation,"mdc-ripple-upgraded--foreground-deactivation":this.fgDeactivation,"mdc-ripple-upgraded--unbounded":this.unbounded};return a.dy`
        <div class="mdc-ripple-surface mdc-ripple-upgraded ${(0,s.$)(r)}"
          style="${(0,l.V)({"--mdc-ripple-fg-scale":this.fgScale,"--mdc-ripple-fg-size":this.fgSize,"--mdc-ripple-fg-translate-end":this.translateEnd,"--mdc-ripple-fg-translate-start":this.translateStart,"--mdc-ripple-left":this.leftPos,"--mdc-ripple-top":this.topPos})}"></div>`}}(0,n.gn)([(0,a.IO)(".mdc-ripple-surface")],c.prototype,"mdcRoot",void 0),(0,n.gn)([(0,a.Cb)({type:Boolean})],c.prototype,"primary",void 0),(0,n.gn)([(0,a.Cb)({type:Boolean})],c.prototype,"accent",void 0),(0,n.gn)([(0,a.Cb)({type:Boolean})],c.prototype,"unbounded",void 0),(0,n.gn)([(0,a.Cb)({type:Boolean})],c.prototype,"disabled",void 0),(0,n.gn)([(0,a.Cb)({type:Boolean})],c.prototype,"activated",void 0),(0,n.gn)([(0,a.Cb)({type:Boolean})],c.prototype,"selected",void 0),(0,n.gn)([(0,a.sz)()],c.prototype,"hovering",void 0),(0,n.gn)([(0,a.sz)()],c.prototype,"bgFocused",void 0),(0,n.gn)([(0,a.sz)()],c.prototype,"fgActivation",void 0),(0,n.gn)([(0,a.sz)()],c.prototype,"fgDeactivation",void 0),(0,n.gn)([(0,a.sz)()],c.prototype,"fgScale",void 0),(0,n.gn)([(0,a.sz)()],c.prototype,"fgSize",void 0),(0,n.gn)([(0,a.sz)()],c.prototype,"translateStart",void 0),(0,n.gn)([(0,a.sz)()],c.prototype,"translateEnd",void 0),(0,n.gn)([(0,a.sz)()],c.prototype,"leftPos",void 0),(0,n.gn)([(0,a.sz)()],c.prototype,"topPos",void 0)},85032:(e,t,r)=>{"use strict";r.d(t,{o:()=>n});const n=r(15652).iv`.mdc-ripple-surface{--mdc-ripple-fg-size: 0;--mdc-ripple-left: 0;--mdc-ripple-top: 0;--mdc-ripple-fg-scale: 1;--mdc-ripple-fg-translate-end: 0;--mdc-ripple-fg-translate-start: 0;-webkit-tap-highlight-color:rgba(0,0,0,0);will-change:transform,opacity;position:relative;outline:none;overflow:hidden}.mdc-ripple-surface::before,.mdc-ripple-surface::after{position:absolute;border-radius:50%;opacity:0;pointer-events:none;content:""}.mdc-ripple-surface::before{transition:opacity 15ms linear,background-color 15ms linear;z-index:1;z-index:var(--mdc-ripple-z-index, 1)}.mdc-ripple-surface::after{z-index:0;z-index:var(--mdc-ripple-z-index, 0)}.mdc-ripple-surface.mdc-ripple-upgraded::before{transform:scale(var(--mdc-ripple-fg-scale, 1))}.mdc-ripple-surface.mdc-ripple-upgraded::after{top:0;left:0;transform:scale(0);transform-origin:center center}.mdc-ripple-surface.mdc-ripple-upgraded--unbounded::after{top:var(--mdc-ripple-top, 0);left:var(--mdc-ripple-left, 0)}.mdc-ripple-surface.mdc-ripple-upgraded--foreground-activation::after{animation:mdc-ripple-fg-radius-in 225ms forwards,mdc-ripple-fg-opacity-in 75ms forwards}.mdc-ripple-surface.mdc-ripple-upgraded--foreground-deactivation::after{animation:mdc-ripple-fg-opacity-out 150ms;transform:translate(var(--mdc-ripple-fg-translate-end, 0)) scale(var(--mdc-ripple-fg-scale, 1))}.mdc-ripple-surface::before,.mdc-ripple-surface::after{background-color:#000;background-color:var(--mdc-ripple-color, #000)}.mdc-ripple-surface:hover::before,.mdc-ripple-surface.mdc-ripple-surface--hover::before{opacity:0.04;opacity:var(--mdc-ripple-hover-opacity, 0.04)}.mdc-ripple-surface.mdc-ripple-upgraded--background-focused::before,.mdc-ripple-surface:not(.mdc-ripple-upgraded):focus::before{transition-duration:75ms;opacity:0.12;opacity:var(--mdc-ripple-focus-opacity, 0.12)}.mdc-ripple-surface:not(.mdc-ripple-upgraded)::after{transition:opacity 150ms linear}.mdc-ripple-surface:not(.mdc-ripple-upgraded):active::after{transition-duration:75ms;opacity:0.12;opacity:var(--mdc-ripple-press-opacity, 0.12)}.mdc-ripple-surface.mdc-ripple-upgraded{--mdc-ripple-fg-opacity: var(--mdc-ripple-press-opacity, 0.12)}.mdc-ripple-surface::before,.mdc-ripple-surface::after{top:calc(50% - 100%);left:calc(50% - 100%);width:200%;height:200%}.mdc-ripple-surface.mdc-ripple-upgraded::after{width:var(--mdc-ripple-fg-size, 100%);height:var(--mdc-ripple-fg-size, 100%)}.mdc-ripple-surface[data-mdc-ripple-is-unbounded],.mdc-ripple-upgraded--unbounded{overflow:visible}.mdc-ripple-surface[data-mdc-ripple-is-unbounded]::before,.mdc-ripple-surface[data-mdc-ripple-is-unbounded]::after,.mdc-ripple-upgraded--unbounded::before,.mdc-ripple-upgraded--unbounded::after{top:calc(50% - 50%);left:calc(50% - 50%);width:100%;height:100%}.mdc-ripple-surface[data-mdc-ripple-is-unbounded].mdc-ripple-upgraded::before,.mdc-ripple-surface[data-mdc-ripple-is-unbounded].mdc-ripple-upgraded::after,.mdc-ripple-upgraded--unbounded.mdc-ripple-upgraded::before,.mdc-ripple-upgraded--unbounded.mdc-ripple-upgraded::after{top:var(--mdc-ripple-top, calc(50% - 50%));left:var(--mdc-ripple-left, calc(50% - 50%));width:var(--mdc-ripple-fg-size, 100%);height:var(--mdc-ripple-fg-size, 100%)}.mdc-ripple-surface[data-mdc-ripple-is-unbounded].mdc-ripple-upgraded::after,.mdc-ripple-upgraded--unbounded.mdc-ripple-upgraded::after{width:var(--mdc-ripple-fg-size, 100%);height:var(--mdc-ripple-fg-size, 100%)}@keyframes mdc-ripple-fg-radius-in{from{animation-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transform:translate(var(--mdc-ripple-fg-translate-start, 0)) scale(1)}to{transform:translate(var(--mdc-ripple-fg-translate-end, 0)) scale(var(--mdc-ripple-fg-scale, 1))}}@keyframes mdc-ripple-fg-opacity-in{from{animation-timing-function:linear;opacity:0}to{opacity:var(--mdc-ripple-fg-opacity, 0)}}@keyframes mdc-ripple-fg-opacity-out{from{animation-timing-function:linear;opacity:var(--mdc-ripple-fg-opacity, 0)}to{opacity:0}}:host{position:absolute;top:0;left:0;width:100%;height:100%;pointer-events:none;display:block}:host .mdc-ripple-surface{position:absolute;top:0;left:0;width:100%;height:100%;pointer-events:none;will-change:unset}.mdc-ripple-surface--primary::before,.mdc-ripple-surface--primary::after{background-color:#6200ee;background-color:var(--mdc-ripple-color, var(--mdc-theme-primary, #6200ee))}.mdc-ripple-surface--primary:hover::before,.mdc-ripple-surface--primary.mdc-ripple-surface--hover::before{opacity:0.04;opacity:var(--mdc-ripple-hover-opacity, 0.04)}.mdc-ripple-surface--primary.mdc-ripple-upgraded--background-focused::before,.mdc-ripple-surface--primary:not(.mdc-ripple-upgraded):focus::before{transition-duration:75ms;opacity:0.12;opacity:var(--mdc-ripple-focus-opacity, 0.12)}.mdc-ripple-surface--primary:not(.mdc-ripple-upgraded)::after{transition:opacity 150ms linear}.mdc-ripple-surface--primary:not(.mdc-ripple-upgraded):active::after{transition-duration:75ms;opacity:0.12;opacity:var(--mdc-ripple-press-opacity, 0.12)}.mdc-ripple-surface--primary.mdc-ripple-upgraded{--mdc-ripple-fg-opacity: var(--mdc-ripple-press-opacity, 0.12)}.mdc-ripple-surface--primary--activated::before{opacity:0.12;opacity:var(--mdc-ripple-activated-opacity, 0.12)}.mdc-ripple-surface--primary--activated::before,.mdc-ripple-surface--primary--activated::after{background-color:#6200ee;background-color:var(--mdc-ripple-color, var(--mdc-theme-primary, #6200ee))}.mdc-ripple-surface--primary--activated:hover::before,.mdc-ripple-surface--primary--activated.mdc-ripple-surface--hover::before{opacity:0.16;opacity:var(--mdc-ripple-hover-opacity, 0.16)}.mdc-ripple-surface--primary--activated.mdc-ripple-upgraded--background-focused::before,.mdc-ripple-surface--primary--activated:not(.mdc-ripple-upgraded):focus::before{transition-duration:75ms;opacity:0.24;opacity:var(--mdc-ripple-focus-opacity, 0.24)}.mdc-ripple-surface--primary--activated:not(.mdc-ripple-upgraded)::after{transition:opacity 150ms linear}.mdc-ripple-surface--primary--activated:not(.mdc-ripple-upgraded):active::after{transition-duration:75ms;opacity:0.24;opacity:var(--mdc-ripple-press-opacity, 0.24)}.mdc-ripple-surface--primary--activated.mdc-ripple-upgraded{--mdc-ripple-fg-opacity: var(--mdc-ripple-press-opacity, 0.24)}.mdc-ripple-surface--primary--selected::before{opacity:0.08;opacity:var(--mdc-ripple-selected-opacity, 0.08)}.mdc-ripple-surface--primary--selected::before,.mdc-ripple-surface--primary--selected::after{background-color:#6200ee;background-color:var(--mdc-ripple-color, var(--mdc-theme-primary, #6200ee))}.mdc-ripple-surface--primary--selected:hover::before,.mdc-ripple-surface--primary--selected.mdc-ripple-surface--hover::before{opacity:0.12;opacity:var(--mdc-ripple-hover-opacity, 0.12)}.mdc-ripple-surface--primary--selected.mdc-ripple-upgraded--background-focused::before,.mdc-ripple-surface--primary--selected:not(.mdc-ripple-upgraded):focus::before{transition-duration:75ms;opacity:0.2;opacity:var(--mdc-ripple-focus-opacity, 0.2)}.mdc-ripple-surface--primary--selected:not(.mdc-ripple-upgraded)::after{transition:opacity 150ms linear}.mdc-ripple-surface--primary--selected:not(.mdc-ripple-upgraded):active::after{transition-duration:75ms;opacity:0.2;opacity:var(--mdc-ripple-press-opacity, 0.2)}.mdc-ripple-surface--primary--selected.mdc-ripple-upgraded{--mdc-ripple-fg-opacity: var(--mdc-ripple-press-opacity, 0.2)}.mdc-ripple-surface--accent::before,.mdc-ripple-surface--accent::after{background-color:#018786;background-color:var(--mdc-ripple-color, var(--mdc-theme-secondary, #018786))}.mdc-ripple-surface--accent:hover::before,.mdc-ripple-surface--accent.mdc-ripple-surface--hover::before{opacity:0.04;opacity:var(--mdc-ripple-hover-opacity, 0.04)}.mdc-ripple-surface--accent.mdc-ripple-upgraded--background-focused::before,.mdc-ripple-surface--accent:not(.mdc-ripple-upgraded):focus::before{transition-duration:75ms;opacity:0.12;opacity:var(--mdc-ripple-focus-opacity, 0.12)}.mdc-ripple-surface--accent:not(.mdc-ripple-upgraded)::after{transition:opacity 150ms linear}.mdc-ripple-surface--accent:not(.mdc-ripple-upgraded):active::after{transition-duration:75ms;opacity:0.12;opacity:var(--mdc-ripple-press-opacity, 0.12)}.mdc-ripple-surface--accent.mdc-ripple-upgraded{--mdc-ripple-fg-opacity: var(--mdc-ripple-press-opacity, 0.12)}.mdc-ripple-surface--accent--activated::before{opacity:0.12;opacity:var(--mdc-ripple-activated-opacity, 0.12)}.mdc-ripple-surface--accent--activated::before,.mdc-ripple-surface--accent--activated::after{background-color:#018786;background-color:var(--mdc-ripple-color, var(--mdc-theme-secondary, #018786))}.mdc-ripple-surface--accent--activated:hover::before,.mdc-ripple-surface--accent--activated.mdc-ripple-surface--hover::before{opacity:0.16;opacity:var(--mdc-ripple-hover-opacity, 0.16)}.mdc-ripple-surface--accent--activated.mdc-ripple-upgraded--background-focused::before,.mdc-ripple-surface--accent--activated:not(.mdc-ripple-upgraded):focus::before{transition-duration:75ms;opacity:0.24;opacity:var(--mdc-ripple-focus-opacity, 0.24)}.mdc-ripple-surface--accent--activated:not(.mdc-ripple-upgraded)::after{transition:opacity 150ms linear}.mdc-ripple-surface--accent--activated:not(.mdc-ripple-upgraded):active::after{transition-duration:75ms;opacity:0.24;opacity:var(--mdc-ripple-press-opacity, 0.24)}.mdc-ripple-surface--accent--activated.mdc-ripple-upgraded{--mdc-ripple-fg-opacity: var(--mdc-ripple-press-opacity, 0.24)}.mdc-ripple-surface--accent--selected::before{opacity:0.08;opacity:var(--mdc-ripple-selected-opacity, 0.08)}.mdc-ripple-surface--accent--selected::before,.mdc-ripple-surface--accent--selected::after{background-color:#018786;background-color:var(--mdc-ripple-color, var(--mdc-theme-secondary, #018786))}.mdc-ripple-surface--accent--selected:hover::before,.mdc-ripple-surface--accent--selected.mdc-ripple-surface--hover::before{opacity:0.12;opacity:var(--mdc-ripple-hover-opacity, 0.12)}.mdc-ripple-surface--accent--selected.mdc-ripple-upgraded--background-focused::before,.mdc-ripple-surface--accent--selected:not(.mdc-ripple-upgraded):focus::before{transition-duration:75ms;opacity:0.2;opacity:var(--mdc-ripple-focus-opacity, 0.2)}.mdc-ripple-surface--accent--selected:not(.mdc-ripple-upgraded)::after{transition:opacity 150ms linear}.mdc-ripple-surface--accent--selected:not(.mdc-ripple-upgraded):active::after{transition-duration:75ms;opacity:0.2;opacity:var(--mdc-ripple-press-opacity, 0.2)}.mdc-ripple-surface--accent--selected.mdc-ripple-upgraded{--mdc-ripple-fg-opacity: var(--mdc-ripple-press-opacity, 0.2)}.mdc-ripple-surface--disabled{opacity:0}`},66702:(e,t,r)=>{"use strict";var n=r(2395),i=r(15652),o=r(80927),a=r(85032);let s=class extends o.L{};s.styles=a.o,s=(0,n.gn)([(0,i.Mo)("mwc-ripple")],s)},2395:(e,t,r)=>{"use strict";r.d(t,{gn:()=>n});function n(e,t,r,n){var i,o=arguments.length,a=o<3?t:null===n?n=Object.getOwnPropertyDescriptor(t,r):n;if("object"==typeof Reflect&&"function"==typeof Reflect.decorate)a=Reflect.decorate(e,t,r,n);else for(var s=e.length-1;s>=0;s--)(i=e[s])&&(a=(o<3?i(a):o>3?i(t,r,a):i(t,r))||a);return o>3&&a&&Object.defineProperty(t,r,a),a}Object.create;Object.create},98734:(e,t,r)=>{"use strict";r.d(t,{A:()=>n});class n{constructor(e){this.startPress=t=>{e().then((e=>{e&&e.startPress(t)}))},this.endPress=()=>{e().then((e=>{e&&e.endPress()}))},this.startFocus=()=>{e().then((e=>{e&&e.startFocus()}))},this.endFocus=()=>{e().then((e=>{e&&e.endFocus()}))},this.startHover=()=>{e().then((e=>{e&&e.startHover()}))},this.endHover=()=>{e().then((e=>{e&&e.endHover()}))}}}},56071:(e,t,r)=>{"use strict";r.d(t,{UX:()=>n,j2:()=>i,KT:()=>o});var n={BG_FOCUSED:"mdc-ripple-upgraded--background-focused",FG_ACTIVATION:"mdc-ripple-upgraded--foreground-activation",FG_DEACTIVATION:"mdc-ripple-upgraded--foreground-deactivation",ROOT:"mdc-ripple-upgraded",UNBOUNDED:"mdc-ripple-upgraded--unbounded"},i={VAR_FG_SCALE:"--mdc-ripple-fg-scale",VAR_FG_SIZE:"--mdc-ripple-fg-size",VAR_FG_TRANSLATE_END:"--mdc-ripple-fg-translate-end",VAR_FG_TRANSLATE_START:"--mdc-ripple-fg-translate-start",VAR_LEFT:"--mdc-ripple-left",VAR_TOP:"--mdc-ripple-top"},o={DEACTIVATION_TIMEOUT_MS:225,FG_DEACTIVATION_MS:150,INITIAL_ORIGIN_SCALE:.6,PADDING:10,TAP_DELAY_MS:300}},9698:(e,t,r)=>{"use strict";r.d(t,{Z:()=>d});var n=r(87480),i=r(72774),o=r(56071),a=r(84445),s=["touchstart","pointerdown","mousedown","keydown"],l=["touchend","pointerup","mouseup","contextmenu"],c=[];const d=function(e){function t(r){var i=e.call(this,(0,n.pi)((0,n.pi)({},t.defaultAdapter),r))||this;return i.activationAnimationHasEnded_=!1,i.activationTimer_=0,i.fgDeactivationRemovalTimer_=0,i.fgScale_="0",i.frame_={width:0,height:0},i.initialSize_=0,i.layoutFrame_=0,i.maxRadius_=0,i.unboundedCoords_={left:0,top:0},i.activationState_=i.defaultActivationState_(),i.activationTimerCallback_=function(){i.activationAnimationHasEnded_=!0,i.runDeactivationUXLogicIfReady_()},i.activateHandler_=function(e){return i.activate_(e)},i.deactivateHandler_=function(){return i.deactivate_()},i.focusHandler_=function(){return i.handleFocus()},i.blurHandler_=function(){return i.handleBlur()},i.resizeHandler_=function(){return i.layout()},i}return(0,n.ZT)(t,e),Object.defineProperty(t,"cssClasses",{get:function(){return o.UX},enumerable:!0,configurable:!0}),Object.defineProperty(t,"strings",{get:function(){return o.j2},enumerable:!0,configurable:!0}),Object.defineProperty(t,"numbers",{get:function(){return o.KT},enumerable:!0,configurable:!0}),Object.defineProperty(t,"defaultAdapter",{get:function(){return{addClass:function(){},browserSupportsCssVars:function(){return!0},computeBoundingRect:function(){return{top:0,right:0,bottom:0,left:0,width:0,height:0}},containsEventTarget:function(){return!0},deregisterDocumentInteractionHandler:function(){},deregisterInteractionHandler:function(){},deregisterResizeHandler:function(){},getWindowPageOffset:function(){return{x:0,y:0}},isSurfaceActive:function(){return!0},isSurfaceDisabled:function(){return!0},isUnbounded:function(){return!0},registerDocumentInteractionHandler:function(){},registerInteractionHandler:function(){},registerResizeHandler:function(){},removeClass:function(){},updateCssVariable:function(){}}},enumerable:!0,configurable:!0}),t.prototype.init=function(){var e=this,r=this.supportsPressRipple_();if(this.registerRootHandlers_(r),r){var n=t.cssClasses,i=n.ROOT,o=n.UNBOUNDED;requestAnimationFrame((function(){e.adapter.addClass(i),e.adapter.isUnbounded()&&(e.adapter.addClass(o),e.layoutInternal_())}))}},t.prototype.destroy=function(){var e=this;if(this.supportsPressRipple_()){this.activationTimer_&&(clearTimeout(this.activationTimer_),this.activationTimer_=0,this.adapter.removeClass(t.cssClasses.FG_ACTIVATION)),this.fgDeactivationRemovalTimer_&&(clearTimeout(this.fgDeactivationRemovalTimer_),this.fgDeactivationRemovalTimer_=0,this.adapter.removeClass(t.cssClasses.FG_DEACTIVATION));var r=t.cssClasses,n=r.ROOT,i=r.UNBOUNDED;requestAnimationFrame((function(){e.adapter.removeClass(n),e.adapter.removeClass(i),e.removeCssVars_()}))}this.deregisterRootHandlers_(),this.deregisterDeactivationHandlers_()},t.prototype.activate=function(e){this.activate_(e)},t.prototype.deactivate=function(){this.deactivate_()},t.prototype.layout=function(){var e=this;this.layoutFrame_&&cancelAnimationFrame(this.layoutFrame_),this.layoutFrame_=requestAnimationFrame((function(){e.layoutInternal_(),e.layoutFrame_=0}))},t.prototype.setUnbounded=function(e){var r=t.cssClasses.UNBOUNDED;e?this.adapter.addClass(r):this.adapter.removeClass(r)},t.prototype.handleFocus=function(){var e=this;requestAnimationFrame((function(){return e.adapter.addClass(t.cssClasses.BG_FOCUSED)}))},t.prototype.handleBlur=function(){var e=this;requestAnimationFrame((function(){return e.adapter.removeClass(t.cssClasses.BG_FOCUSED)}))},t.prototype.supportsPressRipple_=function(){return this.adapter.browserSupportsCssVars()},t.prototype.defaultActivationState_=function(){return{activationEvent:void 0,hasDeactivationUXRun:!1,isActivated:!1,isProgrammatic:!1,wasActivatedByPointer:!1,wasElementMadeActive:!1}},t.prototype.registerRootHandlers_=function(e){var t=this;e&&(s.forEach((function(e){t.adapter.registerInteractionHandler(e,t.activateHandler_)})),this.adapter.isUnbounded()&&this.adapter.registerResizeHandler(this.resizeHandler_)),this.adapter.registerInteractionHandler("focus",this.focusHandler_),this.adapter.registerInteractionHandler("blur",this.blurHandler_)},t.prototype.registerDeactivationHandlers_=function(e){var t=this;"keydown"===e.type?this.adapter.registerInteractionHandler("keyup",this.deactivateHandler_):l.forEach((function(e){t.adapter.registerDocumentInteractionHandler(e,t.deactivateHandler_)}))},t.prototype.deregisterRootHandlers_=function(){var e=this;s.forEach((function(t){e.adapter.deregisterInteractionHandler(t,e.activateHandler_)})),this.adapter.deregisterInteractionHandler("focus",this.focusHandler_),this.adapter.deregisterInteractionHandler("blur",this.blurHandler_),this.adapter.isUnbounded()&&this.adapter.deregisterResizeHandler(this.resizeHandler_)},t.prototype.deregisterDeactivationHandlers_=function(){var e=this;this.adapter.deregisterInteractionHandler("keyup",this.deactivateHandler_),l.forEach((function(t){e.adapter.deregisterDocumentInteractionHandler(t,e.deactivateHandler_)}))},t.prototype.removeCssVars_=function(){var e=this,r=t.strings;Object.keys(r).forEach((function(t){0===t.indexOf("VAR_")&&e.adapter.updateCssVariable(r[t],null)}))},t.prototype.activate_=function(e){var t=this;if(!this.adapter.isSurfaceDisabled()){var r=this.activationState_;if(!r.isActivated){var n=this.previousActivationEvent_;if(!(n&&void 0!==e&&n.type!==e.type))r.isActivated=!0,r.isProgrammatic=void 0===e,r.activationEvent=e,r.wasActivatedByPointer=!r.isProgrammatic&&(void 0!==e&&("mousedown"===e.type||"touchstart"===e.type||"pointerdown"===e.type)),void 0!==e&&c.length>0&&c.some((function(e){return t.adapter.containsEventTarget(e)}))?this.resetActivationState_():(void 0!==e&&(c.push(e.target),this.registerDeactivationHandlers_(e)),r.wasElementMadeActive=this.checkElementMadeActive_(e),r.wasElementMadeActive&&this.animateActivation_(),requestAnimationFrame((function(){c=[],r.wasElementMadeActive||void 0===e||" "!==e.key&&32!==e.keyCode||(r.wasElementMadeActive=t.checkElementMadeActive_(e),r.wasElementMadeActive&&t.animateActivation_()),r.wasElementMadeActive||(t.activationState_=t.defaultActivationState_())})))}}},t.prototype.checkElementMadeActive_=function(e){return void 0===e||"keydown"!==e.type||this.adapter.isSurfaceActive()},t.prototype.animateActivation_=function(){var e=this,r=t.strings,n=r.VAR_FG_TRANSLATE_START,i=r.VAR_FG_TRANSLATE_END,o=t.cssClasses,a=o.FG_DEACTIVATION,s=o.FG_ACTIVATION,l=t.numbers.DEACTIVATION_TIMEOUT_MS;this.layoutInternal_();var c="",d="";if(!this.adapter.isUnbounded()){var u=this.getFgTranslationCoordinates_(),p=u.startPoint,h=u.endPoint;c=p.x+"px, "+p.y+"px",d=h.x+"px, "+h.y+"px"}this.adapter.updateCssVariable(n,c),this.adapter.updateCssVariable(i,d),clearTimeout(this.activationTimer_),clearTimeout(this.fgDeactivationRemovalTimer_),this.rmBoundedActivationClasses_(),this.adapter.removeClass(a),this.adapter.computeBoundingRect(),this.adapter.addClass(s),this.activationTimer_=setTimeout((function(){return e.activationTimerCallback_()}),l)},t.prototype.getFgTranslationCoordinates_=function(){var e,t=this.activationState_,r=t.activationEvent;return{startPoint:e={x:(e=t.wasActivatedByPointer?(0,a.Y)(r,this.adapter.getWindowPageOffset(),this.adapter.computeBoundingRect()):{x:this.frame_.width/2,y:this.frame_.height/2}).x-this.initialSize_/2,y:e.y-this.initialSize_/2},endPoint:{x:this.frame_.width/2-this.initialSize_/2,y:this.frame_.height/2-this.initialSize_/2}}},t.prototype.runDeactivationUXLogicIfReady_=function(){var e=this,r=t.cssClasses.FG_DEACTIVATION,n=this.activationState_,i=n.hasDeactivationUXRun,a=n.isActivated;(i||!a)&&this.activationAnimationHasEnded_&&(this.rmBoundedActivationClasses_(),this.adapter.addClass(r),this.fgDeactivationRemovalTimer_=setTimeout((function(){e.adapter.removeClass(r)}),o.KT.FG_DEACTIVATION_MS))},t.prototype.rmBoundedActivationClasses_=function(){var e=t.cssClasses.FG_ACTIVATION;this.adapter.removeClass(e),this.activationAnimationHasEnded_=!1,this.adapter.computeBoundingRect()},t.prototype.resetActivationState_=function(){var e=this;this.previousActivationEvent_=this.activationState_.activationEvent,this.activationState_=this.defaultActivationState_(),setTimeout((function(){return e.previousActivationEvent_=void 0}),t.numbers.TAP_DELAY_MS)},t.prototype.deactivate_=function(){var e=this,t=this.activationState_;if(t.isActivated){var r=(0,n.pi)({},t);t.isProgrammatic?(requestAnimationFrame((function(){return e.animateDeactivation_(r)})),this.resetActivationState_()):(this.deregisterDeactivationHandlers_(),requestAnimationFrame((function(){e.activationState_.hasDeactivationUXRun=!0,e.animateDeactivation_(r),e.resetActivationState_()})))}},t.prototype.animateDeactivation_=function(e){var t=e.wasActivatedByPointer,r=e.wasElementMadeActive;(t||r)&&this.runDeactivationUXLogicIfReady_()},t.prototype.layoutInternal_=function(){var e=this;this.frame_=this.adapter.computeBoundingRect();var r=Math.max(this.frame_.height,this.frame_.width);this.maxRadius_=this.adapter.isUnbounded()?r:Math.sqrt(Math.pow(e.frame_.width,2)+Math.pow(e.frame_.height,2))+t.numbers.PADDING;var n=Math.floor(r*t.numbers.INITIAL_ORIGIN_SCALE);this.adapter.isUnbounded()&&n%2!=0?this.initialSize_=n-1:this.initialSize_=n,this.fgScale_=""+this.maxRadius_/this.initialSize_,this.updateLayoutCssVars_()},t.prototype.updateLayoutCssVars_=function(){var e=t.strings,r=e.VAR_FG_SIZE,n=e.VAR_LEFT,i=e.VAR_TOP,o=e.VAR_FG_SCALE;this.adapter.updateCssVariable(r,this.initialSize_+"px"),this.adapter.updateCssVariable(o,this.fgScale_),this.adapter.isUnbounded()&&(this.unboundedCoords_={left:Math.round(this.frame_.width/2-this.initialSize_/2),top:Math.round(this.frame_.height/2-this.initialSize_/2)},this.adapter.updateCssVariable(n,this.unboundedCoords_.left+"px"),this.adapter.updateCssVariable(i,this.unboundedCoords_.top+"px"))},t}(i.K)},84445:(e,t,r)=>{"use strict";function n(e,t,r){if(!e)return{x:0,y:0};var n,i,o=t.x,a=t.y,s=o+r.left,l=a+r.top;if("touchstart"===e.type){var c=e;n=c.changedTouches[0].pageX-s,i=c.changedTouches[0].pageY-l}else{var d=e;n=d.pageX-s,i=d.pageY-l}return{x:n,y:i}}r.d(t,{Y:()=>n})},23916:(e,t,r)=>{"use strict";r.d(t,{N:()=>o});r(43437);var n=r(9672),i=r(50856);const o=(0,n.k)({_template:i.d`
    <style>
      :host {
        display: inline-block;
        position: fixed;
        clip: rect(0px,0px,0px,0px);
      }
    </style>
    <div aria-live$="[[mode]]">[[_text]]</div>
`,is:"iron-a11y-announcer",properties:{mode:{type:String,value:"polite"},_text:{type:String,value:""}},created:function(){o.instance||(o.instance=this),document.body.addEventListener("iron-announce",this._onIronAnnounce.bind(this))},announce:function(e){this._text="",this.async((function(){this._text=e}),100)},_onIronAnnounce:function(e){e.detail&&e.detail.text&&this.announce(e.detail.text)}});o.instance=null,o.requestAvailability=function(){o.instance||(o.instance=document.createElement("iron-a11y-announcer")),document.body.appendChild(o.instance)}},8621:(e,t,r)=>{"use strict";r.d(t,{G:()=>m});r(43437);var n={"U+0008":"backspace","U+0009":"tab","U+001B":"esc","U+0020":"space","U+007F":"del"},i={8:"backspace",9:"tab",13:"enter",27:"esc",33:"pageup",34:"pagedown",35:"end",36:"home",32:"space",37:"left",38:"up",39:"right",40:"down",46:"del",106:"*"},o={shift:"shiftKey",ctrl:"ctrlKey",alt:"altKey",meta:"metaKey"},a=/[a-z0-9*]/,s=/U\+/,l=/^arrow/,c=/^space(bar)?/,d=/^escape$/;function u(e,t){var r="";if(e){var n=e.toLowerCase();" "===n||c.test(n)?r="space":d.test(n)?r="esc":1==n.length?t&&!a.test(n)||(r=n):r=l.test(n)?n.replace("arrow",""):"multiply"==n?"*":n}return r}function p(e,t){return e.key?u(e.key,t):e.detail&&e.detail.key?u(e.detail.key,t):(r=e.keyIdentifier,o="",r&&(r in n?o=n[r]:s.test(r)?(r=parseInt(r.replace("U+","0x"),16),o=String.fromCharCode(r).toLowerCase()):o=r.toLowerCase()),o||function(e){var t="";return Number(e)&&(t=e>=65&&e<=90?String.fromCharCode(32+e):e>=112&&e<=123?"f"+(e-112+1):e>=48&&e<=57?String(e-48):e>=96&&e<=105?String(e-96):i[e]),t}(e.keyCode)||"");var r,o}function h(e,t){return p(t,e.hasModifiers)===e.key&&(!e.hasModifiers||!!t.shiftKey==!!e.shiftKey&&!!t.ctrlKey==!!e.ctrlKey&&!!t.altKey==!!e.altKey&&!!t.metaKey==!!e.metaKey)}function f(e){return e.trim().split(" ").map((function(e){return function(e){return 1===e.length?{combo:e,key:e,event:"keydown"}:e.split("+").reduce((function(e,t){var r=t.split(":"),n=r[0],i=r[1];return n in o?(e[o[n]]=!0,e.hasModifiers=!0):(e.key=n,e.event=i||"keydown"),e}),{combo:e.split(":").shift()})}(e)}))}const m={properties:{keyEventTarget:{type:Object,value:function(){return this}},stopKeyboardEventPropagation:{type:Boolean,value:!1},_boundKeyHandlers:{type:Array,value:function(){return[]}},_imperativeKeyBindings:{type:Object,value:function(){return{}}}},observers:["_resetKeyEventListeners(keyEventTarget, _boundKeyHandlers)"],keyBindings:{},registered:function(){this._prepKeyBindings()},attached:function(){this._listenKeyEventListeners()},detached:function(){this._unlistenKeyEventListeners()},addOwnKeyBinding:function(e,t){this._imperativeKeyBindings[e]=t,this._prepKeyBindings(),this._resetKeyEventListeners()},removeOwnKeyBindings:function(){this._imperativeKeyBindings={},this._prepKeyBindings(),this._resetKeyEventListeners()},keyboardEventMatchesKeys:function(e,t){for(var r=f(t),n=0;n<r.length;++n)if(h(r[n],e))return!0;return!1},_collectKeyBindings:function(){var e=this.behaviors.map((function(e){return e.keyBindings}));return-1===e.indexOf(this.keyBindings)&&e.push(this.keyBindings),e},_prepKeyBindings:function(){for(var e in this._keyBindings={},this._collectKeyBindings().forEach((function(e){for(var t in e)this._addKeyBinding(t,e[t])}),this),this._imperativeKeyBindings)this._addKeyBinding(e,this._imperativeKeyBindings[e]);for(var t in this._keyBindings)this._keyBindings[t].sort((function(e,t){var r=e[0].hasModifiers;return r===t[0].hasModifiers?0:r?-1:1}))},_addKeyBinding:function(e,t){f(e).forEach((function(e){this._keyBindings[e.event]=this._keyBindings[e.event]||[],this._keyBindings[e.event].push([e,t])}),this)},_resetKeyEventListeners:function(){this._unlistenKeyEventListeners(),this.isAttached&&this._listenKeyEventListeners()},_listenKeyEventListeners:function(){this.keyEventTarget&&Object.keys(this._keyBindings).forEach((function(e){var t=this._keyBindings[e],r=this._onKeyBindingEvent.bind(this,t);this._boundKeyHandlers.push([this.keyEventTarget,e,r]),this.keyEventTarget.addEventListener(e,r)}),this)},_unlistenKeyEventListeners:function(){for(var e,t,r,n;this._boundKeyHandlers.length;)t=(e=this._boundKeyHandlers.pop())[0],r=e[1],n=e[2],t.removeEventListener(r,n)},_onKeyBindingEvent:function(e,t){if(this.stopKeyboardEventPropagation&&t.stopPropagation(),!t.defaultPrevented)for(var r=0;r<e.length;r++){var n=e[r][0],i=e[r][1];if(h(n,t)&&(this._triggerKeyHandler(n,i,t),t.defaultPrevented))return}},_triggerKeyHandler:function(e,t,r){var n=Object.create(e);n.keyboardEvent=r;var i=new CustomEvent(e.event,{detail:n,cancelable:!0});this[t].call(this,i),i.defaultPrevented&&r.preventDefault()}}},26110:(e,t,r)=>{"use strict";r.d(t,{a:()=>n});r(43437),r(87156);const n={properties:{focused:{type:Boolean,value:!1,notify:!0,readOnly:!0,reflectToAttribute:!0},disabled:{type:Boolean,value:!1,notify:!0,observer:"_disabledChanged",reflectToAttribute:!0},_oldTabIndex:{type:String},_boundFocusBlurHandler:{type:Function,value:function(){return this._focusBlurHandler.bind(this)}}},observers:["_changedControlState(focused, disabled)"],ready:function(){this.addEventListener("focus",this._boundFocusBlurHandler,!0),this.addEventListener("blur",this._boundFocusBlurHandler,!0)},_focusBlurHandler:function(e){this._setFocused("focus"===e.type)},_disabledChanged:function(e,t){this.setAttribute("aria-disabled",e?"true":"false"),this.style.pointerEvents=e?"none":"",e?(this._oldTabIndex=this.getAttribute("tabindex"),this._setFocused(!1),this.tabIndex=-1,this.blur()):void 0!==this._oldTabIndex&&(null===this._oldTabIndex?this.removeAttribute("tabindex"):this.setAttribute("tabindex",this._oldTabIndex))},_changedControlState:function(){this._controlStateChanged&&this._controlStateChanged()}}},65660:(e,t,r)=>{"use strict";r(43437);const n=r(50856).d`
<custom-style>
  <style is="custom-style">
    [hidden] {
      display: none !important;
    }
  </style>
</custom-style>
<custom-style>
  <style is="custom-style">
    html {

      --layout: {
        display: -ms-flexbox;
        display: -webkit-flex;
        display: flex;
      };

      --layout-inline: {
        display: -ms-inline-flexbox;
        display: -webkit-inline-flex;
        display: inline-flex;
      };

      --layout-horizontal: {
        @apply --layout;

        -ms-flex-direction: row;
        -webkit-flex-direction: row;
        flex-direction: row;
      };

      --layout-horizontal-reverse: {
        @apply --layout;

        -ms-flex-direction: row-reverse;
        -webkit-flex-direction: row-reverse;
        flex-direction: row-reverse;
      };

      --layout-vertical: {
        @apply --layout;

        -ms-flex-direction: column;
        -webkit-flex-direction: column;
        flex-direction: column;
      };

      --layout-vertical-reverse: {
        @apply --layout;

        -ms-flex-direction: column-reverse;
        -webkit-flex-direction: column-reverse;
        flex-direction: column-reverse;
      };

      --layout-wrap: {
        -ms-flex-wrap: wrap;
        -webkit-flex-wrap: wrap;
        flex-wrap: wrap;
      };

      --layout-wrap-reverse: {
        -ms-flex-wrap: wrap-reverse;
        -webkit-flex-wrap: wrap-reverse;
        flex-wrap: wrap-reverse;
      };

      --layout-flex-auto: {
        -ms-flex: 1 1 auto;
        -webkit-flex: 1 1 auto;
        flex: 1 1 auto;
      };

      --layout-flex-none: {
        -ms-flex: none;
        -webkit-flex: none;
        flex: none;
      };

      --layout-flex: {
        -ms-flex: 1 1 0.000000001px;
        -webkit-flex: 1;
        flex: 1;
        -webkit-flex-basis: 0.000000001px;
        flex-basis: 0.000000001px;
      };

      --layout-flex-2: {
        -ms-flex: 2;
        -webkit-flex: 2;
        flex: 2;
      };

      --layout-flex-3: {
        -ms-flex: 3;
        -webkit-flex: 3;
        flex: 3;
      };

      --layout-flex-4: {
        -ms-flex: 4;
        -webkit-flex: 4;
        flex: 4;
      };

      --layout-flex-5: {
        -ms-flex: 5;
        -webkit-flex: 5;
        flex: 5;
      };

      --layout-flex-6: {
        -ms-flex: 6;
        -webkit-flex: 6;
        flex: 6;
      };

      --layout-flex-7: {
        -ms-flex: 7;
        -webkit-flex: 7;
        flex: 7;
      };

      --layout-flex-8: {
        -ms-flex: 8;
        -webkit-flex: 8;
        flex: 8;
      };

      --layout-flex-9: {
        -ms-flex: 9;
        -webkit-flex: 9;
        flex: 9;
      };

      --layout-flex-10: {
        -ms-flex: 10;
        -webkit-flex: 10;
        flex: 10;
      };

      --layout-flex-11: {
        -ms-flex: 11;
        -webkit-flex: 11;
        flex: 11;
      };

      --layout-flex-12: {
        -ms-flex: 12;
        -webkit-flex: 12;
        flex: 12;
      };

      /* alignment in cross axis */

      --layout-start: {
        -ms-flex-align: start;
        -webkit-align-items: flex-start;
        align-items: flex-start;
      };

      --layout-center: {
        -ms-flex-align: center;
        -webkit-align-items: center;
        align-items: center;
      };

      --layout-end: {
        -ms-flex-align: end;
        -webkit-align-items: flex-end;
        align-items: flex-end;
      };

      --layout-baseline: {
        -ms-flex-align: baseline;
        -webkit-align-items: baseline;
        align-items: baseline;
      };

      /* alignment in main axis */

      --layout-start-justified: {
        -ms-flex-pack: start;
        -webkit-justify-content: flex-start;
        justify-content: flex-start;
      };

      --layout-center-justified: {
        -ms-flex-pack: center;
        -webkit-justify-content: center;
        justify-content: center;
      };

      --layout-end-justified: {
        -ms-flex-pack: end;
        -webkit-justify-content: flex-end;
        justify-content: flex-end;
      };

      --layout-around-justified: {
        -ms-flex-pack: distribute;
        -webkit-justify-content: space-around;
        justify-content: space-around;
      };

      --layout-justified: {
        -ms-flex-pack: justify;
        -webkit-justify-content: space-between;
        justify-content: space-between;
      };

      --layout-center-center: {
        @apply --layout-center;
        @apply --layout-center-justified;
      };

      /* self alignment */

      --layout-self-start: {
        -ms-align-self: flex-start;
        -webkit-align-self: flex-start;
        align-self: flex-start;
      };

      --layout-self-center: {
        -ms-align-self: center;
        -webkit-align-self: center;
        align-self: center;
      };

      --layout-self-end: {
        -ms-align-self: flex-end;
        -webkit-align-self: flex-end;
        align-self: flex-end;
      };

      --layout-self-stretch: {
        -ms-align-self: stretch;
        -webkit-align-self: stretch;
        align-self: stretch;
      };

      --layout-self-baseline: {
        -ms-align-self: baseline;
        -webkit-align-self: baseline;
        align-self: baseline;
      };

      /* multi-line alignment in main axis */

      --layout-start-aligned: {
        -ms-flex-line-pack: start;  /* IE10 */
        -ms-align-content: flex-start;
        -webkit-align-content: flex-start;
        align-content: flex-start;
      };

      --layout-end-aligned: {
        -ms-flex-line-pack: end;  /* IE10 */
        -ms-align-content: flex-end;
        -webkit-align-content: flex-end;
        align-content: flex-end;
      };

      --layout-center-aligned: {
        -ms-flex-line-pack: center;  /* IE10 */
        -ms-align-content: center;
        -webkit-align-content: center;
        align-content: center;
      };

      --layout-between-aligned: {
        -ms-flex-line-pack: justify;  /* IE10 */
        -ms-align-content: space-between;
        -webkit-align-content: space-between;
        align-content: space-between;
      };

      --layout-around-aligned: {
        -ms-flex-line-pack: distribute;  /* IE10 */
        -ms-align-content: space-around;
        -webkit-align-content: space-around;
        align-content: space-around;
      };

      /*******************************
                Other Layout
      *******************************/

      --layout-block: {
        display: block;
      };

      --layout-invisible: {
        visibility: hidden !important;
      };

      --layout-relative: {
        position: relative;
      };

      --layout-fit: {
        position: absolute;
        top: 0;
        right: 0;
        bottom: 0;
        left: 0;
      };

      --layout-scroll: {
        -webkit-overflow-scrolling: touch;
        overflow: auto;
      };

      --layout-fullbleed: {
        margin: 0;
        height: 100vh;
      };

      /* fixed position */

      --layout-fixed-top: {
        position: fixed;
        top: 0;
        left: 0;
        right: 0;
      };

      --layout-fixed-right: {
        position: fixed;
        top: 0;
        right: 0;
        bottom: 0;
      };

      --layout-fixed-bottom: {
        position: fixed;
        right: 0;
        bottom: 0;
        left: 0;
      };

      --layout-fixed-left: {
        position: fixed;
        top: 0;
        bottom: 0;
        left: 0;
      };

    }
  </style>
</custom-style>`;n.setAttribute("style","display: none;"),document.head.appendChild(n.content);var i=document.createElement("style");i.textContent="[hidden] { display: none !important; }",document.head.appendChild(i)},21006:(e,t,r)=>{"use strict";r.d(t,{V:()=>n});r(43437);const n={properties:{name:{type:String},value:{notify:!0,type:String},required:{type:Boolean,value:!1}},attached:function(){},detached:function(){}}},87772:(e,t,r)=>{"use strict";r(43437);var n=r(23916),i=r(98235),o=r(9672),a=r(87156),s=r(50856);(0,o.k)({_template:s.d`
    <style>
      :host {
        display: inline-block;
      }
    </style>
    <slot id="content"></slot>
`,is:"iron-input",behaviors:[i.x],properties:{bindValue:{type:String,value:""},value:{type:String,computed:"_computeValue(bindValue)"},allowedPattern:{type:String},autoValidate:{type:Boolean,value:!1},_inputElement:Object},observers:["_bindValueChanged(bindValue, _inputElement)"],listeners:{input:"_onInput",keypress:"_onKeypress"},created:function(){n.N.requestAvailability(),this._previousValidInput="",this._patternAlreadyChecked=!1},attached:function(){this._observer=(0,a.vz)(this).observeNodes(function(e){this._initSlottedInput()}.bind(this))},detached:function(){this._observer&&((0,a.vz)(this).unobserveNodes(this._observer),this._observer=null)},get inputElement(){return this._inputElement},_initSlottedInput:function(){this._inputElement=this.getEffectiveChildren()[0],this.inputElement&&this.inputElement.value&&(this.bindValue=this.inputElement.value),this.fire("iron-input-ready")},get _patternRegExp(){var e;if(this.allowedPattern)e=new RegExp(this.allowedPattern);else switch(this.inputElement.type){case"number":e=/[0-9.,e-]/}return e},_bindValueChanged:function(e,t){t&&(void 0===e?t.value=null:e!==t.value&&(this.inputElement.value=e),this.autoValidate&&this.validate(),this.fire("bind-value-changed",{value:e}))},_onInput:function(){this.allowedPattern&&!this._patternAlreadyChecked&&(this._checkPatternValidity()||(this._announceInvalidCharacter("Invalid string of characters not entered."),this.inputElement.value=this._previousValidInput));this.bindValue=this._previousValidInput=this.inputElement.value,this._patternAlreadyChecked=!1},_isPrintable:function(e){var t=8==e.keyCode||9==e.keyCode||13==e.keyCode||27==e.keyCode,r=19==e.keyCode||20==e.keyCode||45==e.keyCode||46==e.keyCode||144==e.keyCode||145==e.keyCode||e.keyCode>32&&e.keyCode<41||e.keyCode>111&&e.keyCode<124;return!(t||0==e.charCode&&r)},_onKeypress:function(e){if(this.allowedPattern||"number"===this.inputElement.type){var t=this._patternRegExp;if(t&&!(e.metaKey||e.ctrlKey||e.altKey)){this._patternAlreadyChecked=!0;var r=String.fromCharCode(e.charCode);this._isPrintable(e)&&!t.test(r)&&(e.preventDefault(),this._announceInvalidCharacter("Invalid character "+r+" not entered."))}}},_checkPatternValidity:function(){var e=this._patternRegExp;if(!e)return!0;for(var t=0;t<this.inputElement.value.length;t++)if(!e.test(this.inputElement.value[t]))return!1;return!0},validate:function(){if(!this.inputElement)return this.invalid=!1,!0;var e=this.inputElement.checkValidity();return e&&(this.required&&""===this.bindValue?e=!1:this.hasValidator()&&(e=i.x.validate.call(this,this.bindValue))),this.invalid=!e,this.fire("iron-input-validate"),e},_announceInvalidCharacter:function(e){this.fire("iron-announce",{text:e})},_computeValue:function(e){return e}})},15112:(e,t,r)=>{"use strict";r.d(t,{P:()=>i});r(43437);var n=r(9672);class i{constructor(e){i[" "](e),this.type=e&&e.type||"default",this.key=e&&e.key,e&&"value"in e&&(this.value=e.value)}get value(){var e=this.type,t=this.key;if(e&&t)return i.types[e]&&i.types[e][t]}set value(e){var t=this.type,r=this.key;t&&r&&(t=i.types[t]=i.types[t]||{},null==e?delete t[r]:t[r]=e)}get list(){if(this.type){var e=i.types[this.type];return e?Object.keys(e).map((function(e){return o[this.type][e]}),this):[]}}byKey(e){return this.key=e,this.value}}i[" "]=function(){},i.types={};var o=i.types;(0,n.k)({is:"iron-meta",properties:{type:{type:String,value:"default"},key:{type:String},value:{type:String,notify:!0},self:{type:Boolean,observer:"_selfChanged"},__meta:{type:Boolean,computed:"__computeMeta(type, key, value)"}},hostAttributes:{hidden:!0},__computeMeta:function(e,t,r){var n=new i({type:e,key:t});return void 0!==r&&r!==n.value?n.value=r:this.value!==n.value&&(this.value=n.value),n},get list(){return this.__meta&&this.__meta.list},_selfChanged:function(e){e&&(this.value=this)},byKey:function(e){return new i({type:this.type,key:e}).value}})},98235:(e,t,r)=>{"use strict";r.d(t,{x:()=>o});r(43437);var n=r(15112);let i=null;const o={properties:{validator:{type:String},invalid:{notify:!0,reflectToAttribute:!0,type:Boolean,value:!1,observer:"_invalidChanged"}},registered:function(){i=new n.P({type:"validator"})},_invalidChanged:function(){this.invalid?this.setAttribute("aria-invalid","true"):this.removeAttribute("aria-invalid")},get _validator(){return i&&i.byKey(this.validator)},hasValidator:function(){return null!=this._validator},validate:function(e){return void 0===e&&void 0!==this.value?this.invalid=!this._getValidity(this.value):this.invalid=!this._getValidity(e),!this.invalid},_getValidity:function(e){return!this.hasValidator()||this._validator.validate(e)}}},71765:(e,t,r)=>{"use strict";r.d(t,{o:()=>n});r(43437);const n={attached:function(){this.fire("addon-attached")},update:function(e){}}},66668:(e,t,r)=>{"use strict";r.d(t,{d0:()=>c});r(43437);var n=r(8621),i=r(26110),o=r(87156),a=r(28426);const s={NextLabelID:1,NextAddonID:1,NextInputID:1},l={properties:{label:{type:String},value:{notify:!0,type:String},disabled:{type:Boolean,value:!1},invalid:{type:Boolean,value:!1,notify:!0},allowedPattern:{type:String},type:{type:String},list:{type:String},pattern:{type:String},required:{type:Boolean,value:!1},errorMessage:{type:String},charCounter:{type:Boolean,value:!1},noLabelFloat:{type:Boolean,value:!1},alwaysFloatLabel:{type:Boolean,value:!1},autoValidate:{type:Boolean,value:!1},validator:{type:String},autocomplete:{type:String,value:"off"},autofocus:{type:Boolean,observer:"_autofocusChanged"},inputmode:{type:String},minlength:{type:Number},maxlength:{type:Number},min:{type:String},max:{type:String},step:{type:String},name:{type:String},placeholder:{type:String,value:""},readonly:{type:Boolean,value:!1},size:{type:Number},autocapitalize:{type:String,value:"none"},autocorrect:{type:String,value:"off"},autosave:{type:String},results:{type:Number},accept:{type:String},multiple:{type:Boolean},_ariaDescribedBy:{type:String,value:""},_ariaLabelledBy:{type:String,value:""},_inputId:{type:String,value:""}},listeners:{"addon-attached":"_onAddonAttached"},keyBindings:{"shift+tab:keydown":"_onShiftTabDown"},hostAttributes:{tabindex:0},get inputElement(){return this.$||(this.$={}),this.$.input||(this._generateInputId(),this.$.input=this.$$("#"+this._inputId)),this.$.input},get _focusableElement(){return this.inputElement},created:function(){this._typesThatHaveText=["date","datetime","datetime-local","month","time","week","file"]},attached:function(){this._updateAriaLabelledBy(),!a.H3&&this.inputElement&&-1!==this._typesThatHaveText.indexOf(this.inputElement.type)&&(this.alwaysFloatLabel=!0)},_appendStringWithSpace:function(e,t){return e=e?e+" "+t:t},_onAddonAttached:function(e){var t=(0,o.vz)(e).rootTarget;if(t.id)this._ariaDescribedBy=this._appendStringWithSpace(this._ariaDescribedBy,t.id);else{var r="paper-input-add-on-"+s.NextAddonID++;t.id=r,this._ariaDescribedBy=this._appendStringWithSpace(this._ariaDescribedBy,r)}},validate:function(){return this.inputElement.validate()},_focusBlurHandler:function(e){i.a._focusBlurHandler.call(this,e),this.focused&&!this._shiftTabPressed&&this._focusableElement&&this._focusableElement.focus()},_onShiftTabDown:function(e){var t=this.getAttribute("tabindex");this._shiftTabPressed=!0,this.setAttribute("tabindex","-1"),this.async((function(){this.setAttribute("tabindex",t),this._shiftTabPressed=!1}),1)},_handleAutoValidate:function(){this.autoValidate&&this.validate()},updateValueAndPreserveCaret:function(e){try{var t=this.inputElement.selectionStart;this.value=e,this.inputElement.selectionStart=t,this.inputElement.selectionEnd=t}catch(t){this.value=e}},_computeAlwaysFloatLabel:function(e,t){return t||e},_updateAriaLabelledBy:function(){var e,t=(0,o.vz)(this.root).querySelector("label");t?(t.id?e=t.id:(e="paper-input-label-"+s.NextLabelID++,t.id=e),this._ariaLabelledBy=e):this._ariaLabelledBy=""},_generateInputId:function(){this._inputId&&""!==this._inputId||(this._inputId="input-"+s.NextInputID++)},_onChange:function(e){this.shadowRoot&&this.fire(e.type,{sourceEvent:e},{node:this,bubbles:e.bubbles,cancelable:e.cancelable})},_autofocusChanged:function(){if(this.autofocus&&this._focusableElement){var e=document.activeElement;e instanceof HTMLElement&&e!==document.body&&e!==document.documentElement||this._focusableElement.focus()}}},c=[i.a,n.G,l]},2178:(e,t,r)=>{"use strict";r(43437),r(70019);var n=r(9672),i=r(50856),o=r(71765);(0,n.k)({_template:i.d`
    <style>
      :host {
        display: inline-block;
        float: right;

        @apply --paper-font-caption;
        @apply --paper-input-char-counter;
      }

      :host([hidden]) {
        display: none !important;
      }

      :host(:dir(rtl)) {
        float: left;
      }
    </style>

    <span>[[_charCounterStr]]</span>
`,is:"paper-input-char-counter",behaviors:[o.o],properties:{_charCounterStr:{type:String,value:"0"}},update:function(e){if(e.inputElement){e.value=e.value||"";var t=e.value.toString().length.toString();e.inputElement.hasAttribute("maxlength")&&(t+="/"+e.inputElement.getAttribute("maxlength")),this._charCounterStr=t}}})},98121:(e,t,r)=>{"use strict";r(43437),r(65660),r(70019);var n=r(9672),i=r(87156),o=r(67130),a=r(50856);const s=a.d`
<custom-style>
  <style is="custom-style">
    html {
      --paper-input-container-shared-input-style: {
        position: relative; /* to make a stacking context */
        outline: none;
        box-shadow: none;
        padding: 0;
        margin: 0;
        width: 100%;
        max-width: 100%;
        background: transparent;
        border: none;
        color: var(--paper-input-container-input-color, var(--primary-text-color));
        -webkit-appearance: none;
        text-align: inherit;
        vertical-align: var(--paper-input-container-input-align, bottom);

        @apply --paper-font-subhead;
      };
    }
  </style>
</custom-style>
`;s.setAttribute("style","display: none;"),document.head.appendChild(s.content),(0,n.k)({_template:a.d`
    <style>
      :host {
        display: block;
        padding: 8px 0;
        @apply --paper-input-container;
      }

      :host([inline]) {
        display: inline-block;
      }

      :host([disabled]) {
        pointer-events: none;
        opacity: 0.33;

        @apply --paper-input-container-disabled;
      }

      :host([hidden]) {
        display: none !important;
      }

      [hidden] {
        display: none !important;
      }

      .floated-label-placeholder {
        @apply --paper-font-caption;
      }

      .underline {
        height: 2px;
        position: relative;
      }

      .focused-line {
        @apply --layout-fit;
        border-bottom: 2px solid var(--paper-input-container-focus-color, var(--primary-color));

        -webkit-transform-origin: center center;
        transform-origin: center center;
        -webkit-transform: scale3d(0,1,1);
        transform: scale3d(0,1,1);

        @apply --paper-input-container-underline-focus;
      }

      .underline.is-highlighted .focused-line {
        -webkit-transform: none;
        transform: none;
        -webkit-transition: -webkit-transform 0.25s;
        transition: transform 0.25s;

        @apply --paper-transition-easing;
      }

      .underline.is-invalid .focused-line {
        border-color: var(--paper-input-container-invalid-color, var(--error-color));
        -webkit-transform: none;
        transform: none;
        -webkit-transition: -webkit-transform 0.25s;
        transition: transform 0.25s;

        @apply --paper-transition-easing;
      }

      .unfocused-line {
        @apply --layout-fit;
        border-bottom: 1px solid var(--paper-input-container-color, var(--secondary-text-color));
        @apply --paper-input-container-underline;
      }

      :host([disabled]) .unfocused-line {
        border-bottom: 1px dashed;
        border-color: var(--paper-input-container-color, var(--secondary-text-color));
        @apply --paper-input-container-underline-disabled;
      }

      .input-wrapper {
        @apply --layout-horizontal;
        @apply --layout-center;
        position: relative;
      }

      .input-content {
        @apply --layout-flex-auto;
        @apply --layout-relative;
        max-width: 100%;
      }

      .input-content ::slotted(label),
      .input-content ::slotted(.paper-input-label) {
        position: absolute;
        top: 0;
        left: 0;
        width: 100%;
        font: inherit;
        color: var(--paper-input-container-color, var(--secondary-text-color));
        -webkit-transition: -webkit-transform 0.25s, width 0.25s;
        transition: transform 0.25s, width 0.25s;
        -webkit-transform-origin: left top;
        transform-origin: left top;
        /* Fix for safari not focusing 0-height date/time inputs with -webkit-apperance: none; */
        min-height: 1px;

        @apply --paper-font-common-nowrap;
        @apply --paper-font-subhead;
        @apply --paper-input-container-label;
        @apply --paper-transition-easing;
      }

      .input-content.label-is-floating ::slotted(label),
      .input-content.label-is-floating ::slotted(.paper-input-label) {
        -webkit-transform: translateY(-75%) scale(0.75);
        transform: translateY(-75%) scale(0.75);

        /* Since we scale to 75/100 of the size, we actually have 100/75 of the
        original space now available */
        width: 133%;

        @apply --paper-input-container-label-floating;
      }

      :host(:dir(rtl)) .input-content.label-is-floating ::slotted(label),
      :host(:dir(rtl)) .input-content.label-is-floating ::slotted(.paper-input-label) {
        right: 0;
        left: auto;
        -webkit-transform-origin: right top;
        transform-origin: right top;
      }

      .input-content.label-is-highlighted ::slotted(label),
      .input-content.label-is-highlighted ::slotted(.paper-input-label) {
        color: var(--paper-input-container-focus-color, var(--primary-color));

        @apply --paper-input-container-label-focus;
      }

      .input-content.is-invalid ::slotted(label),
      .input-content.is-invalid ::slotted(.paper-input-label) {
        color: var(--paper-input-container-invalid-color, var(--error-color));
      }

      .input-content.label-is-hidden ::slotted(label),
      .input-content.label-is-hidden ::slotted(.paper-input-label) {
        visibility: hidden;
      }

      .input-content ::slotted(input),
      .input-content ::slotted(iron-input),
      .input-content ::slotted(textarea),
      .input-content ::slotted(iron-autogrow-textarea),
      .input-content ::slotted(.paper-input-input) {
        @apply --paper-input-container-shared-input-style;
        /* The apply shim doesn't apply the nested color custom property,
          so we have to re-apply it here. */
        color: var(--paper-input-container-input-color, var(--primary-text-color));
        @apply --paper-input-container-input;
      }

      .input-content ::slotted(input)::-webkit-outer-spin-button,
      .input-content ::slotted(input)::-webkit-inner-spin-button {
        @apply --paper-input-container-input-webkit-spinner;
      }

      .input-content.focused ::slotted(input),
      .input-content.focused ::slotted(iron-input),
      .input-content.focused ::slotted(textarea),
      .input-content.focused ::slotted(iron-autogrow-textarea),
      .input-content.focused ::slotted(.paper-input-input) {
        @apply --paper-input-container-input-focus;
      }

      .input-content.is-invalid ::slotted(input),
      .input-content.is-invalid ::slotted(iron-input),
      .input-content.is-invalid ::slotted(textarea),
      .input-content.is-invalid ::slotted(iron-autogrow-textarea),
      .input-content.is-invalid ::slotted(.paper-input-input) {
        @apply --paper-input-container-input-invalid;
      }

      .prefix ::slotted(*) {
        display: inline-block;
        @apply --paper-font-subhead;
        @apply --layout-flex-none;
        @apply --paper-input-prefix;
      }

      .suffix ::slotted(*) {
        display: inline-block;
        @apply --paper-font-subhead;
        @apply --layout-flex-none;

        @apply --paper-input-suffix;
      }

      /* Firefox sets a min-width on the input, which can cause layout issues */
      .input-content ::slotted(input) {
        min-width: 0;
      }

      .input-content ::slotted(textarea) {
        resize: none;
      }

      .add-on-content {
        position: relative;
      }

      .add-on-content.is-invalid ::slotted(*) {
        color: var(--paper-input-container-invalid-color, var(--error-color));
      }

      .add-on-content.is-highlighted ::slotted(*) {
        color: var(--paper-input-container-focus-color, var(--primary-color));
      }
    </style>

    <div class="floated-label-placeholder" aria-hidden="true" hidden="[[noLabelFloat]]">&nbsp;</div>

    <div class="input-wrapper">
      <span class="prefix"><slot name="prefix"></slot></span>

      <div class$="[[_computeInputContentClass(noLabelFloat,alwaysFloatLabel,focused,invalid,_inputHasContent)]]" id="labelAndInputContainer">
        <slot name="label"></slot>
        <slot name="input"></slot>
      </div>

      <span class="suffix"><slot name="suffix"></slot></span>
    </div>

    <div class$="[[_computeUnderlineClass(focused,invalid)]]">
      <div class="unfocused-line"></div>
      <div class="focused-line"></div>
    </div>

    <div class$="[[_computeAddOnContentClass(focused,invalid)]]">
      <slot name="add-on"></slot>
    </div>
`,is:"paper-input-container",properties:{noLabelFloat:{type:Boolean,value:!1},alwaysFloatLabel:{type:Boolean,value:!1},attrForValue:{type:String,value:"bind-value"},autoValidate:{type:Boolean,value:!1},invalid:{observer:"_invalidChanged",type:Boolean,value:!1},focused:{readOnly:!0,type:Boolean,value:!1,notify:!0},_addons:{type:Array},_inputHasContent:{type:Boolean,value:!1},_inputSelector:{type:String,value:"input,iron-input,textarea,.paper-input-input"},_boundOnFocus:{type:Function,value:function(){return this._onFocus.bind(this)}},_boundOnBlur:{type:Function,value:function(){return this._onBlur.bind(this)}},_boundOnInput:{type:Function,value:function(){return this._onInput.bind(this)}},_boundValueChanged:{type:Function,value:function(){return this._onValueChanged.bind(this)}}},listeners:{"addon-attached":"_onAddonAttached","iron-input-validate":"_onIronInputValidate"},get _valueChangedEvent(){return this.attrForValue+"-changed"},get _propertyForValue(){return(0,o.z)(this.attrForValue)},get _inputElement(){return(0,i.vz)(this).querySelector(this._inputSelector)},get _inputElementValue(){return this._inputElement[this._propertyForValue]||this._inputElement.value},ready:function(){this.__isFirstValueUpdate=!0,this._addons||(this._addons=[]),this.addEventListener("focus",this._boundOnFocus,!0),this.addEventListener("blur",this._boundOnBlur,!0)},attached:function(){this.attrForValue?this._inputElement.addEventListener(this._valueChangedEvent,this._boundValueChanged):this.addEventListener("input",this._onInput),this._inputElementValue&&""!=this._inputElementValue?this._handleValueAndAutoValidate(this._inputElement):this._handleValue(this._inputElement)},_onAddonAttached:function(e){this._addons||(this._addons=[]);var t=e.target;-1===this._addons.indexOf(t)&&(this._addons.push(t),this.isAttached&&this._handleValue(this._inputElement))},_onFocus:function(){this._setFocused(!0)},_onBlur:function(){this._setFocused(!1),this._handleValueAndAutoValidate(this._inputElement)},_onInput:function(e){this._handleValueAndAutoValidate(e.target)},_onValueChanged:function(e){var t=e.target;this.__isFirstValueUpdate&&(this.__isFirstValueUpdate=!1,void 0===t.value||""===t.value)||this._handleValueAndAutoValidate(e.target)},_handleValue:function(e){var t=this._inputElementValue;t||0===t||"number"===e.type&&!e.checkValidity()?this._inputHasContent=!0:this._inputHasContent=!1,this.updateAddons({inputElement:e,value:t,invalid:this.invalid})},_handleValueAndAutoValidate:function(e){var t;this.autoValidate&&e&&(t=e.validate?e.validate(this._inputElementValue):e.checkValidity(),this.invalid=!t);this._handleValue(e)},_onIronInputValidate:function(e){this.invalid=this._inputElement.invalid},_invalidChanged:function(){this._addons&&this.updateAddons({invalid:this.invalid})},updateAddons:function(e){for(var t,r=0;t=this._addons[r];r++)t.update(e)},_computeInputContentClass:function(e,t,r,n,i){var o="input-content";if(e)i&&(o+=" label-is-hidden"),n&&(o+=" is-invalid");else{var a=this.querySelector("label");t||i?(o+=" label-is-floating",this.$.labelAndInputContainer.style.position="static",n?o+=" is-invalid":r&&(o+=" label-is-highlighted")):(a&&(this.$.labelAndInputContainer.style.position="relative"),n&&(o+=" is-invalid"))}return r&&(o+=" focused"),o},_computeUnderlineClass:function(e,t){var r="underline";return t?r+=" is-invalid":e&&(r+=" is-highlighted"),r},_computeAddOnContentClass:function(e,t){var r="add-on-content";return t?r+=" is-invalid":e&&(r+=" is-highlighted"),r}})},65911:(e,t,r)=>{"use strict";r(43437),r(70019);var n=r(9672),i=r(50856),o=r(71765);(0,n.k)({_template:i.d`
    <style>
      :host {
        display: inline-block;
        visibility: hidden;

        color: var(--paper-input-container-invalid-color, var(--error-color));

        @apply --paper-font-caption;
        @apply --paper-input-error;
        position: absolute;
        left:0;
        right:0;
      }

      :host([invalid]) {
        visibility: visible;
      }

      #a11yWrapper {
        visibility: hidden;
      }

      :host([invalid]) #a11yWrapper {
        visibility: visible;
      }
    </style>

    <!--
    If the paper-input-error element is directly referenced by an
    \`aria-describedby\` attribute, such as when used as a paper-input add-on,
    then applying \`visibility: hidden;\` to the paper-input-error element itself
    does not hide the error.

    For more information, see:
    https://www.w3.org/TR/accname-1.1/#mapping_additional_nd_description
    -->
    <div id="a11yWrapper">
      <slot></slot>
    </div>
`,is:"paper-input-error",behaviors:[o.o],properties:{invalid:{readOnly:!0,reflectToAttribute:!0,type:Boolean}},update:function(e){this._setInvalid(e.invalid)}})},30879:(e,t,r)=>{"use strict";r(43437),r(87772),r(2178),r(98121),r(65911);var n=r(21006),i=(r(21384),r(9672)),o=r(50856),a=r(66668);(0,i.k)({is:"paper-input",_template:o.d`
    <style>
      :host {
        display: block;
      }

      :host([focused]) {
        outline: none;
      }

      :host([hidden]) {
        display: none !important;
      }

      input {
        /* Firefox sets a min-width on the input, which can cause layout issues */
        min-width: 0;
      }

      /* In 1.x, the <input> is distributed to paper-input-container, which styles it.
      In 2.x the <iron-input> is distributed to paper-input-container, which styles
      it, but in order for this to work correctly, we need to reset some
      of the native input's properties to inherit (from the iron-input) */
      iron-input > input {
        @apply --paper-input-container-shared-input-style;
        font-family: inherit;
        font-weight: inherit;
        font-size: inherit;
        letter-spacing: inherit;
        word-spacing: inherit;
        line-height: inherit;
        text-shadow: inherit;
        color: inherit;
        cursor: inherit;
      }

      input:disabled {
        @apply --paper-input-container-input-disabled;
      }

      input::-webkit-outer-spin-button,
      input::-webkit-inner-spin-button {
        @apply --paper-input-container-input-webkit-spinner;
      }

      input::-webkit-clear-button {
        @apply --paper-input-container-input-webkit-clear;
      }

      input::-webkit-calendar-picker-indicator {
        @apply --paper-input-container-input-webkit-calendar-picker-indicator;
      }

      input::-webkit-input-placeholder {
        color: var(--paper-input-container-color, var(--secondary-text-color));
      }

      input:-moz-placeholder {
        color: var(--paper-input-container-color, var(--secondary-text-color));
      }

      input::-moz-placeholder {
        color: var(--paper-input-container-color, var(--secondary-text-color));
      }

      input::-ms-clear {
        @apply --paper-input-container-ms-clear;
      }

      input::-ms-reveal {
        @apply --paper-input-container-ms-reveal;
      }

      input:-ms-input-placeholder {
        color: var(--paper-input-container-color, var(--secondary-text-color));
      }

      label {
        pointer-events: none;
      }
    </style>

    <paper-input-container id="container" no-label-float="[[noLabelFloat]]" always-float-label="[[_computeAlwaysFloatLabel(alwaysFloatLabel,placeholder)]]" auto-validate$="[[autoValidate]]" disabled$="[[disabled]]" invalid="[[invalid]]">

      <slot name="prefix" slot="prefix"></slot>

      <label hidden$="[[!label]]" aria-hidden="true" for$="[[_inputId]]" slot="label">[[label]]</label>

      <!-- Need to bind maxlength so that the paper-input-char-counter works correctly -->
      <iron-input bind-value="{{value}}" slot="input" class="input-element" id$="[[_inputId]]" maxlength$="[[maxlength]]" allowed-pattern="[[allowedPattern]]" invalid="{{invalid}}" validator="[[validator]]">
        <input aria-labelledby$="[[_ariaLabelledBy]]" aria-describedby$="[[_ariaDescribedBy]]" disabled$="[[disabled]]" title$="[[title]]" type$="[[type]]" pattern$="[[pattern]]" required$="[[required]]" autocomplete$="[[autocomplete]]" autofocus$="[[autofocus]]" inputmode$="[[inputmode]]" minlength$="[[minlength]]" maxlength$="[[maxlength]]" min$="[[min]]" max$="[[max]]" step$="[[step]]" name$="[[name]]" placeholder$="[[placeholder]]" readonly$="[[readonly]]" list$="[[list]]" size$="[[size]]" autocapitalize$="[[autocapitalize]]" autocorrect$="[[autocorrect]]" on-change="_onChange" tabindex$="[[tabIndex]]" autosave$="[[autosave]]" results$="[[results]]" accept$="[[accept]]" multiple$="[[multiple]]">
      </iron-input>

      <slot name="suffix" slot="suffix"></slot>

      <template is="dom-if" if="[[errorMessage]]">
        <paper-input-error aria-live="assertive" slot="add-on">[[errorMessage]]</paper-input-error>
      </template>

      <template is="dom-if" if="[[charCounter]]">
        <paper-input-char-counter slot="add-on"></paper-input-char-counter>
      </template>

    </paper-input-container>
  `,behaviors:[a.d0,n.V],properties:{value:{type:String}},get _focusableElement(){return this.inputElement._inputElement},listeners:{"iron-input-ready":"_onIronInputReady"},_onIronInputReady:function(){this.$.nativeInput||(this.$.nativeInput=this.$$("input")),this.inputElement&&-1!==this._typesThatHaveText.indexOf(this.$.nativeInput.type)&&(this.alwaysFloatLabel=!0),this.inputElement.bindValue&&this.$.container._handleValueAndAutoValidate(this.inputElement)}})},54242:(e,t,r)=>{"use strict";r(43437);const n=r(50856).d`
<custom-style>
  <style is="custom-style">
    html {

      --shadow-transition: {
        transition: box-shadow 0.28s cubic-bezier(0.4, 0, 0.2, 1);
      };

      --shadow-none: {
        box-shadow: none;
      };

      /* from http://codepen.io/shyndman/pen/c5394ddf2e8b2a5c9185904b57421cdb */

      --shadow-elevation-2dp: {
        box-shadow: 0 2px 2px 0 rgba(0, 0, 0, 0.14),
                    0 1px 5px 0 rgba(0, 0, 0, 0.12),
                    0 3px 1px -2px rgba(0, 0, 0, 0.2);
      };

      --shadow-elevation-3dp: {
        box-shadow: 0 3px 4px 0 rgba(0, 0, 0, 0.14),
                    0 1px 8px 0 rgba(0, 0, 0, 0.12),
                    0 3px 3px -2px rgba(0, 0, 0, 0.4);
      };

      --shadow-elevation-4dp: {
        box-shadow: 0 4px 5px 0 rgba(0, 0, 0, 0.14),
                    0 1px 10px 0 rgba(0, 0, 0, 0.12),
                    0 2px 4px -1px rgba(0, 0, 0, 0.4);
      };

      --shadow-elevation-6dp: {
        box-shadow: 0 6px 10px 0 rgba(0, 0, 0, 0.14),
                    0 1px 18px 0 rgba(0, 0, 0, 0.12),
                    0 3px 5px -1px rgba(0, 0, 0, 0.4);
      };

      --shadow-elevation-8dp: {
        box-shadow: 0 8px 10px 1px rgba(0, 0, 0, 0.14),
                    0 3px 14px 2px rgba(0, 0, 0, 0.12),
                    0 5px 5px -3px rgba(0, 0, 0, 0.4);
      };

      --shadow-elevation-12dp: {
        box-shadow: 0 12px 16px 1px rgba(0, 0, 0, 0.14),
                    0 4px 22px 3px rgba(0, 0, 0, 0.12),
                    0 6px 7px -4px rgba(0, 0, 0, 0.4);
      };

      --shadow-elevation-16dp: {
        box-shadow: 0 16px 24px 2px rgba(0, 0, 0, 0.14),
                    0  6px 30px 5px rgba(0, 0, 0, 0.12),
                    0  8px 10px -5px rgba(0, 0, 0, 0.4);
      };

      --shadow-elevation-24dp: {
        box-shadow: 0 24px 38px 3px rgba(0, 0, 0, 0.14),
                    0 9px 46px 8px rgba(0, 0, 0, 0.12),
                    0 11px 15px -7px rgba(0, 0, 0, 0.4);
      };
    }
  </style>
</custom-style>`;n.setAttribute("style","display: none;"),document.head.appendChild(n.content)},70019:(e,t,r)=>{"use strict";r(43437);const n=r(50856).d`<custom-style>
  <style is="custom-style">
    html {

      /* Shared Styles */
      --paper-font-common-base: {
        font-family: 'Roboto', 'Noto', sans-serif;
        -webkit-font-smoothing: antialiased;
      };

      --paper-font-common-code: {
        font-family: 'Roboto Mono', 'Consolas', 'Menlo', monospace;
        -webkit-font-smoothing: antialiased;
      };

      --paper-font-common-expensive-kerning: {
        text-rendering: optimizeLegibility;
      };

      --paper-font-common-nowrap: {
        white-space: nowrap;
        overflow: hidden;
        text-overflow: ellipsis;
      };

      /* Material Font Styles */

      --paper-font-display4: {
        @apply --paper-font-common-base;
        @apply --paper-font-common-nowrap;

        font-size: 112px;
        font-weight: 300;
        letter-spacing: -.044em;
        line-height: 120px;
      };

      --paper-font-display3: {
        @apply --paper-font-common-base;
        @apply --paper-font-common-nowrap;

        font-size: 56px;
        font-weight: 400;
        letter-spacing: -.026em;
        line-height: 60px;
      };

      --paper-font-display2: {
        @apply --paper-font-common-base;

        font-size: 45px;
        font-weight: 400;
        letter-spacing: -.018em;
        line-height: 48px;
      };

      --paper-font-display1: {
        @apply --paper-font-common-base;

        font-size: 34px;
        font-weight: 400;
        letter-spacing: -.01em;
        line-height: 40px;
      };

      --paper-font-headline: {
        @apply --paper-font-common-base;

        font-size: 24px;
        font-weight: 400;
        letter-spacing: -.012em;
        line-height: 32px;
      };

      --paper-font-title: {
        @apply --paper-font-common-base;
        @apply --paper-font-common-nowrap;

        font-size: 20px;
        font-weight: 500;
        line-height: 28px;
      };

      --paper-font-subhead: {
        @apply --paper-font-common-base;

        font-size: 16px;
        font-weight: 400;
        line-height: 24px;
      };

      --paper-font-body2: {
        @apply --paper-font-common-base;

        font-size: 14px;
        font-weight: 500;
        line-height: 24px;
      };

      --paper-font-body1: {
        @apply --paper-font-common-base;

        font-size: 14px;
        font-weight: 400;
        line-height: 20px;
      };

      --paper-font-caption: {
        @apply --paper-font-common-base;
        @apply --paper-font-common-nowrap;

        font-size: 12px;
        font-weight: 400;
        letter-spacing: 0.011em;
        line-height: 20px;
      };

      --paper-font-menu: {
        @apply --paper-font-common-base;
        @apply --paper-font-common-nowrap;

        font-size: 13px;
        font-weight: 500;
        line-height: 24px;
      };

      --paper-font-button: {
        @apply --paper-font-common-base;
        @apply --paper-font-common-nowrap;

        font-size: 14px;
        font-weight: 500;
        letter-spacing: 0.018em;
        line-height: 24px;
        text-transform: uppercase;
      };

      --paper-font-code2: {
        @apply --paper-font-common-code;

        font-size: 14px;
        font-weight: 700;
        line-height: 20px;
      };

      --paper-font-code1: {
        @apply --paper-font-common-code;

        font-size: 14px;
        font-weight: 500;
        line-height: 20px;
      };

    }

  </style>
</custom-style>`;n.setAttribute("style","display: none;"),document.head.appendChild(n.content)},5618:(e,t,r)=>{"use strict";var n=r(34816),i=r(10868),o=r(26539);const a=new n.ZP;window.ShadyCSS||(window.ShadyCSS={prepareTemplate(e,t,r){},prepareTemplateDom(e,t){},prepareTemplateStyles(e,t,r){},styleSubtree(e,t){a.processStyles(),(0,i.wW)(e,t)},styleElement(e){a.processStyles()},styleDocument(e){a.processStyles(),(0,i.wW)(document.body,e)},getComputedStyleValue:(e,t)=>(0,i.B7)(e,t),flushCustomStyles(){},nativeCss:o.rd,nativeShadow:o.WA,cssBuild:o.Cp,disableRuntime:o.jF}),window.ShadyCSS.CustomStyleInterface=a;var s=r(15392);const l="include",c=window.ShadyCSS.CustomStyleInterface;class d extends HTMLElement{constructor(){super(),this._style=null,c.addCustomStyle(this)}getStyle(){if(this._style)return this._style;const e=this.querySelector("style");if(!e)return null;this._style=e;const t=e.getAttribute(l);return t&&(e.removeAttribute(l),e.textContent=(0,s.jv)(t)+e.textContent),this.ownerDocument!==window.document&&window.document.head.appendChild(this),this._style}}window.customElements.define("custom-style",d)},26047:(e,t,r)=>{"use strict";var n=r(28426),i=r(52521),o=r(78956),a=r(93252),s=r(21683),l=r(4059);class c extends n.H3{static get is(){return"dom-if"}static get template(){return null}static get properties(){return{if:{type:Boolean,observer:"__debounceRender"},restamp:{type:Boolean,observer:"__debounceRender"}}}constructor(){super(),this.__renderDebouncer=null,this.__invalidProps=null,this.__instance=null,this._lastIf=!1,this.__ctor=null,this.__hideTemplateChildren__=!1}__debounceRender(){this.__renderDebouncer=o.d.debounce(this.__renderDebouncer,s.YA,(()=>this.__render())),(0,a.E)(this.__renderDebouncer)}disconnectedCallback(){super.disconnectedCallback(),this.parentNode&&(this.parentNode.nodeType!=Node.DOCUMENT_FRAGMENT_NODE||this.parentNode.host)||this.__teardownInstance()}connectedCallback(){super.connectedCallback(),this.style.display="none",this.if&&this.__debounceRender()}render(){(0,a.y)()}__render(){if(this.if){if(!this.__ensureInstance())return;this._showHideChildren()}else this.restamp&&this.__teardownInstance();!this.restamp&&this.__instance&&this._showHideChildren(),this.if!=this._lastIf&&(this.dispatchEvent(new CustomEvent("dom-change",{bubbles:!0,composed:!0})),this._lastIf=this.if)}__ensureInstance(){let e=this.parentNode;if(e){if(!this.__ctor){let e=this.querySelector("template");if(!e){let e=new MutationObserver((()=>{if(!this.querySelector("template"))throw new Error("dom-if requires a <template> child");e.disconnect(),this.__render()}));return e.observe(this,{childList:!0}),!1}this.__ctor=(0,i.Uv)(e,this,{mutableData:!0,forwardHostProp:function(e,t){this.__instance&&(this.if?this.__instance.forwardHostProp(e,t):(this.__invalidProps=this.__invalidProps||Object.create(null),this.__invalidProps[(0,l.Jz)(e)]=!0))}})}if(this.__instance){this.__syncHostProperties();let t=this.__instance.children;if(t&&t.length){if(this.previousSibling!==t[t.length-1])for(let r,n=0;n<t.length&&(r=t[n]);n++)e.insertBefore(r,this)}}else this.__instance=new this.__ctor,e.insertBefore(this.__instance.root,this)}return!0}__syncHostProperties(){let e=this.__invalidProps;if(e){for(let t in e)this.__instance._setPendingProperty(t,this.__dataHost[t]);this.__invalidProps=null,this.__instance._flushProperties()}}__teardownInstance(){if(this.__instance){let e=this.__instance.children;if(e&&e.length){let t=e[0].parentNode;if(t)for(let r,n=0;n<e.length&&(r=e[n]);n++)t.removeChild(r)}this.__instance=null,this.__invalidProps=null}}_showHideChildren(){let e=this.__hideTemplateChildren__||!this.if;this.__instance&&this.__instance._showHideChildren(e)}}customElements.define(c.is,c)},21384:(e,t,r)=>{"use strict";r.d(t,{t:()=>c});r(56646);var n=r(42687),i=r(74460);let o={},a={};function s(e,t){o[e]=a[e.toLowerCase()]=t}function l(e){return o[e]||a[e.toLowerCase()]}class c extends HTMLElement{static get observedAttributes(){return["id"]}static import(e,t){if(e){let r=l(e);return r&&t?r.querySelector(t):r}return null}attributeChangedCallback(e,t,r,n){t!==r&&this.register()}get assetpath(){if(!this.__assetpath){const e=window.HTMLImports&&HTMLImports.importForElement?HTMLImports.importForElement(this)||document:this.ownerDocument,t=(0,n.Kk)(this.getAttribute("assetpath")||"",e.baseURI);this.__assetpath=(0,n.iY)(t)}return this.__assetpath}register(e){if(e=e||this.id){if(i.XN&&void 0!==l(e))throw s(e,null),new Error(`strictTemplatePolicy: dom-module ${e} re-registered`);this.id=e,s(e,this),(t=this).querySelector("style")&&console.warn("dom-module %s has style outside template",t.id)}var t}}c.prototype.modules=o,customElements.define("dom-module",c)},42173:(e,t,r)=>{"use strict";var n=r(28426),i=r(52521),o=r(78956),a=r(93252),s=r(18691),l=r(4059),c=r(21683);const d=(0,s.w)(n.H3);class u extends d{static get is(){return"dom-repeat"}static get template(){return null}static get properties(){return{items:{type:Array},as:{type:String,value:"item"},indexAs:{type:String,value:"index"},itemsIndexAs:{type:String,value:"itemsIndex"},sort:{type:Function,observer:"__sortChanged"},filter:{type:Function,observer:"__filterChanged"},observe:{type:String,observer:"__observeChanged"},delay:Number,renderedItemCount:{type:Number,notify:!0,readOnly:!0},initialCount:{type:Number,observer:"__initializeChunking"},targetFramerate:{type:Number,value:20},_targetFrameTime:{type:Number,computed:"__computeFrameTime(targetFramerate)"}}}static get observers(){return["__itemsChanged(items.*)"]}constructor(){super(),this.__instances=[],this.__limit=1/0,this.__pool=[],this.__renderDebouncer=null,this.__itemsIdxToInstIdx={},this.__chunkCount=null,this.__lastChunkTime=null,this.__sortFn=null,this.__filterFn=null,this.__observePaths=null,this.__ctor=null,this.__isDetached=!0,this.template=null}disconnectedCallback(){super.disconnectedCallback(),this.__isDetached=!0;for(let e=0;e<this.__instances.length;e++)this.__detachInstance(e)}connectedCallback(){if(super.connectedCallback(),this.style.display="none",this.__isDetached){this.__isDetached=!1;let e=this.parentNode;for(let t=0;t<this.__instances.length;t++)this.__attachInstance(t,e)}}__ensureTemplatized(){if(!this.__ctor){let e=this.template=this.querySelector("template");if(!e){let e=new MutationObserver((()=>{if(!this.querySelector("template"))throw new Error("dom-repeat requires a <template> child");e.disconnect(),this.__render()}));return e.observe(this,{childList:!0}),!1}let t={};t[this.as]=!0,t[this.indexAs]=!0,t[this.itemsIndexAs]=!0,this.__ctor=(0,i.Uv)(e,this,{mutableData:this.mutableData,parentModel:!0,instanceProps:t,forwardHostProp:function(e,t){let r=this.__instances;for(let n,i=0;i<r.length&&(n=r[i]);i++)n.forwardHostProp(e,t)},notifyInstanceProp:function(e,t,r){if((0,l.wB)(this.as,t)){let n=e[this.itemsIndexAs];t==this.as&&(this.items[n]=r);let i=(0,l.Iu)(this.as,"items."+n,t);this.notifyPath(i,r)}}})}return!0}__getMethodHost(){return this.__dataHost._methodHost||this.__dataHost}__functionFromPropertyValue(e){if("string"==typeof e){let t=e,r=this.__getMethodHost();return function(){return r[t].apply(r,arguments)}}return e}__sortChanged(e){this.__sortFn=this.__functionFromPropertyValue(e),this.items&&this.__debounceRender(this.__render)}__filterChanged(e){this.__filterFn=this.__functionFromPropertyValue(e),this.items&&this.__debounceRender(this.__render)}__computeFrameTime(e){return Math.ceil(1e3/e)}__initializeChunking(){this.initialCount&&(this.__limit=this.initialCount,this.__chunkCount=this.initialCount,this.__lastChunkTime=performance.now())}__tryRenderChunk(){this.items&&this.__limit<this.items.length&&this.__debounceRender(this.__requestRenderChunk)}__requestRenderChunk(){requestAnimationFrame((()=>this.__renderChunk()))}__renderChunk(){let e=performance.now(),t=this._targetFrameTime/(e-this.__lastChunkTime);this.__chunkCount=Math.round(this.__chunkCount*t)||1,this.__limit+=this.__chunkCount,this.__lastChunkTime=e,this.__debounceRender(this.__render)}__observeChanged(){this.__observePaths=this.observe&&this.observe.replace(".*",".").split(" ")}__itemsChanged(e){this.items&&!Array.isArray(this.items)&&console.warn("dom-repeat expected array for `items`, found",this.items),this.__handleItemPath(e.path,e.value)||(this.__initializeChunking(),this.__debounceRender(this.__render))}__handleObservedPaths(e){if(this.__sortFn||this.__filterFn)if(e){if(this.__observePaths){let t=this.__observePaths;for(let r=0;r<t.length;r++)0===e.indexOf(t[r])&&this.__debounceRender(this.__render,this.delay)}}else this.__debounceRender(this.__render,this.delay)}__debounceRender(e,t=0){this.__renderDebouncer=o.d.debounce(this.__renderDebouncer,t>0?c.Wc.after(t):c.YA,e.bind(this)),(0,a.E)(this.__renderDebouncer)}render(){this.__debounceRender(this.__render),(0,a.y)()}__render(){this.__ensureTemplatized()&&(this.__applyFullRefresh(),this.__pool.length=0,this._setRenderedItemCount(this.__instances.length),this.dispatchEvent(new CustomEvent("dom-change",{bubbles:!0,composed:!0})),this.__tryRenderChunk())}__applyFullRefresh(){let e=this.items||[],t=new Array(e.length);for(let r=0;r<e.length;r++)t[r]=r;this.__filterFn&&(t=t.filter(((t,r,n)=>this.__filterFn(e[t],r,n)))),this.__sortFn&&t.sort(((t,r)=>this.__sortFn(e[t],e[r])));const r=this.__itemsIdxToInstIdx={};let n=0;const i=Math.min(t.length,this.__limit);for(;n<i;n++){let i=this.__instances[n],o=t[n],a=e[o];r[o]=n,i?(i._setPendingProperty(this.as,a),i._setPendingProperty(this.indexAs,n),i._setPendingProperty(this.itemsIndexAs,o),i._flushProperties()):this.__insertInstance(a,n,o)}for(let e=this.__instances.length-1;e>=n;e--)this.__detachAndRemoveInstance(e)}__detachInstance(e){let t=this.__instances[e];for(let e=0;e<t.children.length;e++){let r=t.children[e];t.root.appendChild(r)}return t}__attachInstance(e,t){let r=this.__instances[e];t.insertBefore(r.root,this)}__detachAndRemoveInstance(e){let t=this.__detachInstance(e);t&&this.__pool.push(t),this.__instances.splice(e,1)}__stampInstance(e,t,r){let n={};return n[this.as]=e,n[this.indexAs]=t,n[this.itemsIndexAs]=r,new this.__ctor(n)}__insertInstance(e,t,r){let n=this.__pool.pop();n?(n._setPendingProperty(this.as,e),n._setPendingProperty(this.indexAs,t),n._setPendingProperty(this.itemsIndexAs,r),n._flushProperties()):n=this.__stampInstance(e,t,r);let i=this.__instances[t+1],o=i?i.children[0]:this;return this.parentNode.insertBefore(n.root,o),this.__instances[t]=n,n}_showHideChildren(e){for(let t=0;t<this.__instances.length;t++)this.__instances[t]._showHideChildren(e)}__handleItemPath(e,t){let r=e.slice(6),n=r.indexOf("."),i=n<0?r:r.substring(0,n);if(i==parseInt(i,10)){let e=n<0?"":r.substring(n+1);this.__handleObservedPaths(e);let o=this.__itemsIdxToInstIdx[i],a=this.__instances[o];if(a){let r=this.as+(e?"."+e:"");a._setPendingPropertyOrPath(r,t,!1,!0),a._flushProperties()}return!0}}itemForElement(e){let t=this.modelForElement(e);return t&&t[this.as]}indexForElement(e){let t=this.modelForElement(e);return t&&t[this.indexAs]}modelForElement(e){return(0,i.GJ)(this.template,e)}}customElements.define(u.is,u)},33367:(e,t,r)=>{"use strict";r.d(t,{P:()=>o,w:()=>c});var n=r(81850);let i={attached:!0,detached:!0,ready:!0,created:!0,beforeRegister:!0,registered:!0,attributeChanged:!0,behaviors:!0};function o(e,t){if(!e)return t=t;t=(0,n.x)(t),Array.isArray(e)||(e=[e]);let r=t.prototype.behaviors;return t=a(e=s(e,null,r),t),r&&(e=r.concat(e)),t.prototype.behaviors=e,t}function a(e,t){for(let r=0;r<e.length;r++){let n=e[r];n&&(t=Array.isArray(n)?a(n,t):l(n,t))}return t}function s(e,t,r){t=t||[];for(let n=e.length-1;n>=0;n--){let i=e[n];i?Array.isArray(i)?s(i,t):t.indexOf(i)<0&&(!r||r.indexOf(i)<0)&&t.unshift(i):console.warn("behavior is null, check for missing or 404 import")}return t}function l(e,t){class r extends t{static get properties(){return e.properties}static get observers(){return e.observers}created(){super.created(),e.created&&e.created.call(this)}_registered(){super._registered(),e.beforeRegister&&e.beforeRegister.call(Object.getPrototypeOf(this)),e.registered&&e.registered.call(Object.getPrototypeOf(this))}_applyListeners(){if(super._applyListeners(),e.listeners)for(let t in e.listeners)this._addMethodEventListenerToNode(this,t,e.listeners[t])}_ensureAttributes(){if(e.hostAttributes)for(let t in e.hostAttributes)this._ensureAttribute(t,e.hostAttributes[t]);super._ensureAttributes()}ready(){super.ready(),e.ready&&e.ready.call(this)}attached(){super.attached(),e.attached&&e.attached.call(this)}detached(){super.detached(),e.detached&&e.detached.call(this)}attributeChanged(t,r,n){super.attributeChanged(t,r,n),e.attributeChanged&&e.attributeChanged.call(this,t,r,n)}}r.generatedFrom=e;for(let t in e)if(!(t in i)){let n=Object.getOwnPropertyDescriptor(e,t);n&&Object.defineProperty(r.prototype,t,n)}return r}const c=function(e,t){e||console.warn("Polymer's Class function requires `info` argument");const r=e.behaviors?o(e.behaviors,HTMLElement):(0,n.x)(HTMLElement),i=l(e,t?t(r):r);return i.is=e.is,i}},81850:(e,t,r)=>{"use strict";r.d(t,{x:()=>he});var n=r(26539);class i{constructor(){this.start=0,this.end=0,this.previous=null,this.parent=null,this.rules=null,this.parsedCssText="",this.cssText="",this.atRule=!1,this.type=0,this.keyframesName="",this.selector="",this.parsedSelector=""}}function o(e){return a(function(e){let t=new i;t.start=0,t.end=e.length;let r=t;for(let n=0,o=e.length;n<o;n++)if(e[n]===c){r.rules||(r.rules=[]);let e=r,t=e.rules[e.rules.length-1]||null;r=new i,r.start=n+1,r.parent=e,r.previous=t,e.rules.push(r)}else e[n]===d&&(r.end=n+1,r=r.parent||t);return t}(e=e.replace(u.comments,"").replace(u.port,"")),e)}function a(e,t){let r=t.substring(e.start,e.end-1);if(e.parsedCssText=e.cssText=r.trim(),e.parent){let n=e.previous?e.previous.end:e.parent.start;r=t.substring(n,e.start-1),r=function(e){return e.replace(/\\([0-9a-f]{1,6})\s/gi,(function(){let e=arguments[1],t=6-e.length;for(;t--;)e="0"+e;return"\\"+e}))}(r),r=r.replace(u.multipleSpaces," "),r=r.substring(r.lastIndexOf(";")+1);let i=e.parsedSelector=e.selector=r.trim();e.atRule=0===i.indexOf(f),e.atRule?0===i.indexOf(h)?e.type=l.MEDIA_RULE:i.match(u.keyframesRule)&&(e.type=l.KEYFRAMES_RULE,e.keyframesName=e.selector.split(u.multipleSpaces).pop()):0===i.indexOf(p)?e.type=l.MIXIN_RULE:e.type=l.STYLE_RULE}let n=e.rules;if(n)for(let e,r=0,i=n.length;r<i&&(e=n[r]);r++)a(e,t);return e}function s(e,t,r=""){let n="";if(e.cssText||e.rules){let r=e.rules;if(r&&!function(e){let t=e[0];return Boolean(t)&&Boolean(t.selector)&&0===t.selector.indexOf(p)}(r))for(let e,i=0,o=r.length;i<o&&(e=r[i]);i++)n=s(e,t,n);else n=t?e.cssText:function(e){return function(e){return e.replace(u.mixinApply,"").replace(u.varApply,"")}(e=function(e){return e.replace(u.customProp,"").replace(u.mixinProp,"")}(e))}(e.cssText),n=n.trim(),n&&(n="  "+n+"\n")}return n&&(e.selector&&(r+=e.selector+" "+c+"\n"),r+=n,e.selector&&(r+=d+"\n\n")),r}const l={STYLE_RULE:1,KEYFRAMES_RULE:7,MEDIA_RULE:4,MIXIN_RULE:1e3},c="{",d="}",u={comments:/\/\*[^*]*\*+([^/*][^*]*\*+)*\//gim,port:/@import[^;]*;/gim,customProp:/(?:^[^;\-\s}]+)?--[^;{}]*?:[^{};]*?(?:[;\n]|$)/gim,mixinProp:/(?:^[^;\-\s}]+)?--[^;{}]*?:[^{};]*?{[^}]*?}(?:[;\n]|$)?/gim,mixinApply:/@apply\s*\(?[^);]*\)?\s*(?:[;\n]|$)?/gim,varApply:/[^;:]*?:[^;]*?var\([^;]*\)(?:[;\n]|$)?/gim,keyframesRule:/^@[^\s]*keyframes/,multipleSpaces:/\s+/g},p="--",h="@media",f="@";var m=r(60309);const y=new Set;function g(e){const t=e.textContent;if(!y.has(t)){y.add(t);const r=e.cloneNode(!0);document.head.appendChild(r)}}function b(e){return e.hasAttribute("shady-unscoped")}function _(e,t){return e?("string"==typeof e&&(e=o(e)),t&&w(e,t),s(e,n.rd)):""}function v(e){return!e.__cssRules&&e.textContent&&(e.__cssRules=o(e.textContent)),e.__cssRules||null}function w(e,t,r,n){if(!e)return;let i=!1,o=e.type;if(n&&o===l.MEDIA_RULE){let t=e.selector.match(m.mA);t&&(window.matchMedia(t[1]).matches||(i=!0))}o===l.STYLE_RULE?t(e):r&&o===l.KEYFRAMES_RULE?r(e):o===l.MIXIN_RULE&&(i=!0);let a=e.rules;if(a&&!i)for(let e,i=0,o=a.length;i<o&&(e=a[i]);i++)w(e,t,r,n)}function x(e,t){let r=0;for(let n=t,i=e.length;n<i;n++)if("("===e[n])r++;else if(")"===e[n]&&0==--r)return n;return-1}function k(e,t){let r=e.indexOf("var(");if(-1===r)return t(e,"","","");let n=x(e,r+3),i=e.substring(r+4,n),o=e.substring(0,r),a=k(e.substring(n+1),t),s=i.indexOf(",");return-1===s?t(o,i.trim(),"",a):t(o,i.substring(0,s).trim(),i.substring(s+1).trim(),a)}window.ShadyDOM&&window.ShadyDOM.wrap;const C="css-build";function E(e){if(void 0!==n.Cp)return n.Cp;if(void 0===e.__cssBuild){const t=e.getAttribute(C);if(t)e.__cssBuild=t;else{const t=function(e){const t="template"===e.localName?e.content.firstChild:e.firstChild;if(t instanceof Comment){const e=t.textContent.trim().split(":");if(e[0]===C)return e[1]}return""}(e);""!==t&&function(e){const t="template"===e.localName?e.content.firstChild:e.firstChild;t.parentNode.removeChild(t)}(e),e.__cssBuild=t}}return e.__cssBuild||""}function S(e){return""!==E(e)}var P=r(10868);const A=/;\s*/m,T=/^\s*(initial)|(inherit)\s*$/,O=/\s*!important/,N="_-_";class I{constructor(){this._map={}}set(e,t){e=e.trim(),this._map[e]={properties:t,dependants:{}}}get(e){return e=e.trim(),this._map[e]||null}}let R=null;class D{constructor(){this._currentElement=null,this._measureElement=null,this._map=new I}detectMixin(e){return(0,P.OH)(e)}gatherStyles(e){const t=function(e){const t=[],r=e.querySelectorAll("style");for(let e=0;e<r.length;e++){const i=r[e];b(i)?n.WA||(g(i),i.parentNode.removeChild(i)):(t.push(i.textContent),i.parentNode.removeChild(i))}return t.join("").trim()}(e.content);if(t){const r=document.createElement("style");return r.textContent=t,e.content.insertBefore(r,e.content.firstChild),r}return null}transformTemplate(e,t){void 0===e._gatheredStyle&&(e._gatheredStyle=this.gatherStyles(e));const r=e._gatheredStyle;return r?this.transformStyle(r,t):null}transformStyle(e,t=""){let r=v(e);return this.transformRules(r,t),e.textContent=_(r),r}transformCustomStyle(e){let t=v(e);return w(t,(e=>{":root"===e.selector&&(e.selector="html"),this.transformRule(e)})),e.textContent=_(t),t}transformRules(e,t){this._currentElement=t,w(e,(e=>{this.transformRule(e)})),this._currentElement=null}transformRule(e){e.cssText=this.transformCssText(e.parsedCssText,e),":root"===e.selector&&(e.selector=":host > *")}transformCssText(e,t){return e=e.replace(m.CN,((e,r,n,i)=>this._produceCssProperties(e,r,n,i,t))),this._consumeCssProperties(e,t)}_getInitialValueForProperty(e){return this._measureElement||(this._measureElement=document.createElement("meta"),this._measureElement.setAttribute("apply-shim-measure",""),this._measureElement.style.all="initial",document.head.appendChild(this._measureElement)),window.getComputedStyle(this._measureElement).getPropertyValue(e)}_fallbacksFromPreviousRules(e){let t=e;for(;t.parent;)t=t.parent;const r={};let n=!1;return w(t,(t=>{n=n||t===e,n||t.selector===e.selector&&Object.assign(r,this._cssTextToMap(t.parsedCssText))})),r}_consumeCssProperties(e,t){let r=null;for(;r=m.$T.exec(e);){let n=r[0],i=r[1],o=r.index,a=o+n.indexOf("@apply"),s=o+n.length,l=e.slice(0,a),c=e.slice(s),d=t?this._fallbacksFromPreviousRules(t):{};Object.assign(d,this._cssTextToMap(l));let u=this._atApplyToCssProperties(i,d);e=`${l}${u}${c}`,m.$T.lastIndex=o+u.length}return e}_atApplyToCssProperties(e,t){e=e.replace(A,"");let r=[],n=this._map.get(e);if(n||(this._map.set(e,{}),n=this._map.get(e)),n){let i,o,a;this._currentElement&&(n.dependants[this._currentElement]=!0);const s=n.properties;for(i in s)a=t&&t[i],o=[i,": var(",e,N,i],a&&o.push(",",a.replace(O,"")),o.push(")"),O.test(s[i])&&o.push(" !important"),r.push(o.join(""))}return r.join("; ")}_replaceInitialOrInherit(e,t){let r=T.exec(t);return r&&(t=r[1]?this._getInitialValueForProperty(e):"apply-shim-inherit"),t}_cssTextToMap(e,t=!1){let r,n,i=e.split(";"),o={};for(let e,a,s=0;s<i.length;s++)e=i[s],e&&(a=e.split(":"),a.length>1&&(r=a[0].trim(),n=a.slice(1).join(":"),t&&(n=this._replaceInitialOrInherit(r,n)),o[r]=n));return o}_invalidateMixinEntry(e){if(R)for(let t in e.dependants)t!==this._currentElement&&R(t)}_produceCssProperties(e,t,r,n,i){if(r&&k(r,((e,t)=>{t&&this._map.get(t)&&(n=`@apply ${t};`)})),!n)return e;let o=this._consumeCssProperties(""+n,i),a=e.slice(0,e.indexOf("--")),s=this._cssTextToMap(o,!0),l=s,c=this._map.get(t),d=c&&c.properties;d?l=Object.assign(Object.create(d),s):this._map.set(t,l);let u,p,h=[],f=!1;for(u in l)p=s[u],void 0===p&&(p="initial"),d&&!(u in d)&&(f=!0),h.push(`${t}_-_${u}: ${p}`);return f&&this._invalidateMixinEntry(c),c&&(c.properties=l),r&&(a=`${e};${a}`),`${a}${h.join("; ")};`}}D.prototype.detectMixin=D.prototype.detectMixin,D.prototype.transformStyle=D.prototype.transformStyle,D.prototype.transformCustomStyle=D.prototype.transformCustomStyle,D.prototype.transformRules=D.prototype.transformRules,D.prototype.transformRule=D.prototype.transformRule,D.prototype.transformTemplate=D.prototype.transformTemplate,D.prototype._separator=N,Object.defineProperty(D.prototype,"invalidCallback",{get:()=>R,set(e){R=e}});const z=D,F={},L="_applyShimCurrentVersion",M="_applyShimNextVersion",j="_applyShimValidatingVersion",H=Promise.resolve();function B(e){let t=F[e];t&&function(e){e[L]=e[L]||0,e[j]=e[j]||0,e[M]=(e[M]||0)+1}(t)}function $(e){return e[L]===e[M]}function V(e){return!$(e)&&e[j]===e[M]}function U(e){e[j]=e[M],e._validating||(e._validating=!0,H.then((function(){e[L]=e[M],e._validating=!1})))}r(34816);const q=new z;class K{constructor(){this.customStyleInterface=null,q.invalidCallback=B}ensure(){this.customStyleInterface||window.ShadyCSS.CustomStyleInterface&&(this.customStyleInterface=window.ShadyCSS.CustomStyleInterface,this.customStyleInterface.transformCallback=e=>{q.transformCustomStyle(e)},this.customStyleInterface.validateCallback=()=>{requestAnimationFrame((()=>{this.customStyleInterface.enqueued&&this.flushCustomStyles()}))})}prepareTemplate(e,t){if(this.ensure(),S(e))return;F[t]=e;let r=q.transformTemplate(e,t);e._styleAst=r}flushCustomStyles(){if(this.ensure(),!this.customStyleInterface)return;let e=this.customStyleInterface.processStyles();if(this.customStyleInterface.enqueued){for(let t=0;t<e.length;t++){let r=e[t],n=this.customStyleInterface.getStyleForCustomStyle(r);n&&q.transformCustomStyle(n)}this.customStyleInterface.enqueued=!1}}styleSubtree(e,t){if(this.ensure(),t&&(0,P.wW)(e,t),e.shadowRoot){this.styleElement(e);let t=e.shadowRoot.children||e.shadowRoot.childNodes;for(let e=0;e<t.length;e++)this.styleSubtree(t[e])}else{let t=e.children||e.childNodes;for(let e=0;e<t.length;e++)this.styleSubtree(t[e])}}styleElement(e){this.ensure();let{is:t}=function(e){let t=e.localName,r="",n="";return t?t.indexOf("-")>-1?r=t:(n=t,r=e.getAttribute&&e.getAttribute("is")||""):(r=e.is,n=e.extends),{is:r,typeExtension:n}}(e),r=F[t];if((!r||!S(r))&&r&&!$(r)){V(r)||(this.prepareTemplate(r,t),U(r));let n=e.shadowRoot;if(n){let e=n.querySelector("style");e&&(e.__cssRules=r._styleAst,e.textContent=_(r._styleAst))}}}styleDocument(e){this.ensure(),this.styleSubtree(document.body,e)}}if(!window.ShadyCSS||!window.ShadyCSS.ScopingShim){const e=new K;let t=window.ShadyCSS&&window.ShadyCSS.CustomStyleInterface;window.ShadyCSS={prepareTemplate(t,r,n){e.flushCustomStyles(),e.prepareTemplate(t,r)},prepareTemplateStyles(e,t,r){window.ShadyCSS.prepareTemplate(e,t,r)},prepareTemplateDom(e,t){},styleSubtree(t,r){e.flushCustomStyles(),e.styleSubtree(t,r)},styleElement(t){e.flushCustomStyles(),e.styleElement(t)},styleDocument(t){e.flushCustomStyles(),e.styleDocument(t)},getComputedStyleValue:(e,t)=>(0,P.B7)(e,t),flushCustomStyles(){e.flushCustomStyles()},nativeCss:n.rd,nativeShadow:n.WA,cssBuild:n.Cp,disableRuntime:n.jF},t&&(window.ShadyCSS.CustomStyleInterface=t)}window.ShadyCSS.ApplyShim=q;var Y=r(36608),J=r(60995),W=r(63933),G=r(76389);const X=/:host\(:dir\((ltr|rtl)\)\)/g,Z=/([\s\w-#\.\[\]\*]*):dir\((ltr|rtl)\)/g,Q=[];let ee=null,te="";function re(){te=document.documentElement.getAttribute("dir")}function ne(e){if(!e.__autoDirOptOut){e.setAttribute("dir",te)}}function ie(){re(),te=document.documentElement.getAttribute("dir");for(let e=0;e<Q.length;e++)ne(Q[e])}const oe=(0,G.o)((e=>{ee||(re(),ee=new MutationObserver(ie),ee.observe(document.documentElement,{attributes:!0,attributeFilter:["dir"]}));const t=(0,W.Q)(e);class r extends t{static _processStyleText(e,t){return e=super._processStyleText(e,t),e=this._replaceDirInCssText(e)}static _replaceDirInCssText(e){let t=e;return t=t.replace(X,':host([dir="$1"])'),t=t.replace(Z,':host([dir="$2"]) $1'),e!==t&&(this.__activateDir=!0),t}constructor(){super(),this.__autoDirOptOut=!1}ready(){super.ready(),this.__autoDirOptOut=this.hasAttribute("dir")}connectedCallback(){t.prototype.connectedCallback&&super.connectedCallback(),this.constructor.__activateDir&&(ee&&ee.takeRecords().length&&ie(),Q.push(this),ne(this))}disconnectedCallback(){if(t.prototype.disconnectedCallback&&super.disconnectedCallback(),this.constructor.__activateDir){const e=Q.indexOf(this);e>-1&&Q.splice(e,1)}}}return r.__activateDir=!1,r}));r(87529);function ae(){document.body.removeAttribute("unresolved")}"interactive"===document.readyState||"complete"===document.readyState?ae():window.addEventListener("DOMContentLoaded",ae);var se=r(87156),le=r(81668),ce=r(78956),de=r(21683),ue=r(4059);let pe=window.ShadyCSS;const he=(0,G.o)((e=>{const t=oe((0,J._)((0,Y.SH)(e))),r={x:"pan-x",y:"pan-y",none:"none",all:"auto"};class n extends t{constructor(){super(),this.isAttached,this.__boundListeners,this._debouncers,this._applyListeners()}static get importMeta(){return this.prototype.importMeta}created(){}connectedCallback(){super.connectedCallback(),this.isAttached=!0,this.attached()}attached(){}disconnectedCallback(){super.disconnectedCallback(),this.isAttached=!1,this.detached()}detached(){}attributeChangedCallback(e,t,r,n){t!==r&&(super.attributeChangedCallback(e,t,r,n),this.attributeChanged(e,t,r))}attributeChanged(e,t,r){}_initializeProperties(){let e=Object.getPrototypeOf(this);e.hasOwnProperty("__hasRegisterFinished")||(e.__hasRegisterFinished=!0,this._registered()),super._initializeProperties(),this.root=this,this.created()}_registered(){}ready(){this._ensureAttributes(),super.ready()}_ensureAttributes(){}_applyListeners(){}serialize(e){return this._serializeValue(e)}deserialize(e,t){return this._deserializeValue(e,t)}reflectPropertyToAttribute(e,t,r){this._propertyToAttribute(e,t,r)}serializeValueToAttribute(e,t,r){this._valueToNodeAttribute(r||this,e,t)}extend(e,t){if(!e||!t)return e||t;let r=Object.getOwnPropertyNames(t);for(let n,i=0;i<r.length&&(n=r[i]);i++){let r=Object.getOwnPropertyDescriptor(t,n);r&&Object.defineProperty(e,n,r)}return e}mixin(e,t){for(let r in t)e[r]=t[r];return e}chainObject(e,t){return e&&t&&e!==t&&(e.__proto__=t),e}instanceTemplate(e){let t=this.constructor._contentForTemplate(e);return document.importNode(t,!0)}fire(e,t,r){r=r||{},t=null==t?{}:t;let n=new Event(e,{bubbles:void 0===r.bubbles||r.bubbles,cancelable:Boolean(r.cancelable),composed:void 0===r.composed||r.composed});return n.detail=t,(r.node||this).dispatchEvent(n),n}listen(e,t,r){e=e||this;let n=this.__boundListeners||(this.__boundListeners=new WeakMap),i=n.get(e);i||(i={},n.set(e,i));let o=t+r;i[o]||(i[o]=this._addMethodEventListenerToNode(e,t,r,this))}unlisten(e,t,r){e=e||this;let n=this.__boundListeners&&this.__boundListeners.get(e),i=t+r,o=n&&n[i];o&&(this._removeEventListenerFromNode(e,t,o),n[i]=null)}setScrollDirection(e,t){(0,le.BP)(t||this,r[e]||"auto")}$$(e){return this.root.querySelector(e)}get domHost(){let e=this.getRootNode();return e instanceof DocumentFragment?e.host:e}distributeContent(){window.ShadyDOM&&this.shadowRoot&&ShadyDOM.flush()}getEffectiveChildNodes(){return(0,se.vz)(this).getEffectiveChildNodes()}queryDistributedElements(e){return(0,se.vz)(this).queryDistributedElements(e)}getEffectiveChildren(){return this.getEffectiveChildNodes().filter((function(e){return e.nodeType===Node.ELEMENT_NODE}))}getEffectiveTextContent(){let e=this.getEffectiveChildNodes(),t=[];for(let r,n=0;r=e[n];n++)r.nodeType!==Node.COMMENT_NODE&&t.push(r.textContent);return t.join("")}queryEffectiveChildren(e){let t=this.queryDistributedElements(e);return t&&t[0]}queryAllEffectiveChildren(e){return this.queryDistributedElements(e)}getContentChildNodes(e){let t=this.root.querySelector(e||"slot");return t?(0,se.vz)(t).getDistributedNodes():[]}getContentChildren(e){return this.getContentChildNodes(e).filter((function(e){return e.nodeType===Node.ELEMENT_NODE}))}isLightDescendant(e){const t=this;return t!==e&&t.contains(e)&&t.getRootNode()===e.getRootNode()}isLocalDescendant(e){return this.root===e.getRootNode()}scopeSubtree(e,t){}getComputedStyleValue(e){return pe.getComputedStyleValue(this,e)}debounce(e,t,r){return this._debouncers=this._debouncers||{},this._debouncers[e]=ce.d.debounce(this._debouncers[e],r>0?de.Wc.after(r):de.YA,t.bind(this))}isDebouncerActive(e){this._debouncers=this._debouncers||{};let t=this._debouncers[e];return!(!t||!t.isActive())}flushDebouncer(e){this._debouncers=this._debouncers||{};let t=this._debouncers[e];t&&t.flush()}cancelDebouncer(e){this._debouncers=this._debouncers||{};let t=this._debouncers[e];t&&t.cancel()}async(e,t){return t>0?de.Wc.run(e.bind(this),t):~de.YA.run(e.bind(this))}cancelAsync(e){e<0?de.YA.cancel(~e):de.Wc.cancel(e)}create(e,t){let r=document.createElement(e);if(t)if(r.setProperties)r.setProperties(t);else for(let e in t)r[e]=t[e];return r}elementMatches(e,t){return(0,se.Ku)(t||this,e)}toggleAttribute(e,t){let r=this;return 3===arguments.length&&(r=arguments[2]),1==arguments.length&&(t=!r.hasAttribute(e)),t?(r.setAttribute(e,""),!0):(r.removeAttribute(e),!1)}toggleClass(e,t,r){r=r||this,1==arguments.length&&(t=!r.classList.contains(e)),t?r.classList.add(e):r.classList.remove(e)}transform(e,t){(t=t||this).style.webkitTransform=e,t.style.transform=e}translate3d(e,t,r,n){n=n||this,this.transform("translate3d("+e+","+t+","+r+")",n)}arrayDelete(e,t){let r;if(Array.isArray(e)){if(r=e.indexOf(t),r>=0)return e.splice(r,1)}else{if(r=(0,ue.U2)(this,e).indexOf(t),r>=0)return this.splice(e,r,1)}return null}_logger(e,t){switch(Array.isArray(t)&&1===t.length&&Array.isArray(t[0])&&(t=t[0]),e){case"log":case"warn":case"error":console[e](...t)}}_log(...e){this._logger("log",e)}_warn(...e){this._logger("warn",e)}_error(...e){this._logger("error",e)}_logf(e,...t){return["[%s::%s]",this.is,e,...t]}}return n.prototype.is="",n}))},72419:(e,t,r)=>{"use strict";r.d(t,{x:()=>o});var n=r(18691);let i;i=n.E._mutablePropertyChange;const o={properties:{mutableData:Boolean},_shouldPropertyChange(e,t,r){return i(this,e,t,r,this.mutableData)}}},9672:(e,t,r)=>{"use strict";r.d(t,{k:()=>i});var n=r(33367);r(56646);const i=function(e){let t;return t="function"==typeof e?e:i.Class(e),customElements.define(t.is,t),t};i.Class=n.w},87156:(e,t,r)=>{"use strict";r.d(t,{Ku:()=>a,vz:()=>c});r(56646),r(74460);var n=r(20723);r(93252),r(78956);const i=Element.prototype,o=i.matches||i.matchesSelector||i.mozMatchesSelector||i.msMatchesSelector||i.oMatchesSelector||i.webkitMatchesSelector,a=function(e,t){return o.call(e,t)};class s{constructor(e){this.node=e}observeNodes(e){return new n.o(this.node,e)}unobserveNodes(e){e.disconnect()}notifyObserver(){}deepContains(e){if(this.node.contains(e))return!0;let t=e,r=e.ownerDocument;for(;t&&t!==r&&t!==this.node;)t=t.parentNode||t.host;return t===this.node}getOwnerRoot(){return this.node.getRootNode()}getDistributedNodes(){return"slot"===this.node.localName?this.node.assignedNodes({flatten:!0}):[]}getDestinationInsertionPoints(){let e=[],t=this.node.assignedSlot;for(;t;)e.push(t),t=t.assignedSlot;return e}importNode(e,t){return(this.node instanceof Document?this.node:this.node.ownerDocument).importNode(e,t)}getEffectiveChildNodes(){return n.o.getFlattenedNodes(this.node)}queryDistributedElements(e){let t=this.getEffectiveChildNodes(),r=[];for(let n,i=0,o=t.length;i<o&&(n=t[i]);i++)n.nodeType===Node.ELEMENT_NODE&&a(n,e)&&r.push(n);return r}get activeElement(){let e=this.node;return void 0!==e._activeElement?e._activeElement:e.activeElement}}class l{constructor(e){this.event=e}get rootTarget(){return this.event.composedPath()[0]}get localTarget(){return this.event.target}get path(){return this.event.composedPath()}}s.prototype.cloneNode,s.prototype.appendChild,s.prototype.insertBefore,s.prototype.removeChild,s.prototype.replaceChild,s.prototype.setAttribute,s.prototype.removeAttribute,s.prototype.querySelector,s.prototype.querySelectorAll,s.prototype.parentNode,s.prototype.firstChild,s.prototype.lastChild,s.prototype.nextSibling,s.prototype.previousSibling,s.prototype.firstElementChild,s.prototype.lastElementChild,s.prototype.nextElementSibling,s.prototype.previousElementSibling,s.prototype.childNodes,s.prototype.children,s.prototype.classList,s.prototype.textContent,s.prototype.innerHTML,function(e,t){for(let r=0;r<t.length;r++){let n=t[r];e[n]=function(){return this.node[n].apply(this.node,arguments)}}}(s.prototype,["cloneNode","appendChild","insertBefore","removeChild","replaceChild","setAttribute","removeAttribute","querySelector","querySelectorAll"]),function(e,t){for(let r=0;r<t.length;r++){let n=t[r];Object.defineProperty(e,n,{get:function(){return this.node[n]},configurable:!0})}}(s.prototype,["parentNode","firstChild","lastChild","nextSibling","previousSibling","firstElementChild","lastElementChild","nextElementSibling","previousElementSibling","childNodes","children","classList"]),function(e,t){for(let r=0;r<t.length;r++){let n=t[r];Object.defineProperty(e,n,{get:function(){return this.node[n]},set:function(e){this.node[n]=e},configurable:!0})}}(s.prototype,["textContent","innerHTML"]);const c=function(e){if(!(e=e||document).__domApi){let t;t=e instanceof Event?new l(e):new s(e),e.__domApi=t}return e.__domApi}},37692:(e,t,r)=>{"use strict";r.d(t,{F:()=>i});var n=r(52521);const i={templatize(e,t){this._templatizerTemplate=e,this.ctor=(0,n.Uv)(e,this,{mutableData:Boolean(t),parentModel:this._parentModel,instanceProps:this._instanceProps,forwardHostProp:this._forwardHostPropV2,notifyInstanceProp:this._notifyInstancePropV2})},stamp(e){return new this.ctor(e)},modelForElement(e){return(0,n.GJ)(this._templatizerTemplate,e)}}},36608:(e,t,r)=>{"use strict";r.d(t,{SH:()=>u});r(56646);var n=r(74460),i=r(76389),o=r(15392),a=r(42687),s=r(21384),l=r(40729),c=r(24072);const d=(0,i.o)((e=>{const t=(0,c.e)(e);function r(e){const t=Object.getPrototypeOf(e);return t.prototype instanceof i?t:null}function n(e){if(!e.hasOwnProperty(JSCompiler_renameProperty("__ownProperties",e))){let t=null;if(e.hasOwnProperty(JSCompiler_renameProperty("properties",e))){const r=e.properties;r&&(t=function(e){const t={};for(let r in e){const n=e[r];t[r]="function"==typeof n?{type:n}:n}return t}(r))}e.__ownProperties=t}return e.__ownProperties}class i extends t{static get observedAttributes(){const e=this._properties;return e?Object.keys(e).map((e=>this.attributeNameForProperty(e))):[]}static finalize(){if(!this.hasOwnProperty(JSCompiler_renameProperty("__finalized",this))){const e=r(this);e&&e.finalize(),this.__finalized=!0,this._finalizeClass()}}static _finalizeClass(){const e=n(this);e&&this.createProperties(e)}static get _properties(){if(!this.hasOwnProperty(JSCompiler_renameProperty("__properties",this))){const e=r(this);this.__properties=Object.assign({},e&&e._properties,n(this))}return this.__properties}static typeForProperty(e){const t=this._properties[e];return t&&t.type}_initializeProperties(){this.constructor.finalize(),super._initializeProperties()}connectedCallback(){super.connectedCallback&&super.connectedCallback(),this._enableProperties()}disconnectedCallback(){super.disconnectedCallback&&super.disconnectedCallback()}}return i})),u=(0,i.o)((e=>{const t=d((0,l.q)(e));return class extends t{static get polymerElementVersion(){return"3.0.5"}static _finalizeClass(){var e;super._finalizeClass(),this.hasOwnProperty(JSCompiler_renameProperty("is",this))&&this.is&&(e=this.prototype,p.push(e));const t=((r=this).hasOwnProperty(JSCompiler_renameProperty("__ownObservers",r))||(r.__ownObservers=r.hasOwnProperty(JSCompiler_renameProperty("observers",r))?r.observers:null),r.__ownObservers);var r;t&&this.createObservers(t,this._properties);let n=this.template;n&&("string"==typeof n?(console.error("template getter must return HTMLTemplateElement"),n=null):n=n.cloneNode(!0)),this.prototype._template=n}static createProperties(e){for(let o in e)t=this.prototype,r=o,n=e[o],i=e,n.computed&&(n.readOnly=!0),n.computed&&!t._hasReadOnlyEffect(r)&&t._createComputedProperty(r,n.computed,i),n.readOnly&&!t._hasReadOnlyEffect(r)&&t._createReadOnlyProperty(r,!n.computed),n.reflectToAttribute&&!t._hasReflectEffect(r)&&t._createReflectedProperty(r),n.notify&&!t._hasNotifyEffect(r)&&t._createNotifyingProperty(r),n.observer&&t._createPropertyObserver(r,n.observer,i[n.observer]),t._addPropertyToAttributeMap(r);var t,r,n,i}static createObservers(e,t){const r=this.prototype;for(let n=0;n<e.length;n++)r._createMethodObserver(e[n],t)}static get template(){return this.hasOwnProperty(JSCompiler_renameProperty("_template",this))||(this._template=this.prototype.hasOwnProperty(JSCompiler_renameProperty("_template",this.prototype))?this.prototype._template:function(e){let t=null;if(e&&(!n.XN||n.ZN)&&(t=s.t.import(e,"template"),n.XN&&!t))throw new Error("strictTemplatePolicy: expecting dom-module or null template for "+e);return t}(this.is)||Object.getPrototypeOf(this.prototype).constructor.template),this._template}static set template(e){this._template=e}static get importPath(){if(!this.hasOwnProperty(JSCompiler_renameProperty("_importPath",this))){const e=this.importMeta;if(e)this._importPath=(0,a.iY)(e.url);else{const e=s.t.import(this.is);this._importPath=e&&e.assetpath||Object.getPrototypeOf(this.prototype).constructor.importPath}}return this._importPath}constructor(){super(),this._template,this._importPath,this.rootPath,this.importPath,this.root,this.$}_initializeProperties(){this.constructor.finalize(),this.constructor._finalizeTemplate(this.localName),super._initializeProperties(),this.rootPath=n.sM,this.importPath=this.constructor.importPath;let e=function(e){if(!e.hasOwnProperty(JSCompiler_renameProperty("__propertyDefaults",e))){e.__propertyDefaults=null;let t=e._properties;for(let r in t){let n=t[r];"value"in n&&(e.__propertyDefaults=e.__propertyDefaults||{},e.__propertyDefaults[r]=n)}}return e.__propertyDefaults}(this.constructor);if(e)for(let t in e){let r=e[t];if(!this.hasOwnProperty(t)){let e="function"==typeof r.value?r.value.call(this):r.value;this._hasAccessor(t)?this._setPendingProperty(t,e,!0):this[t]=e}}}static _processStyleText(e,t){return(0,a.Rq)(e,t)}static _finalizeTemplate(e){const t=this.prototype._template;if(t&&!t.__polymerFinalized){t.__polymerFinalized=!0;const r=this.importPath;!function(e,t,r,n){const i=t.content.querySelectorAll("style"),a=(0,o.uT)(t),s=(0,o.lx)(r),l=t.content.firstElementChild;for(let r=0;r<s.length;r++){let i=s[r];i.textContent=e._processStyleText(i.textContent,n),t.content.insertBefore(i,l)}let c=0;for(let t=0;t<a.length;t++){let r=a[t],o=i[c];o!==r?(r=r.cloneNode(!0),o.parentNode.insertBefore(r,o)):c++,r.textContent=e._processStyleText(r.textContent,n)}window.ShadyCSS&&window.ShadyCSS.prepareTemplate(t,r)}(this,t,e,r?(0,a.Kk)(r):""),this.prototype._bindTemplate(t)}}connectedCallback(){window.ShadyCSS&&this._template&&window.ShadyCSS.styleElement(this),super.connectedCallback()}ready(){this._template&&(this.root=this._stampTemplate(this._template),this.$=this.root.$),super.ready()}_readyClients(){this._template&&(this.root=this._attachDom(this.root)),super._readyClients()}_attachDom(e){if(this.attachShadow)return e?(this.shadowRoot||this.attachShadow({mode:"open"}),this.shadowRoot.appendChild(e),this.shadowRoot):null;throw new Error("ShadowDOM not available. PolymerElement can create dom as children instead of in ShadowDOM by setting `this.root = this;` before `ready`.")}updateStyles(e){window.ShadyCSS&&window.ShadyCSS.styleSubtree(this,e)}resolveUrl(e,t){return!t&&this.importPath&&(t=(0,a.Kk)(this.importPath)),(0,a.Kk)(e,t)}static _parseTemplateContent(e,t,r){return t.dynamicFns=t.dynamicFns||this._properties,super._parseTemplateContent(e,t,r)}}}));const p=[]},60995:(e,t,r)=>{"use strict";r.d(t,{_:()=>o});r(56646);var n=r(76389),i=r(81668);const o=(0,n.o)((e=>class extends e{_addEventListenerToNode(e,t,r){(0,i.NH)(e,t,r)||super._addEventListenerToNode(e,t,r)}_removeEventListenerFromNode(e,t,r){(0,i.ys)(e,t,r)||super._removeEventListenerFromNode(e,t,r)}}))},18691:(e,t,r)=>{"use strict";r.d(t,{E:()=>o,w:()=>a});var n=r(76389);function i(e,t,r,n,i){let o;i&&(o="object"==typeof r&&null!==r,o&&(n=e.__dataTemp[t]));let a=n!==r&&(n==n||r==r);return o&&a&&(e.__dataTemp[t]=r),a}const o=(0,n.o)((e=>class extends e{_shouldPropertyChange(e,t,r){return i(this,e,t,r,!0)}})),a=(0,n.o)((e=>class extends e{static get properties(){return{mutableData:Boolean}}_shouldPropertyChange(e,t,r){return i(this,e,t,r,this.mutableData)}}));o._mutablePropertyChange=i},24072:(e,t,r)=>{"use strict";r.d(t,{e:()=>o});r(56646);var n=r(76389);const i=r(21683).YA,o=(0,n.o)((e=>class extends e{static createProperties(e){const t=this.prototype;for(let r in e)r in t||t._createPropertyAccessor(r)}static attributeNameForProperty(e){return e.toLowerCase()}static typeForProperty(e){}_createPropertyAccessor(e,t){this._addPropertyToAttributeMap(e),this.hasOwnProperty("__dataHasAccessor")||(this.__dataHasAccessor=Object.assign({},this.__dataHasAccessor)),this.__dataHasAccessor[e]||(this.__dataHasAccessor[e]=!0,this._definePropertyAccessor(e,t))}_addPropertyToAttributeMap(e){if(this.hasOwnProperty("__dataAttributes")||(this.__dataAttributes=Object.assign({},this.__dataAttributes)),!this.__dataAttributes[e]){const t=this.constructor.attributeNameForProperty(e);this.__dataAttributes[t]=e}}_definePropertyAccessor(e,t){Object.defineProperty(this,e,{get(){return this._getProperty(e)},set:t?function(){}:function(t){this._setProperty(e,t)}})}constructor(){super(),this.__dataEnabled=!1,this.__dataReady=!1,this.__dataInvalid=!1,this.__data={},this.__dataPending=null,this.__dataOld=null,this.__dataInstanceProps=null,this.__serializing=!1,this._initializeProperties()}ready(){this.__dataReady=!0,this._flushProperties()}_initializeProperties(){for(let e in this.__dataHasAccessor)this.hasOwnProperty(e)&&(this.__dataInstanceProps=this.__dataInstanceProps||{},this.__dataInstanceProps[e]=this[e],delete this[e])}_initializeInstanceProperties(e){Object.assign(this,e)}_setProperty(e,t){this._setPendingProperty(e,t)&&this._invalidateProperties()}_getProperty(e){return this.__data[e]}_setPendingProperty(e,t,r){let n=this.__data[e],i=this._shouldPropertyChange(e,t,n);return i&&(this.__dataPending||(this.__dataPending={},this.__dataOld={}),this.__dataOld&&!(e in this.__dataOld)&&(this.__dataOld[e]=n),this.__data[e]=t,this.__dataPending[e]=t),i}_invalidateProperties(){!this.__dataInvalid&&this.__dataReady&&(this.__dataInvalid=!0,i.run((()=>{this.__dataInvalid&&(this.__dataInvalid=!1,this._flushProperties())})))}_enableProperties(){this.__dataEnabled||(this.__dataEnabled=!0,this.__dataInstanceProps&&(this._initializeInstanceProperties(this.__dataInstanceProps),this.__dataInstanceProps=null),this.ready())}_flushProperties(){const e=this.__data,t=this.__dataPending,r=this.__dataOld;this._shouldPropertiesChange(e,t,r)&&(this.__dataPending=null,this.__dataOld=null,this._propertiesChanged(e,t,r))}_shouldPropertiesChange(e,t,r){return Boolean(t)}_propertiesChanged(e,t,r){}_shouldPropertyChange(e,t,r){return r!==t&&(r==r||t==t)}attributeChangedCallback(e,t,r,n){t!==r&&this._attributeToProperty(e,r),super.attributeChangedCallback&&super.attributeChangedCallback(e,t,r,n)}_attributeToProperty(e,t,r){if(!this.__serializing){const n=this.__dataAttributes,i=n&&n[e]||e;this[i]=this._deserializeValue(t,r||this.constructor.typeForProperty(i))}}_propertyToAttribute(e,t,r){this.__serializing=!0,r=arguments.length<3?this[e]:r,this._valueToNodeAttribute(this,r,t||this.constructor.attributeNameForProperty(e)),this.__serializing=!1}_valueToNodeAttribute(e,t,r){const n=this._serializeValue(t);void 0===n?e.removeAttribute(r):e.setAttribute(r,n)}_serializeValue(e){switch(typeof e){case"boolean":return e?"":void 0;default:return null!=e?e.toString():void 0}}_deserializeValue(e,t){switch(t){case Boolean:return null!==e;case Number:return Number(e);default:return e}}}))},63933:(e,t,r)=>{"use strict";r.d(t,{Q:()=>l});r(56646);var n=r(76389),i=r(67130),o=r(24072);const a={};let s=HTMLElement.prototype;for(;s;){let e=Object.getOwnPropertyNames(s);for(let t=0;t<e.length;t++)a[e[t]]=!0;s=Object.getPrototypeOf(s)}const l=(0,n.o)((e=>{const t=(0,o.e)(e);return class extends t{static createPropertiesForAttributes(){let e=this.observedAttributes;for(let t=0;t<e.length;t++)this.prototype._createPropertyAccessor((0,i.z)(e[t]))}static attributeNameForProperty(e){return(0,i.n)(e)}_initializeProperties(){this.__dataProto&&(this._initializeProtoProperties(this.__dataProto),this.__dataProto=null),super._initializeProperties()}_initializeProtoProperties(e){for(let t in e)this._setProperty(t,e[t])}_ensureAttribute(e,t){const r=this;r.hasAttribute(e)||this._valueToNodeAttribute(r,t,e)}_serializeValue(e){switch(typeof e){case"object":if(e instanceof Date)return e.toString();if(e)try{return JSON.stringify(e)}catch(e){return""}default:return super._serializeValue(e)}}_deserializeValue(e,t){let r;switch(t){case Object:try{r=JSON.parse(e)}catch(t){r=e}break;case Array:try{r=JSON.parse(e)}catch(t){r=null,console.warn("Polymer::Attributes: couldn't decode Array as JSON: "+e)}break;case Date:r=isNaN(e)?String(e):Number(e),r=new Date(r);break;default:r=super._deserializeValue(e,t)}return r}_definePropertyAccessor(e,t){!function(e,t){if(!a[t]){let r=e[t];void 0!==r&&(e.__data?e._setPendingProperty(t,r):(e.__dataProto?e.hasOwnProperty(JSCompiler_renameProperty("__dataProto",e))||(e.__dataProto=Object.create(e.__dataProto)):e.__dataProto={},e.__dataProto[t]=r))}}(this,e),super._definePropertyAccessor(e,t)}_hasAccessor(e){return this.__dataHasAccessor&&this.__dataHasAccessor[e]}_isPropertyPending(e){return Boolean(this.__dataPending&&e in this.__dataPending)}}}))},40729:(e,t,r)=>{"use strict";r.d(t,{q:()=>V});r(56646);var n=r(76389),i=r(4059),o=r(67130),a=r(63933);const s={"dom-if":!0,"dom-repeat":!0};function l(e){let t=e.getAttribute("is");if(t&&s[t]){let r=e;for(r.removeAttribute("is"),e=r.ownerDocument.createElement(t),r.parentNode.replaceChild(e,r),e.appendChild(r);r.attributes.length;)e.setAttribute(r.attributes[0].name,r.attributes[0].value),r.removeAttribute(r.attributes[0].name)}return e}function c(e,t){let r=t.parentInfo&&c(e,t.parentInfo);if(!r)return e;for(let e=r.firstChild,n=0;e;e=e.nextSibling)if(t.parentIndex===n++)return e}function d(e,t,r,n){n.id&&(t[n.id]=r)}function u(e,t,r){if(r.events&&r.events.length)for(let n,i=0,o=r.events;i<o.length&&(n=o[i]);i++)e._addMethodEventListenerToNode(t,n.name,n.value,e)}function p(e,t,r){r.templateInfo&&(t._templateInfo=r.templateInfo)}const h=(0,n.o)((e=>class extends e{static _parseTemplate(e,t){if(!e._templateInfo){let r=e._templateInfo={};r.nodeInfoList=[],r.stripWhiteSpace=t&&t.stripWhiteSpace||e.hasAttribute("strip-whitespace"),this._parseTemplateContent(e,r,{parent:null})}return e._templateInfo}static _parseTemplateContent(e,t,r){return this._parseTemplateNode(e.content,t,r)}static _parseTemplateNode(e,t,r){let n,i=e;return"template"!=i.localName||i.hasAttribute("preserve-content")?"slot"===i.localName&&(t.hasInsertionPoint=!0):n=this._parseTemplateNestedTemplate(i,t,r)||n,i.firstChild&&(n=this._parseTemplateChildNodes(i,t,r)||n),i.hasAttributes&&i.hasAttributes()&&(n=this._parseTemplateNodeAttributes(i,t,r)||n),n}static _parseTemplateChildNodes(e,t,r){if("script"!==e.localName&&"style"!==e.localName)for(let n,i=e.firstChild,o=0;i;i=n){if("template"==i.localName&&(i=l(i)),n=i.nextSibling,i.nodeType===Node.TEXT_NODE){let r=n;for(;r&&r.nodeType===Node.TEXT_NODE;)i.textContent+=r.textContent,n=r.nextSibling,e.removeChild(r),r=n;if(t.stripWhiteSpace&&!i.textContent.trim()){e.removeChild(i);continue}}let a={parentIndex:o,parentInfo:r};this._parseTemplateNode(i,t,a)&&(a.infoIndex=t.nodeInfoList.push(a)-1),i.parentNode&&o++}}static _parseTemplateNestedTemplate(e,t,r){let n=this._parseTemplate(e,t);return(n.content=e.content.ownerDocument.createDocumentFragment()).appendChild(e.content),r.templateInfo=n,!0}static _parseTemplateNodeAttributes(e,t,r){let n=!1,i=Array.from(e.attributes);for(let o,a=i.length-1;o=i[a];a--)n=this._parseTemplateNodeAttribute(e,t,r,o.name,o.value)||n;return n}static _parseTemplateNodeAttribute(e,t,r,n,i){return"on-"===n.slice(0,3)?(e.removeAttribute(n),r.events=r.events||[],r.events.push({name:n.slice(3),value:i}),!0):"id"===n&&(r.id=i,!0)}static _contentForTemplate(e){let t=e._templateInfo;return t&&t.content||e.content}_stampTemplate(e){e&&!e.content&&window.HTMLTemplateElement&&HTMLTemplateElement.decorate&&HTMLTemplateElement.decorate(e);let t=this.constructor._parseTemplate(e),r=t.nodeInfoList,n=t.content||e.content,i=document.importNode(n,!0);i.__noInsertionPoint=!t.hasInsertionPoint;let o=i.nodeList=new Array(r.length);i.$={};for(let e,t=0,n=r.length;t<n&&(e=r[t]);t++){let r=o[t]=c(i,e);d(0,i.$,r,e),p(0,r,e),u(this,r,e)}return i=i,i}_addMethodEventListenerToNode(e,t,r,n){let i=function(e,t,r){return e=e._methodHost||e,function(t){e[r]?e[r](t,t.detail):console.warn("listener method `"+r+"` not defined")}}(n=n||e,0,r);return this._addEventListenerToNode(e,t,i),i}_addEventListenerToNode(e,t,r){e.addEventListener(t,r)}_removeEventListenerFromNode(e,t,r){e.removeEventListener(t,r)}}));var f=r(74460);let m=0;const y={COMPUTE:"__computeEffects",REFLECT:"__reflectEffects",NOTIFY:"__notifyEffects",PROPAGATE:"__propagateEffects",OBSERVE:"__observeEffects",READ_ONLY:"__readOnly"},g=/[A-Z]/;let b;function _(e,t){let r=e[t];if(r){if(!e.hasOwnProperty(t)){r=e[t]=Object.create(e[t]);for(let e in r){let t=r[e],n=r[e]=Array(t.length);for(let e=0;e<t.length;e++)n[e]=t[e]}}}else r=e[t]={};return r}function v(e,t,r,n,i,o){if(t){let a=!1,s=m++;for(let l in r)w(e,t,s,l,r,n,i,o)&&(a=!0);return a}return!1}function w(e,t,r,n,o,a,s,l){let c=!1,d=t[s?(0,i.Jz)(n):n];if(d)for(let t,i=0,u=d.length;i<u&&(t=d[i]);i++)t.info&&t.info.lastRun===r||s&&!x(n,t.trigger)||(t.info&&(t.info.lastRun=r),t.fn(e,n,o,a,t.info,s,l),c=!0);return c}function x(e,t){if(t){let r=t.name;return r==e||t.structured&&(0,i.jg)(r,e)||t.wildcard&&(0,i.SG)(r,e)}return!0}function k(e,t,r,n,i){let o="string"==typeof i.method?e[i.method]:i.method,a=i.property;o?o.call(e,e.__data[a],n[a]):i.dynamicFn||console.warn("observer method `"+i.method+"` not defined")}function C(e,t,r){let n=(0,i.Jz)(t);if(n!==t){return E(e,(0,o.n)(n)+"-changed",r[t],t),!0}return!1}function E(e,t,r,n){let i={value:r,queueProperty:!0};n&&(i.path=n),e.dispatchEvent(new CustomEvent(t,{detail:i}))}function S(e,t,r,n,o,a){let s=(a?(0,i.Jz)(t):t)!=t?t:null,l=s?(0,i.U2)(e,s):e.__data[t];s&&void 0===l&&(l=r[t]),E(e,o.eventName,l,s)}function P(e,t,r,n,i){let o=e.__data[t];f.v1&&(o=(0,f.v1)(o,i.attrName,"attribute",e)),e._propertyToAttribute(t,i.attrName,o)}function A(e,t,r,n,i){let o=z(e,t,r,n,i),a=i.methodInfo;e.__dataHasAccessor&&e.__dataHasAccessor[a]?e._setPendingProperty(a,o,!0):e[a]=o}function T(e,t,r,n,i,a,s){r.bindings=r.bindings||[];let l={kind:n,target:i,parts:a,literal:s,isCompound:1!==a.length};if(r.bindings.push(l),function(e){return Boolean(e.target)&&"attribute"!=e.kind&&"text"!=e.kind&&!e.isCompound&&"{"===e.parts[0].mode}(l)){let{event:e,negate:t}=l.parts[0];l.listenerEvent=e||(0,o.n)(i)+"-changed",l.listenerNegate=t}let c=t.nodeInfoList.length;for(let r=0;r<l.parts.length;r++){let n=l.parts[r];n.compoundIndex=r,O(e,t,l,n,c)}}function O(e,t,r,n,i){if(!n.literal)if("attribute"===r.kind&&"-"===r.target[0])console.warn("Cannot set attribute "+r.target+' because "-" is not a valid attribute starting character');else{let o=n.dependencies,a={index:i,binding:r,part:n,evaluator:e};for(let r=0;r<o.length;r++){let n=o[r];"string"==typeof n&&(n=H(n),n.wildcard=!0),e._addTemplatePropertyEffect(t,n.rootProperty,{fn:N,info:a,trigger:n})}}}function N(e,t,r,n,o,a,s){let l=s[o.index],c=o.binding,d=o.part;if(a&&d.source&&t.length>d.source.length&&"property"==c.kind&&!c.isCompound&&l.__isPropertyEffectsClient&&l.__dataHasAccessor&&l.__dataHasAccessor[c.target]){let n=r[t];t=(0,i.Iu)(d.source,c.target,t),l._setPendingPropertyOrPath(t,n,!1,!0)&&e._enqueueClient(l)}else{!function(e,t,r,n,i){i=function(e,t,r,n){if(r.isCompound){let i=e.__dataCompoundStorage[r.target];i[n.compoundIndex]=t,t=i.join("")}"attribute"!==r.kind&&("textContent"!==r.target&&("value"!==r.target||"input"!==e.localName&&"textarea"!==e.localName)||(t=null==t?"":t));return t}(t,i,r,n),f.v1&&(i=(0,f.v1)(i,r.target,r.kind,t));if("attribute"==r.kind)e._valueToNodeAttribute(t,i,r.target);else{let n=r.target;t.__isPropertyEffectsClient&&t.__dataHasAccessor&&t.__dataHasAccessor[n]?t[y.READ_ONLY]&&t[y.READ_ONLY][n]||t._setPendingProperty(n,i)&&e._enqueueClient(t):e._setUnmanagedPropertyToNode(t,n,i)}}(e,l,c,d,o.evaluator._evaluateBinding(e,d,t,r,n,a))}}function I(e,t){if(t.isCompound){let r=e.__dataCompoundStorage||(e.__dataCompoundStorage={}),n=t.parts,i=new Array(n.length);for(let e=0;e<n.length;e++)i[e]=n[e].literal;let o=t.target;r[o]=i,t.literal&&"property"==t.kind&&(e[o]=t.literal)}}function R(e,t,r){if(r.listenerEvent){let n=r.parts[0];e.addEventListener(r.listenerEvent,(function(e){!function(e,t,r,n,o){let a,s=e.detail,l=s&&s.path;l?(n=(0,i.Iu)(r,n,l),a=s&&s.value):a=e.currentTarget[r],a=o?!a:a,t[y.READ_ONLY]&&t[y.READ_ONLY][n]||!t._setPendingPropertyOrPath(n,a,!0,Boolean(l))||s&&s.queueProperty||t._invalidateProperties()}(e,t,r.target,n.source,n.negate)}))}}function D(e,t,r,n,i,o){o=t.static||o&&("object"!=typeof o||o[t.methodName]);let a={methodName:t.methodName,args:t.args,methodInfo:i,dynamicFn:o};for(let i,o=0;o<t.args.length&&(i=t.args[o]);o++)i.literal||e._addPropertyEffect(i.rootProperty,r,{fn:n,info:a,trigger:i});o&&e._addPropertyEffect(t.methodName,r,{fn:n,info:a})}function z(e,t,r,n,i){let o=e._methodHost||e,a=o[i.methodName];if(a){let n=e._marshalArgs(i.args,t,r);return a.apply(o,n)}i.dynamicFn||console.warn("method `"+i.methodName+"` not defined")}const F=[],L=new RegExp("(\\[\\[|{{)\\s*(?:(!)\\s*)?((?:[a-zA-Z_$][\\w.:$\\-*]*)\\s*(?:\\(\\s*(?:(?:(?:((?:[a-zA-Z_$][\\w.:$\\-*]*)|(?:[-+]?[0-9]*\\.?[0-9]+(?:[eE][-+]?[0-9]+)?)|(?:(?:'(?:[^'\\\\]|\\\\.)*')|(?:\"(?:[^\"\\\\]|\\\\.)*\")))\\s*)(?:,\\s*(?:((?:[a-zA-Z_$][\\w.:$\\-*]*)|(?:[-+]?[0-9]*\\.?[0-9]+(?:[eE][-+]?[0-9]+)?)|(?:(?:'(?:[^'\\\\]|\\\\.)*')|(?:\"(?:[^\"\\\\]|\\\\.)*\")))\\s*))*)?)\\)\\s*)?)(?:]]|}})","g");function M(e){let t="";for(let r=0;r<e.length;r++){t+=e[r].literal||""}return t}function j(e){let t=e.match(/([^\s]+?)\(([\s\S]*)\)/);if(t){let e={methodName:t[1],static:!0,args:F};if(t[2].trim()){return function(e,t){return t.args=e.map((function(e){let r=H(e);return r.literal||(t.static=!1),r}),this),t}(t[2].replace(/\\,/g,"&comma;").split(","),e)}return e}return null}function H(e){let t=e.trim().replace(/&comma;/g,",").replace(/\\(.)/g,"$1"),r={name:t,value:"",literal:!1},n=t[0];switch("-"===n&&(n=t[1]),n>="0"&&n<="9"&&(n="#"),n){case"'":case'"':r.value=t.slice(1,-1),r.literal=!0;break;case"#":r.value=Number(t),r.literal=!0}return r.literal||(r.rootProperty=(0,i.Jz)(t),r.structured=(0,i.AZ)(t),r.structured&&(r.wildcard=".*"==t.slice(-2),r.wildcard&&(r.name=t.slice(0,-2)))),r}function B(e,t,r,n){let i=r+".splices";e.notifyPath(i,{indexSplices:n}),e.notifyPath(r+".length",t.length),e.__data[i]={indexSplices:null}}function $(e,t,r,n,i,o){B(e,t,r,[{index:n,addedCount:i,removed:o,object:t,type:"splice"}])}const V=(0,n.o)((e=>{const t=h((0,a.Q)(e));class r extends t{constructor(){super(),this.__isPropertyEffectsClient=!0,this.__dataCounter=0,this.__dataClientsReady,this.__dataPendingClients,this.__dataToNotify,this.__dataLinkedPaths,this.__dataHasPaths,this.__dataCompoundStorage,this.__dataHost,this.__dataTemp,this.__dataClientsInitialized,this.__data,this.__dataPending,this.__dataOld,this.__computeEffects,this.__reflectEffects,this.__notifyEffects,this.__propagateEffects,this.__observeEffects,this.__readOnly,this.__templateInfo}get PROPERTY_EFFECT_TYPES(){return y}_initializeProperties(){super._initializeProperties(),U.registerHost(this),this.__dataClientsReady=!1,this.__dataPendingClients=null,this.__dataToNotify=null,this.__dataLinkedPaths=null,this.__dataHasPaths=!1,this.__dataCompoundStorage=this.__dataCompoundStorage||null,this.__dataHost=this.__dataHost||null,this.__dataTemp={},this.__dataClientsInitialized=!1}_initializeProtoProperties(e){this.__data=Object.create(e),this.__dataPending=Object.create(e),this.__dataOld={}}_initializeInstanceProperties(e){let t=this[y.READ_ONLY];for(let r in e)t&&t[r]||(this.__dataPending=this.__dataPending||{},this.__dataOld=this.__dataOld||{},this.__data[r]=this.__dataPending[r]=e[r])}_addPropertyEffect(e,t,r){this._createPropertyAccessor(e,t==y.READ_ONLY);let n=_(this,t)[e];n||(n=this[t][e]=[]),n.push(r)}_removePropertyEffect(e,t,r){let n=_(this,t)[e],i=n.indexOf(r);i>=0&&n.splice(i,1)}_hasPropertyEffect(e,t){let r=this[t];return Boolean(r&&r[e])}_hasReadOnlyEffect(e){return this._hasPropertyEffect(e,y.READ_ONLY)}_hasNotifyEffect(e){return this._hasPropertyEffect(e,y.NOTIFY)}_hasReflectEffect(e){return this._hasPropertyEffect(e,y.REFLECT)}_hasComputedEffect(e){return this._hasPropertyEffect(e,y.COMPUTE)}_setPendingPropertyOrPath(e,t,r,n){if(n||(0,i.Jz)(Array.isArray(e)?e[0]:e)!==e){if(!n){let r=(0,i.U2)(this,e);if(!(e=(0,i.t8)(this,e,t))||!super._shouldPropertyChange(e,t,r))return!1}if(this.__dataHasPaths=!0,this._setPendingProperty(e,t,r))return function(e,t,r){let n=e.__dataLinkedPaths;if(n){let o;for(let a in n){let s=n[a];(0,i.SG)(a,t)?(o=(0,i.Iu)(a,s,t),e._setPendingPropertyOrPath(o,r,!0,!0)):(0,i.SG)(s,t)&&(o=(0,i.Iu)(s,a,t),e._setPendingPropertyOrPath(o,r,!0,!0))}}}(this,e,t),!0}else{if(this.__dataHasAccessor&&this.__dataHasAccessor[e])return this._setPendingProperty(e,t,r);this[e]=t}return!1}_setUnmanagedPropertyToNode(e,t,r){r===e[t]&&"object"!=typeof r||(e[t]=r)}_setPendingProperty(e,t,r){let n=this.__dataHasPaths&&(0,i.AZ)(e),o=n?this.__dataTemp:this.__data;return!!this._shouldPropertyChange(e,t,o[e])&&(this.__dataPending||(this.__dataPending={},this.__dataOld={}),e in this.__dataOld||(this.__dataOld[e]=this.__data[e]),n?this.__dataTemp[e]=t:this.__data[e]=t,this.__dataPending[e]=t,(n||this[y.NOTIFY]&&this[y.NOTIFY][e])&&(this.__dataToNotify=this.__dataToNotify||{},this.__dataToNotify[e]=r),!0)}_setProperty(e,t){this._setPendingProperty(e,t,!0)&&this._invalidateProperties()}_invalidateProperties(){this.__dataReady&&this._flushProperties()}_enqueueClient(e){this.__dataPendingClients=this.__dataPendingClients||[],e!==this&&this.__dataPendingClients.push(e)}_flushProperties(){this.__dataCounter++,super._flushProperties(),this.__dataCounter--}_flushClients(){this.__dataClientsReady?this.__enableOrFlushClients():(this.__dataClientsReady=!0,this._readyClients(),this.__dataReady=!0)}__enableOrFlushClients(){let e=this.__dataPendingClients;if(e){this.__dataPendingClients=null;for(let t=0;t<e.length;t++){let r=e[t];r.__dataEnabled?r.__dataPending&&r._flushProperties():r._enableProperties()}}}_readyClients(){this.__enableOrFlushClients()}setProperties(e,t){for(let r in e)!t&&this[y.READ_ONLY]&&this[y.READ_ONLY][r]||this._setPendingPropertyOrPath(r,e[r],!0);this._invalidateProperties()}ready(){this._flushProperties(),this.__dataClientsReady||this._flushClients(),this.__dataPending&&this._flushProperties()}_propertiesChanged(e,t,r){let n=this.__dataHasPaths;this.__dataHasPaths=!1,function(e,t,r,n){let i=e[y.COMPUTE];if(i){let o=t;for(;v(e,i,o,r,n);)Object.assign(r,e.__dataOld),Object.assign(t,e.__dataPending),o=e.__dataPending,e.__dataPending=null}}(this,t,r,n);let i=this.__dataToNotify;this.__dataToNotify=null,this._propagatePropertyChanges(t,r,n),this._flushClients(),v(this,this[y.REFLECT],t,r,n),v(this,this[y.OBSERVE],t,r,n),i&&function(e,t,r,n,i){let o,a,s=e[y.NOTIFY],l=m++;for(let a in t)t[a]&&(s&&w(e,s,l,a,r,n,i)||i&&C(e,a,r))&&(o=!0);o&&(a=e.__dataHost)&&a._invalidateProperties&&a._invalidateProperties()}(this,i,t,r,n),1==this.__dataCounter&&(this.__dataTemp={})}_propagatePropertyChanges(e,t,r){this[y.PROPAGATE]&&v(this,this[y.PROPAGATE],e,t,r);let n=this.__templateInfo;for(;n;)v(this,n.propertyEffects,e,t,r,n.nodeList),n=n.nextTemplateInfo}linkPaths(e,t){e=(0,i.Fv)(e),t=(0,i.Fv)(t),this.__dataLinkedPaths=this.__dataLinkedPaths||{},this.__dataLinkedPaths[e]=t}unlinkPaths(e){e=(0,i.Fv)(e),this.__dataLinkedPaths&&delete this.__dataLinkedPaths[e]}notifySplices(e,t){let r={path:""};B(this,(0,i.U2)(this,e,r),r.path,t)}get(e,t){return(0,i.U2)(t||this,e)}set(e,t,r){r?(0,i.t8)(r,e,t):this[y.READ_ONLY]&&this[y.READ_ONLY][e]||this._setPendingPropertyOrPath(e,t,!0)&&this._invalidateProperties()}push(e,...t){let r={path:""},n=(0,i.U2)(this,e,r),o=n.length,a=n.push(...t);return t.length&&$(this,n,r.path,o,t.length,[]),a}pop(e){let t={path:""},r=(0,i.U2)(this,e,t),n=Boolean(r.length),o=r.pop();return n&&$(this,r,t.path,r.length,0,[o]),o}splice(e,t,r,...n){let o,a={path:""},s=(0,i.U2)(this,e,a);return t<0?t=s.length-Math.floor(-t):t&&(t=Math.floor(t)),o=2===arguments.length?s.splice(t):s.splice(t,r,...n),(n.length||o.length)&&$(this,s,a.path,t,n.length,o),o}shift(e){let t={path:""},r=(0,i.U2)(this,e,t),n=Boolean(r.length),o=r.shift();return n&&$(this,r,t.path,0,0,[o]),o}unshift(e,...t){let r={path:""},n=(0,i.U2)(this,e,r),o=n.unshift(...t);return t.length&&$(this,n,r.path,0,t.length,[]),o}notifyPath(e,t){let r;if(1==arguments.length){let n={path:""};t=(0,i.U2)(this,e,n),r=n.path}else r=Array.isArray(e)?(0,i.Fv)(e):e;this._setPendingPropertyOrPath(r,t,!0,!0)&&this._invalidateProperties()}_createReadOnlyProperty(e,t){var r;this._addPropertyEffect(e,y.READ_ONLY),t&&(this["_set"+(r=e,r[0].toUpperCase()+r.substring(1))]=function(t){this._setProperty(e,t)})}_createPropertyObserver(e,t,r){let n={property:e,method:t,dynamicFn:Boolean(r)};this._addPropertyEffect(e,y.OBSERVE,{fn:k,info:n,trigger:{name:e}}),r&&this._addPropertyEffect(t,y.OBSERVE,{fn:k,info:n,trigger:{name:t}})}_createMethodObserver(e,t){let r=j(e);if(!r)throw new Error("Malformed observer expression '"+e+"'");D(this,r,y.OBSERVE,z,null,t)}_createNotifyingProperty(e){this._addPropertyEffect(e,y.NOTIFY,{fn:S,info:{eventName:(0,o.n)(e)+"-changed",property:e}})}_createReflectedProperty(e){let t=this.constructor.attributeNameForProperty(e);"-"===t[0]?console.warn("Property "+e+" cannot be reflected to attribute "+t+' because "-" is not a valid starting attribute name. Use a lowercase first letter for the property instead.'):this._addPropertyEffect(e,y.REFLECT,{fn:P,info:{attrName:t}})}_createComputedProperty(e,t,r){let n=j(t);if(!n)throw new Error("Malformed computed expression '"+t+"'");D(this,n,y.COMPUTE,A,e,r)}_marshalArgs(e,t,r){const n=this.__data;let o=[];for(let a=0,s=e.length;a<s;a++){let s,l=e[a],c=l.name;if(l.literal?s=l.value:l.structured?(s=(0,i.U2)(n,c),void 0===s&&(s=r[c])):s=n[c],l.wildcard){let e=0===c.indexOf(t+"."),n=0===t.indexOf(c)&&!e;o[a]={path:n?t:c,value:n?r[t]:s,base:s}}else o[a]=s}return o}static addPropertyEffect(e,t,r){this.prototype._addPropertyEffect(e,t,r)}static createPropertyObserver(e,t,r){this.prototype._createPropertyObserver(e,t,r)}static createMethodObserver(e,t){this.prototype._createMethodObserver(e,t)}static createNotifyingProperty(e){this.prototype._createNotifyingProperty(e)}static createReadOnlyProperty(e,t){this.prototype._createReadOnlyProperty(e,t)}static createReflectedProperty(e){this.prototype._createReflectedProperty(e)}static createComputedProperty(e,t,r){this.prototype._createComputedProperty(e,t,r)}static bindTemplate(e){return this.prototype._bindTemplate(e)}_bindTemplate(e,t){let r=this.constructor._parseTemplate(e),n=this.__templateInfo==r;if(!n)for(let e in r.propertyEffects)this._createPropertyAccessor(e);if(t&&(r=Object.create(r),r.wasPreBound=n,!n&&this.__templateInfo)){let e=this.__templateInfoLast||this.__templateInfo;return this.__templateInfoLast=e.nextTemplateInfo=r,r.previousTemplateInfo=e,r}return this.__templateInfo=r}static _addTemplatePropertyEffect(e,t,r){(e.hostProps=e.hostProps||{})[t]=!0;let n=e.propertyEffects=e.propertyEffects||{};(n[t]=n[t]||[]).push(r)}_stampTemplate(e){U.beginHosting(this);let t=super._stampTemplate(e);U.endHosting(this);let r=this._bindTemplate(e,!0);if(r.nodeList=t.nodeList,!r.wasPreBound){let e=r.childNodes=[];for(let r=t.firstChild;r;r=r.nextSibling)e.push(r)}return t.templateInfo=r,function(e,t){let{nodeList:r,nodeInfoList:n}=t;if(n.length)for(let t=0;t<n.length;t++){let i=n[t],o=r[t],a=i.bindings;if(a)for(let t=0;t<a.length;t++){let r=a[t];I(o,r),R(o,e,r)}o.__dataHost=e}}(this,r),this.__dataReady&&v(this,r.propertyEffects,this.__data,null,!1,r.nodeList),t}_removeBoundDom(e){let t=e.templateInfo;t.previousTemplateInfo&&(t.previousTemplateInfo.nextTemplateInfo=t.nextTemplateInfo),t.nextTemplateInfo&&(t.nextTemplateInfo.previousTemplateInfo=t.previousTemplateInfo),this.__templateInfoLast==t&&(this.__templateInfoLast=t.previousTemplateInfo),t.previousTemplateInfo=t.nextTemplateInfo=null;let r=t.childNodes;for(let e=0;e<r.length;e++){let t=r[e];t.parentNode.removeChild(t)}}static _parseTemplateNode(e,t,r){let n=super._parseTemplateNode(e,t,r);if(e.nodeType===Node.TEXT_NODE){let i=this._parseBindings(e.textContent,t);i&&(e.textContent=M(i)||" ",T(this,t,r,"text","textContent",i),n=!0)}return n}static _parseTemplateNodeAttribute(e,t,r,n,i){let a=this._parseBindings(i,t);if(a){let i=n,s="property";g.test(n)?s="attribute":"$"==n[n.length-1]&&(n=n.slice(0,-1),s="attribute");let l=M(a);return l&&"attribute"==s&&e.setAttribute(n,l),"input"===e.localName&&"value"===i&&e.setAttribute(i,""),e.removeAttribute(i),"property"===s&&(n=(0,o.z)(n)),T(this,t,r,s,n,a,l),!0}return super._parseTemplateNodeAttribute(e,t,r,n,i)}static _parseTemplateNestedTemplate(e,t,r){let n=super._parseTemplateNestedTemplate(e,t,r),i=r.templateInfo.hostProps;for(let e in i){T(this,t,r,"property","_host_"+e,[{mode:"{",source:e,dependencies:[e]}])}return n}static _parseBindings(e,t){let r,n=[],i=0;for(;null!==(r=L.exec(e));){r.index>i&&n.push({literal:e.slice(i,r.index)});let o=r[1][0],a=Boolean(r[2]),s=r[3].trim(),l=!1,c="",d=-1;"{"==o&&(d=s.indexOf("::"))>0&&(c=s.substring(d+2),s=s.substring(0,d),l=!0);let u=j(s),p=[];if(u){let{args:e,methodName:r}=u;for(let t=0;t<e.length;t++){let r=e[t];r.literal||p.push(r)}let n=t.dynamicFns;(n&&n[r]||u.static)&&(p.push(r),u.dynamicFn=!0)}else p.push(s);n.push({source:s,mode:o,negate:a,customEvent:l,signature:u,dependencies:p,event:c}),i=L.lastIndex}if(i&&i<e.length){let t=e.substring(i);t&&n.push({literal:t})}return n.length?n:null}static _evaluateBinding(e,t,r,n,o,a){let s;return s=t.signature?z(e,r,n,0,t.signature):r!=t.source?(0,i.U2)(e,t.source):a&&(0,i.AZ)(r)?(0,i.U2)(e,r):e.__data[r],t.negate&&(s=!s),s}}return b=r,r}));const U=new class{constructor(){this.stack=[]}registerHost(e){if(this.stack.length){this.stack[this.stack.length-1]._enqueueClient(e)}}beginHosting(e){this.stack.push(e)}endHosting(e){let t=this.stack.length;t&&this.stack[t-1]==e&&this.stack.pop()}}},4507:(e,t,r)=>{"use strict";r.d(t,{c:()=>o});r(56646);function n(e,t,r){return{index:e,removed:t,addedCount:r}}function i(e,t,r,i,o,s){let l,c=0,d=0,u=Math.min(r-t,s-o);if(0==t&&0==o&&(c=function(e,t,r){for(let n=0;n<r;n++)if(!a(e[n],t[n]))return n;return r}(e,i,u)),r==e.length&&s==i.length&&(d=function(e,t,r){let n=e.length,i=t.length,o=0;for(;o<r&&a(e[--n],t[--i]);)o++;return o}(e,i,u-c)),o+=c,s-=d,(r-=d)-(t+=c)==0&&s-o==0)return[];if(t==r){for(l=n(t,[],0);o<s;)l.removed.push(i[o++]);return[l]}if(o==s)return[n(t,[],r-t)];let p=function(e){let t=e.length-1,r=e[0].length-1,n=e[t][r],i=[];for(;t>0||r>0;){if(0==t){i.push(2),r--;continue}if(0==r){i.push(3),t--;continue}let o,a=e[t-1][r-1],s=e[t-1][r],l=e[t][r-1];o=s<l?s<a?s:a:l<a?l:a,o==a?(a==n?i.push(0):(i.push(1),n=a),t--,r--):o==s?(i.push(3),t--,n=s):(i.push(2),r--,n=l)}return i.reverse(),i}(function(e,t,r,n,i,o){let s=o-i+1,l=r-t+1,c=new Array(s);for(let e=0;e<s;e++)c[e]=new Array(l),c[e][0]=e;for(let e=0;e<l;e++)c[0][e]=e;for(let r=1;r<s;r++)for(let o=1;o<l;o++)if(a(e[t+o-1],n[i+r-1]))c[r][o]=c[r-1][o-1];else{let e=c[r-1][o]+1,t=c[r][o-1]+1;c[r][o]=e<t?e:t}return c}(e,t,r,i,o,s));l=void 0;let h=[],f=t,m=o;for(let e=0;e<p.length;e++)switch(p[e]){case 0:l&&(h.push(l),l=void 0),f++,m++;break;case 1:l||(l=n(f,[],0)),l.addedCount++,f++,l.removed.push(i[m]),m++;break;case 2:l||(l=n(f,[],0)),l.addedCount++,f++;break;case 3:l||(l=n(f,[],0)),l.removed.push(i[m]),m++}return l&&h.push(l),h}function o(e,t){return i(e,0,e.length,t,0,t.length)}function a(e,t){return e===t}},21683:(e,t,r)=>{"use strict";r.d(t,{Wc:()=>l,rs:()=>c,t$:()=>d,YA:()=>u});r(56646);let n=0,i=0,o=[],a=0,s=document.createTextNode("");new window.MutationObserver((function(){const e=o.length;for(let t=0;t<e;t++){let e=o[t];if(e)try{e()}catch(e){setTimeout((()=>{throw e}))}}o.splice(0,e),i+=e})).observe(s,{characterData:!0});const l={after:e=>({run:t=>window.setTimeout(t,e),cancel(e){window.clearTimeout(e)}}),run:(e,t)=>window.setTimeout(e,t),cancel(e){window.clearTimeout(e)}},c={run:e=>window.requestAnimationFrame(e),cancel(e){window.cancelAnimationFrame(e)}},d={run:e=>window.requestIdleCallback?window.requestIdleCallback(e):window.setTimeout(e,16),cancel(e){window.cancelIdleCallback?window.cancelIdleCallback(e):window.clearTimeout(e)}},u={run:e=>(s.textContent=a++,o.push(e),n++),cancel(e){const t=e-i;if(t>=0){if(!o[t])throw new Error("invalid async handle: "+e);o[t]=null}}}},56646:()=>{"use strict";window.JSCompiler_renameProperty=function(e,t){return e}},67130:(e,t,r)=>{"use strict";r.d(t,{z:()=>a,n:()=>s});r(56646);const n={},i=/-[a-z]/g,o=/([A-Z])/g;function a(e){return n[e]||(n[e]=e.indexOf("-")<0?e:e.replace(i,(e=>e[1].toUpperCase())))}function s(e){return n[e]||(n[e]=e.replace(o,"-$1").toLowerCase())}},78956:(e,t,r)=>{"use strict";r.d(t,{d:()=>n});r(56646),r(76389),r(21683);class n{constructor(){this._asyncModule=null,this._callback=null,this._timer=null}setConfig(e,t){this._asyncModule=e,this._callback=t,this._timer=this._asyncModule.run((()=>{this._timer=null,this._callback()}))}cancel(){this.isActive()&&(this._asyncModule.cancel(this._timer),this._timer=null)}flush(){this.isActive()&&(this.cancel(),this._callback())}isActive(){return null!=this._timer}static debounce(e,t,r){return e instanceof n?e.cancel():e=new n,e.setConfig(t,r),e}}},20723:(e,t,r)=>{"use strict";r.d(t,{o:()=>a});r(56646);var n=r(4507),i=r(21683);function o(e){return"slot"===e.localName}class a{static getFlattenedNodes(e){return o(e)?(e=e).assignedNodes({flatten:!0}):Array.from(e.childNodes).map((e=>o(e)?(e=e).assignedNodes({flatten:!0}):[e])).reduce(((e,t)=>e.concat(t)),[])}constructor(e,t){this._shadyChildrenObserver=null,this._nativeChildrenObserver=null,this._connected=!1,this._target=e,this.callback=t,this._effectiveNodes=[],this._observer=null,this._scheduled=!1,this._boundSchedule=()=>{this._schedule()},this.connect(),this._schedule()}connect(){o(this._target)?this._listenSlots([this._target]):this._target.children&&(this._listenSlots(this._target.children),window.ShadyDOM?this._shadyChildrenObserver=ShadyDOM.observeChildren(this._target,(e=>{this._processMutations(e)})):(this._nativeChildrenObserver=new MutationObserver((e=>{this._processMutations(e)})),this._nativeChildrenObserver.observe(this._target,{childList:!0}))),this._connected=!0}disconnect(){o(this._target)?this._unlistenSlots([this._target]):this._target.children&&(this._unlistenSlots(this._target.children),window.ShadyDOM&&this._shadyChildrenObserver?(ShadyDOM.unobserveChildren(this._shadyChildrenObserver),this._shadyChildrenObserver=null):this._nativeChildrenObserver&&(this._nativeChildrenObserver.disconnect(),this._nativeChildrenObserver=null)),this._connected=!1}_schedule(){this._scheduled||(this._scheduled=!0,i.YA.run((()=>this.flush())))}_processMutations(e){this._processSlotMutations(e),this.flush()}_processSlotMutations(e){if(e)for(let t=0;t<e.length;t++){let r=e[t];r.addedNodes&&this._listenSlots(r.addedNodes),r.removedNodes&&this._unlistenSlots(r.removedNodes)}}flush(){if(!this._connected)return!1;window.ShadyDOM&&ShadyDOM.flush(),this._nativeChildrenObserver?this._processSlotMutations(this._nativeChildrenObserver.takeRecords()):this._shadyChildrenObserver&&this._processSlotMutations(this._shadyChildrenObserver.takeRecords()),this._scheduled=!1;let e={target:this._target,addedNodes:[],removedNodes:[]},t=this.constructor.getFlattenedNodes(this._target),r=(0,n.c)(t,this._effectiveNodes);for(let t,n=0;n<r.length&&(t=r[n]);n++)for(let r,n=0;n<t.removed.length&&(r=t.removed[n]);n++)e.removedNodes.push(r);for(let n,i=0;i<r.length&&(n=r[i]);i++)for(let r=n.index;r<n.index+n.addedCount;r++)e.addedNodes.push(t[r]);this._effectiveNodes=t;let i=!1;return(e.addedNodes.length||e.removedNodes.length)&&(i=!0,this.callback.call(this._target,e)),i}_listenSlots(e){for(let t=0;t<e.length;t++){let r=e[t];o(r)&&r.addEventListener("slotchange",this._boundSchedule)}}_unlistenSlots(e){for(let t=0;t<e.length;t++){let r=e[t];o(r)&&r.removeEventListener("slotchange",this._boundSchedule)}}}},93252:(e,t,r)=>{"use strict";r.d(t,{E:()=>i,y:()=>a});r(56646),r(78956);let n=[];const i=function(e){n.push(e)};function o(){const e=Boolean(n.length);for(;n.length;)try{n.shift().flush()}catch(e){setTimeout((()=>{throw e}))}return e}const a=function(){let e,t;do{e=window.ShadyDOM&&ShadyDOM.flush(),window.ShadyCSS&&window.ShadyCSS.ScopingShim&&window.ShadyCSS.ScopingShim.flush(),t=o()}while(e||t)}},81668:(e,t,r)=>{"use strict";r.d(t,{NH:()=>N,ys:()=>I,BP:()=>D,nJ:()=>B,IH:()=>$});r(56646);var n=r(21683),i=r(78956),o=r(74460);let a="string"==typeof document.head.style.touchAction,s="__polymerGestures",l="__polymerGesturesHandled",c="__polymerGesturesTouchAction",d=["mousedown","mousemove","mouseup","click"],u=[0,1,4,2],p=function(){try{return 1===new MouseEvent("test",{buttons:1}).buttons}catch(e){return!1}}();function h(e){return d.indexOf(e)>-1}let f=!1;function m(e){if(!h(e)&&"touchend"!==e)return a&&f&&o.f6?{passive:!0}:void 0}!function(){try{let e=Object.defineProperty({},"passive",{get(){f=!0}});window.addEventListener("test",null,e),window.removeEventListener("test",null,e)}catch(e){}}();let y=navigator.userAgent.match(/iP(?:[oa]d|hone)|Android/);const g=[],b={button:!0,input:!0,keygen:!0,meter:!0,output:!0,textarea:!0,progress:!0,select:!0},_={button:!0,command:!0,fieldset:!0,input:!0,keygen:!0,optgroup:!0,option:!0,select:!0,textarea:!0};function v(e){let t=Array.prototype.slice.call(e.labels||[]);if(!t.length){t=[];let r=e.getRootNode();if(e.id){let n=r.querySelectorAll(`label[for = ${e.id}]`);for(let e=0;e<n.length;e++)t.push(n[e])}}return t}let w=function(e){let t=e.sourceCapabilities;var r;if((!t||t.firesTouchEvents)&&(e[l]={skip:!0},"click"===e.type)){let t=!1,n=e.composedPath&&e.composedPath();if(n)for(let e=0;e<n.length;e++){if(n[e].nodeType===Node.ELEMENT_NODE)if("label"===n[e].localName)g.push(n[e]);else if(r=n[e],b[r.localName]){let r=v(n[e]);for(let e=0;e<r.length;e++)t=t||g.indexOf(r[e])>-1}if(n[e]===C.mouse.target)return}if(t)return;e.preventDefault(),e.stopPropagation()}};function x(e){let t=y?["click"]:d;for(let r,n=0;n<t.length;n++)r=t[n],e?(g.length=0,document.addEventListener(r,w,!0)):document.removeEventListener(r,w,!0)}function k(e){let t=e.type;if(!h(t))return!1;if("mousemove"===t){let t=void 0===e.buttons?1:e.buttons;return e instanceof window.MouseEvent&&!p&&(t=u[e.which]||0),Boolean(1&t)}return 0===(void 0===e.button?0:e.button)}let C={mouse:{target:null,mouseIgnoreJob:null},touch:{x:0,y:0,id:-1,scrollDecided:!1}};function E(e,t,r){e.movefn=t,e.upfn=r,document.addEventListener("mousemove",t),document.addEventListener("mouseup",r)}function S(e){document.removeEventListener("mousemove",e.movefn),document.removeEventListener("mouseup",e.upfn),e.movefn=null,e.upfn=null}document.addEventListener("touchend",(function(e){C.mouse.mouseIgnoreJob||x(!0),C.mouse.target=e.composedPath()[0],C.mouse.mouseIgnoreJob=i.d.debounce(C.mouse.mouseIgnoreJob,n.Wc.after(2500),(function(){x(),C.mouse.target=null,C.mouse.mouseIgnoreJob=null}))}),!!f&&{passive:!0});const P={},A=[];function T(e){if(e.composedPath){const t=e.composedPath();return t.length>0?t[0]:e.target}return e.target}function O(e){let t,r=e.type,n=e.currentTarget[s];if(!n)return;let i=n[r];if(i){if(!e[l]&&(e[l]={},"touch"===r.slice(0,5))){let t=(e=e).changedTouches[0];if("touchstart"===r&&1===e.touches.length&&(C.touch.id=t.identifier),C.touch.id!==t.identifier)return;a||"touchstart"!==r&&"touchmove"!==r||function(e){let t=e.changedTouches[0],r=e.type;if("touchstart"===r)C.touch.x=t.clientX,C.touch.y=t.clientY,C.touch.scrollDecided=!1;else if("touchmove"===r){if(C.touch.scrollDecided)return;C.touch.scrollDecided=!0;let r=function(e){let t="auto",r=e.composedPath&&e.composedPath();if(r)for(let e,n=0;n<r.length;n++)if(e=r[n],e[c]){t=e[c];break}return t}(e),n=!1,i=Math.abs(C.touch.x-t.clientX),o=Math.abs(C.touch.y-t.clientY);e.cancelable&&("none"===r?n=!0:"pan-x"===r?n=o>i:"pan-y"===r&&(n=i>o)),n?e.preventDefault():F("track")}}(e)}if(t=e[l],!t.skip){for(let r,n=0;n<A.length;n++)r=A[n],i[r.name]&&!t[r.name]&&r.flow&&r.flow.start.indexOf(e.type)>-1&&r.reset&&r.reset();for(let n,o=0;o<A.length;o++)n=A[o],i[n.name]&&!t[n.name]&&(t[n.name]=!0,n[r](e))}}}function N(e,t,r){return!!P[t]&&(function(e,t,r){let n=P[t],i=n.deps,o=n.name,a=e[s];a||(e[s]=a={});for(let t,r,n=0;n<i.length;n++)t=i[n],y&&h(t)&&"click"!==t||(r=a[t],r||(a[t]=r={_count:0}),0===r._count&&e.addEventListener(t,O,m(t)),r[o]=(r[o]||0)+1,r._count=(r._count||0)+1);e.addEventListener(t,r),n.touchAction&&D(e,n.touchAction)}(e,t,r),!0)}function I(e,t,r){return!!P[t]&&(function(e,t,r){let n=P[t],i=n.deps,o=n.name,a=e[s];if(a)for(let t,r,n=0;n<i.length;n++)t=i[n],r=a[t],r&&r[o]&&(r[o]=(r[o]||1)-1,r._count=(r._count||1)-1,0===r._count&&e.removeEventListener(t,O,m(t)));e.removeEventListener(t,r)}(e,t,r),!0)}function R(e){A.push(e);for(let t=0;t<e.emits.length;t++)P[e.emits[t]]=e}function D(e,t){a&&e instanceof HTMLElement&&n.YA.run((()=>{e.style.touchAction=t})),e[c]=t}function z(e,t,r){let n=new Event(t,{bubbles:!0,cancelable:!0,composed:!0});if(n.detail=r,e.dispatchEvent(n),n.defaultPrevented){let e=r.preventer||r.sourceEvent;e&&e.preventDefault&&e.preventDefault()}}function F(e){let t=function(e){for(let t,r=0;r<A.length;r++){t=A[r];for(let r,n=0;n<t.emits.length;n++)if(r=t.emits[n],r===e)return t}return null}(e);t.info&&(t.info.prevent=!0)}function L(e,t,r,n){t&&z(t,e,{x:r.clientX,y:r.clientY,sourceEvent:r,preventer:n,prevent:function(e){return F(e)}})}function M(e,t,r){if(e.prevent)return!1;if(e.started)return!0;let n=Math.abs(e.x-t),i=Math.abs(e.y-r);return n>=5||i>=5}function j(e,t,r){if(!t)return;let n,i=e.moves[e.moves.length-2],o=e.moves[e.moves.length-1],a=o.x-e.x,s=o.y-e.y,l=0;i&&(n=o.x-i.x,l=o.y-i.y),z(t,"track",{state:e.state,x:r.clientX,y:r.clientY,dx:a,dy:s,ddx:n,ddy:l,sourceEvent:r,hover:function(){return function(e,t){let r=document.elementFromPoint(e,t),n=r;for(;n&&n.shadowRoot&&!window.ShadyDOM;){let i=n;if(n=n.shadowRoot.elementFromPoint(e,t),i===n)break;n&&(r=n)}return r}(r.clientX,r.clientY)}})}function H(e,t,r){let n=Math.abs(t.clientX-e.x),i=Math.abs(t.clientY-e.y),o=T(r||t);!o||_[o.localName]&&o.hasAttribute("disabled")||(isNaN(n)||isNaN(i)||n<=25&&i<=25||function(e){if("click"===e.type){if(0===e.detail)return!0;let t=T(e);if(!t.nodeType||t.nodeType!==Node.ELEMENT_NODE)return!0;let r=t.getBoundingClientRect(),n=e.pageX,i=e.pageY;return!(n>=r.left&&n<=r.right&&i>=r.top&&i<=r.bottom)}return!1}(t))&&(e.prevent||z(o,"tap",{x:t.clientX,y:t.clientY,sourceEvent:t,preventer:r}))}R({name:"downup",deps:["mousedown","touchstart","touchend"],flow:{start:["mousedown","touchstart"],end:["mouseup","touchend"]},emits:["down","up"],info:{movefn:null,upfn:null},reset:function(){S(this.info)},mousedown:function(e){if(!k(e))return;let t=T(e),r=this;E(this.info,(function(e){k(e)||(L("up",t,e),S(r.info))}),(function(e){k(e)&&L("up",t,e),S(r.info)})),L("down",t,e)},touchstart:function(e){L("down",T(e),e.changedTouches[0],e)},touchend:function(e){L("up",T(e),e.changedTouches[0],e)}}),R({name:"track",touchAction:"none",deps:["mousedown","touchstart","touchmove","touchend"],flow:{start:["mousedown","touchstart"],end:["mouseup","touchend"]},emits:["track"],info:{x:0,y:0,state:"start",started:!1,moves:[],addMove:function(e){this.moves.length>2&&this.moves.shift(),this.moves.push(e)},movefn:null,upfn:null,prevent:!1},reset:function(){this.info.state="start",this.info.started=!1,this.info.moves=[],this.info.x=0,this.info.y=0,this.info.prevent=!1,S(this.info)},mousedown:function(e){if(!k(e))return;let t=T(e),r=this,n=function(e){let n=e.clientX,i=e.clientY;M(r.info,n,i)&&(r.info.state=r.info.started?"mouseup"===e.type?"end":"track":"start","start"===r.info.state&&F("tap"),r.info.addMove({x:n,y:i}),k(e)||(r.info.state="end",S(r.info)),t&&j(r.info,t,e),r.info.started=!0)};E(this.info,n,(function(e){r.info.started&&n(e),S(r.info)})),this.info.x=e.clientX,this.info.y=e.clientY},touchstart:function(e){let t=e.changedTouches[0];this.info.x=t.clientX,this.info.y=t.clientY},touchmove:function(e){let t=T(e),r=e.changedTouches[0],n=r.clientX,i=r.clientY;M(this.info,n,i)&&("start"===this.info.state&&F("tap"),this.info.addMove({x:n,y:i}),j(this.info,t,r),this.info.state="track",this.info.started=!0)},touchend:function(e){let t=T(e),r=e.changedTouches[0];this.info.started&&(this.info.state="end",this.info.addMove({x:r.clientX,y:r.clientY}),j(this.info,t,r))}}),R({name:"tap",deps:["mousedown","click","touchstart","touchend"],flow:{start:["mousedown","touchstart"],end:["click","touchend"]},emits:["tap"],info:{x:NaN,y:NaN,prevent:!1},reset:function(){this.info.x=NaN,this.info.y=NaN,this.info.prevent=!1},mousedown:function(e){k(e)&&(this.info.x=e.clientX,this.info.y=e.clientY)},click:function(e){k(e)&&H(this.info,e)},touchstart:function(e){const t=e.changedTouches[0];this.info.x=t.clientX,this.info.y=t.clientY},touchend:function(e){H(this.info,e.changedTouches[0],e)}});const B=T,$=N},50856:(e,t,r)=>{"use strict";r.d(t,{d:()=>o});r(56646);class n{constructor(e){this.value=e.toString()}toString(){return this.value}}function i(e){if(e instanceof n)return e.value;throw new Error("non-literal value passed to Polymer's htmlLiteral function: "+e)}const o=function(e,...t){const r=document.createElement("template");return r.innerHTML=t.reduce(((t,r,o)=>t+function(e){if(e instanceof HTMLTemplateElement)return e.innerHTML;if(e instanceof n)return i(e);throw new Error("non-template value passed to Polymer's html function: "+e)}(r)+e[o+1]),e[0]),r}},76389:(e,t,r)=>{"use strict";r.d(t,{o:()=>o});r(56646);let n=0;function i(){}i.prototype.__mixinApplications,i.prototype.__mixinSet;const o=function(e){let t=e.__mixinApplications;t||(t=new WeakMap,e.__mixinApplications=t);let r=n++;return function(n){let i=n.__mixinSet;if(i&&i[r])return n;let o=t,a=o.get(n);a||(a=e(n),o.set(n,a));let s=Object.create(a.__mixinSet||i||null);return s[r]=!0,a.__mixinSet=s,a}}},4059:(e,t,r)=>{"use strict";r.d(t,{AZ:()=>n,Jz:()=>i,jg:()=>o,SG:()=>a,Iu:()=>s,wB:()=>l,Fv:()=>c,U2:()=>u,t8:()=>p});r(56646);function n(e){return e.indexOf(".")>=0}function i(e){let t=e.indexOf(".");return-1===t?e:e.slice(0,t)}function o(e,t){return 0===e.indexOf(t+".")}function a(e,t){return 0===t.indexOf(e+".")}function s(e,t,r){return t+r.slice(e.length)}function l(e,t){return e===t||o(e,t)||a(e,t)}function c(e){if(Array.isArray(e)){let t=[];for(let r=0;r<e.length;r++){let n=e[r].toString().split(".");for(let e=0;e<n.length;e++)t.push(n[e])}return t.join(".")}return e}function d(e){return Array.isArray(e)?c(e).split("."):e.toString().split(".")}function u(e,t,r){let n=e,i=d(t);for(let e=0;e<i.length;e++){if(!n)return;n=n[i[e]]}return r&&(r.path=i.join(".")),n}function p(e,t,r){let n=e,i=d(t),o=i[i.length-1];if(i.length>1){for(let e=0;e<i.length-1;e++){if(n=n[i[e]],!n)return}n[o]=r}else n[t]=r;return i.join(".")}},87529:(e,t,r)=>{"use strict";r.d(t,{T8:()=>c});r(56646);let n=!1,i=[],o=[];function a(){n=!0,requestAnimationFrame((function(){n=!1,s(i),setTimeout((function(){!function(e){for(let t=0,r=e.length;t<r;t++)l(e.shift())}(o)}))}))}function s(e){for(;e.length;)l(e.shift())}function l(e){const t=e[0],r=e[1],n=e[2];try{r.apply(t,n)}catch(e){setTimeout((()=>{throw e}))}}function c(e,t,r){n||a(),o.push([e,t,r])}},42687:(e,t,r)=>{"use strict";r.d(t,{Kk:()=>s,Rq:()=>l,iY:()=>c});r(56646);let n,i,o=/(url\()([^)]*)(\))/g,a=/(^\/)|(^#)|(^[\w-\d]*:)/;function s(e,t){if(e&&a.test(e))return e;if(void 0===n){n=!1;try{const e=new URL("b","http://a");e.pathname="c%20d",n="http://a/c%20d"===e.href}catch(e){}}return t||(t=document.baseURI||window.location.href),n?new URL(e,t).href:(i||(i=document.implementation.createHTMLDocument("temp"),i.base=i.createElement("base"),i.head.appendChild(i.base),i.anchor=i.createElement("a"),i.body.appendChild(i.anchor)),i.base.href=t,i.anchor.href=e,i.anchor.href||e)}function l(e,t){return e.replace(o,(function(e,r,n,i){return r+"'"+s(n.replace(/["']/g,""),t)+"'"+i}))}function c(e){return e.substring(0,e.lastIndexOf("/")+1)}},74460:(e,t,r)=>{"use strict";r.d(t,{my:()=>i,sM:()=>o,v1:()=>a,f6:()=>s,XN:()=>l,ZN:()=>c});r(56646);var n=r(42687);const i=!window.ShadyDOM;Boolean(!window.ShadyCSS||window.ShadyCSS.nativeCss),window.customElements.polyfillWrapFlushCallback;let o=(0,n.iY)(document.baseURI||window.location.href);let a=window.Polymer&&window.Polymer.sanitizeDOMValue||void 0;let s=!1;let l=!1;let c=!1},15392:(e,t,r)=>{"use strict";r.d(t,{uT:()=>d,lx:()=>u,jv:()=>h});var n=r(21384),i=r(42687);const o="shady-unscoped";function a(e){return n.t.import(e)}function s(e){let t=e.body?e.body:e;const r=(0,i.Rq)(t.textContent,e.baseURI),n=document.createElement("style");return n.textContent=r,n}function l(e){const t=e.trim().split(/\s+/),r=[];for(let e=0;e<t.length;e++)r.push(...c(t[e]));return r}function c(e){const t=a(e);if(!t)return console.warn("Could not find style data in module named",e),[];if(void 0===t._styles){const e=[];e.push(...p(t));const r=t.querySelector("template");r&&e.push(...d(r,t.assetpath)),t._styles=e}return t._styles}function d(e,t){if(!e._styles){const r=[],n=e.content.querySelectorAll("style");for(let e=0;e<n.length;e++){let o=n[e],a=o.getAttribute("include");a&&r.push(...l(a).filter((function(e,t,r){return r.indexOf(e)===t}))),t&&(o.textContent=(0,i.Rq)(o.textContent,t)),r.push(o)}e._styles=r}return e._styles}function u(e){let t=a(e);return t?p(t):[]}function p(e){const t=[],r=e.querySelectorAll("link[rel=import][type~=css]");for(let e=0;e<r.length;e++){let n=r[e];if(n.import){const e=n.import,r=n.hasAttribute(o);if(r&&!e._unscopedStyle){const t=s(e);t.setAttribute(o,""),e._unscopedStyle=t}else e._style||(e._style=s(e));t.push(r?e._unscopedStyle:e._style)}}return t}function h(e){let t=e.trim().split(/\s+/),r="";for(let e=0;e<t.length;e++)r+=f(t[e]);return r}function f(e){let t=a(e);if(t&&void 0===t._cssText){let e=m(t),r=t.querySelector("template");r&&(e+=function(e,t){let r="";const n=d(e,t);for(let e=0;e<n.length;e++){let t=n[e];t.parentNode&&t.parentNode.removeChild(t),r+=t.textContent}return r}(r,t.assetpath)),t._cssText=e||null}return t||console.warn("Could not find style data in module named",e),t&&t._cssText||""}function m(e){let t="",r=p(e);for(let e=0;e<r.length;e++)t+=r[e].textContent;return t}},52521:(e,t,r)=>{"use strict";r.d(t,{Uv:()=>b,GJ:()=>_});r(56646);var n=r(40729),i=r(18691),o=r(74460);let a=null;function s(){return a}s.prototype=Object.create(HTMLTemplateElement.prototype,{constructor:{value:s,writable:!0}});const l=(0,n.q)(s),c=(0,i.E)(l);const d=(0,n.q)(class{});class u extends d{constructor(e){super(),this._configureProperties(e),this.root=this._stampTemplate(this.__dataHost);let t=this.children=[];for(let e=this.root.firstChild;e;e=e.nextSibling)t.push(e),e.__templatizeInstance=this;this.__templatizeOwner&&this.__templatizeOwner.__hideTemplateChildren__&&this._showHideChildren(!0);let r=this.__templatizeOptions;(e&&r.instanceProps||!r.instanceProps)&&this._enableProperties()}_configureProperties(e){if(this.__templatizeOptions.forwardHostProp)for(let e in this.__hostProps)this._setPendingProperty(e,this.__dataHost["_host_"+e]);for(let t in e)this._setPendingProperty(t,e[t])}forwardHostProp(e,t){this._setPendingPropertyOrPath(e,t,!1,!0)&&this.__dataHost._enqueueClient(this)}_addEventListenerToNode(e,t,r){if(this._methodHost&&this.__templatizeOptions.parentModel)this._methodHost._addEventListenerToNode(e,t,(e=>{e.model=this,r(e)}));else{let n=this.__dataHost.__dataHost;n&&n._addEventListenerToNode(e,t,r)}}_showHideChildren(e){let t=this.children;for(let r=0;r<t.length;r++){let n=t[r];if(Boolean(e)!=Boolean(n.__hideTemplateChildren__))if(n.nodeType===Node.TEXT_NODE)e?(n.__polymerTextContent__=n.textContent,n.textContent=""):n.textContent=n.__polymerTextContent__;else if("slot"===n.localName)if(e)n.__polymerReplaced__=document.createComment("hidden-slot"),n.parentNode.replaceChild(n.__polymerReplaced__,n);else{const e=n.__polymerReplaced__;e&&e.parentNode.replaceChild(n,e)}else n.style&&(e?(n.__polymerDisplay__=n.style.display,n.style.display="none"):n.style.display=n.__polymerDisplay__);n.__hideTemplateChildren__=e,n._showHideChildren&&n._showHideChildren(e)}}_setUnmanagedPropertyToNode(e,t,r){e.__hideTemplateChildren__&&e.nodeType==Node.TEXT_NODE&&"textContent"==t?e.__polymerTextContent__=r:super._setUnmanagedPropertyToNode(e,t,r)}get parentModel(){let e=this.__parentModel;if(!e){let t;e=this;do{e=e.__dataHost.__dataHost}while((t=e.__templatizeOptions)&&!t.parentModel);this.__parentModel=e}return e}dispatchEvent(e){return!0}}u.prototype.__dataHost,u.prototype.__templatizeOptions,u.prototype._methodHost,u.prototype.__templatizeOwner,u.prototype.__hostProps;const p=(0,i.E)(u);function h(e){let t=e.__dataHost;return t&&t._methodHost||t}function f(e,t,r){let n=r.mutableData?p:u,i=class extends n{};return i.prototype.__templatizeOptions=r,i.prototype._bindTemplate(e),function(e,t,r,n){let i=r.hostProps||{};for(let t in n.instanceProps){delete i[t];let r=n.notifyInstanceProp;r&&e.prototype._addPropertyEffect(t,e.prototype.PROPERTY_EFFECT_TYPES.NOTIFY,{fn:g(t,r)})}if(n.forwardHostProp&&t.__dataHost)for(let t in i)e.prototype._addPropertyEffect(t,e.prototype.PROPERTY_EFFECT_TYPES.NOTIFY,{fn:function(e,t,r){e.__dataHost._setPendingPropertyOrPath("_host_"+t,r[t],!0,!0)}})}(i,e,t,r),i}function m(e,t,r){let n=r.forwardHostProp;if(n){let i=t.templatizeTemplateClass;if(!i){let e=r.mutableData?c:l;i=t.templatizeTemplateClass=class extends e{};let o=t.hostProps;for(let e in o)i.prototype._addPropertyEffect("_host_"+e,i.prototype.PROPERTY_EFFECT_TYPES.PROPAGATE,{fn:y(e,n)}),i.prototype._createNotifyingProperty("_host_"+e)}!function(e,t){a=e,Object.setPrototypeOf(e,t.prototype),new t,a=null}(e,i),e.__dataProto&&Object.assign(e.__data,e.__dataProto),e.__dataTemp={},e.__dataPending=null,e.__dataOld=null,e._enableProperties()}}function y(e,t){return function(e,r,n){t.call(e.__templatizeOwner,r.substring("_host_".length),n[r])}}function g(e,t){return function(e,r,n){t.call(e.__templatizeOwner,e,r,n[r])}}function b(e,t,r){if(o.XN&&!h(e))throw new Error("strictTemplatePolicy: template owner not trusted");if(r=r||{},e.__templatizeOwner)throw new Error("A <template> can only be templatized once");e.__templatizeOwner=t;let n=(t?t.constructor:u)._parseTemplate(e),i=n.templatizeInstanceClass;i||(i=f(e,n,r),n.templatizeInstanceClass=i),m(e,n,r);let a=class extends i{};return a.prototype._methodHost=h(e),a.prototype.__dataHost=e,a.prototype.__templatizeOwner=t,a.prototype.__hostProps=n.hostProps,a=a,a}function _(e,t){let r;for(;t;)if(r=t.__templatizeInstance){if(r.__dataHost==e)return r;t=r.__dataHost}else t=t.parentNode;return null}},28426:(e,t,r)=>{"use strict";r.d(t,{H3:()=>i});var n=r(36608);r(50856);const i=(0,n.SH)(HTMLElement)},43437:(e,t,r)=>{"use strict";r.d(t,{XY:()=>y,dy:()=>m.d});var n=r(81850),i=(r(9672),r(37692),r(56646),r(40729)),o=r(18691),a=r(60995),s=r(74460);const l=(0,a._)((0,o.w)((0,i.q)(HTMLElement)));customElements.define("dom-bind",class extends l{static get observedAttributes(){return["mutable-data"]}constructor(){if(super(),s.XN)throw new Error("strictTemplatePolicy: dom-bind not allowed");this.root=null,this.$=null,this.__children=null}attributeChangedCallback(){this.mutableData=!0}connectedCallback(){this.style.display="none",this.render()}disconnectedCallback(){this.__removeChildren()}__insertChildren(){this.parentNode.insertBefore(this.root,this)}__removeChildren(){if(this.__children)for(let e=0;e<this.__children.length;e++)this.root.appendChild(this.__children[e])}render(){let e;if(!this.__children){if(e=e||this.querySelector("template"),!e){let t=new MutationObserver((()=>{if(e=this.querySelector("template"),!e)throw new Error("dom-bind requires a <template> child");t.disconnect(),this.render()}));return void t.observe(this,{childList:!0})}this.root=this._stampTemplate(e),this.$=this.root.$,this.__children=[];for(let e=this.root.firstChild;e;e=e.nextSibling)this.__children[this.__children.length]=e;this._enableProperties()}this.__insertChildren(),this.dispatchEvent(new CustomEvent("dom-change",{bubbles:!0,composed:!0}))}});r(42173),r(26047);var c=r(28426),d=r(76389),u=r(4507),p=r(36608);let h=(0,d.o)((e=>{let t=(0,p.SH)(e);return class extends t{static get properties(){return{items:{type:Array},multi:{type:Boolean,value:!1},selected:{type:Object,notify:!0},selectedItem:{type:Object,notify:!0},toggle:{type:Boolean,value:!1}}}static get observers(){return["__updateSelection(multi, items.*)"]}constructor(){super(),this.__lastItems=null,this.__lastMulti=null,this.__selectedMap=null}__updateSelection(e,t){let r=t.path;if("items"==r){let r=t.base||[],n=this.__lastItems;if(e!==this.__lastMulti&&this.clearSelection(),n){let e=(0,u.c)(r,n);this.__applySplices(e)}this.__lastItems=r,this.__lastMulti=e}else if("items.splices"==t.path)this.__applySplices(t.value.indexSplices);else{let e=r.slice("items.".length),t=parseInt(e,10);e.indexOf(".")<0&&e==t&&this.__deselectChangedIdx(t)}}__applySplices(e){let t=this.__selectedMap;for(let r=0;r<e.length;r++){let n=e[r];t.forEach(((e,r)=>{e<n.index||(e>=n.index+n.removed.length?t.set(r,e+n.addedCount-n.removed.length):t.set(r,-1))}));for(let e=0;e<n.addedCount;e++){let r=n.index+e;t.has(this.items[r])&&t.set(this.items[r],r)}}this.__updateLinks();let r=0;t.forEach(((e,n)=>{e<0?(this.multi?this.splice("selected",r,1):this.selected=this.selectedItem=null,t.delete(n)):r++}))}__updateLinks(){if(this.__dataLinkedPaths={},this.multi){let e=0;this.__selectedMap.forEach((t=>{t>=0&&this.linkPaths("items."+t,"selected."+e++)}))}else this.__selectedMap.forEach((e=>{this.linkPaths("selected","items."+e),this.linkPaths("selectedItem","items."+e)}))}clearSelection(){this.__dataLinkedPaths={},this.__selectedMap=new Map,this.selected=this.multi?[]:null,this.selectedItem=null}isSelected(e){return this.__selectedMap.has(e)}isIndexSelected(e){return this.isSelected(this.items[e])}__deselectChangedIdx(e){let t=this.__selectedIndexForItemIndex(e);if(t>=0){let e=0;this.__selectedMap.forEach(((r,n)=>{t==e++&&this.deselect(n)}))}}__selectedIndexForItemIndex(e){let t=this.__dataLinkedPaths["items."+e];if(t)return parseInt(t.slice("selected.".length),10)}deselect(e){let t=this.__selectedMap.get(e);if(t>=0){let r;this.__selectedMap.delete(e),this.multi&&(r=this.__selectedIndexForItemIndex(t)),this.__updateLinks(),this.multi?this.splice("selected",r,1):this.selected=this.selectedItem=null}}deselectIndex(e){this.deselect(this.items[e])}select(e){this.selectIndex(this.items.indexOf(e))}selectIndex(e){let t=this.items[e];this.isSelected(t)?this.toggle&&this.deselectIndex(e):(this.multi||this.__selectedMap.clear(),this.__selectedMap.set(t,e),this.__updateLinks(),this.multi?this.push("selected",t):this.selected=this.selectedItem=t)}}}))(c.H3);class f extends h{static get is(){return"array-selector"}}customElements.define(f.is,f);r(5618),r(72419);var m=r(50856);const y=(0,n.x)(HTMLElement).prototype},60309:(e,t,r)=>{"use strict";r.d(t,{CN:()=>n,$T:()=>i,mA:()=>o});const n=/(?:^|[;\s{]\s*)(--[\w-]*?)\s*:\s*(?:((?:'(?:\\'|.)*?'|"(?:\\"|.)*?"|\([^)]*?\)|[^};{])+)|\{([^}]*)\}(?:(?=[;\s}])|$))/gi,i=/(?:^|\W+)@apply\s*\(?([^);\n]*)\)?/gi,o=/@media\s(.*)/},10868:(e,t,r)=>{"use strict";r.d(t,{wW:()=>i,B7:()=>o,OH:()=>a});var n=r(60309);function i(e,t){for(let r in t)null===r?e.style.removeProperty(r):e.style.setProperty(r,t[r])}function o(e,t){const r=window.getComputedStyle(e).getPropertyValue(t);return r?r.trim():""}function a(e){const t=n.$T.test(e)||n.CN.test(e);return n.$T.lastIndex=0,n.CN.lastIndex=0,t}},34816:(e,t,r)=>{"use strict";r.d(t,{ZP:()=>u});let n,i=null,o=window.HTMLImports&&window.HTMLImports.whenReady||null;function a(e){requestAnimationFrame((function(){o?o(e):(i||(i=new Promise((e=>{n=e})),"complete"===document.readyState?n():document.addEventListener("readystatechange",(()=>{"complete"===document.readyState&&n()}))),i.then((function(){e&&e()})))}))}const s="__seenByShadyCSS",l="__shadyCSSCachedStyle";let c=null,d=null;class u{constructor(){this.customStyles=[],this.enqueued=!1,a((()=>{window.ShadyCSS.flushCustomStyles&&window.ShadyCSS.flushCustomStyles()}))}enqueueDocumentValidation(){!this.enqueued&&d&&(this.enqueued=!0,a(d))}addCustomStyle(e){e[s]||(e[s]=!0,this.customStyles.push(e),this.enqueueDocumentValidation())}getStyleForCustomStyle(e){if(e[l])return e[l];let t;return t=e.getStyle?e.getStyle():e,t}processStyles(){const e=this.customStyles;for(let t=0;t<e.length;t++){const r=e[t];if(r[l])continue;const n=this.getStyleForCustomStyle(r);if(n){const e=n.__appliedElement||n;c&&c(e),r[l]=e}}return e}}u.prototype.addCustomStyle=u.prototype.addCustomStyle,u.prototype.getStyleForCustomStyle=u.prototype.getStyleForCustomStyle,u.prototype.processStyles=u.prototype.processStyles,Object.defineProperties(u.prototype,{transformCallback:{get:()=>c,set(e){c=e}},validateCallback:{get:()=>d,set(e){let t=!1;d||(t=!0),d=e,t&&this.enqueueDocumentValidation()}}})},26539:(e,t,r)=>{"use strict";r.d(t,{WA:()=>n,Cp:()=>o,jF:()=>s,rd:()=>l});const n=!(window.ShadyDOM&&window.ShadyDOM.inUse);let i,o;function a(e){i=(!e||!e.shimcssproperties)&&(n||Boolean(!navigator.userAgent.match(/AppleWebKit\/601|Edge\/15/)&&window.CSS&&CSS.supports&&CSS.supports("box-shadow","0 0 0 var(--foo)")))}window.ShadyCSS&&void 0!==window.ShadyCSS.cssBuild&&(o=window.ShadyCSS.cssBuild);const s=Boolean(window.ShadyCSS&&window.ShadyCSS.disableRuntime);window.ShadyCSS&&void 0!==window.ShadyCSS.nativeCss?i=window.ShadyCSS.nativeCss:window.ShadyCSS?(a(window.ShadyCSS),window.ShadyCSS=void 0):a(window.WebComponents&&window.WebComponents.flags);const l=i},95282:(e,t,r)=>{"use strict";r.d(t,{_:()=>i,B:()=>o});var n=r(12902);const i=(e,t,r,i)=>{if(e[t])return e[t];let o,a=0,s=(0,n.M)();const l=()=>r(e).then((e=>s.setState(e,!0))),c=()=>l().catch((t=>{if(e.connected)throw t}));return e[t]={get state(){return s.state},refresh:l,subscribe(t){a++,1===a&&(i&&(o=i(e,s)),e.addEventListener("ready",c),c());const r=s.subscribe(t);return void 0!==s.state&&setTimeout((()=>t(s.state)),0),()=>{r(),a--,a||(o&&o.then((e=>{e()})),e.removeEventListener("ready",l))}}},e[t]},o=(e,t,r,n,o)=>i(n,e,t,r).subscribe(o)},23553:(e,t,r)=>{"use strict";r.d(t,{Pz:()=>i,U2:()=>o,iE:()=>a,PR:()=>s,_D:()=>l});var n=r(36007);const i=e=>e.sendMessagePromise(n.$q()),o=e=>e.sendMessagePromise(n.uZ()),a=e=>e.sendMessagePromise(n.vc()),s=e=>e.sendMessagePromise(n.EA()),l=(e,t,r,i)=>e.sendMessagePromise(n._D(t,r,i))},4915:(e,t,r)=>{"use strict";r.d(t,{wQ:()=>l,UE:()=>c,dL:()=>d,u5:()=>u});var n=r(95282),i=r(23553);function o(e,t){return void 0===e?null:{components:e.components.concat(t.data.component)}}const a=e=>(0,i.iE)(e),s=(e,t)=>Promise.all([e.subscribeEvents(t.action(o),"component_loaded"),e.subscribeEvents((()=>a(e).then((e=>t.setState(e,!0)))),"core_config_updated")]).then((e=>()=>e.forEach((e=>e())))),l=(e,t)=>(e=>(0,n._)(e,"_cnf",a,s))(e).subscribe(t),c="NOT_RUNNING",d="STARTING",u="RUNNING"},36007:(e,t,r)=>{"use strict";function n(e){return{type:"auth",access_token:e}}function i(){return{type:"get_states"}}function o(){return{type:"get_config"}}function a(){return{type:"get_services"}}function s(){return{type:"auth/current_user"}}function l(e,t,r){const n={type:"call_service",domain:e,service:t};return r&&(n.service_data=r),n}function c(e){const t={type:"subscribe_events"};return e&&(t.event_type=e),t}function d(e){return{type:"unsubscribe_events",subscription:e}}function u(){return{type:"ping"}}function p(e,t){return{type:"result",success:!1,error:{code:e,message:t}}}r.d(t,{I8:()=>n,$q:()=>i,vc:()=>o,uZ:()=>a,EA:()=>s,_D:()=>l,a:()=>c,Mt:()=>d,qE:()=>u,vU:()=>p})},12902:(e,t,r)=>{"use strict";r.d(t,{M:()=>n});const n=e=>{let t=[];function r(r,n){e=n?r:Object.assign(Object.assign({},e),r);let i=t;for(let t=0;t<i.length;t++)i[t](e)}return{get state(){return e},action(t){function n(e){r(e,!1)}return function(){let r=[e];for(let e=0;e<arguments.length;e++)r.push(arguments[e]);let i=t.apply(this,r);if(null!=i)return i instanceof Promise?i.then(n):n(i)}},setState:r,subscribe:e=>(t.push(e),()=>{!function(e){let r=[];for(let n=0;n<t.length;n++)t[n]===e?e=null:r.push(t[n]);t=r}(e)})}}},87466:(e,t,r)=>{"use strict";r.d(t,{Mo:()=>n,Cb:()=>o,sz:()=>a,IO:()=>s,GC:()=>l,Kt:()=>c,hO:()=>p});const n=e=>t=>"function"==typeof t?((e,t)=>(window.customElements.define(e,t),t))(e,t):((e,t)=>{const{kind:r,elements:n}=t;return{kind:r,elements:n,finisher(t){window.customElements.define(e,t)}}})(e,t),i=(e,t)=>"method"===t.kind&&t.descriptor&&!("value"in t.descriptor)?Object.assign(Object.assign({},t),{finisher(r){r.createProperty(t.key,e)}}):{kind:"field",key:Symbol(),placement:"own",descriptor:{},initializer(){"function"==typeof t.initializer&&(this[t.key]=t.initializer.call(this))},finisher(r){r.createProperty(t.key,e)}};function o(e){return(t,r)=>void 0!==r?((e,t,r)=>{t.constructor.createProperty(r,e)})(e,t,r):i(e,t)}function a(e){return o({attribute:!1,hasChanged:null==e?void 0:e.hasChanged})}function s(e,t){return(r,n)=>{const i={get(){return this.renderRoot.querySelector(e)},enumerable:!0,configurable:!0};if(t){const t="symbol"==typeof n?Symbol():"__"+n;i.get=function(){return void 0===this[t]&&(this[t]=this.renderRoot.querySelector(e)),this[t]}}return void 0!==n?d(i,r,n):u(i,r)}}function l(e){return(t,r)=>{const n={async get(){return await this.updateComplete,this.renderRoot.querySelector(e)},enumerable:!0,configurable:!0};return void 0!==r?d(n,t,r):u(n,t)}}function c(e){return(t,r)=>{const n={get(){return this.renderRoot.querySelectorAll(e)},enumerable:!0,configurable:!0};return void 0!==r?d(n,t,r):u(n,t)}}const d=(e,t,r)=>{Object.defineProperty(t,r,e)},u=(e,t)=>({kind:"method",placement:"prototype",key:t.key,descriptor:e});function p(e){return(t,r)=>void 0!==r?((e,t,r)=>{Object.assign(t[r],e)})(e,t,r):((e,t)=>Object.assign(Object.assign({},t),{finisher(r){Object.assign(r.prototype[t.key],e)}}))(e,t)}const h=Element.prototype;h.msMatchesSelector||h.webkitMatchesSelector},15652:(e,t,r)=>{"use strict";r.d(t,{oi:()=>O,f4:()=>x,iv:()=>A,Mo:()=>k.Mo,hO:()=>k.hO,dy:()=>u.dy,sz:()=>k.sz,Cb:()=>k.Cb,IO:()=>k.IO,Kt:()=>k.Kt,GC:()=>k.GC,YP:()=>u.YP,$m:()=>P});var n=r(50115),i=r(27283);function o(e,t){const{element:{content:r},parts:n}=e,i=document.createTreeWalker(r,133,null,!1);let o=s(n),a=n[o],l=-1,c=0;const d=[];let u=null;for(;i.nextNode();){l++;const e=i.currentNode;for(e.previousSibling===u&&(u=null),t.has(e)&&(d.push(e),null===u&&(u=e)),null!==u&&c++;void 0!==a&&a.index===l;)a.index=null!==u?-1:a.index-c,o=s(n,o),a=n[o]}d.forEach((e=>e.parentNode.removeChild(e)))}const a=e=>{let t=11===e.nodeType?0:1;const r=document.createTreeWalker(e,133,null,!1);for(;r.nextNode();)t++;return t},s=(e,t=-1)=>{for(let r=t+1;r<e.length;r++){const t=e[r];if((0,i.pC)(t))return r}return-1};var l=r(84677),c=r(92530),d=r(37581),u=r(94707);const p=(e,t)=>`${e}--${t}`;let h=!0;void 0===window.ShadyCSS?h=!1:void 0===window.ShadyCSS.prepareTemplateDom&&(console.warn("Incompatible ShadyCSS version detected. Please update to at least @webcomponents/webcomponentsjs@2.0.2 and @webcomponents/shadycss@1.3.1."),h=!1);const f=e=>t=>{const r=p(t.type,e);let n=c.r.get(r);void 0===n&&(n={stringsArray:new WeakMap,keyString:new Map},c.r.set(r,n));let o=n.stringsArray.get(t.strings);if(void 0!==o)return o;const a=t.strings.join(i.Jw);if(o=n.keyString.get(a),void 0===o){const r=t.getTemplateElement();h&&window.ShadyCSS.prepareTemplateDom(r,e),o=new i.YS(t,r),n.keyString.set(a,o)}return n.stringsArray.set(t.strings,o),o},m=["html","svg"],y=new Set,g=(e,t,r)=>{y.add(e);const n=r?r.element:document.createElement("template"),i=t.querySelectorAll("style"),{length:l}=i;if(0===l)return void window.ShadyCSS.prepareTemplateStyles(n,e);const d=document.createElement("style");for(let e=0;e<l;e++){const t=i[e];t.parentNode.removeChild(t),d.textContent+=t.textContent}(e=>{m.forEach((t=>{const r=c.r.get(p(t,e));void 0!==r&&r.keyString.forEach((e=>{const{element:{content:t}}=e,r=new Set;Array.from(t.querySelectorAll("style")).forEach((e=>{r.add(e)})),o(e,r)}))}))})(e);const u=n.content;r?function(e,t,r=null){const{element:{content:n},parts:i}=e;if(null==r)return void n.appendChild(t);const o=document.createTreeWalker(n,133,null,!1);let l=s(i),c=0,d=-1;for(;o.nextNode();)for(d++,o.currentNode===r&&(c=a(t),r.parentNode.insertBefore(t,r));-1!==l&&i[l].index===d;){if(c>0){for(;-1!==l;)i[l].index+=c,l=s(i,l);return}l=s(i,l)}}(r,d,u.firstChild):u.insertBefore(d,u.firstChild),window.ShadyCSS.prepareTemplateStyles(n,e);const h=u.querySelector("style");if(window.ShadyCSS.nativeShadow&&null!==h)t.insertBefore(h.cloneNode(!0),t.firstChild);else if(r){u.insertBefore(d,u.firstChild);const e=new Set;e.add(d),o(r,e)}};window.JSCompiler_renameProperty=(e,t)=>e;const b={toAttribute(e,t){switch(t){case Boolean:return e?"":null;case Object:case Array:return null==e?e:JSON.stringify(e)}return e},fromAttribute(e,t){switch(t){case Boolean:return null!==e;case Number:return null===e?null:Number(e);case Object:case Array:return JSON.parse(e)}return e}},_=(e,t)=>t!==e&&(t==t||e==e),v={attribute:!0,type:String,converter:b,reflect:!1,hasChanged:_},w="finalized";class x extends HTMLElement{constructor(){super(),this.initialize()}static get observedAttributes(){this.finalize();const e=[];return this._classProperties.forEach(((t,r)=>{const n=this._attributeNameForProperty(r,t);void 0!==n&&(this._attributeToPropertyMap.set(n,r),e.push(n))})),e}static _ensureClassProperties(){if(!this.hasOwnProperty(JSCompiler_renameProperty("_classProperties",this))){this._classProperties=new Map;const e=Object.getPrototypeOf(this)._classProperties;void 0!==e&&e.forEach(((e,t)=>this._classProperties.set(t,e)))}}static createProperty(e,t=v){if(this._ensureClassProperties(),this._classProperties.set(e,t),t.noAccessor||this.prototype.hasOwnProperty(e))return;const r="symbol"==typeof e?Symbol():"__"+e,n=this.getPropertyDescriptor(e,r,t);void 0!==n&&Object.defineProperty(this.prototype,e,n)}static getPropertyDescriptor(e,t,r){return{get(){return this[t]},set(n){const i=this[e];this[t]=n,this.requestUpdateInternal(e,i,r)},configurable:!0,enumerable:!0}}static getPropertyOptions(e){return this._classProperties&&this._classProperties.get(e)||v}static finalize(){const e=Object.getPrototypeOf(this);if(e.hasOwnProperty(w)||e.finalize(),this.finalized=!0,this._ensureClassProperties(),this._attributeToPropertyMap=new Map,this.hasOwnProperty(JSCompiler_renameProperty("properties",this))){const e=this.properties,t=[...Object.getOwnPropertyNames(e),..."function"==typeof Object.getOwnPropertySymbols?Object.getOwnPropertySymbols(e):[]];for(const r of t)this.createProperty(r,e[r])}}static _attributeNameForProperty(e,t){const r=t.attribute;return!1===r?void 0:"string"==typeof r?r:"string"==typeof e?e.toLowerCase():void 0}static _valueHasChanged(e,t,r=_){return r(e,t)}static _propertyValueFromAttribute(e,t){const r=t.type,n=t.converter||b,i="function"==typeof n?n:n.fromAttribute;return i?i(e,r):e}static _propertyValueToAttribute(e,t){if(void 0===t.reflect)return;const r=t.type,n=t.converter;return(n&&n.toAttribute||b.toAttribute)(e,r)}initialize(){this._updateState=0,this._updatePromise=new Promise((e=>this._enableUpdatingResolver=e)),this._changedProperties=new Map,this._saveInstanceProperties(),this.requestUpdateInternal()}_saveInstanceProperties(){this.constructor._classProperties.forEach(((e,t)=>{if(this.hasOwnProperty(t)){const e=this[t];delete this[t],this._instanceProperties||(this._instanceProperties=new Map),this._instanceProperties.set(t,e)}}))}_applyInstanceProperties(){this._instanceProperties.forEach(((e,t)=>this[t]=e)),this._instanceProperties=void 0}connectedCallback(){this.enableUpdating()}enableUpdating(){void 0!==this._enableUpdatingResolver&&(this._enableUpdatingResolver(),this._enableUpdatingResolver=void 0)}disconnectedCallback(){}attributeChangedCallback(e,t,r){t!==r&&this._attributeToProperty(e,r)}_propertyToAttribute(e,t,r=v){const n=this.constructor,i=n._attributeNameForProperty(e,r);if(void 0!==i){const e=n._propertyValueToAttribute(t,r);if(void 0===e)return;this._updateState=8|this._updateState,null==e?this.removeAttribute(i):this.setAttribute(i,e),this._updateState=-9&this._updateState}}_attributeToProperty(e,t){if(8&this._updateState)return;const r=this.constructor,n=r._attributeToPropertyMap.get(e);if(void 0!==n){const e=r.getPropertyOptions(n);this._updateState=16|this._updateState,this[n]=r._propertyValueFromAttribute(t,e),this._updateState=-17&this._updateState}}requestUpdateInternal(e,t,r){let n=!0;if(void 0!==e){const i=this.constructor;r=r||i.getPropertyOptions(e),i._valueHasChanged(this[e],t,r.hasChanged)?(this._changedProperties.has(e)||this._changedProperties.set(e,t),!0!==r.reflect||16&this._updateState||(void 0===this._reflectingProperties&&(this._reflectingProperties=new Map),this._reflectingProperties.set(e,r))):n=!1}!this._hasRequestedUpdate&&n&&(this._updatePromise=this._enqueueUpdate())}requestUpdate(e,t){return this.requestUpdateInternal(e,t),this.updateComplete}async _enqueueUpdate(){this._updateState=4|this._updateState;try{await this._updatePromise}catch(e){}const e=this.performUpdate();return null!=e&&await e,!this._hasRequestedUpdate}get _hasRequestedUpdate(){return 4&this._updateState}get hasUpdated(){return 1&this._updateState}performUpdate(){if(!this._hasRequestedUpdate)return;this._instanceProperties&&this._applyInstanceProperties();let e=!1;const t=this._changedProperties;try{e=this.shouldUpdate(t),e?this.update(t):this._markUpdated()}catch(t){throw e=!1,this._markUpdated(),t}e&&(1&this._updateState||(this._updateState=1|this._updateState,this.firstUpdated(t)),this.updated(t))}_markUpdated(){this._changedProperties=new Map,this._updateState=-5&this._updateState}get updateComplete(){return this._getUpdateComplete()}_getUpdateComplete(){return this._updatePromise}shouldUpdate(e){return!0}update(e){void 0!==this._reflectingProperties&&this._reflectingProperties.size>0&&(this._reflectingProperties.forEach(((e,t)=>this._propertyToAttribute(t,this[t],e))),this._reflectingProperties=void 0),this._markUpdated()}updated(e){}firstUpdated(e){}}x.finalized=!0;var k=r(87466);const C=window.ShadowRoot&&(void 0===window.ShadyCSS||window.ShadyCSS.nativeShadow)&&"adoptedStyleSheets"in Document.prototype&&"replace"in CSSStyleSheet.prototype,E=Symbol();class S{constructor(e,t){if(t!==E)throw new Error("CSSResult is not constructable. Use `unsafeCSS` or `css` instead.");this.cssText=e}get styleSheet(){return void 0===this._styleSheet&&(C?(this._styleSheet=new CSSStyleSheet,this._styleSheet.replaceSync(this.cssText)):this._styleSheet=null),this._styleSheet}toString(){return this.cssText}}const P=e=>new S(String(e),E),A=(e,...t)=>{const r=t.reduce(((t,r,n)=>t+(e=>{if(e instanceof S)return e.cssText;if("number"==typeof e)return e;throw new Error(`Value passed to 'css' function must be a 'css' function result: ${e}. Use 'unsafeCSS' to pass non-literal values, but\n            take care to ensure page security.`)})(r)+e[n+1]),e[0]);return new S(r,E)};(window.litElementVersions||(window.litElementVersions=[])).push("2.4.0");const T={};class O extends x{static getStyles(){return this.styles}static _getUniqueStyles(){if(this.hasOwnProperty(JSCompiler_renameProperty("_styles",this)))return;const e=this.getStyles();if(Array.isArray(e)){const t=(e,r)=>e.reduceRight(((e,r)=>Array.isArray(r)?t(r,e):(e.add(r),e)),r),r=t(e,new Set),n=[];r.forEach((e=>n.unshift(e))),this._styles=n}else this._styles=void 0===e?[]:[e];this._styles=this._styles.map((e=>{if(e instanceof CSSStyleSheet&&!C){const t=Array.prototype.slice.call(e.cssRules).reduce(((e,t)=>e+t.cssText),"");return P(t)}return e}))}initialize(){super.initialize(),this.constructor._getUniqueStyles(),this.renderRoot=this.createRenderRoot(),window.ShadowRoot&&this.renderRoot instanceof window.ShadowRoot&&this.adoptStyles()}createRenderRoot(){return this.attachShadow({mode:"open"})}adoptStyles(){const e=this.constructor._styles;0!==e.length&&(void 0===window.ShadyCSS||window.ShadyCSS.nativeShadow?C?this.renderRoot.adoptedStyleSheets=e.map((e=>e instanceof CSSStyleSheet?e:e.styleSheet)):this._needsShimAdoptedStyleSheets=!0:window.ShadyCSS.ScopingShim.prepareAdoptedCssText(e.map((e=>e.cssText)),this.localName))}connectedCallback(){super.connectedCallback(),this.hasUpdated&&void 0!==window.ShadyCSS&&window.ShadyCSS.styleElement(this)}update(e){const t=this.render();super.update(e),t!==T&&this.constructor.render(t,this.renderRoot,{scopeName:this.localName,eventContext:this}),this._needsShimAdoptedStyleSheets&&(this._needsShimAdoptedStyleSheets=!1,this.constructor._styles.forEach((e=>{const t=document.createElement("style");t.textContent=e.cssText,this.renderRoot.appendChild(t)})))}render(){return T}}O.finalized=!0,O.render=(e,t,r)=>{if(!r||"object"!=typeof r||!r.scopeName)throw new Error("The `scopeName` option is required.");const i=r.scopeName,o=l.L.has(t),a=h&&11===t.nodeType&&!!t.host,s=a&&!y.has(i),c=s?document.createDocumentFragment():t;if((0,l.s)(e,c,Object.assign({templateFactory:f(i)},r)),s){const e=l.L.get(c);l.L.delete(c);const r=e.value instanceof d.R?e.value.template:void 0;g(i,c,r),(0,n.r4)(t,t.firstChild),t.appendChild(c),l.L.set(t,e)}!o&&a&&window.ShadyCSS.styleElement(t.host)}},81471:(e,t,r)=>{"use strict";r.d(t,{$:()=>a});var n=r(94707);class i{constructor(e){this.classes=new Set,this.changed=!1,this.element=e;const t=(e.getAttribute("class")||"").split(/\s+/);for(const e of t)this.classes.add(e)}add(e){this.classes.add(e),this.changed=!0}remove(e){this.classes.delete(e),this.changed=!0}commit(){if(this.changed){let e="";this.classes.forEach((t=>e+=t+" ")),this.element.setAttribute("class",e)}}}const o=new WeakMap,a=(0,n.XM)((e=>t=>{if(!(t instanceof n._l)||t instanceof n.sL||"class"!==t.committer.name||t.committer.parts.length>1)throw new Error("The `classMap` directive must be used in the `class` attribute and must be the only part in the attribute.");const{committer:r}=t,{element:a}=r;let s=o.get(t);void 0===s&&(a.setAttribute("class",r.strings.join(" ")),o.set(t,s=new Set));const l=a.classList||new i(a);s.forEach((t=>{t in e||(l.remove(t),s.delete(t))}));for(const t in e){const r=e[t];r!=s.has(t)&&(r?(l.add(t),s.add(t)):(l.remove(t),s.delete(t)))}"function"==typeof l.commit&&l.commit()}))},79865:(e,t,r)=>{"use strict";r.d(t,{V:()=>o});var n=r(94707);const i=new WeakMap,o=(0,n.XM)((e=>t=>{if(!(t instanceof n._l)||t instanceof n.sL||"style"!==t.committer.name||t.committer.parts.length>1)throw new Error("The `styleMap` directive must be used in the style attribute and must be the only part in the attribute.");const{committer:r}=t,{style:o}=r.element;let a=i.get(t);void 0===a&&(o.cssText=r.strings.join(" "),i.set(t,a=new Set)),a.forEach((t=>{t in e||(a.delete(t),-1===t.indexOf("-")?o[t]=null:o.removeProperty(t))}));for(const t in e)a.add(t),-1===t.indexOf("-")?o[t]=e[t]:o.setProperty(t,e[t])}))},76747:(e,t,r)=>{"use strict";r.d(t,{X:()=>i,w:()=>o});const n=new WeakMap,i=e=>(...t)=>{const r=e(...t);return n.set(r,!0),r},o=e=>"function"==typeof e&&n.has(e)},50115:(e,t,r)=>{"use strict";r.d(t,{eC:()=>n,V:()=>i,r4:()=>o});const n="undefined"!=typeof window&&null!=window.customElements&&void 0!==window.customElements.polyfillWrapFlushCallback,i=(e,t,r=null,n=null)=>{for(;t!==r;){const r=t.nextSibling;e.insertBefore(t,n),t=r}},o=(e,t,r=null)=>{for(;t!==r;){const r=t.nextSibling;e.removeChild(t),t=r}}},43401:(e,t,r)=>{"use strict";r.d(t,{J:()=>n,L:()=>i});const n={},i={}},28823:(e,t,r)=>{"use strict";r.d(t,{pt:()=>c,QG:()=>u,_l:()=>p,nt:()=>h,JG:()=>f,m:()=>m,sL:()=>y,K1:()=>b});var n=r(76747),i=r(50115),o=r(43401),a=r(37581),s=r(87842),l=r(27283);const c=e=>null===e||!("object"==typeof e||"function"==typeof e),d=e=>Array.isArray(e)||!(!e||!e[Symbol.iterator]);class u{constructor(e,t,r){this.dirty=!0,this.element=e,this.name=t,this.strings=r,this.parts=[];for(let e=0;e<r.length-1;e++)this.parts[e]=this._createPart()}_createPart(){return new p(this)}_getValue(){const e=this.strings,t=e.length-1,r=this.parts;if(1===t&&""===e[0]&&""===e[1]){const e=r[0].value;if("symbol"==typeof e)return String(e);if("string"==typeof e||!d(e))return e}let n="";for(let i=0;i<t;i++){n+=e[i];const t=r[i];if(void 0!==t){const e=t.value;if(c(e)||!d(e))n+="string"==typeof e?e:String(e);else for(const t of e)n+="string"==typeof t?t:String(t)}}return n+=e[t],n}commit(){this.dirty&&(this.dirty=!1,this.element.setAttribute(this.name,this._getValue()))}}class p{constructor(e){this.value=void 0,this.committer=e}setValue(e){e===o.J||c(e)&&e===this.value||(this.value=e,(0,n.w)(e)||(this.committer.dirty=!0))}commit(){for(;(0,n.w)(this.value);){const e=this.value;this.value=o.J,e(this)}this.value!==o.J&&this.committer.commit()}}class h{constructor(e){this.value=void 0,this.__pendingValue=void 0,this.options=e}appendInto(e){this.startNode=e.appendChild((0,l.IW)()),this.endNode=e.appendChild((0,l.IW)())}insertAfterNode(e){this.startNode=e,this.endNode=e.nextSibling}appendIntoPart(e){e.__insert(this.startNode=(0,l.IW)()),e.__insert(this.endNode=(0,l.IW)())}insertAfterPart(e){e.__insert(this.startNode=(0,l.IW)()),this.endNode=e.endNode,e.endNode=this.startNode}setValue(e){this.__pendingValue=e}commit(){if(null===this.startNode.parentNode)return;for(;(0,n.w)(this.__pendingValue);){const e=this.__pendingValue;this.__pendingValue=o.J,e(this)}const e=this.__pendingValue;e!==o.J&&(c(e)?e!==this.value&&this.__commitText(e):e instanceof s.j?this.__commitTemplateResult(e):e instanceof Node?this.__commitNode(e):d(e)?this.__commitIterable(e):e===o.L?(this.value=o.L,this.clear()):this.__commitText(e))}__insert(e){this.endNode.parentNode.insertBefore(e,this.endNode)}__commitNode(e){this.value!==e&&(this.clear(),this.__insert(e),this.value=e)}__commitText(e){const t=this.startNode.nextSibling,r="string"==typeof(e=null==e?"":e)?e:String(e);t===this.endNode.previousSibling&&3===t.nodeType?t.data=r:this.__commitNode(document.createTextNode(r)),this.value=e}__commitTemplateResult(e){const t=this.options.templateFactory(e);if(this.value instanceof a.R&&this.value.template===t)this.value.update(e.values);else{const r=new a.R(t,e.processor,this.options),n=r._clone();r.update(e.values),this.__commitNode(n),this.value=r}}__commitIterable(e){Array.isArray(this.value)||(this.value=[],this.clear());const t=this.value;let r,n=0;for(const i of e)r=t[n],void 0===r&&(r=new h(this.options),t.push(r),0===n?r.appendIntoPart(this):r.insertAfterPart(t[n-1])),r.setValue(i),r.commit(),n++;n<t.length&&(t.length=n,this.clear(r&&r.endNode))}clear(e=this.startNode){(0,i.r4)(this.startNode.parentNode,e.nextSibling,this.endNode)}}class f{constructor(e,t,r){if(this.value=void 0,this.__pendingValue=void 0,2!==r.length||""!==r[0]||""!==r[1])throw new Error("Boolean attributes can only contain a single expression");this.element=e,this.name=t,this.strings=r}setValue(e){this.__pendingValue=e}commit(){for(;(0,n.w)(this.__pendingValue);){const e=this.__pendingValue;this.__pendingValue=o.J,e(this)}if(this.__pendingValue===o.J)return;const e=!!this.__pendingValue;this.value!==e&&(e?this.element.setAttribute(this.name,""):this.element.removeAttribute(this.name),this.value=e),this.__pendingValue=o.J}}class m extends u{constructor(e,t,r){super(e,t,r),this.single=2===r.length&&""===r[0]&&""===r[1]}_createPart(){return new y(this)}_getValue(){return this.single?this.parts[0].value:super._getValue()}commit(){this.dirty&&(this.dirty=!1,this.element[this.name]=this._getValue())}}class y extends p{}let g=!1;(()=>{try{const e={get capture(){return g=!0,!1}};window.addEventListener("test",e,e),window.removeEventListener("test",e,e)}catch(e){}})();class b{constructor(e,t,r){this.value=void 0,this.__pendingValue=void 0,this.element=e,this.eventName=t,this.eventContext=r,this.__boundHandleEvent=e=>this.handleEvent(e)}setValue(e){this.__pendingValue=e}commit(){for(;(0,n.w)(this.__pendingValue);){const e=this.__pendingValue;this.__pendingValue=o.J,e(this)}if(this.__pendingValue===o.J)return;const e=this.__pendingValue,t=this.value,r=null==e||null!=t&&(e.capture!==t.capture||e.once!==t.once||e.passive!==t.passive),i=null!=e&&(null==t||r);r&&this.element.removeEventListener(this.eventName,this.__boundHandleEvent,this.__options),i&&(this.__options=_(e),this.element.addEventListener(this.eventName,this.__boundHandleEvent,this.__options)),this.value=e,this.__pendingValue=o.J}handleEvent(e){"function"==typeof this.value?this.value.call(this.eventContext||this.element,e):this.value.handleEvent(e)}}const _=e=>e&&(g?{capture:e.capture,passive:e.passive,once:e.once}:e.capture)},84677:(e,t,r)=>{"use strict";r.d(t,{L:()=>a,s:()=>s});var n=r(50115),i=r(28823),o=r(92530);const a=new WeakMap,s=(e,t,r)=>{let s=a.get(t);void 0===s&&((0,n.r4)(t,t.firstChild),a.set(t,s=new i.nt(Object.assign({templateFactory:o.t},r))),s.appendInto(t)),s.setValue(e),s.commit()}},92530:(e,t,r)=>{"use strict";r.d(t,{t:()=>i,r:()=>o});var n=r(27283);function i(e){let t=o.get(e.type);void 0===t&&(t={stringsArray:new WeakMap,keyString:new Map},o.set(e.type,t));let r=t.stringsArray.get(e.strings);if(void 0!==r)return r;const i=e.strings.join(n.Jw);return r=t.keyString.get(i),void 0===r&&(r=new n.YS(e,e.getTemplateElement()),t.keyString.set(i,r)),t.stringsArray.set(e.strings,r),r}const o=new Map},37581:(e,t,r)=>{"use strict";r.d(t,{R:()=>o});var n=r(50115),i=r(27283);class o{constructor(e,t,r){this.__parts=[],this.template=e,this.processor=t,this.options=r}update(e){let t=0;for(const r of this.__parts)void 0!==r&&r.setValue(e[t]),t++;for(const e of this.__parts)void 0!==e&&e.commit()}_clone(){const e=n.eC?this.template.element.content.cloneNode(!0):document.importNode(this.template.element.content,!0),t=[],r=this.template.parts,o=document.createTreeWalker(e,133,null,!1);let a,s=0,l=0,c=o.nextNode();for(;s<r.length;)if(a=r[s],(0,i.pC)(a)){for(;l<a.index;)l++,"TEMPLATE"===c.nodeName&&(t.push(c),o.currentNode=c.content),null===(c=o.nextNode())&&(o.currentNode=t.pop(),c=o.nextNode());if("node"===a.type){const e=this.processor.handleTextExpression(this.options);e.insertAfterNode(c.previousSibling),this.__parts.push(e)}else this.__parts.push(...this.processor.handleAttributeExpressions(c,a.name,a.strings,this.options));s++}else this.__parts.push(void 0),s++;return n.eC&&(document.adoptNode(e),customElements.upgrade(e)),e}}},87842:(e,t,r)=>{"use strict";r.d(t,{j:()=>s,C:()=>l});var n=r(50115),i=r(27283);const o=window.trustedTypes&&trustedTypes.createPolicy("lit-html",{createHTML:e=>e}),a=` ${i.Jw} `;class s{constructor(e,t,r,n){this.strings=e,this.values=t,this.type=r,this.processor=n}getHTML(){const e=this.strings.length-1;let t="",r=!1;for(let n=0;n<e;n++){const e=this.strings[n],o=e.lastIndexOf("\x3c!--");r=(o>-1||r)&&-1===e.indexOf("--\x3e",o+1);const s=i.W5.exec(e);t+=null===s?e+(r?a:i.N):e.substr(0,s.index)+s[1]+s[2]+i.$E+s[3]+i.Jw}return t+=this.strings[e],t}getTemplateElement(){const e=document.createElement("template");let t=this.getHTML();return void 0!==o&&(t=o.createHTML(t)),e.innerHTML=t,e}}class l extends s{getHTML(){return`<svg>${super.getHTML()}</svg>`}getTemplateElement(){const e=super.getTemplateElement(),t=e.content,r=t.firstChild;return t.removeChild(r),(0,n.V)(t,r.firstChild),e}}},27283:(e,t,r)=>{"use strict";r.d(t,{Jw:()=>n,N:()=>i,$E:()=>a,YS:()=>s,pC:()=>c,IW:()=>d,W5:()=>u});const n=`{{lit-${String(Math.random()).slice(2)}}}`,i=`\x3c!--${n}--\x3e`,o=new RegExp(`${n}|${i}`),a="$lit$";class s{constructor(e,t){this.parts=[],this.element=t;const r=[],i=[],s=document.createTreeWalker(t.content,133,null,!1);let c=0,p=-1,h=0;const{strings:f,values:{length:m}}=e;for(;h<m;){const e=s.nextNode();if(null!==e){if(p++,1===e.nodeType){if(e.hasAttributes()){const t=e.attributes,{length:r}=t;let n=0;for(let e=0;e<r;e++)l(t[e].name,a)&&n++;for(;n-- >0;){const t=f[h],r=u.exec(t)[2],n=r.toLowerCase()+a,i=e.getAttribute(n);e.removeAttribute(n);const s=i.split(o);this.parts.push({type:"attribute",index:p,name:r,strings:s}),h+=s.length-1}}"TEMPLATE"===e.tagName&&(i.push(e),s.currentNode=e.content)}else if(3===e.nodeType){const t=e.data;if(t.indexOf(n)>=0){const n=e.parentNode,i=t.split(o),s=i.length-1;for(let t=0;t<s;t++){let r,o=i[t];if(""===o)r=d();else{const e=u.exec(o);null!==e&&l(e[2],a)&&(o=o.slice(0,e.index)+e[1]+e[2].slice(0,-a.length)+e[3]),r=document.createTextNode(o)}n.insertBefore(r,e),this.parts.push({type:"node",index:++p})}""===i[s]?(n.insertBefore(d(),e),r.push(e)):e.data=i[s],h+=s}}else if(8===e.nodeType)if(e.data===n){const t=e.parentNode;null!==e.previousSibling&&p!==c||(p++,t.insertBefore(d(),e)),c=p,this.parts.push({type:"node",index:p}),null===e.nextSibling?e.data="":(r.push(e),p--),h++}else{let t=-1;for(;-1!==(t=e.data.indexOf(n,t+1));)this.parts.push({type:"node",index:-1}),h++}}else s.currentNode=i.pop()}for(const e of r)e.parentNode.removeChild(e)}}const l=(e,t)=>{const r=e.length-t.length;return r>=0&&e.slice(r)===t},c=e=>-1!==e.index,d=()=>document.createComment(""),u=/([ \x09\x0a\x0c\x0d])([^\0-\x1F\x7F-\x9F "'>=/]+)([ \x09\x0a\x0c\x0d]*=[ \x09\x0a\x0c\x0d]*(?:[^ \x09\x0a\x0c\x0d"'`<>=]*|"[^"]*|'[^']*))$/},94707:(e,t,r)=>{"use strict";r.d(t,{_l:()=>n._l,nt:()=>n.nt,sL:()=>n.sL,js:()=>o.j,IW:()=>l.IW,XM:()=>a.X,dy:()=>c,r4:()=>s.r4,V:()=>s.V,YP:()=>d});var n=r(28823);const i=new class{handleAttributeExpressions(e,t,r,i){const o=t[0];if("."===o){return new n.m(e,t.slice(1),r).parts}if("@"===o)return[new n.K1(e,t.slice(1),i.eventContext)];if("?"===o)return[new n.JG(e,t.slice(1),r)];return new n.QG(e,t,r).parts}handleTextExpression(e){return new n.nt(e)}};var o=r(87842),a=r(76747),s=r(50115),l=(r(43401),r(84677),r(92530),r(37581),r(27283));"undefined"!=typeof window&&(window.litHtmlVersions||(window.litHtmlVersions=[])).push("1.3.0");const c=(e,...t)=>new o.j(e,t,"html",i),d=(e,...t)=>new o.C(e,t,"svg",i)},87480:(e,t,r)=>{"use strict";r.d(t,{ZT:()=>i,pi:()=>o,gn:()=>a,XA:()=>s,CR:()=>l});var n=function(e,t){return(n=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var r in t)t.hasOwnProperty(r)&&(e[r]=t[r])})(e,t)};function i(e,t){function r(){this.constructor=e}n(e,t),e.prototype=null===t?Object.create(t):(r.prototype=t.prototype,new r)}var o=function(){return(o=Object.assign||function(e){for(var t,r=1,n=arguments.length;r<n;r++)for(var i in t=arguments[r])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)};function a(e,t,r,n){var i,o=arguments.length,a=o<3?t:null===n?n=Object.getOwnPropertyDescriptor(t,r):n;if("object"==typeof Reflect&&"function"==typeof Reflect.decorate)a=Reflect.decorate(e,t,r,n);else for(var s=e.length-1;s>=0;s--)(i=e[s])&&(a=(o<3?i(a):o>3?i(t,r,a):i(t,r))||a);return o>3&&a&&Object.defineProperty(t,r,a),a}function s(e){var t="function"==typeof Symbol&&e[Symbol.iterator],r=0;return t?t.call(e):{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}}}function l(e,t){var r="function"==typeof Symbol&&e[Symbol.iterator];if(!r)return e;var n,i,o=r.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(n=o.next()).done;)a.push(n.value)}catch(e){i={error:e}}finally{try{n&&!n.done&&(r=o.return)&&r.call(o)}finally{if(i)throw i.error}}return a}},66386:(e,t,r)=>{"use strict";r.d(t,{IO:()=>o,ed:()=>a});const n=window.localStorage||{};let i=window.__tokenCache;function o(){return void 0!==i.tokens&&void 0===i.writeEnabled}function a(){i.writeEnabled=!0,i.tokens&&function(e){if(i.tokens=e,i.writeEnabled)try{n.hassTokens=JSON.stringify(e)}catch(e){}}(i.tokens)}i||(i=window.__tokenCache={tokens:void 0,writeEnabled:void 0})},74790:(e,t,r)=>{"use strict";r.d(t,{f:()=>i,$:()=>o});const n=e=>{const t=[0,0,0];for(let r=0;r<e.length;r++){const n=e[r]/255;t[r]=n<=.03928?n/12.92:((n+.055)/1.055)**2.4}return.2126*t[0]+.7152*t[1]+.0722*t[2]},i=(e,t)=>{const r=n(e),i=n(t);return r>i?(r+.05)/(i+.05):(i+.05)/(r+.05)},o=(e,t)=>Math.round(100*(i(e,t)+Number.EPSILON))/100},27060:(e,t,r)=>{"use strict";r.d(t,{R:()=>w,p:()=>k});var n=r(11654);const i=e=>{if(6===(e=e.replace("#","")).length)return e;let t="";for(const r of e)t+=r+r;return t},o=e=>{const t=Math.round(Math.min(Math.max(e,0),255)).toString(16);return 1===t.length?"0"+t:t},a=e=>(e=i(e),[parseInt(e.substring(0,2),16),parseInt(e.substring(2,4),16),parseInt(e.substring(4,6),16)]),s=e=>`#${o(e[0])}${o(e[1])}${o(e[2])}`,l=.95047,c=1.08883,d=.137931034,u=.12841855,p=e=>(e/=255)<=.04045?e/12.92:((e+.055)/1.055)**2.4,h=e=>e>.008856452?e**(1/3):e/u+d,f=e=>255*(e<=.00304?12.92*e:1.055*e**(1/2.4)-.055),m=e=>e>.206896552?e*e*e:u*(e-d),y=e=>{const[t,r,n]=(e=>{let[t,r,n]=e;return t=p(t),r=p(r),n=p(n),[h((.4124564*t+.3575761*r+.1804375*n)/l),h((.2126729*t+.7151522*r+.072175*n)/1),h((.0193339*t+.119192*r+.9503041*n)/c)]})(e),i=116*r-16;return[i<0?0:i,500*(t-r),200*(r-n)]},g=e=>{const[t,r,n]=e;let i=(t+16)/116,o=isNaN(r)?i:i+r/500,a=isNaN(n)?i:i-n/200;i=1*m(i),o=l*m(o),a=c*m(a);return[f(3.2404542*o-1.5371385*i-.4985314*a),f(-.969266*o+1.8760108*i+.041556*a),f(.0556434*o-.2040259*i+1.0572252*a)]},b=(e,t=1)=>[e[0]-18*t,e[1],e[2]];var _=r(74790);let v={};const w=(e,t,r,o)=>{let l=r,c={};if("default"===r&&o){if(o.dark&&(l+="__dark",c=n._l,o.primaryColor&&(c["app-header-background-color"]=((e,t,r=50)=>{let n="";e=i(e),t=i(t);for(let i=0;i<=5;i+=2){const o=parseInt(e.substr(i,2),16),a=parseInt(t.substr(i,2),16);let s=Math.floor(a+r/100*(o-a)).toString(16);for(;s.length<2;)s="0"+s;n+=s}return"#"+n})(o.primaryColor,"#121212",8))),o.primaryColor){l=`${l}__primary_${o.primaryColor}`;const e=a(o.primaryColor),t=y(e);c["primary-color"]=o.primaryColor;const r=g(((e,t=1)=>b(e,-t))(t));c["light-primary-color"]=s(r),c["dark-primary-color"]=(e=>{const t=g(e);return s(t)})(b(t)),c["text-primary-color"]=(0,_.f)(e,[33,33,33])<6?"#fff":"#212121",c["text-light-primary-color"]=(0,_.f)(r,[33,33,33])<6?"#fff":"#212121",c["state-icon-color"]=c["dark-primary-color"]}if(o.accentColor){l=`${l}__accent_${o.accentColor}`,c["accent-color"]=o.accentColor;const e=a(o.accentColor);c["text-accent-color"]=(0,_.f)(e,[33,33,33])<6?"#fff":"#212121"}}if(r&&t.themes[r]&&(c=t.themes[r]),!e._themes&&!Object.keys(c).length)return;const d=c&&l?v[l]||x(l,c):void 0,u={...e._themes,...null==d?void 0:d.styles};e._themes=null==d?void 0:d.keys,e.updateStyles?e.updateStyles(u):window.ShadyCSS&&window.ShadyCSS.styleSubtree(e,u)},x=(e,t)=>{if(!t||!Object.keys(t).length)return;const r={...n.q0,...t},i={},o={};for(const e of Object.keys(r)){const t="--"+e,n=String(r[e]);if(i[t]=n,o[t]="",!n.startsWith("#"))continue;const s="rgb-"+e;if(void 0===r[s])try{const e=a(n).join(","),t="--"+s;i[t]=e,o[t]=""}catch(e){continue}}return v[e]={styles:i,keys:o},{styles:i,keys:o}},k=()=>{v={}}},47181:(e,t,r)=>{"use strict";r.d(t,{B:()=>n});const n=(e,t,r,n)=>{n=n||{},r=null==r?{}:r;const i=new Event(t,{bubbles:void 0===n.bubbles||n.bubbles,cancelable:Boolean(n.cancelable),composed:void 0===n.composed||n.composed});return i.detail=r,e.dispatchEvent(i),i}},35359:(e,t,r)=>{"use strict";r.d(t,{X:()=>Z,I:()=>Q});var n,i,o=r(27815);function a(e){return e.type===n.literal}function s(e){return e.type===n.argument}function l(e){return e.type===n.number}function c(e){return e.type===n.date}function d(e){return e.type===n.time}function u(e){return e.type===n.select}function p(e){return e.type===n.plural}function h(e){return e.type===n.pound}function f(e){return e.type===n.tag}function m(e){return!(!e||"object"!=typeof e||0!==e.type)}function y(e){return!(!e||"object"!=typeof e||1!==e.type)}!function(e){e[e.literal=0]="literal",e[e.argument=1]="argument",e[e.number=2]="number",e[e.date=3]="date",e[e.time=4]="time",e[e.select=5]="select",e[e.plural=6]="plural",e[e.pound=7]="pound",e[e.tag=8]="tag"}(n||(n={})),function(e){e[e.number=0]="number",e[e.dateTime=1]="dateTime"}(i||(i={}));var g,b=(g=function(e,t){return(g=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var r in t)t.hasOwnProperty(r)&&(e[r]=t[r])})(e,t)},function(e,t){function r(){this.constructor=e}g(e,t),e.prototype=null===t?Object.create(t):(r.prototype=t.prototype,new r)}),_=function(){return(_=Object.assign||function(e){for(var t,r=1,n=arguments.length;r<n;r++)for(var i in t=arguments[r])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)},v=function(e){function t(r,n,i,o){var a=e.call(this)||this;return a.message=r,a.expected=n,a.found=i,a.location=o,a.name="SyntaxError","function"==typeof Error.captureStackTrace&&Error.captureStackTrace(a,t),a}return b(t,e),t.buildMessage=function(e,t){function r(e){return e.charCodeAt(0).toString(16).toUpperCase()}function n(e){return e.replace(/\\/g,"\\\\").replace(/"/g,'\\"').replace(/\0/g,"\\0").replace(/\t/g,"\\t").replace(/\n/g,"\\n").replace(/\r/g,"\\r").replace(/[\x00-\x0F]/g,(function(e){return"\\x0"+r(e)})).replace(/[\x10-\x1F\x7F-\x9F]/g,(function(e){return"\\x"+r(e)}))}function i(e){return e.replace(/\\/g,"\\\\").replace(/\]/g,"\\]").replace(/\^/g,"\\^").replace(/-/g,"\\-").replace(/\0/g,"\\0").replace(/\t/g,"\\t").replace(/\n/g,"\\n").replace(/\r/g,"\\r").replace(/[\x00-\x0F]/g,(function(e){return"\\x0"+r(e)})).replace(/[\x10-\x1F\x7F-\x9F]/g,(function(e){return"\\x"+r(e)}))}function o(e){switch(e.type){case"literal":return'"'+n(e.text)+'"';case"class":var t=e.parts.map((function(e){return Array.isArray(e)?i(e[0])+"-"+i(e[1]):i(e)}));return"["+(e.inverted?"^":"")+t+"]";case"any":return"any character";case"end":return"end of input";case"other":return e.description}}return"Expected "+function(e){var t,r,n=e.map(o);if(n.sort(),n.length>0){for(t=1,r=1;t<n.length;t++)n[t-1]!==n[t]&&(n[r]=n[t],r++);n.length=r}switch(n.length){case 1:return n[0];case 2:return n[0]+" or "+n[1];default:return n.slice(0,-1).join(", ")+", or "+n[n.length-1]}}(e)+" but "+(((a=t)?'"'+n(a)+'"':"end of input")+" found.");var a},t}(Error);var w=function(e,t){t=void 0!==t?t:{};var r,i={},o={start:Ye},a=Ye,s=He("#",!1),l=$e("tagElement"),c="<",d=He("<",!1),u="/>",p=He("/>",!1),h=">",f=He(">",!1),m=function(e){return mt.pop(),!0},y="</",g=He("</",!1),b=$e("argumentElement"),w="{",x=He("{",!1),k="}",C=He("}",!1),E=$e("numberSkeletonId"),S=/^['\/{}]/,P=Be(["'","/","{","}"],!1,!1),A={type:"any"},T=$e("numberSkeletonTokenOption"),O=He("/",!1),N=$e("numberSkeletonToken"),I="::",R=He("::",!1),D=function(e){return mt.pop(),e.replace(/\s*$/,"")},z=",",F=He(",",!1),L="number",M=He("number",!1),j=function(e,t,r){return _({type:"number"===t?n.number:"date"===t?n.date:n.time,style:r&&r[2],value:e},bt())},H="'",B=He("'",!1),$=/^[^']/,V=Be(["'"],!0,!1),U=/^[^a-zA-Z'{}]/,q=Be([["a","z"],["A","Z"],"'","{","}"],!0,!1),K=/^[a-zA-Z]/,Y=Be([["a","z"],["A","Z"]],!1,!1),J="date",W=He("date",!1),G="time",X=He("time",!1),Z="plural",Q=He("plural",!1),ee="selectordinal",te=He("selectordinal",!1),re="offset:",ne=He("offset:",!1),ie="select",oe=He("select",!1),ae=He("=",!1),se=$e("whitespace"),le=/^[\t-\r \x85\xA0\u1680\u2000-\u200A\u2028\u2029\u202F\u205F\u3000]/,ce=Be([["\t","\r"]," ",""," "," ",[" "," "],"\u2028","\u2029"," "," ","　"],!1,!1),de=$e("syntax pattern"),ue=/^[!-\/:-@[-\^`{-~\xA1-\xA7\xA9\xAB\xAC\xAE\xB0\xB1\xB6\xBB\xBF\xD7\xF7\u2010-\u2027\u2030-\u203E\u2041-\u2053\u2055-\u205E\u2190-\u245F\u2500-\u2775\u2794-\u2BFF\u2E00-\u2E7F\u3001-\u3003\u3008-\u3020\u3030\uFD3E\uFD3F\uFE45\uFE46]/,pe=Be([["!","/"],[":","@"],["[","^"],"`",["{","~"],["¡","§"],"©","«","¬","®","°","±","¶","»","¿","×","÷",["‐","‧"],["‰","‾"],["⁁","⁓"],["⁕","⁞"],["←","⑟"],["─","❵"],["➔","⯿"],["⸀","⹿"],["、","〃"],["〈","〠"],"〰","﴾","﴿","﹅","﹆"],!1,!1),he=$e("optional whitespace"),fe=$e("number"),me="-",ye=He("-",!1),ge=($e("apostrophe"),$e("double apostrophes")),be="''",_e=He("''",!1),ve=He("\n",!1),we=$e("argNameOrNumber"),xe=$e("validTag"),ke=$e("argNumber"),Ce=He("0",!1),Ee=/^[1-9]/,Se=Be([["1","9"]],!1,!1),Pe=/^[0-9]/,Ae=Be([["0","9"]],!1,!1),Te=$e("argName"),Oe=$e("tagName"),Ne=0,Ie=0,Re=[{line:1,column:1}],De=0,ze=[],Fe=0;if(void 0!==t.startRule){if(!(t.startRule in o))throw new Error("Can't start parsing from rule \""+t.startRule+'".');a=o[t.startRule]}function Le(){return e.substring(Ie,Ne)}function Me(){return Ue(Ie,Ne)}function je(e,t){throw function(e,t){return new v(e,[],"",t)}(e,t=void 0!==t?t:Ue(Ie,Ne))}function He(e,t){return{type:"literal",text:e,ignoreCase:t}}function Be(e,t,r){return{type:"class",parts:e,inverted:t,ignoreCase:r}}function $e(e){return{type:"other",description:e}}function Ve(t){var r,n=Re[t];if(n)return n;for(r=t-1;!Re[r];)r--;for(n={line:(n=Re[r]).line,column:n.column};r<t;)10===e.charCodeAt(r)?(n.line++,n.column=1):n.column++,r++;return Re[t]=n,n}function Ue(e,t){var r=Ve(e),n=Ve(t);return{start:{offset:e,line:r.line,column:r.column},end:{offset:t,line:n.line,column:n.column}}}function qe(e){Ne<De||(Ne>De&&(De=Ne,ze=[]),ze.push(e))}function Ke(e,t,r){return new v(v.buildMessage(e,t),e,t,r)}function Ye(){return Je()}function Je(){var e,t;for(e=[],t=We();t!==i;)e.push(t),t=We();return e}function We(){var t;return(t=function(){var e,t;e=Ne,(t=Ge())!==i&&(Ie=e,r=t,t=_({type:n.literal,value:r},bt()));var r;return e=t}())===i&&(t=function(){var t,r,o,a;Fe++,t=Ne,123===e.charCodeAt(Ne)?(r=w,Ne++):(r=i,0===Fe&&qe(x));r!==i&&at()!==i&&(o=ut())!==i&&at()!==i?(125===e.charCodeAt(Ne)?(a=k,Ne++):(a=i,0===Fe&&qe(C)),a!==i?(Ie=t,s=o,t=r=_({type:n.argument,value:s},bt())):(Ne=t,t=i)):(Ne=t,t=i);var s;Fe--,t===i&&(r=i,0===Fe&&qe(b));return t}())===i&&(t=function(){var t;(t=function(){var t,r,n,o,a,s,l,c,d;t=Ne,123===e.charCodeAt(Ne)?(r=w,Ne++):(r=i,0===Fe&&qe(x));r!==i&&at()!==i&&(n=ut())!==i&&at()!==i?(44===e.charCodeAt(Ne)?(o=z,Ne++):(o=i,0===Fe&&qe(F)),o!==i&&at()!==i?(e.substr(Ne,6)===L?(a=L,Ne+=6):(a=i,0===Fe&&qe(M)),a!==i&&at()!==i?(s=Ne,44===e.charCodeAt(Ne)?(l=z,Ne++):(l=i,0===Fe&&qe(F)),l!==i&&(c=at())!==i&&(d=function(){var t,r,n;t=Ne,e.substr(Ne,2)===I?(r=I,Ne+=2):(r=i,0===Fe&&qe(R));r!==i&&(n=function(){var e,t,r;if(e=Ne,t=[],(r=Qe())!==i)for(;r!==i;)t.push(r),r=Qe();else t=i;t!==i&&(Ie=e,t=_({type:0,tokens:t},bt()));return e=t}())!==i?(Ie=t,t=r=n):(Ne=t,t=i);t===i&&(t=Ne,Ie=Ne,mt.push("numberArgStyle"),(r=(r=!0)?void 0:i)!==i&&(n=Ge())!==i?(Ie=t,t=r=D(n)):(Ne=t,t=i));return t}())!==i?s=l=[l,c,d]:(Ne=s,s=i),s===i&&(s=null),s!==i&&(l=at())!==i?(125===e.charCodeAt(Ne)?(c=k,Ne++):(c=i,0===Fe&&qe(C)),c!==i?(Ie=t,t=r=j(n,a,s)):(Ne=t,t=i)):(Ne=t,t=i)):(Ne=t,t=i)):(Ne=t,t=i)):(Ne=t,t=i);return t}())===i&&(t=function(){var t,r,n,o,a,s,l,c,d;t=Ne,123===e.charCodeAt(Ne)?(r=w,Ne++):(r=i,0===Fe&&qe(x));r!==i&&at()!==i&&(n=ut())!==i&&at()!==i?(44===e.charCodeAt(Ne)?(o=z,Ne++):(o=i,0===Fe&&qe(F)),o!==i&&at()!==i?(e.substr(Ne,4)===J?(a=J,Ne+=4):(a=i,0===Fe&&qe(W)),a===i&&(e.substr(Ne,4)===G?(a=G,Ne+=4):(a=i,0===Fe&&qe(X))),a!==i&&at()!==i?(s=Ne,44===e.charCodeAt(Ne)?(l=z,Ne++):(l=i,0===Fe&&qe(F)),l!==i&&(c=at())!==i&&(d=function(){var t,r,n;t=Ne,e.substr(Ne,2)===I?(r=I,Ne+=2):(r=i,0===Fe&&qe(R));r!==i&&(n=function(){var t,r,n,o;t=Ne,r=Ne,n=[],(o=et())===i&&(o=tt());if(o!==i)for(;o!==i;)n.push(o),(o=et())===i&&(o=tt());else n=i;r=n!==i?e.substring(r,Ne):n;r!==i&&(Ie=t,r=_({type:1,pattern:r},bt()));return t=r}())!==i?(Ie=t,t=r=n):(Ne=t,t=i);t===i&&(t=Ne,Ie=Ne,mt.push("dateOrTimeArgStyle"),(r=(r=!0)?void 0:i)!==i&&(n=Ge())!==i?(Ie=t,t=r=D(n)):(Ne=t,t=i));return t}())!==i?s=l=[l,c,d]:(Ne=s,s=i),s===i&&(s=null),s!==i&&(l=at())!==i?(125===e.charCodeAt(Ne)?(c=k,Ne++):(c=i,0===Fe&&qe(C)),c!==i?(Ie=t,t=r=j(n,a,s)):(Ne=t,t=i)):(Ne=t,t=i)):(Ne=t,t=i)):(Ne=t,t=i)):(Ne=t,t=i);return t}());return t}())===i&&(t=function(){var t,r,o,a,s,l,c,d,u,p,h;t=Ne,123===e.charCodeAt(Ne)?(r=w,Ne++):(r=i,0===Fe&&qe(x));if(r!==i)if(at()!==i)if((o=ut())!==i)if(at()!==i)if(44===e.charCodeAt(Ne)?(a=z,Ne++):(a=i,0===Fe&&qe(F)),a!==i)if(at()!==i)if(e.substr(Ne,6)===Z?(s=Z,Ne+=6):(s=i,0===Fe&&qe(Q)),s===i&&(e.substr(Ne,13)===ee?(s=ee,Ne+=13):(s=i,0===Fe&&qe(te))),s!==i)if(at()!==i)if(44===e.charCodeAt(Ne)?(l=z,Ne++):(l=i,0===Fe&&qe(F)),l!==i)if(at()!==i)if(c=Ne,e.substr(Ne,7)===re?(d=re,Ne+=7):(d=i,0===Fe&&qe(ne)),d!==i&&(u=at())!==i&&(p=st())!==i?c=d=[d,u,p]:(Ne=c,c=i),c===i&&(c=null),c!==i)if((d=at())!==i){if(u=[],(p=nt())!==i)for(;p!==i;)u.push(p),p=nt();else u=i;u!==i&&(p=at())!==i?(125===e.charCodeAt(Ne)?(h=k,Ne++):(h=i,0===Fe&&qe(C)),h!==i?(Ie=t,t=r=function(e,t,r,i){return _({type:n.plural,pluralType:"plural"===t?"cardinal":"ordinal",value:e,offset:r?r[2]:0,options:i.reduce((function(e,t){var r=t.id,n=t.value,i=t.location;return r in e&&je('Duplicate option "'+r+'" in plural element: "'+Le()+'"',Me()),e[r]={value:n,location:i},e}),{})},bt())}(o,s,c,u)):(Ne=t,t=i)):(Ne=t,t=i)}else Ne=t,t=i;else Ne=t,t=i;else Ne=t,t=i;else Ne=t,t=i;else Ne=t,t=i;else Ne=t,t=i;else Ne=t,t=i;else Ne=t,t=i;else Ne=t,t=i;else Ne=t,t=i;else Ne=t,t=i;else Ne=t,t=i;return t}())===i&&(t=function(){var t,r,o,a,s,l,c,d,u;t=Ne,123===e.charCodeAt(Ne)?(r=w,Ne++):(r=i,0===Fe&&qe(x));if(r!==i)if(at()!==i)if((o=ut())!==i)if(at()!==i)if(44===e.charCodeAt(Ne)?(a=z,Ne++):(a=i,0===Fe&&qe(F)),a!==i)if(at()!==i)if(e.substr(Ne,6)===ie?(s=ie,Ne+=6):(s=i,0===Fe&&qe(oe)),s!==i)if(at()!==i)if(44===e.charCodeAt(Ne)?(l=z,Ne++):(l=i,0===Fe&&qe(F)),l!==i)if(at()!==i){if(c=[],(d=rt())!==i)for(;d!==i;)c.push(d),d=rt();else c=i;c!==i&&(d=at())!==i?(125===e.charCodeAt(Ne)?(u=k,Ne++):(u=i,0===Fe&&qe(C)),u!==i?(Ie=t,t=r=function(e,t){return _({type:n.select,value:e,options:t.reduce((function(e,t){var r=t.id,n=t.value,i=t.location;return r in e&&je('Duplicate option "'+r+'" in select element: "'+Le()+'"',Me()),e[r]={value:n,location:i},e}),{})},bt())}(o,c)):(Ne=t,t=i)):(Ne=t,t=i)}else Ne=t,t=i;else Ne=t,t=i;else Ne=t,t=i;else Ne=t,t=i;else Ne=t,t=i;else Ne=t,t=i;else Ne=t,t=i;else Ne=t,t=i;else Ne=t,t=i;else Ne=t,t=i;return t}())===i&&(t=function(){var t,r,o,a,s,b;Fe++,t=Ne,r=Ne,60===e.charCodeAt(Ne)?(o="<",Ne++):(o=i,0===Fe&&qe(d));o!==i&&(a=pt())!==i&&(s=at())!==i?(e.substr(Ne,2)===u?(b=u,Ne+=2):(b=i,0===Fe&&qe(p)),b!==i?r=o=[o,a,s,b]:(Ne=r,r=i)):(Ne=r,r=i);r!==i&&(Ie=t,v=r,r=_({type:n.literal,value:v.join("")},bt()));var v;(t=r)===i&&(t=Ne,(r=function(){var t,r,n,o;t=Ne,60===e.charCodeAt(Ne)?(r=c,Ne++):(r=i,0===Fe&&qe(d));r!==i?(Ie=Ne,mt.push("openingTag"),(!0?void 0:i)!==i&&(n=pt())!==i?(62===e.charCodeAt(Ne)?(o=">",Ne++):(o=i,0===Fe&&qe(f)),o!==i?(Ie=Ne,(m()?void 0:i)!==i?(Ie=t,t=r=n):(Ne=t,t=i)):(Ne=t,t=i)):(Ne=t,t=i)):(Ne=t,t=i);return t}())!==i&&(o=Je())!==i&&(a=function(){var t,r,n,o;t=Ne,e.substr(Ne,2)===y?(r=y,Ne+=2):(r=i,0===Fe&&qe(g));r!==i?(Ie=Ne,mt.push("closingTag"),(!0?void 0:i)!==i&&(n=pt())!==i?(62===e.charCodeAt(Ne)?(o=h,Ne++):(o=i,0===Fe&&qe(f)),o!==i?(Ie=Ne,(m()?void 0:i)!==i?(Ie=t,t=r=n):(Ne=t,t=i)):(Ne=t,t=i)):(Ne=t,t=i)):(Ne=t,t=i);return t}())!==i?(Ie=t,x=o,(w=r)!==(k=a)&&je('Mismatch tag "'+w+'" !== "'+k+'"',Me()),t=r=_({type:n.tag,value:w,children:x},bt())):(Ne=t,t=i));var w,x,k;Fe--,t===i&&(r=i,0===Fe&&qe(l));return t}())===i&&(t=function(){var t,r;t=Ne,35===e.charCodeAt(Ne)?(r="#",Ne++):(r=i,0===Fe&&qe(s));r!==i&&(Ie=t,r=_({type:n.pound},bt()));return t=r}()),t}function Ge(){var e,t,r;if(e=Ne,t=[],(r=lt())===i&&(r=ct())===i&&(r=dt()),r!==i)for(;r!==i;)t.push(r),(r=lt())===i&&(r=ct())===i&&(r=dt());else t=i;return t!==i&&(Ie=e,t=t.join("")),e=t}function Xe(){var t,r,n,o,a;if(Fe++,t=Ne,r=[],n=Ne,o=Ne,Fe++,(a=it())===i&&(S.test(e.charAt(Ne))?(a=e.charAt(Ne),Ne++):(a=i,0===Fe&&qe(P))),Fe--,a===i?o=void 0:(Ne=o,o=i),o!==i?(e.length>Ne?(a=e.charAt(Ne),Ne++):(a=i,0===Fe&&qe(A)),a!==i?n=o=[o,a]:(Ne=n,n=i)):(Ne=n,n=i),n!==i)for(;n!==i;)r.push(n),n=Ne,o=Ne,Fe++,(a=it())===i&&(S.test(e.charAt(Ne))?(a=e.charAt(Ne),Ne++):(a=i,0===Fe&&qe(P))),Fe--,a===i?o=void 0:(Ne=o,o=i),o!==i?(e.length>Ne?(a=e.charAt(Ne),Ne++):(a=i,0===Fe&&qe(A)),a!==i?n=o=[o,a]:(Ne=n,n=i)):(Ne=n,n=i);else r=i;return t=r!==i?e.substring(t,Ne):r,Fe--,t===i&&(r=i,0===Fe&&qe(E)),t}function Ze(){var t,r,n;return Fe++,t=Ne,47===e.charCodeAt(Ne)?(r="/",Ne++):(r=i,0===Fe&&qe(O)),r!==i&&(n=Xe())!==i?(Ie=t,t=r=n):(Ne=t,t=i),Fe--,t===i&&(r=i,0===Fe&&qe(T)),t}function Qe(){var e,t,r,n;if(Fe++,e=Ne,at()!==i)if((t=Xe())!==i){for(r=[],n=Ze();n!==i;)r.push(n),n=Ze();r!==i?(Ie=e,e=function(e,t){return{stem:e,options:t}}(t,r)):(Ne=e,e=i)}else Ne=e,e=i;else Ne=e,e=i;return Fe--,e===i&&(i,0===Fe&&qe(N)),e}function et(){var t,r,n,o;if(t=Ne,39===e.charCodeAt(Ne)?(r=H,Ne++):(r=i,0===Fe&&qe(B)),r!==i){if(n=[],(o=lt())===i&&($.test(e.charAt(Ne))?(o=e.charAt(Ne),Ne++):(o=i,0===Fe&&qe(V))),o!==i)for(;o!==i;)n.push(o),(o=lt())===i&&($.test(e.charAt(Ne))?(o=e.charAt(Ne),Ne++):(o=i,0===Fe&&qe(V)));else n=i;n!==i?(39===e.charCodeAt(Ne)?(o=H,Ne++):(o=i,0===Fe&&qe(B)),o!==i?t=r=[r,n,o]:(Ne=t,t=i)):(Ne=t,t=i)}else Ne=t,t=i;if(t===i)if(t=[],(r=lt())===i&&(U.test(e.charAt(Ne))?(r=e.charAt(Ne),Ne++):(r=i,0===Fe&&qe(q))),r!==i)for(;r!==i;)t.push(r),(r=lt())===i&&(U.test(e.charAt(Ne))?(r=e.charAt(Ne),Ne++):(r=i,0===Fe&&qe(q)));else t=i;return t}function tt(){var t,r;if(t=[],K.test(e.charAt(Ne))?(r=e.charAt(Ne),Ne++):(r=i,0===Fe&&qe(Y)),r!==i)for(;r!==i;)t.push(r),K.test(e.charAt(Ne))?(r=e.charAt(Ne),Ne++):(r=i,0===Fe&&qe(Y));else t=i;return t}function rt(){var t,r,n,o,a,s,l;return t=Ne,at()!==i&&(r=ft())!==i&&at()!==i?(123===e.charCodeAt(Ne)?(n=w,Ne++):(n=i,0===Fe&&qe(x)),n!==i?(Ie=Ne,mt.push("select"),(!0?void 0:i)!==i&&(o=Je())!==i?(125===e.charCodeAt(Ne)?(a=k,Ne++):(a=i,0===Fe&&qe(C)),a!==i?(Ie=t,s=r,l=o,mt.pop(),t=_({id:s,value:l},bt())):(Ne=t,t=i)):(Ne=t,t=i)):(Ne=t,t=i)):(Ne=t,t=i),t}function nt(){var t,r,n,o,a,s,l;return t=Ne,at()!==i&&(r=function(){var t,r,n,o;return t=Ne,r=Ne,61===e.charCodeAt(Ne)?(n="=",Ne++):(n=i,0===Fe&&qe(ae)),n!==i&&(o=st())!==i?r=n=[n,o]:(Ne=r,r=i),(t=r!==i?e.substring(t,Ne):r)===i&&(t=ft()),t}())!==i&&at()!==i?(123===e.charCodeAt(Ne)?(n=w,Ne++):(n=i,0===Fe&&qe(x)),n!==i?(Ie=Ne,mt.push("plural"),(!0?void 0:i)!==i&&(o=Je())!==i?(125===e.charCodeAt(Ne)?(a=k,Ne++):(a=i,0===Fe&&qe(C)),a!==i?(Ie=t,s=r,l=o,mt.pop(),t=_({id:s,value:l},bt())):(Ne=t,t=i)):(Ne=t,t=i)):(Ne=t,t=i)):(Ne=t,t=i),t}function it(){var t;return Fe++,le.test(e.charAt(Ne))?(t=e.charAt(Ne),Ne++):(t=i,0===Fe&&qe(ce)),Fe--,t===i&&(i,0===Fe&&qe(se)),t}function ot(){var t;return Fe++,ue.test(e.charAt(Ne))?(t=e.charAt(Ne),Ne++):(t=i,0===Fe&&qe(pe)),Fe--,t===i&&(i,0===Fe&&qe(de)),t}function at(){var t,r,n;for(Fe++,t=Ne,r=[],n=it();n!==i;)r.push(n),n=it();return t=r!==i?e.substring(t,Ne):r,Fe--,t===i&&(r=i,0===Fe&&qe(he)),t}function st(){var t,r,n,o,a;return Fe++,t=Ne,45===e.charCodeAt(Ne)?(r="-",Ne++):(r=i,0===Fe&&qe(ye)),r===i&&(r=null),r!==i&&(n=ht())!==i?(Ie=t,o=r,t=r=(a=n)?o?-a:a:0):(Ne=t,t=i),Fe--,t===i&&(r=i,0===Fe&&qe(fe)),t}function lt(){var t,r;return Fe++,t=Ne,e.substr(Ne,2)===be?(r=be,Ne+=2):(r=i,0===Fe&&qe(_e)),r!==i&&(Ie=t,r="'"),Fe--,(t=r)===i&&(r=i,0===Fe&&qe(ge)),t}function ct(){var t,r,n,o,a,s;if(t=Ne,39===e.charCodeAt(Ne)?(r=H,Ne++):(r=i,0===Fe&&qe(B)),r!==i)if((n=function(){var t,r,n,o;t=Ne,r=Ne,e.length>Ne?(n=e.charAt(Ne),Ne++):(n=i,0===Fe&&qe(A));n!==i?(Ie=Ne,(o=(o="<"===(a=n)||">"===a||"{"===a||"}"===a||gt()&&"#"===a)?void 0:i)!==i?r=n=[n,o]:(Ne=r,r=i)):(Ne=r,r=i);var a;t=r!==i?e.substring(t,Ne):r;return t}())!==i){for(o=Ne,a=[],e.substr(Ne,2)===be?(s=be,Ne+=2):(s=i,0===Fe&&qe(_e)),s===i&&($.test(e.charAt(Ne))?(s=e.charAt(Ne),Ne++):(s=i,0===Fe&&qe(V)));s!==i;)a.push(s),e.substr(Ne,2)===be?(s=be,Ne+=2):(s=i,0===Fe&&qe(_e)),s===i&&($.test(e.charAt(Ne))?(s=e.charAt(Ne),Ne++):(s=i,0===Fe&&qe(V)));(o=a!==i?e.substring(o,Ne):a)!==i?(39===e.charCodeAt(Ne)?(a=H,Ne++):(a=i,0===Fe&&qe(B)),a===i&&(a=null),a!==i?(Ie=t,t=r=n+o.replace("''","'")):(Ne=t,t=i)):(Ne=t,t=i)}else Ne=t,t=i;else Ne=t,t=i;return t}function dt(){var t,r,n,o,a;return t=Ne,r=Ne,e.length>Ne?(n=e.charAt(Ne),Ne++):(n=i,0===Fe&&qe(A)),n!==i?(Ie=Ne,(o=(o=!("<"===(a=n)||"{"===a||gt()&&"#"===a||yt()&&"}"===a||yt()&&">"===a))?void 0:i)!==i?r=n=[n,o]:(Ne=r,r=i)):(Ne=r,r=i),r===i&&(10===e.charCodeAt(Ne)?(r="\n",Ne++):(r=i,0===Fe&&qe(ve))),t=r!==i?e.substring(t,Ne):r}function ut(){var t,r;return Fe++,t=Ne,(r=ht())===i&&(r=ft()),t=r!==i?e.substring(t,Ne):r,Fe--,t===i&&(r=i,0===Fe&&qe(we)),t}function pt(){var t,r;return Fe++,t=Ne,(r=ht())===i&&(r=function(){var t,r,n,o,a;Fe++,t=Ne,r=[],45===e.charCodeAt(Ne)?(n=me,Ne++):(n=i,0===Fe&&qe(ye));n===i&&(n=Ne,o=Ne,Fe++,(a=it())===i&&(a=ot()),Fe--,a===i?o=void 0:(Ne=o,o=i),o!==i?(e.length>Ne?(a=e.charAt(Ne),Ne++):(a=i,0===Fe&&qe(A)),a!==i?n=o=[o,a]:(Ne=n,n=i)):(Ne=n,n=i));if(n!==i)for(;n!==i;)r.push(n),45===e.charCodeAt(Ne)?(n=me,Ne++):(n=i,0===Fe&&qe(ye)),n===i&&(n=Ne,o=Ne,Fe++,(a=it())===i&&(a=ot()),Fe--,a===i?o=void 0:(Ne=o,o=i),o!==i?(e.length>Ne?(a=e.charAt(Ne),Ne++):(a=i,0===Fe&&qe(A)),a!==i?n=o=[o,a]:(Ne=n,n=i)):(Ne=n,n=i));else r=i;t=r!==i?e.substring(t,Ne):r;Fe--,t===i&&(r=i,0===Fe&&qe(Oe));return t}()),t=r!==i?e.substring(t,Ne):r,Fe--,t===i&&(r=i,0===Fe&&qe(xe)),t}function ht(){var t,r,n,o,a;if(Fe++,t=Ne,48===e.charCodeAt(Ne)?(r="0",Ne++):(r=i,0===Fe&&qe(Ce)),r!==i&&(Ie=t,r=0),(t=r)===i){if(t=Ne,r=Ne,Ee.test(e.charAt(Ne))?(n=e.charAt(Ne),Ne++):(n=i,0===Fe&&qe(Se)),n!==i){for(o=[],Pe.test(e.charAt(Ne))?(a=e.charAt(Ne),Ne++):(a=i,0===Fe&&qe(Ae));a!==i;)o.push(a),Pe.test(e.charAt(Ne))?(a=e.charAt(Ne),Ne++):(a=i,0===Fe&&qe(Ae));o!==i?r=n=[n,o]:(Ne=r,r=i)}else Ne=r,r=i;r!==i&&(Ie=t,r=parseInt(r.join(""),10)),t=r}return Fe--,t===i&&(r=i,0===Fe&&qe(ke)),t}function ft(){var t,r,n,o,a;if(Fe++,t=Ne,r=[],n=Ne,o=Ne,Fe++,(a=it())===i&&(a=ot()),Fe--,a===i?o=void 0:(Ne=o,o=i),o!==i?(e.length>Ne?(a=e.charAt(Ne),Ne++):(a=i,0===Fe&&qe(A)),a!==i?n=o=[o,a]:(Ne=n,n=i)):(Ne=n,n=i),n!==i)for(;n!==i;)r.push(n),n=Ne,o=Ne,Fe++,(a=it())===i&&(a=ot()),Fe--,a===i?o=void 0:(Ne=o,o=i),o!==i?(e.length>Ne?(a=e.charAt(Ne),Ne++):(a=i,0===Fe&&qe(A)),a!==i?n=o=[o,a]:(Ne=n,n=i)):(Ne=n,n=i);else r=i;return t=r!==i?e.substring(t,Ne):r,Fe--,t===i&&(r=i,0===Fe&&qe(Te)),t}var mt=["root"];function yt(){return mt.length>1}function gt(){return"plural"===mt[mt.length-1]}function bt(){return t&&t.captureLocation?{location:Me()}:{}}if((r=a())!==i&&Ne===e.length)return r;throw r!==i&&Ne<e.length&&qe({type:"end"}),Ke(ze,De<e.length?e.charAt(De):null,De<e.length?Ue(De,De+1):Ue(De,De))},x=function(){for(var e=0,t=0,r=arguments.length;t<r;t++)e+=arguments[t].length;var n=Array(e),i=0;for(t=0;t<r;t++)for(var o=arguments[t],a=0,s=o.length;a<s;a++,i++)n[i]=o[a];return n},k=/(^|[^\\])#/g;function C(e){e.forEach((function(e){(p(e)||u(e))&&Object.keys(e.options).forEach((function(t){for(var r,n=e.options[t],i=-1,o=void 0,s=0;s<n.value.length;s++){var l=n.value[s];if(a(l)&&k.test(l.value)){i=s,o=l;break}}if(o){var c=o.value.replace(k,"$1{"+e.value+", number}"),d=w(c);(r=n.value).splice.apply(r,x([i,1],d))}C(n.value)}))}))}function E(e,t){var r=w(e,t);return t&&!1===t.normalizeHashtagInPlural||C(r),r}var S=function(){for(var e=0,t=0,r=arguments.length;t<r;t++)e+=arguments[t].length;var n=Array(e),i=0;for(t=0;t<r;t++)for(var o=arguments[t],a=0,s=o.length;a<s;a++,i++)n[i]=o[a];return n};function P(e){return JSON.stringify(e.map((function(e){return e&&"object"==typeof e?(t=e,Object.keys(t).sort().map((function(e){var r;return(r={})[e]=t[e],r}))):e;var t})))}const A=function(e,t){return void 0===t&&(t={}),function(){for(var r,n=[],i=0;i<arguments.length;i++)n[i]=arguments[i];var o=P(n),a=o&&t[o];return a||(a=new((r=e).bind.apply(r,S([void 0],n))),o&&(t[o]=a)),a}};var T=function(){return(T=Object.assign||function(e){for(var t,r=1,n=arguments.length;r<n;r++)for(var i in t=arguments[r])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)},O=/(?:[Eec]{1,6}|G{1,5}|[Qq]{1,5}|(?:[yYur]+|U{1,5})|[ML]{1,5}|d{1,2}|D{1,3}|F{1}|[abB]{1,5}|[hkHK]{1,2}|w{1,2}|W{1}|m{1,2}|s{1,2}|[zZOvVxX]{1,4})(?=([^']*'[^']*')*[^']*$)/g;function N(e){var t={};return e.replace(O,(function(e){var r=e.length;switch(e[0]){case"G":t.era=4===r?"long":5===r?"narrow":"short";break;case"y":t.year=2===r?"2-digit":"numeric";break;case"Y":case"u":case"U":case"r":throw new RangeError("`Y/u/U/r` (year) patterns are not supported, use `y` instead");case"q":case"Q":throw new RangeError("`q/Q` (quarter) patterns are not supported");case"M":case"L":t.month=["numeric","2-digit","short","long","narrow"][r-1];break;case"w":case"W":throw new RangeError("`w/W` (week) patterns are not supported");case"d":t.day=["numeric","2-digit"][r-1];break;case"D":case"F":case"g":throw new RangeError("`D/F/g` (day) patterns are not supported, use `d` instead");case"E":t.weekday=4===r?"short":5===r?"narrow":"short";break;case"e":if(r<4)throw new RangeError("`e..eee` (weekday) patterns are not supported");t.weekday=["short","long","narrow","short"][r-4];break;case"c":if(r<4)throw new RangeError("`c..ccc` (weekday) patterns are not supported");t.weekday=["short","long","narrow","short"][r-4];break;case"a":t.hour12=!0;break;case"b":case"B":throw new RangeError("`b/B` (period) patterns are not supported, use `a` instead");case"h":t.hourCycle="h12",t.hour=["numeric","2-digit"][r-1];break;case"H":t.hourCycle="h23",t.hour=["numeric","2-digit"][r-1];break;case"K":t.hourCycle="h11",t.hour=["numeric","2-digit"][r-1];break;case"k":t.hourCycle="h24",t.hour=["numeric","2-digit"][r-1];break;case"j":case"J":case"C":throw new RangeError("`j/J/C` (hour) patterns are not supported, use `h/H/K/k` instead");case"m":t.minute=["numeric","2-digit"][r-1];break;case"s":t.second=["numeric","2-digit"][r-1];break;case"S":case"A":throw new RangeError("`S/A` (second) pattenrs are not supported, use `s` instead");case"z":t.timeZoneName=r<4?"short":"long";break;case"Z":case"O":case"v":case"V":case"X":case"x":throw new RangeError("`Z/O/v/V/X/x` (timeZone) pattenrs are not supported, use `z` instead")}return""})),t}var I=/^\.(?:(0+)(\*)?|(#+)|(0+)(#+))$/g,R=/^(@+)?(\+|#+)?$/g;function D(e){var t={};return e.replace(R,(function(e,r,n){return"string"!=typeof n?(t.minimumSignificantDigits=r.length,t.maximumSignificantDigits=r.length):"+"===n?t.minimumSignificantDigits=r.length:"#"===r[0]?t.maximumSignificantDigits=r.length:(t.minimumSignificantDigits=r.length,t.maximumSignificantDigits=r.length+("string"==typeof n?n.length:0)),""})),t}function z(e){switch(e){case"sign-auto":return{signDisplay:"auto"};case"sign-accounting":return{currencySign:"accounting"};case"sign-always":return{signDisplay:"always"};case"sign-accounting-always":return{signDisplay:"always",currencySign:"accounting"};case"sign-except-zero":return{signDisplay:"exceptZero"};case"sign-accounting-except-zero":return{signDisplay:"exceptZero",currencySign:"accounting"};case"sign-never":return{signDisplay:"never"}}}function F(e){var t=z(e);return t||{}}function L(e){for(var t={},r=0,n=e;r<n.length;r++){var i=n[r];switch(i.stem){case"percent":t.style="percent";continue;case"currency":t.style="currency",t.currency=i.options[0];continue;case"group-off":t.useGrouping=!1;continue;case"precision-integer":case".":t.maximumFractionDigits=0;continue;case"measure-unit":t.style="unit",t.unit=i.options[0].replace(/^(.*?)-/,"");continue;case"compact-short":t.notation="compact",t.compactDisplay="short";continue;case"compact-long":t.notation="compact",t.compactDisplay="long";continue;case"scientific":t=T(T(T({},t),{notation:"scientific"}),i.options.reduce((function(e,t){return T(T({},e),F(t))}),{}));continue;case"engineering":t=T(T(T({},t),{notation:"engineering"}),i.options.reduce((function(e,t){return T(T({},e),F(t))}),{}));continue;case"notation-simple":t.notation="standard";continue;case"unit-width-narrow":t.currencyDisplay="narrowSymbol",t.unitDisplay="narrow";continue;case"unit-width-short":t.currencyDisplay="code",t.unitDisplay="short";continue;case"unit-width-full-name":t.currencyDisplay="name",t.unitDisplay="long";continue;case"unit-width-iso-code":t.currencyDisplay="symbol";continue}if(I.test(i.stem)){if(i.options.length>1)throw new RangeError("Fraction-precision stems only accept a single optional option");i.stem.replace(I,(function(e,r,n,i,o,a){return"*"===n?t.minimumFractionDigits=r.length:i&&"#"===i[0]?t.maximumFractionDigits=i.length:o&&a?(t.minimumFractionDigits=o.length,t.maximumFractionDigits=o.length+a.length):(t.minimumFractionDigits=r.length,t.maximumFractionDigits=r.length),""})),i.options.length&&(t=T(T({},t),D(i.options[0])))}else if(R.test(i.stem))t=T(T({},t),D(i.stem));else{var o=z(i.stem);o&&(t=T(T({},t),o))}}return t}var M,j=function(){var e=function(t,r){return(e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var r in t)t.hasOwnProperty(r)&&(e[r]=t[r])})(t,r)};return function(t,r){function n(){this.constructor=t}e(t,r),t.prototype=null===r?Object.create(r):(n.prototype=r.prototype,new n)}}();!function(e){e.MISSING_VALUE="MISSING_VALUE",e.INVALID_VALUE="INVALID_VALUE",e.MISSING_INTL_API="MISSING_INTL_API"}(M||(M={}));var H,B=function(e){function t(t,r,n){var i=e.call(this,t)||this;return i.code=r,i.originalMessage=n,i}return j(t,e),t.prototype.toString=function(){return"[formatjs Error: "+this.code+"] "+this.message},t}(Error),$=function(e){function t(t,r,n,i){return e.call(this,'Invalid values for "'+t+'": "'+r+'". Options are "'+Object.keys(n).join('", "')+'"',"INVALID_VALUE",i)||this}return j(t,e),t}(B),V=function(e){function t(t,r,n){return e.call(this,'Value for "'+t+'" must be of type '+r,"INVALID_VALUE",n)||this}return j(t,e),t}(B),U=function(e){function t(t,r){return e.call(this,'The intl string context variable "'+t+'" was not provided to the string "'+r+'"',"MISSING_VALUE",r)||this}return j(t,e),t}(B);function q(e){return"function"==typeof e}function K(e,t,r,n,i,o,g){if(1===e.length&&a(e[0]))return[{type:0,value:e[0].value}];for(var b=[],_=0,v=e;_<v.length;_++){var w=v[_];if(a(w))b.push({type:0,value:w.value});else if(h(w))"number"==typeof o&&b.push({type:0,value:r.getNumberFormat(t).format(o)});else{var x=w.value;if(!i||!(x in i))throw new U(x,g);var k=i[x];if(s(w))k&&"string"!=typeof k&&"number"!=typeof k||(k="string"==typeof k||"number"==typeof k?String(k):""),b.push({type:"string"==typeof k?0:1,value:k});else if(c(w)){var C="string"==typeof w.style?n.date[w.style]:y(w.style)?N(w.style.pattern):void 0;b.push({type:0,value:r.getDateTimeFormat(t,C).format(k)})}else if(d(w)){C="string"==typeof w.style?n.time[w.style]:y(w.style)?N(w.style.pattern):void 0;b.push({type:0,value:r.getDateTimeFormat(t,C).format(k)})}else if(l(w)){C="string"==typeof w.style?n.number[w.style]:m(w.style)?L(w.style.tokens):void 0;b.push({type:0,value:r.getNumberFormat(t,C).format(k)})}else{if(f(w)){var E=w.children,S=w.value,P=i[S];if(!q(P))throw new V(S,"function",g);var A=K(E,t,r,n,i),T=P.apply(void 0,A.map((function(e){return e.value})));Array.isArray(T)||(T=[T]),b.push.apply(b,T.map((function(e){return{type:"string"==typeof e?0:1,value:e}})))}if(u(w)){if(!(O=w.options[k]||w.options.other))throw new $(w.value,k,Object.keys(w.options),g);b.push.apply(b,K(O.value,t,r,n,i))}else if(p(w)){var O;if(!(O=w.options["="+k])){if(!Intl.PluralRules)throw new B('Intl.PluralRules is not available in this environment.\nTry polyfilling it using "@formatjs/intl-pluralrules"\n',"MISSING_INTL_API",g);var I=r.getPluralRules(t,{type:w.pluralType}).select(k-(w.offset||0));O=w.options[I]||w.options.other}if(!O)throw new $(w.value,k,Object.keys(w.options),g);b.push.apply(b,K(O.value,t,r,n,i,k-(w.offset||0)))}else;}}}return function(e){return e.length<2?e:e.reduce((function(e,t){var r=e[e.length-1];return r&&0===r.type&&0===t.type?r.value+=t.value:e.push(t),e}),[])}(b)}!function(e){e[e.literal=0]="literal",e[e.object=1]="object"}(H||(H={}));var Y=function(){return(Y=Object.assign||function(e){for(var t,r=1,n=arguments.length;r<n;r++)for(var i in t=arguments[r])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)};function J(e,t){return t?Object.keys(e).reduce((function(r,n){var i,o;return r[n]=(i=e[n],(o=t[n])?Y(Y(Y({},i||{}),o||{}),Object.keys(i).reduce((function(e,t){return e[t]=Y(Y({},i[t]),o[t]||{}),e}),{})):i),r}),Y({},e)):e}const W=function(){function e(t,r,n,i){var o,a=this;if(void 0===r&&(r=e.defaultLocale),this.formatterCache={number:{},dateTime:{},pluralRules:{}},this.format=function(e){var t=a.formatToParts(e);if(1===t.length)return t[0].value;var r=t.reduce((function(e,t){return e.length&&0===t.type&&"string"==typeof e[e.length-1]?e[e.length-1]+=t.value:e.push(t.value),e}),[]);return r.length<=1?r[0]||"":r},this.formatToParts=function(e){return K(a.ast,a.locales,a.formatters,a.formats,e,void 0,a.message)},this.resolvedOptions=function(){return{locale:Intl.NumberFormat.supportedLocalesOf(a.locales)[0]}},this.getAst=function(){return a.ast},"string"==typeof t){if(this.message=t,!e.__parse)throw new TypeError("IntlMessageFormat.__parse must be set to process `message` of type `string`");this.ast=e.__parse(t,{normalizeHashtagInPlural:!1})}else this.ast=t;if(!Array.isArray(this.ast))throw new TypeError("A message must be provided as a String or AST.");this.formats=J(e.formats,n),this.locales=r,this.formatters=i&&i.formatters||(void 0===(o=this.formatterCache)&&(o={number:{},dateTime:{},pluralRules:{}}),{getNumberFormat:A(Intl.NumberFormat,o.number),getDateTimeFormat:A(Intl.DateTimeFormat,o.dateTime),getPluralRules:A(Intl.PluralRules,o.pluralRules)})}return Object.defineProperty(e,"defaultLocale",{get:function(){return e.memoizedDefaultLocale||(e.memoizedDefaultLocale=(new Intl.NumberFormat).resolvedOptions().locale),e.memoizedDefaultLocale},enumerable:!0,configurable:!0}),e.memoizedDefaultLocale=null,e.__parse=E,e.formats={number:{currency:{style:"currency"},percent:{style:"percent"}},date:{short:{month:"numeric",day:"numeric",year:"2-digit"},medium:{month:"short",day:"numeric",year:"numeric"},long:{month:"long",day:"numeric",year:"numeric"},full:{weekday:"long",month:"long",day:"numeric",year:"numeric"}},time:{short:{hour:"numeric",minute:"numeric"},medium:{hour:"numeric",minute:"numeric",second:"numeric"},long:{hour:"numeric",minute:"numeric",second:"numeric",timeZoneName:"short"},full:{hour:"numeric",minute:"numeric",second:"numeric",timeZoneName:"short"}}},e}();let G=!(0,o.shouldPolyfill)();const X=G?void 0:r.e(113).then(r.t.bind(r,50113,7)).then((()=>{G=!0})),Z=async(e,t,r,n)=>(G||await X,e._localizationCache={},(i,...o)=>{if(!(i&&r&&t&&r[t]))return"";const a=r[t][i];if(!a)return"";const s=i+a;let l=e._localizationCache[s];l||(l=new W(a,t,n),e._localizationCache[s]=l);const c={};for(let e=0;e<o.length;e+=2)c[o[e]]=o[e+1];try{return l.format(c)}catch(e){return"Translation "+e}}),Q=(e,t,r)=>{const n=[t];return r&&Object.keys(r).forEach((e=>{n.push(e),n.push(r[e])})),e(...n)}},87744:(e,t,r)=>{"use strict";function n(e){const t=e.language||"en";return e.translationMetadata.translations[t]&&e.translationMetadata.translations[t].isRTL||!1}function i(e){return o(n(e))}function o(e){return e?"rtl":"ltr"}r.d(t,{HE:()=>n,Zu:()=>i,$3:()=>o})},38346:(e,t,r)=>{"use strict";r.d(t,{D:()=>n});const n=(e,t,r=!1)=>{let n;return function(...i){const o=this,a=r&&!n;clearTimeout(n),n=setTimeout((()=>{n=null,r||e.apply(o,i)}),t),a&&e.apply(o,i)}}},22814:(e,t,r)=>{"use strict";r.d(t,{uw:()=>n,iI:()=>i});const n=`${location.protocol}//${location.host}`,i=(e,t)=>e.callWS({type:"auth/sign_path",path:t})},62359:(e,t,r)=>{"use strict";r.d(t,{j:()=>i});var n=r(47181);const i=e=>{(0,n.B)(window,"haptic",e)}},76307:(e,t,r)=>{"use strict";r.d(t,{pM:()=>i,k1:()=>o,Rj:()=>a,ec:()=>s});var n=r(53775);const i=()=>fetch("/api/onboarding",{credentials:"same-origin"}),o=e=>(0,n.h)(fetch("/api/onboarding/users",{method:"POST",credentials:"same-origin",body:JSON.stringify(e)})),a=e=>e.callApi("POST","onboarding/core_config"),s=(e,t)=>e.callApi("POST","onboarding/integration",t)},74265:(e,t,r)=>{"use strict";r.d(t,{vC:()=>i,ku:()=>o,gk:()=>a,lD:()=>s});const n={},i=async(e,t,r,i,o)=>{var a,s;if(!(r in n)){if(!o)return;n[r]=o().then((()=>{const n=document.createElement(r);return e.provideHass(n),t.appendChild(n),n}))}history.replaceState({dialog:r,open:!1,oldState:(null===(a=history.state)||void 0===a?void 0:a.open)&&(null===(s=history.state)||void 0===s?void 0:s.dialog)!==r?history.state:null},"");try{history.pushState({dialog:r,dialogParams:i,open:!0},"")}catch(e){history.pushState({dialog:r,dialogParams:null,open:!0},"")}(await n[r]).showDialog(i)},o=()=>{history.replaceState({...history.state,replaced:!0},"")},a=async e=>{if(!(e in n))return!0;const t=await n[e];return!t.closeDialog||!1!==t.closeDialog()},s=(e,t)=>{e.addEventListener("show-dialog",(r=>{const{dialogTag:n,dialogImport:o,dialogParams:a}=r.detail;i(e,t,n,a,o)}))}},38544:(e,t,r)=>{"use strict";var n=r(15652);function i(){i=function(){return e};var e={elementsDefinitionOrder:[["method"],["field"]],initializeInstanceElements:function(e,t){["method","field"].forEach((function(r){t.forEach((function(t){t.kind===r&&"own"===t.placement&&this.defineClassElement(e,t)}),this)}),this)},initializeClassElements:function(e,t){var r=e.prototype;["method","field"].forEach((function(n){t.forEach((function(t){var i=t.placement;if(t.kind===n&&("static"===i||"prototype"===i)){var o="static"===i?e:r;this.defineClassElement(o,t)}}),this)}),this)},defineClassElement:function(e,t){var r=t.descriptor;if("field"===t.kind){var n=t.initializer;r={enumerable:r.enumerable,writable:r.writable,configurable:r.configurable,value:void 0===n?void 0:n.call(e)}}Object.defineProperty(e,t.key,r)},decorateClass:function(e,t){var r=[],n=[],i={static:[],prototype:[],own:[]};if(e.forEach((function(e){this.addElementPlacement(e,i)}),this),e.forEach((function(e){if(!s(e))return r.push(e);var t=this.decorateElement(e,i);r.push(t.element),r.push.apply(r,t.extras),n.push.apply(n,t.finishers)}),this),!t)return{elements:r,finishers:n};var o=this.decorateConstructor(r,t);return n.push.apply(n,o.finishers),o.finishers=n,o},addElementPlacement:function(e,t,r){var n=t[e.placement];if(!r&&-1!==n.indexOf(e.key))throw new TypeError("Duplicated element ("+e.key+")");n.push(e.key)},decorateElement:function(e,t){for(var r=[],n=[],i=e.decorators,o=i.length-1;o>=0;o--){var a=t[e.placement];a.splice(a.indexOf(e.key),1);var s=this.fromElementDescriptor(e),l=this.toElementFinisherExtras((0,i[o])(s)||s);e=l.element,this.addElementPlacement(e,t),l.finisher&&n.push(l.finisher);var c=l.extras;if(c){for(var d=0;d<c.length;d++)this.addElementPlacement(c[d],t);r.push.apply(r,c)}}return{element:e,finishers:n,extras:r}},decorateConstructor:function(e,t){for(var r=[],n=t.length-1;n>=0;n--){var i=this.fromClassDescriptor(e),o=this.toClassDescriptor((0,t[n])(i)||i);if(void 0!==o.finisher&&r.push(o.finisher),void 0!==o.elements){e=o.elements;for(var a=0;a<e.length-1;a++)for(var s=a+1;s<e.length;s++)if(e[a].key===e[s].key&&e[a].placement===e[s].placement)throw new TypeError("Duplicated element ("+e[a].key+")")}}return{elements:e,finishers:r}},fromElementDescriptor:function(e){var t={kind:e.kind,key:e.key,placement:e.placement,descriptor:e.descriptor};return Object.defineProperty(t,Symbol.toStringTag,{value:"Descriptor",configurable:!0}),"field"===e.kind&&(t.initializer=e.initializer),t},toElementDescriptors:function(e){var t;if(void 0!==e)return(t=e,function(e){if(Array.isArray(e))return e}(t)||function(e){if("undefined"!=typeof Symbol&&Symbol.iterator in Object(e))return Array.from(e)}(t)||function(e,t){if(e){if("string"==typeof e)return u(e,t);var r=Object.prototype.toString.call(e).slice(8,-1);return"Object"===r&&e.constructor&&(r=e.constructor.name),"Map"===r||"Set"===r?Array.from(e):"Arguments"===r||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r)?u(e,t):void 0}}(t)||function(){throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()).map((function(e){var t=this.toElementDescriptor(e);return this.disallowProperty(e,"finisher","An element descriptor"),this.disallowProperty(e,"extras","An element descriptor"),t}),this)},toElementDescriptor:function(e){var t=String(e.kind);if("method"!==t&&"field"!==t)throw new TypeError('An element descriptor\'s .kind property must be either "method" or "field", but a decorator created an element descriptor with .kind "'+t+'"');var r=d(e.key),n=String(e.placement);if("static"!==n&&"prototype"!==n&&"own"!==n)throw new TypeError('An element descriptor\'s .placement property must be one of "static", "prototype" or "own", but a decorator created an element descriptor with .placement "'+n+'"');var i=e.descriptor;this.disallowProperty(e,"elements","An element descriptor");var o={kind:t,key:r,placement:n,descriptor:Object.assign({},i)};return"field"!==t?this.disallowProperty(e,"initializer","A method descriptor"):(this.disallowProperty(i,"get","The property descriptor of a field descriptor"),this.disallowProperty(i,"set","The property descriptor of a field descriptor"),this.disallowProperty(i,"value","The property descriptor of a field descriptor"),o.initializer=e.initializer),o},toElementFinisherExtras:function(e){return{element:this.toElementDescriptor(e),finisher:c(e,"finisher"),extras:this.toElementDescriptors(e.extras)}},fromClassDescriptor:function(e){var t={kind:"class",elements:e.map(this.fromElementDescriptor,this)};return Object.defineProperty(t,Symbol.toStringTag,{value:"Descriptor",configurable:!0}),t},toClassDescriptor:function(e){var t=String(e.kind);if("class"!==t)throw new TypeError('A class descriptor\'s .kind property must be "class", but a decorator created a class descriptor with .kind "'+t+'"');this.disallowProperty(e,"key","A class descriptor"),this.disallowProperty(e,"placement","A class descriptor"),this.disallowProperty(e,"descriptor","A class descriptor"),this.disallowProperty(e,"initializer","A class descriptor"),this.disallowProperty(e,"extras","A class descriptor");var r=c(e,"finisher");return{elements:this.toElementDescriptors(e.elements),finisher:r}},runClassFinishers:function(e,t){for(var r=0;r<t.length;r++){var n=(0,t[r])(e);if(void 0!==n){if("function"!=typeof n)throw new TypeError("Finishers must return a constructor.");e=n}}return e},disallowProperty:function(e,t,r){if(void 0!==e[t])throw new TypeError(r+" can't have a ."+t+" property.")}};return e}function o(e){var t,r=d(e.key);"method"===e.kind?t={value:e.value,writable:!0,configurable:!0,enumerable:!1}:"get"===e.kind?t={get:e.value,configurable:!0,enumerable:!1}:"set"===e.kind?t={set:e.value,configurable:!0,enumerable:!1}:"field"===e.kind&&(t={configurable:!0,writable:!0,enumerable:!0});var n={kind:"field"===e.kind?"field":"method",key:r,placement:e.static?"static":"field"===e.kind?"own":"prototype",descriptor:t};return e.decorators&&(n.decorators=e.decorators),"field"===e.kind&&(n.initializer=e.value),n}function a(e,t){void 0!==e.descriptor.get?t.descriptor.get=e.descriptor.get:t.descriptor.set=e.descriptor.set}function s(e){return e.decorators&&e.decorators.length}function l(e){return void 0!==e&&!(void 0===e.value&&void 0===e.writable)}function c(e,t){var r=e[t];if(void 0!==r&&"function"!=typeof r)throw new TypeError("Expected '"+t+"' to be a function");return r}function d(e){var t=function(e,t){if("object"!=typeof e||null===e)return e;var r=e[Symbol.toPrimitive];if(void 0!==r){var n=r.call(e,t||"default");if("object"!=typeof n)return n;throw new TypeError("@@toPrimitive must return a primitive value.")}return("string"===t?String:Number)(e)}(e,"string");return"symbol"==typeof t?t:String(t)}function u(e,t){(null==t||t>e.length)&&(t=e.length);for(var r=0,n=new Array(t);r<t;r++)n[r]=e[r];return n}!function(e,t,r,n){var c=i();if(n)for(var d=0;d<n.length;d++)c=n[d](c);var u=t((function(e){c.initializeInstanceElements(e,p.elements)}),r),p=c.decorateClass(function(e){for(var t=[],r=function(e){return"method"===e.kind&&e.key===o.key&&e.placement===o.placement},n=0;n<e.length;n++){var i,o=e[n];if("method"===o.kind&&(i=t.find(r)))if(l(o.descriptor)||l(i.descriptor)){if(s(o)||s(i))throw new ReferenceError("Duplicated methods ("+o.key+") can't be decorated.");i.descriptor=o.descriptor}else{if(s(o)){if(s(i))throw new ReferenceError("Decorators can't be placed on different accessors with for the same property ("+o.key+").");i.decorators=o.decorators}a(o,i)}else t.push(o)}return t}(u.d.map(o)),e);c.initializeClassElements(u.F,p.elements),c.runClassFinishers(u.F,p.finishers)}([(0,n.Mo)("onboarding-loading")],(function(e,t){return{F:class extends t{constructor(...t){super(...t),e(this)}},d:[{kind:"method",key:"render",value:function(){return n.dy` <div class="loader"></div> `}},{kind:"get",static:!0,key:"styles",value:function(){return n.iv`
      /* MIT License (MIT). Copyright (c) 2014 Luke Haas */
      .loader,
      .loader:after {
        border-radius: 50%;
        width: 40px;
        height: 40px;
      }
      .loader {
        margin: 60px auto;
        font-size: 4px;
        position: relative;
        text-indent: -9999em;
        border-top: 1.1em solid rgba(3, 169, 244, 0.2);
        border-right: 1.1em solid rgba(3, 169, 244, 0.2);
        border-bottom: 1.1em solid rgba(3, 169, 244, 0.2);
        border-left: 1.1em solid rgb(3, 168, 244);
        -webkit-transform: translateZ(0);
        -ms-transform: translateZ(0);
        transform: translateZ(0);
        -webkit-animation: load8 1.4s infinite linear;
        animation: load8 1.4s infinite linear;
      }
      @-webkit-keyframes load8 {
        0% {
          -webkit-transform: rotate(0deg);
          transform: rotate(0deg);
        }
        100% {
          -webkit-transform: rotate(360deg);
          transform: rotate(360deg);
        }
      }
      @keyframes load8 {
        0% {
          -webkit-transform: rotate(0deg);
          transform: rotate(0deg);
        }
        100% {
          -webkit-transform: rotate(360deg);
          transform: rotate(360deg);
        }
      }
    `}}]}}),n.oi)},64702:()=>{const e=document.createElement("template");e.setAttribute("style","display: none;"),e.innerHTML='<style>\n@font-face {\nfont-family: "Roboto";\nsrc:\n  local("Roboto Thin"),\n  local("Roboto-Thin"),\n  url(/static/fonts/roboto/Roboto-Thin.woff2) format("woff2");\nfont-weight: 100;\nfont-style: normal;\n}\n@font-face {\nfont-family: "Roboto";\nsrc:\n  local("Roboto Thin Italic"),\n  local("Roboto-ThinItalic"),\n  url(/static/fonts/roboto/Roboto-ThinItalic.woff2) format("woff2");\nfont-weight: 100;\nfont-style: italic;\n}\n@font-face {\nfont-family: "Roboto";\nsrc:\n  local("Roboto Light"),\n  local("Roboto-Light"),\n  url(/static/fonts/roboto/Roboto-Light.woff2) format("woff2");\nfont-weight: 300;\nfont-style: normal;\n}\n@font-face {\nfont-family: "Roboto";\nsrc:\n  local("Roboto Light Italic"),\n  local("Roboto-LightItalic"),\n  url(/static/fonts/roboto/Roboto-LightItalic.woff2) format("woff2");\nfont-weight: 300;\nfont-style: italic;\n}\n@font-face {\nfont-family: "Roboto";\nsrc:\n  local("Roboto Regular"),\n  local("Roboto-Regular"),\n  url(/static/fonts/roboto/Roboto-Regular.woff2) format("woff2");\nfont-weight: 400;\nfont-style: normal;\n}\n@font-face {\nfont-family: "Roboto";\nsrc:\n  local("Roboto Italic"),\n  local("Roboto-Italic"),\n  url(/static/fonts/roboto/Roboto-RegularItalic.woff2) format("woff2");\nfont-weight: 400;\nfont-style: italic;\n}\n@font-face {\nfont-family: "Roboto";\nsrc:\n  local("Roboto Medium"),\n  local("Roboto-Medium"),\n  url(/static/fonts/roboto/Roboto-Medium.woff2) format("woff2");\nfont-weight: 500;\nfont-style: normal;\n}\n@font-face {\nfont-family: "Roboto";\nsrc:\n  local("Roboto Medium Italic"),\n  local("Roboto-MediumItalic"),\n  url(/static/fonts/roboto/Roboto-MediumItalic.woff2) format("woff2");\nfont-weight: 500;\nfont-style: italic;\n}\n@font-face {\nfont-family: "Roboto";\nsrc:\n  local("Roboto Bold"),\n  local("Roboto-Bold"),\n  url(/static/fonts/roboto/Roboto-Bold.woff2) format("woff2");\nfont-weight: 700;\nfont-style: normal;\n}\n@font-face {\nfont-family: "Roboto";\nsrc:\n  local("Roboto Bold Italic"),\n  local("Roboto-BoldItalic"),\n  url(/static/fonts/roboto/Roboto-BoldItalic.woff2) format("woff2");\nfont-weight: 700;\nfont-style: italic;\n}\n@font-face {\nfont-family: "Roboto";\nsrc:\n  local("Roboto Black"),\n  local("Roboto-Black"),\n  url(/static/fonts/roboto/Roboto-Black.woff2) format("woff2");\nfont-weight: 900;\nfont-style: normal;\n}\n@font-face {\nfont-family: "Roboto";\nsrc:\n  local("Roboto Black Italic"),\n  local("Roboto-BlackItalic"),\n  url(/static/fonts/roboto/Roboto-BlackItalic.woff2) format("woff2");\nfont-weight: 900;\nfont-style: italic;\n}\n</style>',document.head.appendChild(e.content)},37846:()=>{if(/^((?!chrome|android).)*version\/14\.0.*safari/i.test(navigator.userAgent)){const e=window.Element.prototype.attachShadow;window.Element.prototype.attachShadow=function(t){return t&&t.delegatesFocus&&delete t.delegatesFocus,e.apply(this,[t])}}},11654:(e,t,r)=>{"use strict";r.d(t,{_l:()=>i,q0:()=>o,Qx:()=>a,yu:()=>s,$c:()=>l});var n=r(15652);const i={"primary-background-color":"#111111","card-background-color":"#1c1c1c","secondary-background-color":"#202020","primary-text-color":"#e1e1e1","secondary-text-color":"#9b9b9b","disabled-text-color":"#6f6f6f","app-header-text-color":"#e1e1e1","app-header-background-color":"#101e24","switch-unchecked-button-color":"#999999","switch-unchecked-track-color":"#9b9b9b","divider-color":"rgba(225, 225, 225, .12)","mdc-ripple-color":"#AAAAAA","codemirror-keyword":"#C792EA","codemirror-operator":"#89DDFF","codemirror-variable":"#f07178","codemirror-variable-2":"#EEFFFF","codemirror-variable-3":"#DECB6B","codemirror-builtin":"#FFCB6B","codemirror-atom":"#F78C6C","codemirror-number":"#FF5370","codemirror-def":"#82AAFF","codemirror-string":"#C3E88D","codemirror-string-2":"#f07178","codemirror-comment":"#545454","codemirror-tag":"#FF5370","codemirror-meta":"#FFCB6B","codemirror-attribute":"#C792EA","codemirror-property":"#C792EA","codemirror-qualifier":"#DECB6B","codemirror-type":"#DECB6B"},o={"error-state-color":"var(--error-color)","state-icon-unavailable-color":"var(--disabled-text-color)","sidebar-text-color":"var(--primary-text-color)","sidebar-background-color":"var(--card-background-color)","sidebar-selected-text-color":"var(--primary-color)","sidebar-selected-icon-color":"var(--primary-color)","sidebar-icon-color":"rgba(var(--rgb-primary-text-color), 0.6)","switch-checked-color":"var(--primary-color)","switch-checked-button-color":"var(--switch-checked-color, var(--primary-background-color))","switch-checked-track-color":"var(--switch-checked-color, #000000)","switch-unchecked-button-color":"var(--switch-unchecked-color, var(--primary-background-color))","switch-unchecked-track-color":"var(--switch-unchecked-color, #000000)","slider-color":"var(--primary-color)","slider-secondary-color":"var(--light-primary-color)","slider-bar-color":"var(--disabled-text-color)","label-badge-grey":"var(--paper-grey-500)","label-badge-background-color":"var(--card-background-color)","label-badge-text-color":"rgba(var(--rgb-primary-text-color), 0.8)","paper-listbox-background-color":"var(--card-background-color)","paper-item-icon-color":"var(--state-icon-color)","paper-item-icon-active-color":"var(--state-icon-active-color)","table-row-background-color":"var(--primary-background-color)","table-row-alternative-background-color":"var(--secondary-background-color)","paper-slider-knob-color":"var(--slider-color)","paper-slider-knob-start-color":"var(--slider-color)","paper-slider-pin-color":"var(--slider-color)","paper-slider-pin-start-color":"var(--slider-color)","paper-slider-active-color":"var(--slider-color)","paper-slider-secondary-color":"var(--slider-secondary-color)","paper-slider-container-color":"var(--slider-bar-color)","data-table-background-color":"var(--card-background-color)","markdown-code-background-color":"var(--primary-background-color)","mdc-theme-primary":"var(--primary-color)","mdc-theme-secondary":"var(--accent-color)","mdc-theme-background":"var(--primary-background-color)","mdc-theme-surface":"var(--card-background-color)","mdc-theme-on-primary":"var(--text-primary-color)","mdc-theme-on-secondary":"var(--text-primary-color)","mdc-theme-on-surface":"var(--primary-text-color)","mdc-theme-text-primary-on-background":"var(--primary-text-color)","mdc-theme-text-secondary-on-background":"var(--secondary-text-color)","mdc-theme-text-icon-on-background":"var(--secondary-text-color)","app-header-text-color":"var(--text-primary-color)","app-header-background-color":"var(--primary-color)","material-body-text-color":"var(--primary-text-color)","material-background-color":"var(--card-background-color)","material-secondary-background-color":"var(--secondary-background-color)","material-secondary-text-color":"var(--secondary-text-color)","mdc-checkbox-unchecked-color":"rgba(var(--rgb-primary-text-color), 0.54)","mdc-checkbox-disabled-color":"var(--disabled-text-color)","mdc-radio-unchecked-color":"rgba(var(--rgb-primary-text-color), 0.54)","mdc-radio-disabled-color":"var(--disabled-text-color)","mdc-tab-text-label-color-default":"var(--primary-text-color)","mdc-button-disabled-ink-color":"var(--disabled-text-color)","mdc-button-outline-color":"var(--divider-color)","mdc-dialog-scroll-divider-color":"var(--divider-color)"},a=n.iv`
  :host {
    font-family: var(--paper-font-body1_-_font-family);
    -webkit-font-smoothing: var(--paper-font-body1_-_-webkit-font-smoothing);
    font-size: var(--paper-font-body1_-_font-size);
    font-weight: var(--paper-font-body1_-_font-weight);
    line-height: var(--paper-font-body1_-_line-height);
  }

  app-header-layout,
  ha-app-layout {
    background-color: var(--primary-background-color);
  }

  app-header,
  app-toolbar {
    background-color: var(--app-header-background-color);
    font-weight: 400;
    color: var(--app-header-text-color, white);
  }

  app-toolbar {
    height: var(--header-height);
  }

  app-header div[sticky] {
    height: 48px;
  }

  app-toolbar [main-title] {
    margin-left: 20px;
  }

  h1 {
    font-family: var(--paper-font-headline_-_font-family);
    -webkit-font-smoothing: var(--paper-font-headline_-_-webkit-font-smoothing);
    white-space: var(--paper-font-headline_-_white-space);
    overflow: var(--paper-font-headline_-_overflow);
    text-overflow: var(--paper-font-headline_-_text-overflow);
    font-size: var(--paper-font-headline_-_font-size);
    font-weight: var(--paper-font-headline_-_font-weight);
    line-height: var(--paper-font-headline_-_line-height);
  }

  h2 {
    font-family: var(--paper-font-title_-_font-family);
    -webkit-font-smoothing: var(--paper-font-title_-_-webkit-font-smoothing);
    white-space: var(--paper-font-title_-_white-space);
    overflow: var(--paper-font-title_-_overflow);
    text-overflow: var(--paper-font-title_-_text-overflow);
    font-size: var(--paper-font-title_-_font-size);
    font-weight: var(--paper-font-title_-_font-weight);
    line-height: var(--paper-font-title_-_line-height);
  }

  h3 {
    font-family: var(--paper-font-subhead_-_font-family);
    -webkit-font-smoothing: var(--paper-font-subhead_-_-webkit-font-smoothing);
    white-space: var(--paper-font-subhead_-_white-space);
    overflow: var(--paper-font-subhead_-_overflow);
    text-overflow: var(--paper-font-subhead_-_text-overflow);
    font-size: var(--paper-font-subhead_-_font-size);
    font-weight: var(--paper-font-subhead_-_font-weight);
    line-height: var(--paper-font-subhead_-_line-height);
  }

  a {
    color: var(--primary-color);
  }

  .secondary {
    color: var(--secondary-text-color);
  }

  .error {
    color: var(--error-color);
  }

  .warning {
    color: var(--error-color);
  }

  mwc-button.warning {
    --mdc-theme-primary: var(--error-color);
  }

  button.link {
    background: none;
    color: inherit;
    border: none;
    padding: 0;
    font: inherit;
    text-align: left;
    text-decoration: underline;
    cursor: pointer;
  }

  .card-actions a {
    text-decoration: none;
  }

  .card-actions .warning {
    --mdc-theme-primary: var(--error-color);
  }

  .layout.horizontal,
  .layout.vertical {
    display: flex;
  }
  .layout.inline {
    display: inline-flex;
  }
  .layout.horizontal {
    flex-direction: row;
  }
  .layout.vertical {
    flex-direction: column;
  }
  .layout.wrap {
    flex-wrap: wrap;
  }
  .layout.no-wrap {
    flex-wrap: nowrap;
  }
  .layout.center,
  .layout.center-center {
    align-items: center;
  }
  .layout.bottom {
    align-items: flex-end;
  }
  .layout.center-justified,
  .layout.center-center {
    justify-content: center;
  }
  .flex {
    flex: 1;
    flex-basis: 0.000000001px;
  }
  .flex-auto {
    flex: 1 1 auto;
  }
  .flex-none {
    flex: none;
  }
  .layout.justified {
    justify-content: space-between;
  }
`,s=n.iv`
  /* prevent clipping of positioned elements */
  paper-dialog-scrollable {
    --paper-dialog-scrollable: {
      -webkit-overflow-scrolling: auto;
    }
  }

  /* force smooth scrolling for iOS 10 */
  paper-dialog-scrollable.can-scroll {
    --paper-dialog-scrollable: {
      -webkit-overflow-scrolling: touch;
    }
  }

  .paper-dialog-buttons {
    align-items: flex-end;
    padding: 8px;
    padding-bottom: max(env(safe-area-inset-bottom), 8px);
  }

  @media all and (min-width: 450px) and (min-height: 500px) {
    ha-paper-dialog {
      min-width: 400px;
    }
  }

  @media all and (max-width: 450px), all and (max-height: 500px) {
    paper-dialog,
    ha-paper-dialog {
      margin: 0;
      width: calc(
        100% - env(safe-area-inset-right) - env(safe-area-inset-left)
      ) !important;
      min-width: calc(
        100% - env(safe-area-inset-right) - env(safe-area-inset-left)
      ) !important;
      max-width: calc(
        100% - env(safe-area-inset-right) - env(safe-area-inset-left)
      ) !important;
      max-height: calc(100% - var(--header-height));

      position: fixed !important;
      bottom: 0px;
      left: env(safe-area-inset-left);
      right: env(safe-area-inset-right);
      overflow: scroll;
      border-bottom-left-radius: 0px;
      border-bottom-right-radius: 0px;
    }
  }

  /* mwc-dialog (ha-dialog) styles */
  ha-dialog {
    --mdc-dialog-min-width: 400px;
    --mdc-dialog-max-width: 600px;
    --mdc-dialog-heading-ink-color: var(--primary-text-color);
    --mdc-dialog-content-ink-color: var(--primary-text-color);
    --justify-action-buttons: space-between;
  }

  ha-dialog .form {
    padding-bottom: 24px;
    color: var(--primary-text-color);
  }

  a {
    color: var(--primary-color);
  }

  /* make dialog fullscreen on small screens */
  @media all and (max-width: 450px), all and (max-height: 500px) {
    ha-dialog {
      --mdc-dialog-min-width: calc(
        100vw - env(safe-area-inset-right) - env(safe-area-inset-left)
      );
      --mdc-dialog-max-width: calc(
        100vw - env(safe-area-inset-right) - env(safe-area-inset-left)
      );
      --mdc-dialog-min-height: 100%;
      --mdc-dialog-max-height: 100%;
      --mdc-shape-medium: 0px;
      --vertial-align-dialog: flex-end;
    }
  }
  mwc-button.warning {
    --mdc-theme-primary: var(--error-color);
  }
  .error {
    color: var(--error-color);
  }
`,l=n.iv`
  .ha-scrollbar::-webkit-scrollbar {
    width: 0.4rem;
    height: 0.4rem;
  }

  .ha-scrollbar::-webkit-scrollbar-thumb {
    -webkit-border-radius: 4px;
    border-radius: 4px;
    background: var(--scrollbar-thumb-color);
  }

  .ha-scrollbar {
    overflow-y: auto;
    scrollbar-color: var(--scrollbar-thumb-color) transparent;
    scrollbar-width: thin;
  }
`},30320:(e,t,r)=>{"use strict";r.d(t,{r:()=>n});const n=async(e,t,r={})=>(e.expired&&await e.refreshAccessToken(),r.credentials="same-origin",r.headers||(r.headers={}),r.headers||(r.headers={}),r.headers.authorization="Bearer "+e.accessToken,fetch(t,r))},53775:(e,t,r)=>{"use strict";r.d(t,{h:()=>i,Z:()=>o});var n=r(30320);const i=async e=>{let t;try{t=await e}catch(e){throw{error:"Request error",status_code:void 0,body:void 0}}let r=null;const n=t.headers.get("content-type");if(n&&n.includes("application/json"))try{r=await t.json()}catch(e){throw{error:"Unable to parse JSON response",status_code:e.status,body:null}}else r=await t.text();if(!t.ok)throw{error:"Response error: "+t.status,status_code:t.status,body:r};return r};async function o(e,t,r,o,a){const s=`${e.data.hassUrl}/api/${r}`,l={method:t,headers:a||{}};return o&&(l.headers["Content-Type"]="application/json;charset=UTF-8",l.body=JSON.stringify(o)),i((0,n.r)(e,s,l))}},81796:(e,t,r)=>{"use strict";r.d(t,{C:()=>i});var n=r(47181);const i=(e,t)=>(0,n.B)(e,"hass-notification",t)}},n={};function i(e){if(n[e])return n[e].exports;var t=n[e]={id:e,loaded:!1,exports:{}};return r[e].call(t.exports,t,t.exports,i),t.loaded=!0,t.exports}i.m=r,i.n=e=>{var t=e&&e.__esModule?()=>e.default:()=>e;return i.d(t,{a:t}),t},i.t=function(e,t){if(1&t&&(e=this(e)),8&t)return e;if(4&t&&"object"==typeof e&&e&&e.__esModule)return e;var r=Object.create(null);i.r(r);var n={};if(2&t&&"object"==typeof e&&e)for(const t in e)n[t]=()=>e[t];return n.default=()=>e,i.d(r,n),r},i.d=(e,t)=>{for(var r in t)i.o(t,r)&&!i.o(e,r)&&Object.defineProperty(e,r,{enumerable:!0,get:t[r]})},i.f={},i.e=e=>Promise.all(Object.keys(i.f).reduce(((t,r)=>(i.f[r](e,t),t)),[])),i.u=e=>"chunk."+{76:"450f2b48ac02232f339e",113:"478928465ef39e460450",287:"d3b4db00e4908e0aaf25",305:"45022101f8bcf954c00d",319:"3765d06348bc31e8b1a0",362:"7f7996a1defec0b70fd4",434:"eeee1c3acd6f929f19ef",486:"f2488b56e14d31fbb3b6",586:"1b7c9ea03be65ce99806",664:"bbe3bf5855725ede9de0",681:"6de2bed84290c35695ea",753:"3c9c0bdd938b835e80a2",851:"630b27d91e277bc016f1",875:"a67ef00f1f55cc846c89",879:"ff6d79235b7730a51af8",947:"6b18c64ed740014d3f00",1002:"3cadd193879fad680e68",1041:"7235c3780b2a63a1d2ea",1102:"a3d504470bbbe0d52b01",1139:"360d3196cd26bdaff0a3",1146:"87e0adce91d44803b585",1203:"74407e76ea3e18e9e274",1206:"a5f9fbbbb54449ea5cea",1237:"b1611853f62c46fac7ce",1480:"38d3977ff7f099485538",1482:"bdca498b404e986cbf37",1527:"17e91532e58ae6fa4be6",1534:"9ee25bf64ac32af7e392",1593:"f88732ef1dd9710cb0be",1596:"98d514c7a505fef03629",1740:"af43f6ec356055cbfe65",1785:"2d96cbf7014526e88755",1790:"1c85ef2a16bf067728d5",1803:"85d7b8cf920c459dfe76",1838:"4c6704b99bd2cc64b4c4",1850:"a034672a15d74686d1d1",1860:"df3fff123aeffcb990c3",1878:"570560ffd17144b68aa8",1895:"280dd52ae8fd48b80df4",1927:"73e8ba24d10facdc59c5",1930:"bbeaaa77d7ec414384c1",1968:"06f6098f2a559d43d909",2105:"44d7cce272a6ac5c3ff9",2137:"f4796ca2d28eb9bc9172",2211:"e4c426c1c3566439af34",2247:"40361de984d24760c3c1",2296:"8b7c13d200037096d385",2335:"29e59c604db02dd75a5a",2374:"5243779d55b7814b3ccf",2382:"2d032a166ceed6fc83b9",2394:"d408c8d8f5bc55a705c5",2472:"447e45af4311b1f53ac9",2581:"e6181e962362c22e0505",2587:"e8d60cbaa6ecbb5d9029",2665:"ee526429134a2b50a878",2669:"8044df133f125ec77e35",2781:"eee7c47bdbb7411cc15b",2858:"3900ecc4e1ac1f50f585",2914:"6ce95f807b6994d28ccf",2955:"979e6fb0cc6da93148fb",2979:"d1450e44af848620832d",2982:"5650e5787d738686ad6a",2994:"fc74828c2386d4150996",3098:"ab18ddfd51f27de8403c",3177:"7e03346835c59cb395a9",3376:"aa792571d25c0793d82b",3397:"c9e8f752c6e16007b83b",3450:"ce0cd2126983f28ef2a3",3459:"420321d5c399ee1f1959",3472:"67b2ba81862cbcc5aeec",3525:"6a93a539907b60c3069a",3529:"1ce571ae046953d1ec86",3688:"f5ffa951699170c4df13",3822:"952d581f7a2cade5d4ea",3943:"7a523c71693a463d8eea",4018:"307823d4a42a86dba081",4026:"0b9fddcb222953babdb2",4036:"e1e4d2dfd8c00ed35978",4102:"f27a9329dc7a5d744a5f",4237:"b1b33d643c0f240e280b",4266:"45ff0ba0917ffec2acd2",4281:"0d5dc53c13211c70c05b",4325:"64da3012594cac26542e",4326:"7fe98b4d953fee5d28b8",4503:"d87b1f3ceb7d27b19999",4535:"a0ff1530dc36f9fbf49d",4567:"39f5c5bf31882f65d779",4570:"2f3926b5ed8e2c056fa1",4689:"c5f55dffc7b17ec75729",4728:"b470f8660e8764ccbbde",4782:"b9337f76c078ae8f5a44",4832:"b246f3774221060b424a",4909:"a0d0103e2e6bc12ee21e",4920:"b2ce5f75a4b1ce36f8c1",4940:"cd3c8d9e4dcedc8f4cf8",4971:"7db99564319cf22f42fa",5009:"bd51308493be1ac46c3c",5018:"1cf757f5aa141833bd30",5056:"953834dde854b4ec7a14",5083:"b6300942575dc8fec4b4",5170:"1a07b61795b407aa752c",5220:"7728b6789f318aaf47f4",5223:"3f06d72e4dfca7669f0a",5317:"9cfe97f1a252cd00b0ee",5325:"778fe3916ed9924ac169",5328:"16f567b0fb1e40492118",5338:"c2c7e537291e982f230d",5397:"5f191359847e4ee12aac",5469:"c2243fa0ac9f1afd8b7e",5513:"ed855d7f56419025b032",5632:"2381850446194085a2e7",5642:"60a597a60ca9535589d8",5649:"93d04041023ba52305e2",5675:"a8bf2850069817b20849",5773:"6fb57851506dc2a8b29b",5829:"69a2c99fe99493c9478e",5840:"cf6f7e8e83219f6f9a54",5906:"bd2ec40f82887add70b9",6016:"0f2a51b751178e9e5203",6085:"95d66c74cae7e6ffd795",6087:"85f377f22eba4f7ba43c",6133:"0ee8efb94ffd88c180ac",6169:"18ec46dd1b63fb84be5c",6227:"80977ab3b8d260aa80f7",6332:"cf86d3a3d7edb0f71ec1",6369:"57baafb725e98e9ad62a",6443:"b022e5655b92d42a32f8",6448:"733f4c1fe186fcbe9e4b",6467:"6123c8e9a8c646fa523f",6470:"568602ce84bccad16911",6474:"cc699cb4826454c8a6f7",6509:"af2c4ee707044fc61cd5",6532:"20765f5bf7dabe49a674",6576:"830a4657ebf05b57d5b1",6684:"ed661491f7fc5b0e948b",6719:"fcb56555f0793d37e4de",6755:"8b3b301bcdbacadbccf4",6758:"bb73f21f07ca4775f183",6778:"73e84af688eb835108de",6830:"ab5b51b468bcf4f21e94",6839:"3c42d509b0ad8fd5480c",6850:"cb9f1b6c3f8b692b2939",6902:"da9cde5e440140c70abc",6952:"1ce7147cff4c9d76d288",6955:"330334fb332d26da4194",7071:"96d76b94bbf4ba7020f3",7078:"9531d82c59d09a41597e",7130:"cc707b897e9e9616ac4e",7210:"1b33ca555d62e76fb06d",7253:"0ef8d927345fc3a67e6e",7282:"7f843aa4ec0660f02cd8",7284:"b081e0fc95c3999a76b5",7305:"f5fcf7cefb050a60a0b0",7321:"ac93c4858dec9fad56a8",7345:"200550f11bad99869b1d",7477:"c8efed6a4e987e1de0d6",7482:"46d188aefa1499458b72",7523:"af817b88af24be611cf4",7631:"a01fc49cb6fa229a7d98",7716:"384b10106a3b072d9e4e",7717:"723bf92ae3e2511e5f1c",7737:"fe7ca20326db68e00f39",7749:"e52e68c88f6d1ad74146",7761:"9f05425b20ffcd2f7808",7794:"fe1b9830e727ddc78047",7820:"e77d9bf649ffeaffe714",7839:"f6307486a304e6228d4f",7873:"9ffd3fdc3775f184da6c",7887:"5d30c6bd63d1ecefee17",7982:"584fc08e8cd688d49536",7987:"b3ecb458d5865406aa72",7992:"421312c92d7416138396",8045:"f3298162096dd3548bfa",8101:"869686ba5bed3577d527",8161:"eca4c4a68710363fdcdf",8200:"cda3af98b329b42a3a95",8251:"12fc8464dcbf8ffc3d80",8317:"d0b23bf8a93579733595",8331:"016fcec2d02732c1a798",8360:"6dd565de1dd2dfd0be8c",8374:"5587b72294eb8ed12316",8394:"6ee22619c757ca0f5202",8558:"9b7772274131fc9cde91",8559:"75d4107d30f012428474",8723:"1c0e6367423e105431ff",8800:"c6e048dc8664d9d0d8cd",8825:"a0144242b210ee0a59e6",8857:"a4ce373b02ad056eb798",8894:"c716075d7f974a3b35a7",8914:"0d7c07dcc58156ed3ac5",9001:"7091ec279a1a2d3cfdc3",9021:"c2e23282c08267cb97d8",9033:"f34f74e8c91989cb578a",9109:"5a3a69f55c68dd87d76c",9119:"75f7d290f82547b486aa",9123:"76e3c0cc57c38bc04ca7",9130:"bdacda0c9668d17bfcae",9146:"31b12554c80980b201c4",9160:"d9afc17c1272cd8180e6",9176:"10a16e4ddf47c2e020af",9188:"7c4eeb49f17e27106e50",9277:"c0731d37a4bd768a63b3",9374:"f6c8fe33789fb757345d",9448:"7f751d2379d613c0a331",9491:"5f9636f6b9446eb1b772",9543:"bea2f09f5a017af9749d",9626:"172ba27851835fa8aaaf",9631:"73978ab23c822df9d973",9669:"a2f5e7baa28dcdc80222",9680:"671cccf625c3b6fcb0ba",9759:"07c07175b104a9aa7203",9810:"267853423f8249fce92f",9902:"a304ee4177da88defe02"}[e]+".js",i.o=(e,t)=>Object.prototype.hasOwnProperty.call(e,t),e={},t="home-assistant-frontend:",i.l=(r,n,o)=>{if(e[r])e[r].push(n);else{var a,s;if(void 0!==o)for(var l=document.getElementsByTagName("script"),c=0;c<l.length;c++){var d=l[c];if(d.getAttribute("src")==r||d.getAttribute("data-webpack")==t+o){a=d;break}}a||(s=!0,(a=document.createElement("script")).charset="utf-8",a.timeout=120,i.nc&&a.setAttribute("nonce",i.nc),a.setAttribute("data-webpack",t+o),a.src=r),e[r]=[n];var u=(t,n)=>{a.onerror=a.onload=null,clearTimeout(p);var i=e[r];if(delete e[r],a.parentNode&&a.parentNode.removeChild(a),i&&i.forEach((e=>e(n))),t)return t(n)},p=setTimeout(u.bind(null,void 0,{type:"timeout",target:a}),12e4);a.onerror=u.bind(null,a.onerror),a.onload=u.bind(null,a.onload),s&&document.head.appendChild(a)}},i.r=e=>{"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})},i.nmd=e=>(e.paths=[],e.children||(e.children=[]),e),i.p="/frontend_latest/",(()=>{i.b=document.baseURI||self.location.href;var e={2343:0,8200:0,879:0,1900:0};i.f.j=(t,r)=>{var n=i.o(e,t)?e[t]:void 0;if(0!==n)if(n)r.push(n[2]);else{var o=new Promise(((r,i)=>{n=e[t]=[r,i]}));r.push(n[2]=o);var a=i.p+i.u(t),s=new Error;i.l(a,(r=>{if(i.o(e,t)&&(0!==(n=e[t])&&(e[t]=void 0),n)){var o=r&&("load"===r.type?"missing":r.type),a=r&&r.target&&r.target.src;s.message="Loading chunk "+t+" failed.\n("+o+": "+a+")",s.name="ChunkLoadError",s.type=o,s.request=a,n[1](s)}}),"chunk-"+t)}};var t=self.webpackChunkhome_assistant_frontend=self.webpackChunkhome_assistant_frontend||[],r=t.push.bind(t);t.push=t=>{for(var n,o,[a,s,l]=t,c=0,d=[];c<a.length;c++)o=a[c],i.o(e,o)&&e[o]&&d.push(e[o][0]),e[o]=0;for(n in s)i.o(s,n)&&(i.m[n]=s[n]);for(l&&l(i),r(t);d.length;)d.shift()()}})(),(()=>{"use strict";var e=i(36007);const t=!1;function r(r){if(!r.auth)throw 4;const n=r.auth;let i=n.expired?n.refreshAccessToken().then((()=>{i=void 0}),(()=>{i=void 0})):void 0;const o=n.wsUrl;function a(r,s,l){const c=new WebSocket(o);let d=!1;const u=()=>{if(c.removeEventListener("close",u),d)return void l(2);if(0===r)return void l(1);const e=-1===r?-1:r-1;setTimeout((()=>a(e,s,l)),1e3)},p=async t=>{try{n.expired&&await(i||n.refreshAccessToken()),c.send(JSON.stringify(e.I8(n.accessToken)))}catch(e){d=2===e,c.close()}},h=async e=>{const r=JSON.parse(e.data);switch(r.type){case"auth_invalid":d=!0,c.close();break;case"auth_ok":c.removeEventListener("open",p),c.removeEventListener("message",h),c.removeEventListener("close",u),c.removeEventListener("error",u),c.haVersion=r.ha_version,s(c);break;default:t}};c.addEventListener("open",p),c.addEventListener("message",h),c.addEventListener("close",u),c.addEventListener("error",u)}return new Promise(((e,t)=>a(r.setupRetry,e,t)))}const n=!1;class o{constructor(e,t){this.options=t,this.commandId=1,this.commands=new Map,this.eventListeners=new Map,this.closeRequested=!1,this.setSocket(e)}get haVersion(){return this.socket.haVersion}get connected(){return this.socket.readyState==this.socket.OPEN}setSocket(e){const t=this.socket;if(this.socket=e,e.addEventListener("message",(e=>this._handleMessage(e))),e.addEventListener("close",(e=>this._handleClose(e))),t){const e=this.commands;this.commandId=1,this.commands=new Map,e.forEach((e=>{"subscribe"in e&&e.subscribe().then((t=>{e.unsubscribe=t,e.resolve()}))}));const t=this._queuedMessages;if(t){this._queuedMessages=void 0;for(const e of t)e.resolve()}this.fireEvent("ready")}}addEventListener(e,t){let r=this.eventListeners.get(e);r||(r=[],this.eventListeners.set(e,r)),r.push(t)}removeEventListener(e,t){const r=this.eventListeners.get(e);if(!r)return;const n=r.indexOf(t);-1!==n&&r.splice(n,1)}fireEvent(e,t){(this.eventListeners.get(e)||[]).forEach((e=>e(this,t)))}suspendReconnectUntil(e){this.suspendReconnectPromise=e}suspend(){if(!this.suspendReconnectPromise)throw new Error("Suspend promise not set");this.socket.close()}close(){this.closeRequested=!0,this.socket.close()}async subscribeEvents(t,r){return this.subscribeMessage(t,e.a(r))}ping(){return this.sendMessagePromise(e.qE())}sendMessage(e,t){if(this._queuedMessages){if(t)throw new Error("Cannot queue with commandId");this._queuedMessages.push({resolve:()=>this.sendMessage(e)})}else t||(t=this._genCmdId()),e.id=t,this.socket.send(JSON.stringify(e))}sendMessagePromise(e){return new Promise(((t,r)=>{if(this._queuedMessages)return void this._queuedMessages.push({reject:r,resolve:async()=>{try{t(await this.sendMessagePromise(e))}catch(e){r(e)}}});const n=this._genCmdId();this.commands.set(n,{resolve:t,reject:r}),this.sendMessage(e,n)}))}async subscribeMessage(t,r){let n;return this._queuedMessages&&await new Promise(((e,t)=>{this._queuedMessages.push({resolve:e,reject:t})})),await new Promise(((i,o)=>{const a=this._genCmdId();n={resolve:i,reject:o,callback:t,subscribe:()=>this.subscribeMessage(t,r),unsubscribe:async()=>{this.connected&&await this.sendMessagePromise(e.Mt(a)),this.commands.delete(a)}},this.commands.set(a,n);try{this.sendMessage(r,a)}catch(e){}})),()=>n.unsubscribe()}_handleMessage(t){const r=JSON.parse(t.data);const i=this.commands.get(r.id);switch(r.type){case"event":i?i.callback(r.event):(console.warn(`Received event for unknown subscription ${r.id}. Unsubscribing.`),this.sendMessagePromise(e.Mt(r.id)));break;case"result":i&&(r.success?(i.resolve(r.result),"subscribe"in i||this.commands.delete(r.id)):(i.reject(r.error),this.commands.delete(r.id)));break;case"pong":i?(i.resolve(),this.commands.delete(r.id)):console.warn("Received unknown pong response "+r.id);break;default:n}}async _handleClose(t){if(this.commands.forEach((t=>{"subscribe"in t||t.reject(e.vU(3,"Connection lost"))})),this.closeRequested)return;this.fireEvent("disconnected");const r=Object.assign(Object.assign({},this.options),{setupRetry:0}),n=e=>{setTimeout((async()=>{try{const e=await r.createSocket(r);this.setSocket(e)}catch(t){if(this._queuedMessages){const e=this._queuedMessages;this._queuedMessages=void 0;for(const t of e)t.reject&&t.reject(3)}2===t?this.fireEvent("reconnect-error",t):n(e+1)}}),1e3*Math.min(e,5))};this.suspendReconnectPromise&&(await this.suspendReconnectPromise,this.suspendReconnectPromise=void 0,this._queuedMessages=[]),n(0)}_genCmdId(){return++this.commandId}}const a=()=>`${location.protocol}//${location.host}/`;function s(e,t,r,n){r+=(r.includes("?")?"&":"?")+"auth_callback=1",document.location.href=function(e,t,r,n){let i=`${e}/auth/authorize?response_type=code&redirect_uri=${encodeURIComponent(r)}`;return null!==t&&(i+="&client_id="+encodeURIComponent(t)),n&&(i+="&state="+encodeURIComponent(n)),i}(e,t,r,n)}async function l(e,t,r){const n="undefined"!=typeof location&&location;if(n&&"https:"===n.protocol){const t=document.createElement("a");if(t.href=e,"http:"===t.protocol&&"localhost"!==t.hostname)throw 5}const i=new FormData;null!==t&&i.append("client_id",t),Object.keys(r).forEach((e=>{i.append(e,r[e])}));const o=await fetch(e+"/auth/token",{method:"POST",credentials:"same-origin",body:i});if(!o.ok)throw 400===o.status||403===o.status?2:new Error("Unable to fetch tokens");const a=await o.json();return a.hassUrl=e,a.clientId=t,a.expires=1e3*a.expires_in+Date.now(),a}function c(e,t,r){return l(e,t,{code:r,grant_type:"authorization_code"})}class d{constructor(e,t){this.data=e,this._saveTokens=t}get wsUrl(){return`ws${this.data.hassUrl.substr(4)}/api/websocket`}get accessToken(){return this.data.access_token}get expired(){return Date.now()>this.data.expires}async refreshAccessToken(){if(!this.data.refresh_token)throw new Error("No refresh_token");const e=await l(this.data.hassUrl,this.data.clientId,{grant_type:"refresh_token",refresh_token:this.data.refresh_token});e.refresh_token=this.data.refresh_token,this.data=e,this._saveTokens&&this._saveTokens(e)}async revoke(){if(!this.data.refresh_token)throw new Error("No refresh_token to revoke");const e=new FormData;e.append("action","revoke"),e.append("token",this.data.refresh_token),await fetch(this.data.hassUrl+"/auth/token",{method:"POST",credentials:"same-origin",body:e}),this._saveTokens&&this._saveTokens(null)}}async function u(e={}){let t,r=e.hassUrl;r&&"/"===r[r.length-1]&&(r=r.substr(0,r.length-1));const n=void 0!==e.clientId?e.clientId:a();if(!t&&e.authCode&&r&&(t=await c(r,n,e.authCode),e.saveTokens&&e.saveTokens(t)),!t){const r=function(e){const t={},r=e.split("&");for(let e=0;e<r.length;e++){const n=r[e].split("="),i=decodeURIComponent(n[0]),o=n.length>1?decodeURIComponent(n[1]):void 0;t[i]=o}return t}(location.search.substr(1));if("auth_callback"in r){const n=(i=r.state,JSON.parse(atob(i)));t=await c(n.hassUrl,n.clientId,r.code),e.saveTokens&&e.saveTokens(t)}}var i,o;if(!t&&e.loadTokens&&(t=await e.loadTokens()),t)return new d(t,e.saveTokens);if(void 0===r)throw 4;return s(r,n,e.redirectUrl||function(){const{protocol:e,host:t,pathname:r,search:n}=location;return`${e}//${t}${r}${n}`}(),(o={hassUrl:r,clientId:n},btoa(JSON.stringify(o)))),new Promise((()=>{}))}var p=i(4915),h=i(15652);const f=async(e,t)=>new Promise((r=>{const n=t(e,(e=>{n(),r(e)}))}));var m=i(22814);var y=i(76307),g=i(95282),b=i(23553);const _=e=>(0,g._)(e,"_usr",(()=>(0,b.PR)(e)),void 0),v=(e,t)=>_(e).subscribe(t);var w=i(35359);const x=async(e,t)=>(await e.sendMessagePromise({type:"frontend/get_user_data",key:t})).value,k=async(e,t,r)=>e.sendMessagePromise({type:"frontend/set_user_data",key:t,value:r}),C=(e,t)=>((e,t,r,n,i)=>{const o=r+"-optimistic";return{...(0,g._)(t,r,n,(async(e,r)=>{const n=i?i(t,r):void 0;return t[o]=r,()=>{n&&n.then((e=>e())),t[o]=void 0}})),async save(r){const n=t[o];let i;n&&(i=n.state,n.setState(r,!0));try{return await e(t,r)}catch(e){throw n&&n.setState(i,!0),e}}}})(((r,n)=>k(e,t,n)),e,"_frontendUserData-"+t,(()=>x(e,t))),E=JSON.parse('{"fragments":["config","history","logbook","lovelace","mailbox","profile","shopping_list","page-authorize","page-demo","developer-tools","page-onboarding","custom"],"translations":{"af":{"nativeName":"Afrikaans","hash":"464bc29fec875eee110ed3bf1e40971e"},"ar":{"nativeName":"العربية","isRTL":true,"hash":"653b0eca83b44adfa5df9b54c8556e04"},"bg":{"nativeName":"Български","hash":"1c5a9d7bc91aa27411654b2ea14a666e"},"bn":{"nativeName":"বাংলা","hash":"8be7da1cf5ce5483770a864ced37967d"},"bs":{"nativeName":"Bosanski","hash":"da6504bd6a3c0fbeb8f509ab55a719d3"},"ca":{"nativeName":"Català","hash":"d216967055cf44d1cb622b49cba919cb"},"cs":{"nativeName":"Čeština","hash":"393e1c305b6e0d8a841164715e778341"},"cy":{"nativeName":"Cymraeg","hash":"890317953d7dfd7fa8e05f41995dde96"},"da":{"nativeName":"Dansk","hash":"657b23c1ed6784f03402259417fdd7b1"},"de":{"nativeName":"Deutsch","hash":"fcec9eb1bad365a3885f207c0f5ccbb3"},"el":{"nativeName":"Ελληνικά","hash":"41089143898ff98d7223b93ba2191eee"},"en":{"nativeName":"English","hash":"a3ca61a101b409f47eb9d9e2159b5be1"},"en-GB":{"nativeName":"English (GB)","hash":"a3ca61a101b409f47eb9d9e2159b5be1"},"eo":{"nativeName":"Esperanto","hash":"d779de1b6083a446a242bcd19fce2f7d"},"es":{"nativeName":"Español","hash":"73ac5ac5704db4be2fca55b96ece20b3"},"es-419":{"nativeName":"Español (Latin America)","hash":"19e4b0c7de0216508cfbc5b04f6ad972"},"et":{"nativeName":"Eesti","hash":"84771abb72bd864d5a93f5ca45c6f9d3"},"eu":{"nativeName":"Euskara","hash":"2d42caa6490b304326c8a41875ce9a63"},"fa":{"nativeName":"فارسی","isRTL":true,"hash":"a1cdec0bccee6be9ce1328430ee05d04"},"fi":{"nativeName":"Suomi","hash":"36f468cb3710f230b0a5e683571edd70"},"fy":{"nativeName":"Frysk","hash":"f3532ea2ab235c40687b50a0b235b9ab"},"fr":{"nativeName":"Français","hash":"4ffdd977fa0b256482645abd57953013"},"gl":{"nativeName":"Galego","hash":"a3ca61a101b409f47eb9d9e2159b5be1"},"gsw":{"nativeName":"Schwiizerdütsch","hash":"81c3441561d61c57f7029bd9ccf1c57c"},"he":{"nativeName":"עברית","isRTL":true,"hash":"8c43368da15cd3b68c07d902e71fb2d8"},"hi":{"nativeName":"हिन्दी","hash":"e1a57db2a0630ee449522f5eca5a1239"},"hr":{"nativeName":"Hrvatski","hash":"972ecf3cc3bb9bb7d1978ae1d542bc22"},"hu":{"nativeName":"Magyar","hash":"cd9bffe43f535dd69b7d02102589afb4"},"hy":{"nativeName":"Հայերեն","hash":"fb0568d45cdbc6fe7db1f1c8e15871f9"},"id":{"nativeName":"Indonesia","hash":"33cb0bbbf5a4146c74d7e02d935d4a54"},"it":{"nativeName":"Italiano","hash":"af6e3380f96f6e49f335b2f630d61749"},"is":{"nativeName":"Íslenska","hash":"b9e50b505a8515b40eb8fe93db263f84"},"ja":{"nativeName":"日本語","hash":"e926acb9c2b76e3b5de1a86463b468c2"},"ka":{"nativeName":"Kartuli","hash":"f5b1ad38241cd8652a4f6781601899c5"},"ko":{"nativeName":"한국어","hash":"28421c7061b9199900dded7ab599a658"},"lb":{"nativeName":"Lëtzebuergesch","hash":"c7bf24c51414c4268e3a5008773a5d61"},"lt":{"nativeName":"Lietuvių","hash":"172bf147c133d5b129e5eddd2cd3a5c7"},"lv":{"nativeName":"Latviešu","hash":"dd9898dfd24af61a0228b5dfb01274ff"},"nl":{"nativeName":"Nederlands","hash":"eeed3f8a570a8228ad38d638ede8be8b"},"nb":{"nativeName":"Norsk Bokmål","hash":"acb1619bf0da38affbec0383ed282711"},"nn":{"nativeName":"Norsk Nynorsk","hash":"c21167d0fdf82f8ccbee1561d7e60b8d"},"pl":{"nativeName":"Polski","hash":"6223d4e0a8a61d88c1a3851688dd6162"},"pt":{"nativeName":"Português","hash":"1679e089fa924e4e53fa4412ed82e0ce"},"pt-BR":{"nativeName":"Português (BR)","hash":"4f44632e82c4404807ab7307a58b315b"},"ro":{"nativeName":"Română","hash":"c3aa07d6e13d1eedd0eb2b1409847c55"},"ru":{"nativeName":"Русский","hash":"3a1d6d706e43f9c7e9fddd49e72d2714"},"sk":{"nativeName":"Slovenčina","hash":"9679040c745e0cdddd4ae23a340f6313"},"sl":{"nativeName":"Slovenščina","hash":"07d684d3a3042eeb4ca63abd30108f10"},"sr":{"nativeName":"Српски","hash":"c79c605b6e3f6488dc060e550419212f"},"sr-Latn":{"nativeName":"Srpski","hash":"dbba9df919f605f50ac507891c056895"},"sv":{"nativeName":"Svenska","hash":"5df3d99e95958f272a0b3926434fe188"},"ta":{"nativeName":"தமிழ்","hash":"3419e1676c4c19d015b92340fcff6044"},"te":{"nativeName":"తెలుగు","hash":"af274d7bb41c159fdc334ce14e14a1f7"},"th":{"nativeName":"ภาษาไทย","hash":"e392acd346d76041a93efbbadc70d0b8"},"tr":{"nativeName":"Türkçe","hash":"886f14f1674bf9fda072de40769d5d05"},"uk":{"nativeName":"Українська","hash":"bc0e594151036c967917591c5067fdd2"},"ur":{"nativeName":"اُردُو","hash":"3204233f4fdf1211743961699c866dbb"},"vi":{"nativeName":"Tiếng Việt","hash":"9cc94572d246901d14cb25d4f385409a"},"zh-Hans":{"nativeName":"简体中文","hash":"1c2750a39ddc76b9859095625754f9d0"},"zh-Hant":{"nativeName":"繁體中文","hash":"790b2192e55fe9a449d06454b35e94d8"},"test":{"nativeName":"Test","hash":"d2ac98ce5a268c50fd5d300a2cb0b9f3"},"en_GB":{"hash":"627d7cab98f79daa58894fac212bb172"}}}'),S=window.localStorage||{},P={"zh-cn":"zh-Hans","zh-sg":"zh-Hans","zh-my":"zh-Hans","zh-tw":"zh-Hant","zh-hk":"zh-Hant","zh-mo":"zh-Hant",zh:"zh-Hant"};function A(e){if(e in E.translations)return e;const t=e.toLowerCase();return t in P?P[t]:Object.keys(E.translations).find((e=>e.toLowerCase()===t))}async function T(e){const t=await(e=>x(e.connection,"language"))(e),r=t?t.language:null;if(r){const e=A(r);if(e)return e}return null}function O(){let e=null;if(S.selectedLanguage)try{const t=JSON.parse(S.selectedLanguage);if(t&&(e=A(t),e))return e}catch(e){}if(navigator.languages)for(const t of navigator.languages)if(e=A(t),e)return e;return e=A(navigator.language),e||(navigator.language&&navigator.language.includes("-")&&(e=A(navigator.language.split("-")[0]),e)?e:"en")}const N={};async function I(e,t){const r=E.translations[t];if(!r){if("en"!==t)return I(e,"en");throw new Error("Language en is not found in metadata")}const n=`${e?e+"/":""}${t}-${r.hash}.json`;return N[n]||(N[n]=async function(e){const t=await fetch("/static/translations/"+e,{credentials:"same-origin"});if(!t.ok)throw new Error(`Fail to fetch translation ${e}: HTTP response status is ${t.status}`);return t.json()}(n).then((e=>({language:t,data:e}))).catch((r=>(delete N[n],"en"!==t?I(e,"en"):Promise.reject(r))))),N[n]}function R(e,t,r,n){var i=D();if(n)for(var o=0;o<n.length;o++)i=n[o](i);var a=t((function(e){i.initializeInstanceElements(e,s.elements)}),r),s=i.decorateClass(function(e){for(var t=[],r=function(e){return"method"===e.kind&&e.key===o.key&&e.placement===o.placement},n=0;n<e.length;n++){var i,o=e[n];if("method"===o.kind&&(i=t.find(r)))if(M(o.descriptor)||M(i.descriptor)){if(L(o)||L(i))throw new ReferenceError("Duplicated methods ("+o.key+") can't be decorated.");i.descriptor=o.descriptor}else{if(L(o)){if(L(i))throw new ReferenceError("Decorators can't be placed on different accessors with for the same property ("+o.key+").");i.decorators=o.decorators}F(o,i)}else t.push(o)}return t}(a.d.map(z)),e);return i.initializeClassElements(a.F,s.elements),i.runClassFinishers(a.F,s.finishers)}function D(){D=function(){return e};var e={elementsDefinitionOrder:[["method"],["field"]],initializeInstanceElements:function(e,t){["method","field"].forEach((function(r){t.forEach((function(t){t.kind===r&&"own"===t.placement&&this.defineClassElement(e,t)}),this)}),this)},initializeClassElements:function(e,t){var r=e.prototype;["method","field"].forEach((function(n){t.forEach((function(t){var i=t.placement;if(t.kind===n&&("static"===i||"prototype"===i)){var o="static"===i?e:r;this.defineClassElement(o,t)}}),this)}),this)},defineClassElement:function(e,t){var r=t.descriptor;if("field"===t.kind){var n=t.initializer;r={enumerable:r.enumerable,writable:r.writable,configurable:r.configurable,value:void 0===n?void 0:n.call(e)}}Object.defineProperty(e,t.key,r)},decorateClass:function(e,t){var r=[],n=[],i={static:[],prototype:[],own:[]};if(e.forEach((function(e){this.addElementPlacement(e,i)}),this),e.forEach((function(e){if(!L(e))return r.push(e);var t=this.decorateElement(e,i);r.push(t.element),r.push.apply(r,t.extras),n.push.apply(n,t.finishers)}),this),!t)return{elements:r,finishers:n};var o=this.decorateConstructor(r,t);return n.push.apply(n,o.finishers),o.finishers=n,o},addElementPlacement:function(e,t,r){var n=t[e.placement];if(!r&&-1!==n.indexOf(e.key))throw new TypeError("Duplicated element ("+e.key+")");n.push(e.key)},decorateElement:function(e,t){for(var r=[],n=[],i=e.decorators,o=i.length-1;o>=0;o--){var a=t[e.placement];a.splice(a.indexOf(e.key),1);var s=this.fromElementDescriptor(e),l=this.toElementFinisherExtras((0,i[o])(s)||s);e=l.element,this.addElementPlacement(e,t),l.finisher&&n.push(l.finisher);var c=l.extras;if(c){for(var d=0;d<c.length;d++)this.addElementPlacement(c[d],t);r.push.apply(r,c)}}return{element:e,finishers:n,extras:r}},decorateConstructor:function(e,t){for(var r=[],n=t.length-1;n>=0;n--){var i=this.fromClassDescriptor(e),o=this.toClassDescriptor((0,t[n])(i)||i);if(void 0!==o.finisher&&r.push(o.finisher),void 0!==o.elements){e=o.elements;for(var a=0;a<e.length-1;a++)for(var s=a+1;s<e.length;s++)if(e[a].key===e[s].key&&e[a].placement===e[s].placement)throw new TypeError("Duplicated element ("+e[a].key+")")}}return{elements:e,finishers:r}},fromElementDescriptor:function(e){var t={kind:e.kind,key:e.key,placement:e.placement,descriptor:e.descriptor};return Object.defineProperty(t,Symbol.toStringTag,{value:"Descriptor",configurable:!0}),"field"===e.kind&&(t.initializer=e.initializer),t},toElementDescriptors:function(e){var t;if(void 0!==e)return(t=e,function(e){if(Array.isArray(e))return e}(t)||function(e){if("undefined"!=typeof Symbol&&Symbol.iterator in Object(e))return Array.from(e)}(t)||function(e,t){if(e){if("string"==typeof e)return B(e,t);var r=Object.prototype.toString.call(e).slice(8,-1);return"Object"===r&&e.constructor&&(r=e.constructor.name),"Map"===r||"Set"===r?Array.from(e):"Arguments"===r||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r)?B(e,t):void 0}}(t)||function(){throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()).map((function(e){var t=this.toElementDescriptor(e);return this.disallowProperty(e,"finisher","An element descriptor"),this.disallowProperty(e,"extras","An element descriptor"),t}),this)},toElementDescriptor:function(e){var t=String(e.kind);if("method"!==t&&"field"!==t)throw new TypeError('An element descriptor\'s .kind property must be either "method" or "field", but a decorator created an element descriptor with .kind "'+t+'"');var r=H(e.key),n=String(e.placement);if("static"!==n&&"prototype"!==n&&"own"!==n)throw new TypeError('An element descriptor\'s .placement property must be one of "static", "prototype" or "own", but a decorator created an element descriptor with .placement "'+n+'"');var i=e.descriptor;this.disallowProperty(e,"elements","An element descriptor");var o={kind:t,key:r,placement:n,descriptor:Object.assign({},i)};return"field"!==t?this.disallowProperty(e,"initializer","A method descriptor"):(this.disallowProperty(i,"get","The property descriptor of a field descriptor"),this.disallowProperty(i,"set","The property descriptor of a field descriptor"),this.disallowProperty(i,"value","The property descriptor of a field descriptor"),o.initializer=e.initializer),o},toElementFinisherExtras:function(e){return{element:this.toElementDescriptor(e),finisher:j(e,"finisher"),extras:this.toElementDescriptors(e.extras)}},fromClassDescriptor:function(e){var t={kind:"class",elements:e.map(this.fromElementDescriptor,this)};return Object.defineProperty(t,Symbol.toStringTag,{value:"Descriptor",configurable:!0}),t},toClassDescriptor:function(e){var t=String(e.kind);if("class"!==t)throw new TypeError('A class descriptor\'s .kind property must be "class", but a decorator created a class descriptor with .kind "'+t+'"');this.disallowProperty(e,"key","A class descriptor"),this.disallowProperty(e,"placement","A class descriptor"),this.disallowProperty(e,"descriptor","A class descriptor"),this.disallowProperty(e,"initializer","A class descriptor"),this.disallowProperty(e,"extras","A class descriptor");var r=j(e,"finisher");return{elements:this.toElementDescriptors(e.elements),finisher:r}},runClassFinishers:function(e,t){for(var r=0;r<t.length;r++){var n=(0,t[r])(e);if(void 0!==n){if("function"!=typeof n)throw new TypeError("Finishers must return a constructor.");e=n}}return e},disallowProperty:function(e,t,r){if(void 0!==e[t])throw new TypeError(r+" can't have a ."+t+" property.")}};return e}function z(e){var t,r=H(e.key);"method"===e.kind?t={value:e.value,writable:!0,configurable:!0,enumerable:!1}:"get"===e.kind?t={get:e.value,configurable:!0,enumerable:!1}:"set"===e.kind?t={set:e.value,configurable:!0,enumerable:!1}:"field"===e.kind&&(t={configurable:!0,writable:!0,enumerable:!0});var n={kind:"field"===e.kind?"field":"method",key:r,placement:e.static?"static":"field"===e.kind?"own":"prototype",descriptor:t};return e.decorators&&(n.decorators=e.decorators),"field"===e.kind&&(n.initializer=e.value),n}function F(e,t){void 0!==e.descriptor.get?t.descriptor.get=e.descriptor.get:t.descriptor.set=e.descriptor.set}function L(e){return e.decorators&&e.decorators.length}function M(e){return void 0!==e&&!(void 0===e.value&&void 0===e.writable)}function j(e,t){var r=e[t];if(void 0!==r&&"function"!=typeof r)throw new TypeError("Expected '"+t+"' to be a function");return r}function H(e){var t=function(e,t){if("object"!=typeof e||null===e)return e;var r=e[Symbol.toPrimitive];if(void 0!==r){var n=r.call(e,t||"default");if("object"!=typeof n)return n;throw new TypeError("@@toPrimitive must return a primitive value.")}return("string"===t?String:Number)(e)}(e,"string");return"symbol"==typeof t?t:String(t)}function B(e,t){(null==t||t>e.length)&&(t=e.length);for(var r=0,n=new Array(t);r<t;r++)n[r]=e[r];return n}function $(e,t,r){return($="undefined"!=typeof Reflect&&Reflect.get?Reflect.get:function(e,t,r){var n=function(e,t){for(;!Object.prototype.hasOwnProperty.call(e,t)&&null!==(e=V(e)););return e}(e,t);if(n){var i=Object.getOwnPropertyDescriptor(n,t);return i.get?i.get.call(r):i.value}})(e,t,r||e)}function V(e){return(V=Object.setPrototypeOf?Object.getPrototypeOf:function(e){return e.__proto__||Object.getPrototypeOf(e)})(e)}I(null,O());const U=()=>"";var q=i(66386);const K=["dockedSidebar","selectedTheme","selectedLanguage","vibrate","suspendWhenHidden","enableShortcuts","defaultPanel"],Y=window.localStorage||{};function J(e){try{K.forEach((t=>{const r=e[t];Y[t]=JSON.stringify(void 0===r?null:r)}))}catch(e){}}function W(){const e={};return K.forEach((t=>{if(t in Y){let r=JSON.parse(Y[t]);"selectedTheme"===t&&"string"==typeof r&&(r={theme:r}),"dockedSidebar"===t&&"boolean"==typeof r&&(r=r?"docked":"auto"),e[t]=r}})),e}const G=e=>class extends e{firstUpdated(e){super.firstUpdated(e),this.addEventListener("hass-logout",(()=>this._handleLogout())),this.addEventListener("hass-refresh-current-user",(()=>{_(this.hass.connection).refresh()}))}hassConnected(){super.hassConnected(),v(this.hass.connection,(e=>this._updateHass({user:e}))),(0,q.IO)()&&this.updateComplete.then((()=>i.e(1041).then(i.bind(i,41041)))).then((()=>{const e=document.createElement("ha-store-auth-card");this.shadowRoot.appendChild(e),this.provideHass(e)}))}async _handleLogout(){try{await this.hass.auth.revoke(),this.hass.connection.close(),Y.clear&&Y.clear(),document.location.href="/"}catch(e){console.error(e),alert("Log out failed")}}};async function X(e){const t=await(0,b.Pz)(e),r={};for(let e=0;e<t.length;e++){const n=t[e];r[n.entity_id]=n}return r}const Z=(e,t)=>e.subscribeEvents((e=>function(e,t){const r=e.state;if(void 0===r)return;const{entity_id:n,new_state:i}=t.data;if(i)e.setState({[i.entity_id]:i});else{const t=Object.assign({},r);delete t[n],e.setState(t,!0)}}(t,e)),"state_changed"),Q=(e,t)=>(e=>(0,g._)(e,"_ent",X,Z))(e).subscribe(t);function ee(e,t){if(void 0===e)return null;const{domain:r,service:n}=t.data;return{[r]:Object.assign({},e[r],{[n]:{description:"",fields:{}}})}}function te(e,t){if(void 0===e)return null;const{domain:r,service:n}=t.data,i=e[r];if(!i||!(n in i))return null;const o={};return Object.keys(i).forEach((e=>{e!==n&&(o[e]=i[e])})),{[r]:o}}const re=e=>(0,b.U2)(e),ne=(e,t)=>Promise.all([e.subscribeEvents(t.action(ee),"service_registered"),e.subscribeEvents(t.action(te),"service_removed")]).then((e=>()=>e.forEach((e=>e())))),ie=(e,t)=>(e=>(0,g._)(e,"_srv",re,ne))(e).subscribe(t);var oe=i(47181);const ae=e=>{(0,oe.B)(window,"connection-status",e)};var se=i(62359);const le="lovelace",ce=e=>e.sendMessagePromise({type:"get_panels"}),de=(e,t)=>e.subscribeEvents((()=>ce(e).then((e=>t.setState(e,!0)))),"panels_updated");var ue=i(30320),pe=i(53775);const he=e=>class extends e{initializeHass(e,t){this.hass={auth:e,connection:t,connected:!0,states:null,config:null,themes:null,panels:null,services:null,user:null,panelUrl:this._panelUrl,defaultPanel:le,language:O(),selectedLanguage:null,resources:null,localize:()=>"",translationMetadata:E,dockedSidebar:"docked",vibrate:!0,suspendWhenHidden:!0,enableShortcuts:!0,moreInfoEntityId:null,hassUrl:(t="")=>new URL(t,e.data.hassUrl).toString(),callService:async(e,r,n={})=>{try{return await(0,b._D)(t,e,r,n)}catch(t){0,(0,se.j)("failure");const n=this.hass.localize("ui.notification_toast.service_call_failed","service",`${e}/${r}`)+" "+t.message;throw(0,oe.B)(this,"hass-notification",{message:n}),t}},callApi:async(t,r,n,i)=>(0,pe.Z)(e,t,r,n,i),fetchWithAuth:(t,r)=>(0,ue.r)(e,`${e.data.hassUrl}${t}`,r),sendWS:e=>{t.sendMessage(e)},callWS:e=>{return t.sendMessagePromise(e)},loadBackendTranslation:(e,t,r)=>{var n;return this._loadHassTranslations(null===(n=this.hass)||void 0===n?void 0:n.language,e,t,r)},...W(),...this._pendingHass},this.hassConnected()}hassConnected(){super.hassConnected();const e=this.hass.connection;ae("connected"),e.addEventListener("ready",(()=>this.hassReconnected())),e.addEventListener("disconnected",(()=>this.hassDisconnected())),e.addEventListener("reconnect-error",((e,t)=>{2===t&&(ae("auth-invalid"),location.reload())})),Q(e,(e=>this._updateHass({states:e}))),(0,p.wQ)(e,(e=>this._updateHass({config:e}))),ie(e,(e=>this._updateHass({services:e}))),((e,t)=>{(0,g.B)("_pnl",ce,de,e,t)})(e,(e=>this._updateHass({panels:e}))),((e,t,r)=>{C(e,t).subscribe(r)})(e,"core",(e=>this._updateHass({userData:e})))}hassReconnected(){super.hassReconnected(),this._updateHass({connected:!0}),ae("connected"),this.hass.callWS({type:"get_config"}).then((e=>{this._updateHass({config:e})}))}hassDisconnected(){super.hassDisconnected(),this._updateHass({connected:!1}),ae("disconnected")}};var fe=i(74265);const me=e=>class extends e{firstUpdated(e){super.firstUpdated(e),this.addEventListener("register-dialog",(e=>this.registerDialog(e.detail))),(0,fe.lD)(this,this.shadowRoot)}registerDialog({dialogShowEvent:e,dialogTag:t,dialogImport:r}){this.addEventListener(e,(e=>{(0,fe.vC)(this,this.shadowRoot,t,e.detail,r)}))}};var ye=i(81796);const ge=e=>class extends e{firstUpdated(e){super.firstUpdated(e),Promise.all([i.e(5009),i.e(486)]).then(i.bind(i,35003))}updated(e){var t;super.updated(e);const r=e.get("hass");e.has("hass")&&this.hass.config&&(null==r||null===(t=r.config)||void 0===t?void 0:t.state)!==this.hass.config.state&&(this.hass.config.state===p.UE?(0,ye.C)(this,{message:this.hass.localize("ui.notification_toast.starting")||"Home Assistant is starting, not everything will be available until it is finished.",duration:0,dismissable:!1,action:{text:this.hass.localize("ui.notification_toast.dismiss")||"Dismiss",action:()=>{}}}):!(null==r?void 0:r.config)||r.config.state!==p.UE||this.hass.config.state!==p.dL&&this.hass.config.state!==p.u5||(0,ye.C)(this,{message:this.hass.localize("ui.notification_toast.started"),duration:5e3}))}hassReconnected(){super.hassReconnected(),(0,ye.C)(this,{message:"",duration:1})}hassDisconnected(){super.hassDisconnected(),(0,ye.C)(this,{message:this.hass.localize("ui.notification_toast.connection_lost"),duration:0,dismissable:!1})}},be={success:[50,50,50],warning:[100,50,100],failure:[200,100,200],light:[50],medium:[100],heavy:[200],selection:[20]},_e=e=>{navigator.vibrate(be[e.detail])},ve=e=>class extends e{firstUpdated(e){super.firstUpdated(e),this.addEventListener("hass-vibrate",(e=>{const t=e.detail.vibrate;navigator.vibrate&&t?window.addEventListener("haptic",_e):window.removeEventListener("haptic",_e),this._updateHass({vibrate:t}),J(this.hass)}))}hassConnected(){super.hassConnected(),navigator.vibrate&&this.hass.vibrate&&window.addEventListener("haptic",_e)}};function we(){we=function(){return e};var e={elementsDefinitionOrder:[["method"],["field"]],initializeInstanceElements:function(e,t){["method","field"].forEach((function(r){t.forEach((function(t){t.kind===r&&"own"===t.placement&&this.defineClassElement(e,t)}),this)}),this)},initializeClassElements:function(e,t){var r=e.prototype;["method","field"].forEach((function(n){t.forEach((function(t){var i=t.placement;if(t.kind===n&&("static"===i||"prototype"===i)){var o="static"===i?e:r;this.defineClassElement(o,t)}}),this)}),this)},defineClassElement:function(e,t){var r=t.descriptor;if("field"===t.kind){var n=t.initializer;r={enumerable:r.enumerable,writable:r.writable,configurable:r.configurable,value:void 0===n?void 0:n.call(e)}}Object.defineProperty(e,t.key,r)},decorateClass:function(e,t){var r=[],n=[],i={static:[],prototype:[],own:[]};if(e.forEach((function(e){this.addElementPlacement(e,i)}),this),e.forEach((function(e){if(!Ce(e))return r.push(e);var t=this.decorateElement(e,i);r.push(t.element),r.push.apply(r,t.extras),n.push.apply(n,t.finishers)}),this),!t)return{elements:r,finishers:n};var o=this.decorateConstructor(r,t);return n.push.apply(n,o.finishers),o.finishers=n,o},addElementPlacement:function(e,t,r){var n=t[e.placement];if(!r&&-1!==n.indexOf(e.key))throw new TypeError("Duplicated element ("+e.key+")");n.push(e.key)},decorateElement:function(e,t){for(var r=[],n=[],i=e.decorators,o=i.length-1;o>=0;o--){var a=t[e.placement];a.splice(a.indexOf(e.key),1);var s=this.fromElementDescriptor(e),l=this.toElementFinisherExtras((0,i[o])(s)||s);e=l.element,this.addElementPlacement(e,t),l.finisher&&n.push(l.finisher);var c=l.extras;if(c){for(var d=0;d<c.length;d++)this.addElementPlacement(c[d],t);r.push.apply(r,c)}}return{element:e,finishers:n,extras:r}},decorateConstructor:function(e,t){for(var r=[],n=t.length-1;n>=0;n--){var i=this.fromClassDescriptor(e),o=this.toClassDescriptor((0,t[n])(i)||i);if(void 0!==o.finisher&&r.push(o.finisher),void 0!==o.elements){e=o.elements;for(var a=0;a<e.length-1;a++)for(var s=a+1;s<e.length;s++)if(e[a].key===e[s].key&&e[a].placement===e[s].placement)throw new TypeError("Duplicated element ("+e[a].key+")")}}return{elements:e,finishers:r}},fromElementDescriptor:function(e){var t={kind:e.kind,key:e.key,placement:e.placement,descriptor:e.descriptor};return Object.defineProperty(t,Symbol.toStringTag,{value:"Descriptor",configurable:!0}),"field"===e.kind&&(t.initializer=e.initializer),t},toElementDescriptors:function(e){var t;if(void 0!==e)return(t=e,function(e){if(Array.isArray(e))return e}(t)||function(e){if("undefined"!=typeof Symbol&&Symbol.iterator in Object(e))return Array.from(e)}(t)||function(e,t){if(e){if("string"==typeof e)return Ae(e,t);var r=Object.prototype.toString.call(e).slice(8,-1);return"Object"===r&&e.constructor&&(r=e.constructor.name),"Map"===r||"Set"===r?Array.from(e):"Arguments"===r||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r)?Ae(e,t):void 0}}(t)||function(){throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()).map((function(e){var t=this.toElementDescriptor(e);return this.disallowProperty(e,"finisher","An element descriptor"),this.disallowProperty(e,"extras","An element descriptor"),t}),this)},toElementDescriptor:function(e){var t=String(e.kind);if("method"!==t&&"field"!==t)throw new TypeError('An element descriptor\'s .kind property must be either "method" or "field", but a decorator created an element descriptor with .kind "'+t+'"');var r=Pe(e.key),n=String(e.placement);if("static"!==n&&"prototype"!==n&&"own"!==n)throw new TypeError('An element descriptor\'s .placement property must be one of "static", "prototype" or "own", but a decorator created an element descriptor with .placement "'+n+'"');var i=e.descriptor;this.disallowProperty(e,"elements","An element descriptor");var o={kind:t,key:r,placement:n,descriptor:Object.assign({},i)};return"field"!==t?this.disallowProperty(e,"initializer","A method descriptor"):(this.disallowProperty(i,"get","The property descriptor of a field descriptor"),this.disallowProperty(i,"set","The property descriptor of a field descriptor"),this.disallowProperty(i,"value","The property descriptor of a field descriptor"),o.initializer=e.initializer),o},toElementFinisherExtras:function(e){return{element:this.toElementDescriptor(e),finisher:Se(e,"finisher"),extras:this.toElementDescriptors(e.extras)}},fromClassDescriptor:function(e){var t={kind:"class",elements:e.map(this.fromElementDescriptor,this)};return Object.defineProperty(t,Symbol.toStringTag,{value:"Descriptor",configurable:!0}),t},toClassDescriptor:function(e){var t=String(e.kind);if("class"!==t)throw new TypeError('A class descriptor\'s .kind property must be "class", but a decorator created a class descriptor with .kind "'+t+'"');this.disallowProperty(e,"key","A class descriptor"),this.disallowProperty(e,"placement","A class descriptor"),this.disallowProperty(e,"descriptor","A class descriptor"),this.disallowProperty(e,"initializer","A class descriptor"),this.disallowProperty(e,"extras","A class descriptor");var r=Se(e,"finisher");return{elements:this.toElementDescriptors(e.elements),finisher:r}},runClassFinishers:function(e,t){for(var r=0;r<t.length;r++){var n=(0,t[r])(e);if(void 0!==n){if("function"!=typeof n)throw new TypeError("Finishers must return a constructor.");e=n}}return e},disallowProperty:function(e,t,r){if(void 0!==e[t])throw new TypeError(r+" can't have a ."+t+" property.")}};return e}function xe(e){var t,r=Pe(e.key);"method"===e.kind?t={value:e.value,writable:!0,configurable:!0,enumerable:!1}:"get"===e.kind?t={get:e.value,configurable:!0,enumerable:!1}:"set"===e.kind?t={set:e.value,configurable:!0,enumerable:!1}:"field"===e.kind&&(t={configurable:!0,writable:!0,enumerable:!0});var n={kind:"field"===e.kind?"field":"method",key:r,placement:e.static?"static":"field"===e.kind?"own":"prototype",descriptor:t};return e.decorators&&(n.decorators=e.decorators),"field"===e.kind&&(n.initializer=e.value),n}function ke(e,t){void 0!==e.descriptor.get?t.descriptor.get=e.descriptor.get:t.descriptor.set=e.descriptor.set}function Ce(e){return e.decorators&&e.decorators.length}function Ee(e){return void 0!==e&&!(void 0===e.value&&void 0===e.writable)}function Se(e,t){var r=e[t];if(void 0!==r&&"function"!=typeof r)throw new TypeError("Expected '"+t+"' to be a function");return r}function Pe(e){var t=function(e,t){if("object"!=typeof e||null===e)return e;var r=e[Symbol.toPrimitive];if(void 0!==r){var n=r.call(e,t||"default");if("object"!=typeof n)return n;throw new TypeError("@@toPrimitive must return a primitive value.")}return("string"===t?String:Number)(e)}(e,"string");return"symbol"==typeof t?t:String(t)}function Ae(e,t){(null==t||t>e.length)&&(t=e.length);for(var r=0,n=new Array(t);r<t;r++)n[r]=e[r];return n}let Te=function(e,t,r,n){var i=we();if(n)for(var o=0;o<n.length;o++)i=n[o](i);var a=t((function(e){i.initializeInstanceElements(e,s.elements)}),r),s=i.decorateClass(function(e){for(var t=[],r=function(e){return"method"===e.kind&&e.key===o.key&&e.placement===o.placement},n=0;n<e.length;n++){var i,o=e[n];if("method"===o.kind&&(i=t.find(r)))if(Ee(o.descriptor)||Ee(i.descriptor)){if(Ce(o)||Ce(i))throw new ReferenceError("Duplicated methods ("+o.key+") can't be decorated.");i.descriptor=o.descriptor}else{if(Ce(o)){if(Ce(i))throw new ReferenceError("Decorators can't be placed on different accessors with for the same property ("+o.key+").");i.decorators=o.decorators}ke(o,i)}else t.push(o)}return t}(a.d.map(xe)),e);return i.initializeClassElements(a.F,s.elements),i.runClassFinishers(a.F,s.finishers)}(null,(function(e,t){return{F:class extends t{constructor(...t){super(...t),e(this)}},d:[{kind:"field",decorators:[(0,h.Cb)({attribute:!1})],key:"hass",value:void 0},{kind:"field",key:"_pendingHass",value:()=>({})},{kind:"field",key:"__provideHass",value:()=>[]},{kind:"method",key:"provideHass",value:function(e){this.__provideHass.push(e),e.hass=this.hass}},{kind:"method",key:"initializeHass",value:function(e,t){}},{kind:"method",key:"hassConnected",value:function(){}},{kind:"method",key:"hassReconnected",value:function(){}},{kind:"method",key:"hassDisconnected",value:function(){}},{kind:"method",key:"panelUrlChanged",value:function(e){}},{kind:"method",key:"hassChanged",value:function(e,t){this.__provideHass.forEach((t=>{t.hass=e}))}},{kind:"method",key:"_updateHass",value:function(e){this.hass?this.hass={...this.hass,...e}:this._pendingHass={...this._pendingHass,...e}}}]}}),h.oi);const Oe=e=>class extends e{firstUpdated(e){super.firstUpdated(e),this.addEventListener("write_log",(e=>{this._writeLog(e.detail)}))}_writeLog(e){var t;null===(t=this.hass)||void 0===t||t.callService("system_log","write",{logger:"frontend.js.latest."+"20210127.3".replace(".",""),message:e.message,level:e.level||"error"})}};let Ne;const Ie=()=>(Ne||(Ne=Promise.all([i.e(5009),i.e(8161),i.e(2955),i.e(8200),i.e(879),i.e(5906),i.e(9160),i.e(7982),i.e(5829),i.e(6133),i.e(7839),i.e(5469),i.e(1803),i.e(6443),i.e(4018),i.e(362),i.e(2581),i.e(6509),i.e(1927),i.e(4909),i.e(1146),i.e(319),i.e(7305),i.e(9669),i.e(7282),i.e(6470),i.e(9123),i.e(5056),i.e(1206),i.e(9810),i.e(2781),i.e(3397),i.e(753)]).then(i.bind(i,7001))),Ne),Re=e=>class extends e{firstUpdated(e){super.firstUpdated(e),this.addEventListener("hass-more-info",(e=>this._handleMoreInfo(e))),Ie()}async _handleMoreInfo(e){(0,fe.vC)(this,this.shadowRoot,"ha-more-info-dialog",{entityId:e.detail.entityId},Ie)}},De=e=>class extends e{firstUpdated(e){super.firstUpdated(e),this.registerDialog({dialogShowEvent:"hass-notification",dialogTag:"notification-manager",dialogImport:()=>Promise.all([i.e(5009),i.e(486)]).then(i.bind(i,35003))})}},ze=e=>class extends e{updated(e){if(super.updated(e),!e.has("hass")||!this.hass)return;const t=e.get("hass");var r;t&&t.panels===this.hass.panels&&t.panelUrl===this.hass.panelUrl&&t.localize===this.hass.localize||(r=(e=>{if(!e.panels)return;const t=Object.values(e.panels).find((t=>t.url_path===e.panelUrl));if(!t)return;const r=(e=>"lovelace"===e.url_path?"panel.states":"profile"===e.url_path?"panel.profile":"panel."+e.title)(t);return e.localize(r)||t.title||void 0})(this.hass),document.title=r?r+" - Home Assistant":"Home Assistant")}},Fe=e=>class extends e{firstUpdated(e){super.firstUpdated(e),this.addEventListener("hass-dock-sidebar",(e=>{this._updateHass({dockedSidebar:e.detail.dock}),J(this.hass)})),this.addEventListener("hass-default-panel",(e=>{this._updateHass({defaultPanel:e.detail.defaultPanel}),J(this.hass)}))}};var Le=i(27060);const Me=e=>e.sendMessagePromise({type:"frontend/get_themes"}),je=(e,t)=>e.subscribeEvents((()=>Me(e).then((e=>t.setState(e,!0)))),"themes_updated"),He=matchMedia("(prefers-color-scheme: dark)"),Be=e=>class extends e{firstUpdated(e){super.firstUpdated(e),this.addEventListener("settheme",(e=>{this._updateHass({selectedTheme:{...this.hass.selectedTheme,...e.detail}}),this._applyTheme(He.matches),J(this.hass)})),He.addListener((e=>this._applyTheme(e.matches)))}hassConnected(){var e,t;super.hassConnected(),e=this.hass.connection,t=e=>{this._updateHass({themes:e}),(0,Le.p)(),this._applyTheme(He.matches)},(0,g.B)("_thm",Me,je,e,t)}_applyTheme(e){var t,r,n;if(!this.hass)return;const i=(null===(t=this.hass.selectedTheme)||void 0===t?void 0:t.theme)||(e&&this.hass.themes.default_dark_theme?this.hass.themes.default_dark_theme:this.hass.themes.default_theme);let o=this.hass.selectedTheme;"default"===i&&void 0===(null===(r=o)||void 0===r?void 0:r.dark)&&(o={...this.hass.selectedTheme,dark:e}),(0,Le.R)(document.documentElement,this.hass.themes,i,o);const a="default"===i?!!(null===(n=o)||void 0===n?void 0:n.dark):!(!e||!this.hass.themes.default_dark_theme);if(a!==this.hass.themes.darkMode){this._updateHass({themes:{...this.hass.themes,darkMode:a}});const e=document.querySelector("meta[name=color-scheme]");e&&e.setAttribute("content",a?"dark":"default"===i?"light":"dark light")}const s=document.querySelector("meta[name=theme-color]"),l=getComputedStyle(document.documentElement),c=l.getPropertyValue("--app-header-background-color");if(document.documentElement.style.backgroundColor=l.getPropertyValue("--primary-background-color"),s){s.hasAttribute("default-content")||s.setAttribute("default-content",s.getAttribute("content"));const e=(null==c?void 0:c.trim())||s.getAttribute("default-content");s.setAttribute("content",e)}}};var $e=i(87744),Ve=i(38346);function Ue(e,t,r){return t in e?Object.defineProperty(e,t,{value:r,enumerable:!0,configurable:!0,writable:!0}):e[t]=r,e}const qe=e=>class extends e{constructor(...e){super(...e),Ue(this,"__coreProgress",void 0),Ue(this,"__loadedFragmetTranslations",new Set),Ue(this,"__loadedTranslations",{})}firstUpdated(e){super.firstUpdated(e),this.addEventListener("hass-language-select",(e=>this._selectLanguage(e.detail.language,!0))),this._loadCoreTranslations(O())}hassConnected(){super.hassConnected(),T(this.hass).then((e=>{e&&this.hass.language!==e&&this._selectLanguage(e,!1)})),this.hass.connection.subscribeEvents((0,Ve.D)((()=>{this._refetchCachedHassTranslations(!1,!1)}),500),"component_loaded"),this._applyTranslations(this.hass)}hassReconnected(){super.hassReconnected(),this._refetchCachedHassTranslations(!0,!1),this._applyTranslations(this.hass)}panelUrlChanged(e){super.panelUrlChanged(e),this._loadFragmentTranslations(this.hass?this.hass.language:O(),e)}_selectLanguage(e,t){var r,n;this.hass&&(this._updateHass({language:e,selectedLanguage:e}),J(this.hass),t&&(r=this.hass,n={language:e},k(r.connection,"language",n)),this._applyTranslations(this.hass),this._refetchCachedHassTranslations(!0,!0))}_applyTranslations(e){document.querySelector("html").setAttribute("lang",e.language),this.style.direction=(0,$e.HE)(e)?"rtl":"ltr",this._loadCoreTranslations(e.language),this.__loadedFragmetTranslations=new Set,this._loadFragmentTranslations(e.language,e.panelUrl)}async _loadHassTranslations(e,t,r,n,i=!1){let o;if(o=t in this.__loadedTranslations?this.__loadedTranslations[t]:this.__loadedTranslations[t]={integrations:[],setup:!1,configFlow:!1},!i)if(r){if(o.integrations.includes(r))return this.hass.localize}else if(n?o.configFlow:o.setup)return this.hass.localize;r?o.integrations.includes(r)||o.integrations.push(r):(o.setup=!0,n&&(o.configFlow=!0));const a=await(async(e,t,r,n,i)=>(await e.callWS({type:"frontend/get_translations",language:t,category:r,integration:n,config_flow:i})).resources)(this.hass,e,t,r,n);return this.hass.language!==e||await this._updateResources(e,a),this.hass.localize}async _loadFragmentTranslations(e,t){var r,n,i;if(!t)return;const o=null===(r=this.hass)||void 0===r||null===(n=r.panels)||void 0===n||null===(i=n[t])||void 0===i?void 0:i.component_name,a=E.fragments.includes(o||t)?o||t:o?void 0:"lovelace";if(!a)return;if(this.__loadedFragmetTranslations.has(a))return;this.__loadedFragmetTranslations.add(a);const s=await I(a,e);this._updateResources(s.language,s.data)}async _loadCoreTranslations(e){if(this.__coreProgress!==e){this.__coreProgress=e;try{const t=await I(null,e);await this._updateResources(t.language,t.data)}finally{this.__coreProgress=void 0}}}async _updateResources(e,t){var r,n,i,o,a;if(await new Promise((e=>setTimeout(e,0))),e!==(null!==(r=this.hass)&&void 0!==r?r:this._pendingHass).language)return;const s={[e]:{...null===(n=null!==(o=this.hass)&&void 0!==o?o:this._pendingHass)||void 0===n||null===(i=n.resources)||void 0===i?void 0:i[e],...t}},l={resources:s,localize:await(0,w.X)(this,e,s)};e===(null!==(a=this.hass)&&void 0!==a?a:this._pendingHass).language&&this._updateHass(l)}_refetchCachedHassTranslations(e,t){for(const[r,n]of Object.entries(this.__loadedTranslations))t&&(n.integrations=[]),n.setup&&this._loadHassTranslations(this.hass.language,r,void 0,e&&n.configFlow,!0)}};function Ke(e,t,r){return t in e?Object.defineProperty(e,t,{value:r,enumerable:!0,configurable:!0,writable:!0}):e[t]=r,e}const Ye=e=>class extends e{constructor(...e){super(...e),Ke(this,"_ignoreNextPopState",!1),Ke(this,"_dialogClosedListener",(e=>{var t,r;(null===(t=history.state)||void 0===t?void 0:t.open)&&(null===(r=history.state)||void 0===r?void 0:r.dialog)===e.detail.dialog&&(this._ignoreNextPopState=!0,history.back())})),Ke(this,"_popstateChangeListener",(e=>{var t,r;if(this._ignoreNextPopState)return(null===(t=e.state)||void 0===t||null===(r=t.oldState)||void 0===r?void 0:r.replaced)?void history.back():void(this._ignoreNextPopState=!1);e.state&&"dialog"in e.state&&this._handleDialogStateChange(e.state)}))}connectedCallback(){super.connectedCallback(),window.addEventListener("popstate",this._popstateChangeListener),this.addEventListener("dialog-closed",this._dialogClosedListener)}disconnectedCallback(){super.disconnectedCallback(),window.removeEventListener("popstate",this._popstateChangeListener),this.removeEventListener("dialog-closed",this._dialogClosedListener)}async _handleDialogStateChange(e){if(!e.open){return await(0,fe.gk)(e.dialog)?void(e.oldState&&this._handleDialogStateChange(e.oldState)):void history.pushState({dialog:e.dialog,open:!0,dialogParams:null,oldState:null},"")}null!==e.dialogParams&&(0,fe.vC)(this,this.shadowRoot,e.dialog,e.dialogParams)}};class Je extends(((e,t)=>t.reduceRight(((e,t)=>t(e)),e))(Te,[G,Be,qe,Re,Fe,ge,he,De,me,Ye,ve,ze,Oe])){}const We=async(e,t=!0)=>{if(!("serviceWorker"in navigator)||"https:"!==location.protocol&&"localhost"!==location.hostname)return;navigator.serviceWorker.addEventListener("controllerchange",(()=>{location.reload()}));const r=await navigator.serviceWorker.register("/service_worker.js");t&&r.addEventListener("updatefound",(()=>{const t=r.installing;t&&t.addEventListener("statechange",(()=>{"installed"===t.state&&navigator.serviceWorker.controller&&(0,ye.C)(e,{message:"A new version of the frontend is available.",action:{action:()=>t.postMessage({type:"skipWaiting"}),text:"reload"},duration:0,dismissable:!1})}))}))};i(53918),i(30879);function Ge(){Ge=function(){return e};var e={elementsDefinitionOrder:[["method"],["field"]],initializeInstanceElements:function(e,t){["method","field"].forEach((function(r){t.forEach((function(t){t.kind===r&&"own"===t.placement&&this.defineClassElement(e,t)}),this)}),this)},initializeClassElements:function(e,t){var r=e.prototype;["method","field"].forEach((function(n){t.forEach((function(t){var i=t.placement;if(t.kind===n&&("static"===i||"prototype"===i)){var o="static"===i?e:r;this.defineClassElement(o,t)}}),this)}),this)},defineClassElement:function(e,t){var r=t.descriptor;if("field"===t.kind){var n=t.initializer;r={enumerable:r.enumerable,writable:r.writable,configurable:r.configurable,value:void 0===n?void 0:n.call(e)}}Object.defineProperty(e,t.key,r)},decorateClass:function(e,t){var r=[],n=[],i={static:[],prototype:[],own:[]};if(e.forEach((function(e){this.addElementPlacement(e,i)}),this),e.forEach((function(e){if(!Qe(e))return r.push(e);var t=this.decorateElement(e,i);r.push(t.element),r.push.apply(r,t.extras),n.push.apply(n,t.finishers)}),this),!t)return{elements:r,finishers:n};var o=this.decorateConstructor(r,t);return n.push.apply(n,o.finishers),o.finishers=n,o},addElementPlacement:function(e,t,r){var n=t[e.placement];if(!r&&-1!==n.indexOf(e.key))throw new TypeError("Duplicated element ("+e.key+")");n.push(e.key)},decorateElement:function(e,t){for(var r=[],n=[],i=e.decorators,o=i.length-1;o>=0;o--){var a=t[e.placement];a.splice(a.indexOf(e.key),1);var s=this.fromElementDescriptor(e),l=this.toElementFinisherExtras((0,i[o])(s)||s);e=l.element,this.addElementPlacement(e,t),l.finisher&&n.push(l.finisher);var c=l.extras;if(c){for(var d=0;d<c.length;d++)this.addElementPlacement(c[d],t);r.push.apply(r,c)}}return{element:e,finishers:n,extras:r}},decorateConstructor:function(e,t){for(var r=[],n=t.length-1;n>=0;n--){var i=this.fromClassDescriptor(e),o=this.toClassDescriptor((0,t[n])(i)||i);if(void 0!==o.finisher&&r.push(o.finisher),void 0!==o.elements){e=o.elements;for(var a=0;a<e.length-1;a++)for(var s=a+1;s<e.length;s++)if(e[a].key===e[s].key&&e[a].placement===e[s].placement)throw new TypeError("Duplicated element ("+e[a].key+")")}}return{elements:e,finishers:r}},fromElementDescriptor:function(e){var t={kind:e.kind,key:e.key,placement:e.placement,descriptor:e.descriptor};return Object.defineProperty(t,Symbol.toStringTag,{value:"Descriptor",configurable:!0}),"field"===e.kind&&(t.initializer=e.initializer),t},toElementDescriptors:function(e){var t;if(void 0!==e)return(t=e,function(e){if(Array.isArray(e))return e}(t)||function(e){if("undefined"!=typeof Symbol&&Symbol.iterator in Object(e))return Array.from(e)}(t)||function(e,t){if(e){if("string"==typeof e)return nt(e,t);var r=Object.prototype.toString.call(e).slice(8,-1);return"Object"===r&&e.constructor&&(r=e.constructor.name),"Map"===r||"Set"===r?Array.from(e):"Arguments"===r||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r)?nt(e,t):void 0}}(t)||function(){throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()).map((function(e){var t=this.toElementDescriptor(e);return this.disallowProperty(e,"finisher","An element descriptor"),this.disallowProperty(e,"extras","An element descriptor"),t}),this)},toElementDescriptor:function(e){var t=String(e.kind);if("method"!==t&&"field"!==t)throw new TypeError('An element descriptor\'s .kind property must be either "method" or "field", but a decorator created an element descriptor with .kind "'+t+'"');var r=rt(e.key),n=String(e.placement);if("static"!==n&&"prototype"!==n&&"own"!==n)throw new TypeError('An element descriptor\'s .placement property must be one of "static", "prototype" or "own", but a decorator created an element descriptor with .placement "'+n+'"');var i=e.descriptor;this.disallowProperty(e,"elements","An element descriptor");var o={kind:t,key:r,placement:n,descriptor:Object.assign({},i)};return"field"!==t?this.disallowProperty(e,"initializer","A method descriptor"):(this.disallowProperty(i,"get","The property descriptor of a field descriptor"),this.disallowProperty(i,"set","The property descriptor of a field descriptor"),this.disallowProperty(i,"value","The property descriptor of a field descriptor"),o.initializer=e.initializer),o},toElementFinisherExtras:function(e){return{element:this.toElementDescriptor(e),finisher:tt(e,"finisher"),extras:this.toElementDescriptors(e.extras)}},fromClassDescriptor:function(e){var t={kind:"class",elements:e.map(this.fromElementDescriptor,this)};return Object.defineProperty(t,Symbol.toStringTag,{value:"Descriptor",configurable:!0}),t},toClassDescriptor:function(e){var t=String(e.kind);if("class"!==t)throw new TypeError('A class descriptor\'s .kind property must be "class", but a decorator created a class descriptor with .kind "'+t+'"');this.disallowProperty(e,"key","A class descriptor"),this.disallowProperty(e,"placement","A class descriptor"),this.disallowProperty(e,"descriptor","A class descriptor"),this.disallowProperty(e,"initializer","A class descriptor"),this.disallowProperty(e,"extras","A class descriptor");var r=tt(e,"finisher");return{elements:this.toElementDescriptors(e.elements),finisher:r}},runClassFinishers:function(e,t){for(var r=0;r<t.length;r++){var n=(0,t[r])(e);if(void 0!==n){if("function"!=typeof n)throw new TypeError("Finishers must return a constructor.");e=n}}return e},disallowProperty:function(e,t,r){if(void 0!==e[t])throw new TypeError(r+" can't have a ."+t+" property.")}};return e}function Xe(e){var t,r=rt(e.key);"method"===e.kind?t={value:e.value,writable:!0,configurable:!0,enumerable:!1}:"get"===e.kind?t={get:e.value,configurable:!0,enumerable:!1}:"set"===e.kind?t={set:e.value,configurable:!0,enumerable:!1}:"field"===e.kind&&(t={configurable:!0,writable:!0,enumerable:!0});var n={kind:"field"===e.kind?"field":"method",key:r,placement:e.static?"static":"field"===e.kind?"own":"prototype",descriptor:t};return e.decorators&&(n.decorators=e.decorators),"field"===e.kind&&(n.initializer=e.value),n}function Ze(e,t){void 0!==e.descriptor.get?t.descriptor.get=e.descriptor.get:t.descriptor.set=e.descriptor.set}function Qe(e){return e.decorators&&e.decorators.length}function et(e){return void 0!==e&&!(void 0===e.value&&void 0===e.writable)}function tt(e,t){var r=e[t];if(void 0!==r&&"function"!=typeof r)throw new TypeError("Expected '"+t+"' to be a function");return r}function rt(e){var t=function(e,t){if("object"!=typeof e||null===e)return e;var r=e[Symbol.toPrimitive];if(void 0!==r){var n=r.call(e,t||"default");if("object"!=typeof n)return n;throw new TypeError("@@toPrimitive must return a primitive value.")}return("string"===t?String:Number)(e)}(e,"string");return"symbol"==typeof t?t:String(t)}function nt(e,t){(null==t||t>e.length)&&(t=e.length);for(var r=0,n=new Array(t);r<t;r++)n[r]=e[r];return n}function it(e,t,r){return(it="undefined"!=typeof Reflect&&Reflect.get?Reflect.get:function(e,t,r){var n=function(e,t){for(;!Object.prototype.hasOwnProperty.call(e,t)&&null!==(e=ot(e)););return e}(e,t);if(n){var i=Object.getOwnPropertyDescriptor(n,t);return i.get?i.get.call(r):i.value}})(e,t,r||e)}function ot(e){return(ot=Object.setPrototypeOf?Object.getPrototypeOf:function(e){return e.__proto__||Object.getPrototypeOf(e)})(e)}!function(e,t,r,n){var i=Ge();if(n)for(var o=0;o<n.length;o++)i=n[o](i);var a=t((function(e){i.initializeInstanceElements(e,s.elements)}),r),s=i.decorateClass(function(e){for(var t=[],r=function(e){return"method"===e.kind&&e.key===o.key&&e.placement===o.placement},n=0;n<e.length;n++){var i,o=e[n];if("method"===o.kind&&(i=t.find(r)))if(et(o.descriptor)||et(i.descriptor)){if(Qe(o)||Qe(i))throw new ReferenceError("Duplicated methods ("+o.key+") can't be decorated.");i.descriptor=o.descriptor}else{if(Qe(o)){if(Qe(i))throw new ReferenceError("Decorators can't be placed on different accessors with for the same property ("+o.key+").");i.decorators=o.decorators}Ze(o,i)}else t.push(o)}return t}(a.d.map(Xe)),e);i.initializeClassElements(a.F,s.elements),i.runClassFinishers(a.F,s.finishers)}([(0,h.Mo)("onboarding-create-user")],(function(e,t){class r extends t{constructor(...t){super(...t),e(this)}}return{F:r,d:[{kind:"field",decorators:[(0,h.Cb)()],key:"localize",value:void 0},{kind:"field",decorators:[(0,h.Cb)()],key:"language",value:void 0},{kind:"field",decorators:[(0,h.sz)()],key:"_name",value:()=>""},{kind:"field",decorators:[(0,h.sz)()],key:"_username",value:()=>""},{kind:"field",decorators:[(0,h.sz)()],key:"_password",value:()=>""},{kind:"field",decorators:[(0,h.sz)()],key:"_passwordConfirm",value:()=>""},{kind:"field",decorators:[(0,h.sz)()],key:"_loading",value:()=>!1},{kind:"field",decorators:[(0,h.sz)()],key:"_errorMsg",value(){}},{kind:"method",key:"render",value:function(){return h.dy`
    <p>
      ${this.localize("ui.panel.page-onboarding.intro")}
    </p>

    <p>
      ${this.localize("ui.panel.page-onboarding.user.intro")}
    </p>

    ${this._errorMsg?h.dy`
            <p class="error">
              ${this.localize("ui.panel.page-onboarding.user.error."+this._errorMsg)||this._errorMsg}
            </p>
          `:""}

    <form>
      <paper-input
        name="name"
        label="${this.localize("ui.panel.page-onboarding.user.data.name")}"
        .value=${this._name}
        @value-changed=${this._handleValueChanged}
        required
        auto-validate
        autocapitalize='on'
        .errorMessage="${this.localize("ui.panel.page-onboarding.user.required_field")}"
        @blur=${this._maybePopulateUsername}
      ></paper-input>

      <paper-input
        name="username"
        label="${this.localize("ui.panel.page-onboarding.user.data.username")}"
        value=${this._username}
        @value-changed=${this._handleValueChanged}
        required
        auto-validate
        autocapitalize='none'
        .errorMessage="${this.localize("ui.panel.page-onboarding.user.required_field")}"
      ></paper-input>

      <paper-input
        name="password"
        label="${this.localize("ui.panel.page-onboarding.user.data.password")}"
        value=${this._password}
        @value-changed=${this._handleValueChanged}
        required
        type='password'
        auto-validate
        .errorMessage="${this.localize("ui.panel.page-onboarding.user.required_field")}"
      ></paper-input>

      <paper-input
        name="passwordConfirm"
        label="${this.localize("ui.panel.page-onboarding.user.data.password_confirm")}"
        value=${this._passwordConfirm}
        @value-changed=${this._handleValueChanged}
        required
        type='password'
        .invalid=${""!==this._password&&""!==this._passwordConfirm&&this._passwordConfirm!==this._password}
        .errorMessage="${this.localize("ui.panel.page-onboarding.user.error.password_not_match")}"
      ></paper-input>

      <p class="action">
        <mwc-button
          raised
          @click=${this._submitForm}
          .disabled=${this._loading}
        >
          ${this.localize("ui.panel.page-onboarding.user.create_account")}
        </mwc-button>
      </p>
    </div>
  </form>
`}},{kind:"method",key:"firstUpdated",value:function(e){it(ot(r.prototype),"firstUpdated",this).call(this,e),setTimeout((()=>this.shadowRoot.querySelector("paper-input").focus()),100),this.addEventListener("keypress",(e=>{13===e.keyCode&&this._submitForm(e)}))}},{kind:"method",key:"_handleValueChanged",value:function(e){this["_"+e.target.name]=e.detail.value}},{kind:"method",key:"_maybePopulateUsername",value:function(){if(this._username)return;const e=this._name.split(" ");e.length&&(this._username=e[0].toLowerCase())}},{kind:"method",key:"_submitForm",value:async function(e){if(e.preventDefault(),this._name&&this._username&&this._password)if(this._password===this._passwordConfirm){this._loading=!0,this._errorMsg="";try{const e=a(),t=await(0,y.k1)({client_id:e,name:this._name,username:this._username,password:this._password,language:this.language});(0,oe.B)(this,"onboarding-step",{type:"user",result:t})}catch(e){console.error(e),this._loading=!1,this._errorMsg=e.body.message}}else this._errorMsg="password_not_match";else this._errorMsg="required_fields"}},{kind:"get",static:!0,key:"styles",value:function(){return h.iv`
      .error {
        color: red;
      }

      .action {
        margin: 32px 0;
        text-align: center;
      }
    `}}]}}),h.oi);i(38544);function at(){at=function(){return e};var e={elementsDefinitionOrder:[["method"],["field"]],initializeInstanceElements:function(e,t){["method","field"].forEach((function(r){t.forEach((function(t){t.kind===r&&"own"===t.placement&&this.defineClassElement(e,t)}),this)}),this)},initializeClassElements:function(e,t){var r=e.prototype;["method","field"].forEach((function(n){t.forEach((function(t){var i=t.placement;if(t.kind===n&&("static"===i||"prototype"===i)){var o="static"===i?e:r;this.defineClassElement(o,t)}}),this)}),this)},defineClassElement:function(e,t){var r=t.descriptor;if("field"===t.kind){var n=t.initializer;r={enumerable:r.enumerable,writable:r.writable,configurable:r.configurable,value:void 0===n?void 0:n.call(e)}}Object.defineProperty(e,t.key,r)},decorateClass:function(e,t){var r=[],n=[],i={static:[],prototype:[],own:[]};if(e.forEach((function(e){this.addElementPlacement(e,i)}),this),e.forEach((function(e){if(!ct(e))return r.push(e);var t=this.decorateElement(e,i);r.push(t.element),r.push.apply(r,t.extras),n.push.apply(n,t.finishers)}),this),!t)return{elements:r,finishers:n};var o=this.decorateConstructor(r,t);return n.push.apply(n,o.finishers),o.finishers=n,o},addElementPlacement:function(e,t,r){var n=t[e.placement];if(!r&&-1!==n.indexOf(e.key))throw new TypeError("Duplicated element ("+e.key+")");n.push(e.key)},decorateElement:function(e,t){for(var r=[],n=[],i=e.decorators,o=i.length-1;o>=0;o--){var a=t[e.placement];a.splice(a.indexOf(e.key),1);var s=this.fromElementDescriptor(e),l=this.toElementFinisherExtras((0,i[o])(s)||s);e=l.element,this.addElementPlacement(e,t),l.finisher&&n.push(l.finisher);var c=l.extras;if(c){for(var d=0;d<c.length;d++)this.addElementPlacement(c[d],t);r.push.apply(r,c)}}return{element:e,finishers:n,extras:r}},decorateConstructor:function(e,t){for(var r=[],n=t.length-1;n>=0;n--){var i=this.fromClassDescriptor(e),o=this.toClassDescriptor((0,t[n])(i)||i);if(void 0!==o.finisher&&r.push(o.finisher),void 0!==o.elements){e=o.elements;for(var a=0;a<e.length-1;a++)for(var s=a+1;s<e.length;s++)if(e[a].key===e[s].key&&e[a].placement===e[s].placement)throw new TypeError("Duplicated element ("+e[a].key+")")}}return{elements:e,finishers:r}},fromElementDescriptor:function(e){var t={kind:e.kind,key:e.key,placement:e.placement,descriptor:e.descriptor};return Object.defineProperty(t,Symbol.toStringTag,{value:"Descriptor",configurable:!0}),"field"===e.kind&&(t.initializer=e.initializer),t},toElementDescriptors:function(e){var t;if(void 0!==e)return(t=e,function(e){if(Array.isArray(e))return e}(t)||function(e){if("undefined"!=typeof Symbol&&Symbol.iterator in Object(e))return Array.from(e)}(t)||function(e,t){if(e){if("string"==typeof e)return ht(e,t);var r=Object.prototype.toString.call(e).slice(8,-1);return"Object"===r&&e.constructor&&(r=e.constructor.name),"Map"===r||"Set"===r?Array.from(e):"Arguments"===r||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r)?ht(e,t):void 0}}(t)||function(){throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()).map((function(e){var t=this.toElementDescriptor(e);return this.disallowProperty(e,"finisher","An element descriptor"),this.disallowProperty(e,"extras","An element descriptor"),t}),this)},toElementDescriptor:function(e){var t=String(e.kind);if("method"!==t&&"field"!==t)throw new TypeError('An element descriptor\'s .kind property must be either "method" or "field", but a decorator created an element descriptor with .kind "'+t+'"');var r=pt(e.key),n=String(e.placement);if("static"!==n&&"prototype"!==n&&"own"!==n)throw new TypeError('An element descriptor\'s .placement property must be one of "static", "prototype" or "own", but a decorator created an element descriptor with .placement "'+n+'"');var i=e.descriptor;this.disallowProperty(e,"elements","An element descriptor");var o={kind:t,key:r,placement:n,descriptor:Object.assign({},i)};return"field"!==t?this.disallowProperty(e,"initializer","A method descriptor"):(this.disallowProperty(i,"get","The property descriptor of a field descriptor"),this.disallowProperty(i,"set","The property descriptor of a field descriptor"),this.disallowProperty(i,"value","The property descriptor of a field descriptor"),o.initializer=e.initializer),o},toElementFinisherExtras:function(e){return{element:this.toElementDescriptor(e),finisher:ut(e,"finisher"),extras:this.toElementDescriptors(e.extras)}},fromClassDescriptor:function(e){var t={kind:"class",elements:e.map(this.fromElementDescriptor,this)};return Object.defineProperty(t,Symbol.toStringTag,{value:"Descriptor",configurable:!0}),t},toClassDescriptor:function(e){var t=String(e.kind);if("class"!==t)throw new TypeError('A class descriptor\'s .kind property must be "class", but a decorator created a class descriptor with .kind "'+t+'"');this.disallowProperty(e,"key","A class descriptor"),this.disallowProperty(e,"placement","A class descriptor"),this.disallowProperty(e,"descriptor","A class descriptor"),this.disallowProperty(e,"initializer","A class descriptor"),this.disallowProperty(e,"extras","A class descriptor");var r=ut(e,"finisher");return{elements:this.toElementDescriptors(e.elements),finisher:r}},runClassFinishers:function(e,t){for(var r=0;r<t.length;r++){var n=(0,t[r])(e);if(void 0!==n){if("function"!=typeof n)throw new TypeError("Finishers must return a constructor.");e=n}}return e},disallowProperty:function(e,t,r){if(void 0!==e[t])throw new TypeError(r+" can't have a ."+t+" property.")}};return e}function st(e){var t,r=pt(e.key);"method"===e.kind?t={value:e.value,writable:!0,configurable:!0,enumerable:!1}:"get"===e.kind?t={get:e.value,configurable:!0,enumerable:!1}:"set"===e.kind?t={set:e.value,configurable:!0,enumerable:!1}:"field"===e.kind&&(t={configurable:!0,writable:!0,enumerable:!0});var n={kind:"field"===e.kind?"field":"method",key:r,placement:e.static?"static":"field"===e.kind?"own":"prototype",descriptor:t};return e.decorators&&(n.decorators=e.decorators),"field"===e.kind&&(n.initializer=e.value),n}function lt(e,t){void 0!==e.descriptor.get?t.descriptor.get=e.descriptor.get:t.descriptor.set=e.descriptor.set}function ct(e){return e.decorators&&e.decorators.length}function dt(e){return void 0!==e&&!(void 0===e.value&&void 0===e.writable)}function ut(e,t){var r=e[t];if(void 0!==r&&"function"!=typeof r)throw new TypeError("Expected '"+t+"' to be a function");return r}function pt(e){var t=function(e,t){if("object"!=typeof e||null===e)return e;var r=e[Symbol.toPrimitive];if(void 0!==r){var n=r.call(e,t||"default");if("object"!=typeof n)return n;throw new TypeError("@@toPrimitive must return a primitive value.")}return("string"===t?String:Number)(e)}(e,"string");return"symbol"==typeof t?t:String(t)}function ht(e,t){(null==t||t>e.length)&&(t=e.length);for(var r=0,n=new Array(t);r<t;r++)n[r]=e[r];return n}function ft(e,t,r){return(ft="undefined"!=typeof Reflect&&Reflect.get?Reflect.get:function(e,t,r){var n=function(e,t){for(;!Object.prototype.hasOwnProperty.call(e,t)&&null!==(e=mt(e)););return e}(e,t);if(n){var i=Object.getOwnPropertyDescriptor(n,t);return i.get?i.get.call(r):i.value}})(e,t,r||e)}function mt(e){return(mt=Object.setPrototypeOf?Object.getPrototypeOf:function(e){return e.__proto__||Object.getPrototypeOf(e)})(e)}!function(e,t,r,n){var i=at();if(n)for(var o=0;o<n.length;o++)i=n[o](i);var a=t((function(e){i.initializeInstanceElements(e,s.elements)}),r),s=i.decorateClass(function(e){for(var t=[],r=function(e){return"method"===e.kind&&e.key===o.key&&e.placement===o.placement},n=0;n<e.length;n++){var i,o=e[n];if("method"===o.kind&&(i=t.find(r)))if(dt(o.descriptor)||dt(i.descriptor)){if(ct(o)||ct(i))throw new ReferenceError("Duplicated methods ("+o.key+") can't be decorated.");i.descriptor=o.descriptor}else{if(ct(o)){if(ct(i))throw new ReferenceError("Decorators can't be placed on different accessors with for the same property ("+o.key+").");i.decorators=o.decorators}lt(o,i)}else t.push(o)}return t}(a.d.map(st)),e);i.initializeClassElements(a.F,s.elements),i.runClassFinishers(a.F,s.finishers)}([(0,h.Mo)("ha-onboarding")],(function(e,t){class n extends t{constructor(...t){super(...t),e(this)}}return{F:n,d:[{kind:"field",decorators:[(0,h.Cb)({attribute:!1})],key:"hass",value:void 0},{kind:"field",key:"translationFragment",value:()=>"page-onboarding"},{kind:"field",decorators:[(0,h.sz)()],key:"_loading",value:()=>!1},{kind:"field",decorators:[(0,h.sz)()],key:"_restoring",value:()=>!1},{kind:"field",decorators:[(0,h.sz)()],key:"_supervisor",value:void 0},{kind:"field",decorators:[(0,h.sz)()],key:"_steps",value:void 0},{kind:"method",key:"render",value:function(){const e=this._curStep();return this._loading||!e?h.dy` <onboarding-loading></onboarding-loading> `:"user"===e.step?h.dy`
        ${this._restoring?"":h.dy`<onboarding-create-user
              .localize=${this.localize}
              .language=${this.language}
            >
            </onboarding-create-user>`}
        ${this._supervisor?h.dy`<onboarding-restore-snapshot
              .localize=${this.localize}
              .restoring=${this._restoring}
              @restoring=${this._restoringSnapshot}
            >
            </onboarding-restore-snapshot>`:""}
      `:"core_config"===e.step?h.dy`
        <onboarding-core-config
          .hass=${this.hass}
          .onboardingLocalize=${this.localize}
        ></onboarding-core-config>
      `:"integration"===e.step?h.dy`
        <onboarding-integrations
          .hass=${this.hass}
          .onboardingLocalize=${this.localize}
        ></onboarding-integrations>
      `:h.dy``}},{kind:"method",key:"firstUpdated",value:function(e){ft(mt(n.prototype),"firstUpdated",this).call(this,e),this._fetchOnboardingSteps(),this._fetchDiscoveryInformation(),Promise.all([i.e(6509),i.e(9176)]).then(i.bind(i,74561)),Promise.all([i.e(8161),i.e(1895),i.e(1482),i.e(6448)]).then(i.bind(i,58404)),We(this,!1),this.addEventListener("onboarding-step",(e=>this._handleStepDone(e)))}},{kind:"method",key:"updated",value:function(e){ft(mt(n.prototype),"updated",this).call(this,e),e.has("language")&&document.querySelector("html").setAttribute("lang",this.language),e.has("hass")&&this.hassChanged(this.hass,e.get("hass"))}},{kind:"method",key:"_curStep",value:function(){return this._steps?this._steps.find((e=>!e.done)):void 0}},{kind:"method",key:"_restoringSnapshot",value:function(){this._restoring=!0}},{kind:"method",key:"_fetchDiscoveryInformation",value:async function(){try{const e=await(async()=>{const e=await fetch("/api/discovery_info",{method:"GET"});return await e.json()})();this._supervisor=["Home Assistant OS","Home Assistant Supervised"].includes(e.installation_type),this._supervisor&&Promise.all([i.e(4018),i.e(2247),i.e(1206),i.e(8894)]).then(i.bind(i,88894))}catch(e){console.error("Something went wrong loading onboarding-restore-snapshot",e)}}},{kind:"method",key:"_fetchOnboardingSteps",value:async function(){try{const e=await(window.stepsPromise||(0,y.pM)());if(404===e.status)return void document.location.assign("/");const t=await e.json();if(t.every((e=>e.done)))return void document.location.assign("/");if(t[0].done){const e=await u({hassUrl:m.uw});history.replaceState(null,"",location.pathname),await this._connectHass(e)}this._steps=t}catch(e){alert("Something went wrong loading onboarding, try refreshing")}}},{kind:"method",key:"_handleStepDone",value:async function(e){const t=e.detail;if(this._steps=this._steps.map((e=>e.step===t.type?{...e,done:!0}:e)),"user"===t.type){const e=t.result;this._loading=!0;try{const t=await u({hassUrl:m.uw,authCode:e.auth_code});await this._connectHass(t)}catch(e){alert("Ah snap, something went wrong!"),location.reload()}finally{this._loading=!1}}else if("core_config"===t.type);else if("integration"===t.type){this._loading=!0;const e=(()=>{const e={},t=new URLSearchParams(location.search);for(const[r,n]of t.entries())e[r]=n;return e})(),t=e.client_id&&e.redirect_uri?e:{client_id:a(),redirect_uri:`${location.protocol}//${location.host}/?auth_callback=1`,state:btoa(JSON.stringify({hassUrl:`${location.protocol}//${location.host}`,clientId:a()}))};let r;try{r=await(0,y.ec)(this.hass,{client_id:t.client_id,redirect_uri:t.redirect_uri})}catch(e){return this.hass.connection.close(),await this.hass.auth.revoke(),alert("Unable to finish onboarding: "+e.message),void document.location.assign("/?")}this.hass.connection.close(),await this.hass.auth.revoke();let n=t.redirect_uri;n+=(n.includes("?")?"&":"?")+"code="+encodeURIComponent(r.auth_code),t.state&&(n+="&state="+encodeURIComponent(t.state)),document.location.assign(n)}}},{kind:"method",key:"_connectHass",value:async function(e){const t=await async function(e){const t=Object.assign({setupRetry:0,createSocket:r},e),n=await t.createSocket(t);return new o(n,t)}({auth:e});await Promise.all([f(t,p.wQ),f(t,v)]),this.initializeHass(e,t),this._loadFragmentTranslations(this.hass.language,"config"),await new Promise((e=>setTimeout(e,0)))}}]}}),R(null,(function(e,t){class r extends t{constructor(...t){super(...t),e(this)}}return{F:r,d:[{kind:"field",decorators:[(0,h.Cb)()],key:"localize",value:()=>U},{kind:"field",decorators:[(0,h.Cb)()],key:"resources",value:void 0},{kind:"field",decorators:[(0,h.Cb)()],key:"language",value:()=>O()},{kind:"field",decorators:[(0,h.Cb)()],key:"translationFragment",value:void 0},{kind:"method",key:"connectedCallback",value:function(){$(V(r.prototype),"connectedCallback",this).call(this),this._initializeLocalizeLite()}},{kind:"method",key:"updated",value:function(e){$(V(r.prototype),"updated",this).call(this,e),e.get("translationFragment")&&this._initializeLocalizeLite(),this.language&&this.resources&&(e.has("language")||e.has("resources"))&&(0,w.X)(this.constructor.prototype,this.language,this.resources).then((e=>{this.localize=e}))}},{kind:"method",key:"_initializeLocalizeLite",value:async function(){if(this.resources)return;if(!this.translationFragment)return;const{language:e,data:t}=await I(this.translationFragment,this.language);this.resources={[e]:t}}}]}}),Je));i(65660),i(54242),i(70019),i(5618);var yt=i(11654);const gt=document.createElement("template");gt.setAttribute("style","display: none;"),gt.innerHTML=`<custom-style>\n  <style>\n    /*\n      Home Assistant default styles.\n\n      In Polymer 2.0, default styles should to be set on the html selector.\n      (Setting all default styles only on body breaks shadyCSS polyfill.)\n      See: https://github.com/home-assistant/home-assistant-polymer/pull/901\n    */\n    html {\n      font-size: 14px;\n      height: 100vh;\n\n      /* text */\n      --primary-text-color: #212121;\n      --secondary-text-color: #727272;\n      --text-primary-color: #ffffff;\n      --text-light-primary-color: #212121;\n      --disabled-text-color: #bdbdbd;\n\n      /* main interface colors */\n      --primary-color: #03a9f4;\n      --dark-primary-color: #0288d1;\n      --light-primary-color: #b3e5fC;\n      --accent-color: #ff9800;\n      --divider-color: rgba(0, 0, 0, .12);\n\n      --scrollbar-thumb-color: rgb(194, 194, 194);\n\n      --error-color: #db4437;\n      --warning-color: #FF9800;\n      --success-color: #0f9d58;\n      --info-color: #4285f4;\n\n      /* states and badges */\n      --state-icon-color: #44739e;\n      --state-icon-active-color: #FDD835;\n\n      /* background and sidebar */\n      --card-background-color: #ffffff;\n      --primary-background-color: #fafafa;\n      --secondary-background-color: #e5e5e5; /* behind the cards on state */\n\n      /* for header */\n      --header-height: 56px;\n\n      /* for label-badge */\n      --label-badge-red: #DF4C1E;\n      --label-badge-blue: #039be5;\n      --label-badge-green: #0DA035;\n      --label-badge-yellow: #f4b400;\n\n      /*\n        Paper-styles color.html dependency is stripped on build.\n        When a default paper-style color is used, it needs to be copied\n        from paper-styles/color.html to here.\n      */\n\n      --paper-grey-50: #fafafa; /* default for: --mwc-switch-unchecked-button-color */\n      --paper-grey-200: #eeeeee;  /* for ha-date-picker-style */\n      --paper-grey-500: #9e9e9e;  /* --label-badge-grey */\n\n      /* for paper-slider */\n      --paper-green-400: #66bb6a;\n      --paper-blue-400: #42a5f5;\n      --paper-orange-400: #ffa726;\n\n      /* opacity for dark text on a light background */\n      --dark-divider-opacity: 0.12;\n      --dark-disabled-opacity: 0.38; /* or hint text or icon */\n      --dark-secondary-opacity: 0.54;\n      --dark-primary-opacity: 0.87;\n\n      /* opacity for light text on a dark background */\n      --light-divider-opacity: 0.12;\n      --light-disabled-opacity: 0.3; /* or hint text or icon */\n      --light-secondary-opacity: 0.7;\n      --light-primary-opacity: 1.0;\n\n      /* set our slider style */\n      --ha-slider-pin-font-size: 15px;\n\n      /* rgb */\n      --rgb-primary-color: 3, 169, 244;\n      --rgb-accent-color: 255, 152, 0;\n      --rgb-primary-text-color: 33, 33, 33;\n      --rgb-secondary-text-color: 114, 114, 114;\n      --rgb-text-primary-color: 255, 255, 255;\n      --rgb-card-background-color: 255, 255, 255;\n\n      ${Object.entries(yt.q0).map((([e,t])=>`--${e}: ${t};`)).join("")}\n    }\n\n    /*\n      prevent clipping of positioned elements in a small scrollable\n      force smooth scrolling if can scroll\n      use non-shady selectors so this only targets iOS 9\n      conditional mixin set in ha-style-dialog does not work with shadyCSS\n    */\n    paper-dialog-scrollable:not(.can-scroll) > .scrollable {\n      -webkit-overflow-scrolling: auto !important;\n    }\n\n    paper-dialog-scrollable.can-scroll > .scrollable {\n      -webkit-overflow-scrolling: touch !important;\n    }\n\n    /* for paper-dialog */\n    iron-overlay-backdrop {\n      backdrop-filter: var(--dialog-backdrop-filter, none);\n    }\n  </style>\n</custom-style>`,document.head.appendChild(gt.content);i(64702),i(37846)})()})();
//# sourceMappingURL=onboarding.4e62ac17.js.map